package com.unis.common.utils;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.unis.common.utils.jwt.JwtConstant;
import com.unis.common.utils.jwt.JwtUtil;

import java.io.Serializable;
import java.util.List;
import java.util.concurrent.TimeUnit;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.unis.common.utils.vo.UserDTO;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

@Component
public class SessionUtil
{
    private final String MID_AT = "@";
    private final String PRE_REDIS_KEY_USERINF = "userinfo@";

    @Autowired
    private RedisUtil<Serializable> redisUtil;

    public void setUserInfo(UserDTO userDTO)
    {
        String redisKey = "userinfo@" + userDTO.getUserCode();
        String redisValue = JSONObject.toJSONString(userDTO);
        this.redisUtil.setStr(redisKey, redisValue);
    }

    public UserDTO getUserInfo()
    {
        UserDTO userDTO = null;

        String token = getToken();

        if (StringUtils.isNotEmpty(token)) {
            String userId = JwtUtil.getUserId(token);
            String redisKey = "userinfo@" + userId;

            String userInfo = this.redisUtil.getStr(redisKey);
            userDTO = (UserDTO)JSON.parseObject(userInfo, UserDTO.class);
        }

        return userDTO;
    }

    public String createToken(UserDTO userDTO)
    {
        String token = JwtUtil.createJWT(JwtConstant.JWT_ID, userDTO.getUserCode(), userDTO.getUserLoginName(), "auth", "", 86400000L);

        return token;
    }

    public String getToken() {
        HttpServletRequest request = getRequest();
        String token = request.getHeader(JwtConstant.TOKEN);

        return token;
    }

    public void setTokenExpiration(String token)
    {
        this.redisUtil.setForTime(JwtUtil.getJwtId(token), token, JwtUtil.CREAT_TIME.longValue() + 43200000L, TimeUnit.DAYS);
    }

    public void removeToken()
    {
        String token = getToken();
        if (StringUtils.isNotEmpty(token))
            this.redisUtil.delete(JwtUtil.getJwtId(token));
    }

    public void removeUserInfo()
    {
        String token = getToken();
        if (StringUtils.isNotEmpty(token)) {
            String userId = JwtUtil.getUserId(token);
            String redisKey = "userinfo@" + userId;
            this.redisUtil.delete(redisKey);
        }
    }

    public void removeUserRights() {
        String token = getToken();
        if (StringUtils.isNotEmpty(token)) {
            String userId = JwtUtil.getUserId(token);
            String redisKey = "user_rights@" + userId;
            this.redisUtil.delete(redisKey);
            redisKey = "admin_rights@" + userId;
            this.redisUtil.delete(redisKey);
        }
    }

    public String getUserId()
    {
        return getUserInfo().getUserCode();
    }

    public String getAccount()
    {
        return getUserInfo() == null ? null : getUserInfo().getUserLoginName();
    }

    public String getUserName()
    {
        return getUserInfo().getUserName();
    }

    public String getOrgId()
    {
        return getUserInfo().getOrgCode();
    }

    public String getOrgName()
    {
        return getUserInfo().getOrgName();
    }

    public String getDeptId()
    {
        return getUserInfo().getDeptCode();
    }

    public String getDeptName()
    {
        return getUserInfo().getDeptName();
    }

    public String getAreaCode()
    {
        return getUserInfo().getCountyCode();
    }

    public String getPassWord()
    {
        return getUserInfo().getUserPassword();
    }

    public List<String> getUserRole()
    {
        return getUserInfo().getUserRole();
    }

    public String getUserType()
    {
        return getUserInfo().getUserType();
    }

    public static HttpServletRequest getRequest()
    {
        ServletRequestAttributes attributes = (ServletRequestAttributes)RequestContextHolder.getRequestAttributes();
        HttpServletRequest request = attributes.getRequest();
        return request;
    }

    public static HttpServletResponse getResponse()
    {
        return ((ServletRequestAttributes)RequestContextHolder.getRequestAttributes()).getResponse();
    }
}

