/*
* RoleShowVO.java
* 版权所有 © 2011-2017 北京神舟良实信息技术有限公司
* Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
* 2020-07-06 17:12:10 created by lipenghe with LAPTOP-IJQ2SDFV
*/
package com.unis.user.common.vo.role;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.unis.common.vo.groups.InsertGroup;
import com.unis.common.vo.groups.UpdateGroup;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import org.hibernate.validator.constraints.Length;
import org.springframework.format.annotation.DateTimeFormat;

import javax.persistence.Column;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.validation.constraints.NotBlank;
import java.io.Serializable;
import java.util.Date;

/**
 * SYS_ROLE_INFO-角色
 * @author lipenghe at 2020-07-06 17:12:10
 */
@ApiModel(value = "SYS_ROLE_INFO:角色-RoleShowVO")
@Data
@Table(name="SYS_ROLE_INFO")
public class RoleShowVO implements Serializable{

    @NotBlank(message = "角色编号不能为空",groups ={UpdateGroup.class})
    @Length(max=255,message="角色编号最大为255字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "角色编号#<主键><唯一><非空>R+0000001", notes ="角色编号", example = "角色编号#<主键><唯一><非空>R+0000001")
    @Id
    @Column(name="ROLE_CODE",length=255)
    private String roleCode;

    @ApiModelProperty(value = "创建时间", notes ="创建时间", example = "2019-10-01", hidden = true)
    @Column(name="CREATE_DATE")
    @DateTimeFormat( pattern = "yyyy-MM-dd")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "PRC")
    private Date createDate;

    @Length(max=255,message="创建人最大为255字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "创建人", notes ="创建人", example = "创建人", hidden = true)
    @Column(name="CREATOR", length=255)
    private String creator;

    @ApiModelProperty(value = "无字段注释 ", notes ="无字段注释 ", example = "0", hidden = true)
    @Column(name="STATE_CODE", length=10, precision=10, scale=0)
    private Long stateCode;

    @ApiModelProperty(value = "无字段注释 ", notes ="无字段注释 ", example = "0", hidden = true)
    @Column(name="VERSION", length=10, precision=10, scale=0)
    private Long version;

    @Length(max=255,message="角色简介最大为255字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "角色简介", notes ="角色简介", example = "角色简介", hidden = true)
    @Column(name="BREIF", length=255)
    private String breif;

    @ApiModelProperty(value = "排序", notes ="排序", example = "0", hidden = true)
    @Column(name="ORDER_BY", length=10, precision=10, scale=0)
    private Long orderBy;

    @Length(max=255,message="角色名称最大为255字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "角色名称", notes ="角色名称", example = "角色名称", hidden = true)
    @Column(name="ROLE_NAME", length=255)
    private String roleName;

    @Length(max=255,message="角色类型最大为255字符",groups ={UpdateGroup.class, InsertGroup.class})
    @ApiModelProperty(value = "角色类型#10280001：菜单资源角色；10280002：数据资源角色；10280003：其他资源角色", notes ="角色类型", example = "角色类型#10280001：菜单资源角色；10280002：数据资源角色；10280003：其他资源角色", hidden = true)
    @Column(name="ROLE_TYPE", length=255)
    private String roleType;

    public RoleShowVO(){
        super();
    }
}