package com.unis.user.server.common.beforeconfig;

import lombok.extern.slf4j.Slf4j;
import org.aspectj.lang.JoinPoint;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.*;
import org.springframework.stereotype.Component;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;
import org.springframework.web.context.request.NativeWebRequest;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import javax.servlet.http.HttpServletRequest;
import java.util.Arrays;
import java.util.Enumeration;
import java.util.Map;

/**
 * 拦截器
 */
@Aspect
//@Component
@Slf4j
public class ControllerInterceptors {

    /**
     * 定义拦截规则：拦截 com.unis.user.server.controller包下面的所有类中，有@RequestMapping注解的方法。
     */
    @Pointcut("execution(* com.unis.user.server.controller..*(..)) || @annotation(org.springframework.web.bind.annotation.RequestMapping)")
    public void webLog() {
    }

    @Before("webLog()")
    public void doBefore(JoinPoint joinPoint) {
        // 接收到请求，记录请求内容
        log.info( "----------------------请求记录拦截开始--------------------------" );
        ServletRequestAttributes attributes = (ServletRequestAttributes) RequestContextHolder.getRequestAttributes();
        HttpServletRequest request = attributes.getRequest();
        /**
         * 1.获得客户机信息
         */
        //得到请求的URL地址
        String requestUrl = request.getRequestURL().toString();
        //得到请求的资源
        String requestUri = request.getRequestURI();
        //得到请求的URL地址中附带的参数
        String queryString = request.getQueryString();
        //得到来访者的IP地址
        String remoteAddr = request.getRemoteAddr();
        String remoteHost = request.getRemoteHost();
        int remotePort = request.getRemotePort();
        String remoteUser = request.getRemoteUser();
        //得到请求URL地址时使用的方法
        String method = request.getMethod();
        String pathInfo = request.getPathInfo();
        //获取WEB服务器的IP地址
        String localAddr = request.getLocalAddr();
        //获取WEB服务器的主机名
        String localName = request.getLocalName();
        StringBuilder stringBuilder= new StringBuilder( "" );

        stringBuilder.append("---------获取到的客户机信息如下：");
        stringBuilder.append("请求的URL地址："+requestUrl+"----");
        stringBuilder.append("请求的资源："+requestUri+"----");
        stringBuilder.append("请求的URL地址中附带的参数："+queryString+"----");
        stringBuilder.append("来访者的IP地址："+remoteAddr+"----");
        stringBuilder.append("来访者的主机名："+remoteHost+"----");
        stringBuilder.append("使用的端口号："+remotePort+"----");
        stringBuilder.append("remoteUser："+remoteUser+"----");
        stringBuilder.append("请求使用的方法："+method+"----");
        stringBuilder.append("pathInfo："+pathInfo+"----");
        stringBuilder.append("localAddr："+localAddr+"----");
        stringBuilder.append("localName："+localName+"----");
        stringBuilder.append("获取参数 paraName：----");

        // 获取所有参数方法一：
        Enumeration <String> enu = request.getParameterNames();
        while (enu.hasMoreElements()) {
            String paraName = (String) enu.nextElement();
            stringBuilder.append(  paraName + ": " + request.getParameter( paraName ));
        }
        stringBuilder.append("----------获取到的客户机信息结束---------------");
        log.info( stringBuilder.toString() );

    }

    @AfterReturning("webLog()")
    public void doAfterReturning(JoinPoint joinPoint) {
        // 处理完请求，返回内容
//		logger.info("---------------------请求返回内容-------------");
    }

    @Around("webLog()")
    public Object doAround(ProceedingJoinPoint pjp) throws Throwable {
        long startTime = System.currentTimeMillis();
        // ob 为方法的返回值
        Object ob = pjp.proceed();
        long endDate = System.currentTimeMillis();

        log.info( "耗时 : " + +(endDate - startTime) / 1000 + "秒" + (endDate - startTime) % 1000 + "毫秒" );
        return ob;
    }

    private MultiValueMap<String, String> getParameterMap(NativeWebRequest webRequest) {
        MultiValueMap<String, String> parameters = new LinkedMultiValueMap<String, String>();

        for (Map.Entry<String, String[]> entry : webRequest.getParameterMap().entrySet()) {
            parameters.put(entry.getKey(), Arrays.asList(entry.getValue()));
        }
        return parameters;
    }

}
