package com.unis.user.server.common.logconfig;

import com.unis.user.server.untils.PageUtils;
import com.unis.user.server.untils.ResponseWrapper;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Sort;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.web.bind.annotation.*;

import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Predicate;
import javax.persistence.criteria.Root;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * 功能描述:
 *
 * @Auther: 蒋青茂
 * @Date: 2018/6/11 10:33
 */
@RestController
@RequestMapping("/log")
public class LogController {

    @Autowired
    private LogRepository logRepository;

    /**
     * @描述 日志page
     * @param：[logVO page, size]
     * @rerurn： com.unis.sxls.user.units.ResponseWrapper
     * @author：蒋青茂
     * @date 2018/5/17
     */
    @PostMapping("/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(@RequestBody LogVO logVO, @PathVariable Integer page, @PathVariable Integer size) {
        try {
            Pageable pageable = PageRequest.of( page - 1, size, Sort.Direction.ASC, "id" );
            Page <LogVO> rolePage = logRepository.findAll( new Specification <LogVO>() {
                @Override
                public Predicate toPredicate(Root <LogVO> root, CriteriaQuery <?> query, CriteriaBuilder cb) {
                    List <Predicate> list = new ArrayList <Predicate>();
                    if (StringUtils.isNotBlank( logVO.getUserName() )) {
                        list.add( cb.like( root.get( "userName" ).as( String.class ), "%" + logVO.getUserName() + "%" ) );
                    }
                    if (StringUtils.isNotBlank( logVO.getTypes() )) {
                        list.add( cb.like( root.get( "types" ).as( String.class ), "%" + logVO.getTypes() + "%" ) );
                    }
                    return cb.and( list.toArray( new Predicate[list.size()] ) );
                }
            }, pageable );
            Map <String, Object> map = PageUtils.getPage( rolePage );
            return ResponseWrapper.success( 200, "查询成功！", map );
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error( 500, "查询失败!" );
        }
    }
}
