package com.unis.user.server.common.restconfig;

import com.alibaba.fastjson.JSONArray;
import com.unis.user.server.untils.ResponseWrapper;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.client.ServiceInstance;
import org.springframework.cloud.client.loadbalancer.LoadBalancerClient;
import org.springframework.stereotype.Component;
import org.springframework.web.client.RestTemplate;

import javax.validation.constraints.NotNull;
import java.util.List;


/**
 * TODO description：
 *
 * @author bing.li
 * @version v1.0
 * @date 2018-08-13 14:42
 */
@Component
@Log4j2
public class RedisServer {

    @Autowired
    private RestTemplate restTemplate;

    @Autowired
    private LoadBalancerClient loadBalancerClient;

    /**
     * TODO serviceId eureka注册的服务名
     */
    private String serviceId = "redis";


    /**
     * TODO 可以进行负载均衡，该服务是从eureka中拿到redis服务工程实例。
     *
     * @return url
     */
    private synchronized String getUrl() {
        ServiceInstance serviceInstance = loadBalancerClient.choose(serviceId);
        String url = String.format("http://%s:%s", serviceInstance.getHost(), serviceInstance.getPort());
        log.info("调用地址{ }", url);
        return url;
    }


    /**
     * 读取缓存数据
     * @param key
     * @return
     */
    public ResponseWrapper get(String key) throws Exception {
        return restTemplate.getForObject(this.getUrl() + "/redis/get?key={1}", ResponseWrapper.class,key);
    }


    /**
     * 调用redis 服务的set接口
     *
     * @param key
     * @param value
     * @return
     */
    public ResponseWrapper set(String key,String value) throws Exception {
        return restTemplate.postForObject(this.getUrl() + "/redis/set?key={1}&value={2}", String.class, ResponseWrapper.class, key,value);
    }

    /**
     * 读取缓存数据 key为用户部门或者单位id
     *
     * @param key
     * @return
     */
    public List<Long> getPermission(@NotNull String key) throws Exception {
        StringBuffer stringBuffer = new StringBuffer("sys_department");
        stringBuffer.append("@");
        stringBuffer.append(key);
        ResponseWrapper responseWrapper = restTemplate.getForObject(this.getUrl() + "/redis/get?key={1}", ResponseWrapper.class, stringBuffer.toString());
        if (responseWrapper.getInfoCode()==200){
            Object data = responseWrapper.getData();
            List<Long> list = JSONArray.parseArray(data.toString(), Long.class);
            return list;
        }
        return null;
    }
}

