package com.unis.user.server.controller;

import java.util.List;

import com.unis.user.server.dto.AreaDO;
import com.unis.user.server.model.AreaAllVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import com.unis.user.server.dto.AreaDTO;
import com.unis.user.server.model.AreaVO;
import com.unis.user.server.server.AreaServer;
import com.unis.user.server.untils.ResponseWrapper;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

@RestController
@RequestMapping("/area")
@Api(tags = "区域配置")
public class AreaController {
	
	@Autowired
	private AreaServer areaServer;

	@ApiOperation( value = "获取所有省级编号")
    @GetMapping("/findProvince")
    public ResponseWrapper fingProvince() {
        try {
            List<AreaDTO> child = areaServer.fingAreaTree();
            return ResponseWrapper.success( child );
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }
	
	@ApiOperation( value = "根据省编号获取市级编号")
    @GetMapping("/findCity")
    public ResponseWrapper fingCity(String code) {
        try {
        	AreaDTO areaDTO = new AreaDTO();
        	areaDTO.setCountyCode(code);
            List<AreaDTO> child = areaServer.findCity(areaDTO);
            return ResponseWrapper.success( child );
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }
	
	@ApiOperation( value = "根据市级编号获取区编号")
    @GetMapping("/findCounty")
    public ResponseWrapper fingCounty(String code) {
        try {
        	AreaDTO areaDTO = new AreaDTO();
        	areaDTO.setCountyCode(code);
            List<AreaDTO> child = areaServer.findCounty(areaDTO);
            return ResponseWrapper.success( child );
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    @ApiOperation( value = "根据直辖市级编号获取区编号")
    @GetMapping("/findCountyQ")
    public ResponseWrapper findCountyQ(String code) {
        try {
            AreaDTO areaDTO = new AreaDTO();
            areaDTO.setCountyCode(code);
            List<AreaDTO> child = areaServer.findCountyQ(areaDTO);
            return ResponseWrapper.success( child );
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }


    @ApiOperation( value = "省编号获取市级编号，盟市编号返回自身编号")
    @GetMapping("/findCityOr")
    public ResponseWrapper fingCityOr(String code) {
        try {
            AreaDTO areaDTO = new AreaDTO();
            areaDTO.setCountyCode(code);
            List<AreaDTO> child = areaServer.findCityOr(areaDTO);
            return ResponseWrapper.success( child );
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    @ApiOperation( value = "省编号获取市级编号，盟市编号返回自身编号")
    @PostMapping("/findCity")
    public ResponseWrapper findCity(@RequestParam String code) {
        try {
            AreaDTO areaDTO = new AreaDTO();
            areaDTO.setCountyCode(code);
            List<AreaDTO> child = areaServer.findCityOr(areaDTO);
            return ResponseWrapper.success( child );
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    @ApiOperation( value = "省编号获取市级编号，盟市编号返回自身编号")
    @PostMapping("/findAreaCodeByAreaName")
    public ResponseWrapper findAreaCodeByAreaName(@RequestParam String areaCode) {
        try {
            AreaDTO areaDTO = new AreaDTO();
            areaDTO.setCountyCode(areaCode);
            List<AreaDTO> child = areaServer.findCityOr(areaDTO);
            return ResponseWrapper.success( child );
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    @ApiOperation( value = "获取省信息")
    @PostMapping("/getProvinByAreaName")
    public ResponseWrapper getProvinByAreaName(@RequestParam String areaName) {
        try {
            List<AreaAllVO> list = areaServer.getProvinByAreaName(areaName);
            return ResponseWrapper.success( list );
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    @ApiOperation( value = "获取市区信息")
    @PostMapping("/getCityByAreaName")
    public ResponseWrapper getCityByAreaName(@RequestParam String areaName) {
        try {
            List<AreaAllVO> list = areaServer.getCityByAreaName(areaName);
            return ResponseWrapper.success( list );
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

}
