package com.unis.user.server.controller;


import com.unis.user.server.dto.DepartmentDTO;
import com.unis.user.server.dto.tree.Tree;
import com.unis.user.server.model.DepartmentPO;
import com.unis.user.server.model.OrgainzeVO;
import com.unis.user.server.repository.UserRepository;
import com.unis.user.server.server.DepartmentServer;
import com.unis.user.server.untils.ResponseWrapper;
import com.unis.user.server.untils.tree.MenuTreeUtil;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.*;


/**
 * 功能描述：部门处理层
 *
 */
@RestController
@RequestMapping("/department")
@Slf4j
@Api(value = "部门管理处理层", tags = "部门管理处理层")
@SuppressWarnings("all")
public class DepartmentController{

	@Autowired
	private DepartmentServer server;
	@Autowired
	private UserRepository userRepository;


	/**
	 * 获取单条数据
	 *
	 * @param id
	 *            the id
	 * @return the response wrapper
	 */
	@ApiOperation(value = "(post)传入多条code获取详情集合", notes = "(post)传入多条code获取详情集合")
	@PostMapping("/findByDeptCode")
	public ResponseWrapper findByDeptCode(@RequestBody List<String>  deptCodes) {
		try {
			List<DepartmentPO> list = new ArrayList<>();
			for (String deptCode:deptCodes) {
				DepartmentPO departmentPO = server.findByDeptCode(deptCode);
			    list.add(departmentPO);
			}
			return ResponseWrapper.success(list);
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}

	/**
	 * 获取单条数据
	 * @param deptCode
	 * @return the response wrapper
	 */
	@ApiOperation(value = "(get)传入单条code获取详情", notes = "(get)传入单条code获取详情")
	@GetMapping("/findByDeptCode")
	public ResponseWrapper findByDeptCode(@RequestParam String deptCode) {
		try {
			List<DepartmentPO> list = new ArrayList<>();
			DepartmentPO departmentPO = server.findByDeptCode(deptCode);
			return ResponseWrapper.success(departmentPO);
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}

	/**
	 * 获取列表数据
	 *
	 * @param id
	 *            the id
	 * @return the response wrapper
	 */
	@ApiOperation(value = "获取组织编码查询部门用户", notes = "根据传入的组织id获取部门信息")
	@GetMapping("/findByOrgCodeFindUser")
	public ResponseWrapper findByOrgCodeFindUser( String orgCode) {
		try {
			List<DepartmentPO> list = null;
			if(StringUtils.isEmpty(orgCode)||"null".equals(orgCode)) {
				list = server.findByOrgCodenNew();
			}else {
				list = server.findByOrgCodeFindUser(orgCode);
			}
//			List<Object> findListTree = findListTree(list,"DP");

			return ResponseWrapper.success(list);
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}

	/**
	 * 获取列表数据
	 *
	 * @param id
	 *            the id
	 * @return the response wrapper
	 */
	@ApiOperation(value = "获取组织部门列表", notes = "根据传入的组织id获取部门信息")
	@GetMapping("/findByOrgCode")
	public ResponseWrapper findByOrgCode( String orgCode) {
		try {
			List<DepartmentPO> list = null;
			if(StringUtils.isEmpty(orgCode)||"null".equals(orgCode)) {
				list = server.findByOrgCodenNew();
			}else {
				list = server.findByOrgCode(orgCode);
			}
//			List<Object> findListTree = findListTree(list,"DP");
			
			return ResponseWrapper.success(list);
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}

	/**
	 * 获取列表数据
	 *
	 * @param id
	 *            the id
	 * @return the response wrapper
	 */
	@ApiOperation(value = "获取组织部门列表", notes = "根据传入的组织id获取部门信息")
	@GetMapping("/findByOrgCodeTree")
	public ResponseWrapper findByOrgCodeTree( String orgCode) {
		try {
			return ResponseWrapper.success(server.findByOrgCodeTree(orgCode));
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}
	
    public List<Object> findListTree(List<DepartmentPO> list, String topCode) {
        //待封装数据 所有数据的集合  包含父
//    	List<AreaInfoPO> list = repository.findByIsDeleted(0);
    	List<Tree> menu = new ArrayList<>();
    	for (DepartmentPO obj : list) {
    		Tree tree = new Tree();
    		tree.setId(obj.getDeptCode());
    		tree.setName(obj.getDeptName());
    		tree.setpId(obj.getParentCode());
    		menu.add(tree);
		}
        MenuTreeUtil menuTree = new MenuTreeUtil();
        List<Object> treeList = menuTree.menuList(menu,topCode);
    	return treeList;
    }

	/**
	 * 获取列表数据
	 *
	 * @param id
	 *            the id
	 * @return the response wrapper
	 */
	@ApiOperation(value = "获取省市所有部门信息--非树", notes = "")
	@GetMapping("/getAllDept")
	public ResponseWrapper getAllDept() {
		try {
			List<DepartmentPO> departmentPO = server.getAllDept();
			return ResponseWrapper.success(departmentPO);
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}

	/**
	 * 新增组织机构
	 *
	 * @param departmentVO
	 *            the department vo
	 * @return the response wrapper
	 */
	@ApiOperation(value = "保存部门信息", notes = "传入部门对象")
	@PostMapping("/save")
	public ResponseWrapper save(@RequestBody DepartmentDTO departmentDTO) {
		try {
			String save = server.save(departmentDTO);
			if (save==null){
				return ResponseWrapper.error(500, "该部门名字存在");
			}
			return ResponseWrapper.success(200, "机构新增成功");
		} catch (Exception e) {
			log.error("机构新增失败{}", e);
			e.printStackTrace();
			return ResponseWrapper.error(1000, "机构新增失败!原因：" + e.getLocalizedMessage());
		}
	}

	/**
	 * Delete response wrapper.
	 *
	 * @param ids
	 *            the ids
	 * @return the response wrapper
	 */
	@ApiOperation(value = "删除部门信息", notes = "传入部门deptCode(可以传入多值)")
	@DeleteMapping("/delete")
	public ResponseWrapper delete(@RequestBody List<String> deptCode) {
		try {
			server.deleted(deptCode);
			return ResponseWrapper.success();
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error();
		}
	}

	/**
	 * 更新部门信息
	 *
	 * @param departmentVO
	 *            the department vo
	 * @return the response wrapper
	 */
	@ApiOperation(value = "更新部门信息", notes = "传入部门对象")
	@PostMapping("/update")
	public ResponseWrapper update(@RequestBody DepartmentDTO departmentDTO) {
		try {
			server.update(departmentDTO);
			return ResponseWrapper.success("机构修改成功");
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error("机构修改失败!原因：" + e.getLocalizedMessage());
		}
	}
	/**
	 * 查询上级部门
	 *
	 * @param departmentVO
	 *            the department vo
	 * @return the response wrapper
	 */
	@ApiOperation(value = "查询上级部门", notes = "传入部门对象")
	@PostMapping("/findByParentDep")
	public ResponseWrapper findByParentDep(@RequestBody DepartmentDTO departmentDTO) {
		try {
			 DepartmentPO byParentDep = server.findByParentDep(departmentDTO);
			return ResponseWrapper.success(byParentDep);
		} catch (Exception e) {
			e.printStackTrace();
			return ResponseWrapper.error("机构修改失败!原因：" + e.getLocalizedMessage());
		}
	}
	/**
	 * 获取所有的叶子节点数据
	 *
	 * @return the response wrapper
	 */
	@ApiOperation(value = "获取所有的组织机构数据。")
	@GetMapping("getTreeData")
	public ResponseWrapper getTreeData() {
		try {
			List<DepartmentPO> treeData = server.getTreeData();
			return ResponseWrapper.success(treeData);
		} catch (Exception e) {
			e.printStackTrace();
			log.error("获取部门目录树失败{ }", e.getMessage());
			return ResponseWrapper.error();
		}
	}
	/**
	 * 获取所有的叶子节点数据
	 *
	 * @return the response wrapper
	 */
	@ApiOperation(value = "根据父节点获取信息。")
	@GetMapping("getParentData")
	public ResponseWrapper getParentData(String parentCode) {
		try {
			List<DepartmentPO> treeData = server.findByParentCodeAndStateCode(parentCode);
			return ResponseWrapper.success(treeData);
		} catch (Exception e) {
			e.printStackTrace();
			log.error("获取部门目录树失败{ }", e.getMessage());
			return ResponseWrapper.error();
		}
	}


	@ApiOperation(value = "根据部门名称查询部门信息", notes = "参数：deptName（string，必填）：deptName,orgCode")
	@PostMapping(value = "/findByDeptName")
	public ResponseWrapper findByDeptName(@RequestParam String deptName,@RequestParam String orgCode) {
		try {
			DepartmentPO departmentPO = server.findByDeptName(deptName,orgCode);
			return ResponseWrapper.success(200, "查询成功", departmentPO);
		} catch (Exception e) {
			log.error(e.getMessage());
			return ResponseWrapper.error(500, "查询失败");
		}
	}

	@ApiOperation(value = "根据orgCode查询所有下属部门", notes = "参数：orgCode")
	@PostMapping(value = "/findByOrgCodes")
	public ResponseWrapper findByOrgCodes(@RequestParam List<String> OrgCodes,String deptType) {
		try {
			List <OrgainzeVO> list = server.findByOrgCodes(OrgCodes,deptType);
			return ResponseWrapper.success(200, "查询成功", list);
		} catch (Exception e) {
			log.error(e.getMessage());
			return ResponseWrapper.error(500, "查询失败");
		}
	}
}