package com.unis.user.server.controller;

import com.unis.common.base.BaseController;
import com.unis.common.constant.CommonConstant;
import com.unis.common.enums.IsLockedEnum;
import com.unis.common.utils.*;
import com.unis.common.utils.jwt.JwtConstant;
import com.unis.common.utils.vo.UserDTO;
import com.unis.common.utils.vo.UserInfoVO;
import com.unis.user.server.dto.ReqLoginDTO;


import com.unis.user.server.model.UserPO;
import com.unis.user.server.repository.UserRoleRepository;
import com.unis.user.server.server.UserServer;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.Cookie;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 *
 * @ClassName: LoginController
 * @Description: 用户登录、退出、用户权限操作-控制层
 * @author 杨祖榕
 * @date 2019年01月07日 10:54:23
 * @version v1.0
 */
@RestController
@RequestMapping("/login")
@Slf4j
@Api(value = "用户登录、退出、用户权限操作-控制层", tags = "用户登录、退出、用户权限操作-控制层")
public class LoginController extends BaseController {

    @Autowired
    private UserServer userServer;
    @Autowired
    private UserRoleRepository userRoleRepository;

    @ApiOperation(value = "用户登录", notes = "参数 reqLoginVO 1是粮食局 2是企业")
    @PostMapping(value = "/userLogin")
    public ResponseWrapper userLogin (@RequestBody ReqLoginDTO reqLoginDTO) {
        Map<String, Object> resultMap = new HashMap<>();
        String desc = "用户登录";
        try {
            //验证用户名、密码是否为空
            if(StringUtils.isEmpty(reqLoginDTO.getUserLoginName())) {
                return ResponseWrapper.error("用户名不能为空！");
            }
            if(StringUtils.isEmpty(reqLoginDTO.getUserPassword())) {
                return ResponseWrapper.error("密码不能为空！");
            }
            //根据用户名获取 用户对象，如果用户对象为空，说明用户不存在
            UserPO userPO = userServer.findByUserTypeAndUserLoginName(reqLoginDTO.getUserType(),reqLoginDTO.getUserLoginName());
            if(null == userPO) {
                return ResponseWrapper.error("用户不存在！");
            }
            //比对密码是否正确
            //密码要加密后比对
//            if(! EncryptUtil.verify(reqLoginVO.getUserPasswd(), sysUserInfoDO.getPwSalt(), sysUserInfoDO.getUserPasswd()) ) {
                String loginPassword = reqLoginDTO.getUserPassword();
                String password = userPO.getUserPassword();
            if(! EncryptUtil.verify(loginPassword, password) ) {
                return ResponseWrapper.error("密码错误！");
            }
            //用户对象是否被锁定
            if(userPO.getIsDisavled() == IsLockedEnum.YES.getCode()) {
                return ResponseWrapper.error("用户被禁用！");
            }
            //包装用户
            UserDTO userDTO = LsBeanUtils.copyProperties(userPO, UserDTO.class);

            sessionUtil.setUserInfo(userDTO);
            //生成token
            String token = sessionUtil.createToken(userDTO);
            sessionUtil.setTokenExpiration(token);//设置token的过期时间
            //获取用户信息
            UserPO userPO1 = userServer.findByUserTypeAndUserLoginName(reqLoginDTO.getUserType(),reqLoginDTO.getUserLoginName());
            //根据用户id 获取角色code数组
            List<String> roleCode = userRoleRepository.findByUserCode(userPO1.getUserCode());
//            resultMap.put("userInfoVO", userInfoVO);//将用户信息返回页面
            resultMap.put(JwtConstant.TOKEN, token);//将token返回页面
            resultMap.put("userType", userDTO.getUserType());//1：粮食局，2：企业用户
            resultMap.put("photo", userPO1.getUserImgurl());//头像
            resultMap.put("deparmentCode",userPO1.getDeptCode());//部门编码
            resultMap.put("name",userPO1.getUserName());//用户姓名
            resultMap.put("username",userPO1.getUserLoginName());//登录名
            resultMap.put("password",userPO1.getUserPassword());//密码
            resultMap.put("roleCode",roleCode);//角色code
//            resultMap.put("userNodeLevel", userNodeLevel);

            return ResponseWrapper.success(200, desc + CommonConstant.SUCCESS, resultMap);
        } catch (Exception e) {
            return responseCatchedException(e, desc);
        }
    }


    @ApiOperation(value = "用户注销", notes = "参数：")
    @PostMapping(value = "/userLogout")
    public ResponseWrapper userLogout() {
        String desc = "用户注销";
        try {
            //删除Redis中的登录的用户token
            sessionUtil.removeToken();
            //删除Redis中的用户信息
            sessionUtil.removeUserInfo();
            //删除Redis中的用户权限信息
//            sessionUtil.removeUserRights();
            //删除cookie中的token信息
            removeCookieToken();
            //
        } catch (Exception e) {
//            e.printStackTrace();
        }
        return ResponseWrapper.success("用户注销成功");
    }

    /**
     * 删除cookie中的token信息
     */
    private void removeCookieToken() {
        Cookie[] cookies = RequestUtils.getRequest().getCookies();
        if(null != cookies && cookies.length > 0) {
            for (Cookie cookie : cookies) {
                if ( cookie.getName().equals(JwtConstant.TOKEN) ) {
                    //if ( cookie.getName().equals("TOKENL") ||cookie.getName().equals("TOKENB") )
                    CookieUtil.removeCookie(cookie.getName());
                }
            }
        }
    }


}
