package com.unis.user.server.controller;

import com.unis.common.utils.vo.UserDTO;
import com.unis.user.server.dto.RoleResourcesDTO;
import com.unis.user.server.model.ResourcePO;
import com.unis.user.server.model.RoleResourcesVO;
import com.unis.user.server.server.RoleResourcesServer;
import com.unis.user.server.server.UserServer;
import com.unis.user.server.untils.ResponseWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Set;

@Api(tags = "用户-菜单权限资源")
@RestController
@RequestMapping("/menuPrivilege")
@Log4j2
public class MenuPrivilegeController {

    @Autowired
    private RoleResourcesServer roleResourcesServer;
    @Autowired
    private UserServer userServer;

    @ApiOperation(value = "根绝用户id获取所有角色资源信息列表")
    @GetMapping("/")
    public ResponseWrapper findRoleResourcesByCode(@RequestParam String userId) {
        try {
            List<String> userCodes = new ArrayList<String>();
            userCodes.add(userId);
            List<UserDTO> byUserCode = userServer.findByUserCode(userCodes);
            String userLoginName = byUserCode.get(0).getUserLoginName();
            String userType = byUserCode.get(0).getUserType();
            UserDTO userDTO = userServer.findByUserLoginName(userType, userLoginName);
            List<String> userRole = userDTO.getUserRole();
            String[] roleCode = userRole.toArray(new String[userRole.size()]);
            Set<ResourcePO> firstStageRoleResources = roleResourcesServer.findFirstStageRoleResources(roleCode);
            return ResponseWrapper.success(firstStageRoleResources);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    @ApiOperation(value = "根绝用户id获取所有角色资源信息列表")
    @GetMapping("/listRoleResourcesByCode")
    public ResponseWrapper listRoleResourcesByCode(@RequestParam String userId) {
        try {
            long begin = System.currentTimeMillis();
            log.info("开始 》》》》》》》》》》》》》》》{}", begin);
            List<ResourcePO> firstStageRoleResources = roleResourcesServer.listRoleResourcesByCode(null, userId);
            log.info("结束 》》》》》》》》》》》》》》》{}",  (System.currentTimeMillis() - begin));
            return ResponseWrapper.success(firstStageRoleResources);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

	/*@ApiOperation(value ="根据userId获取所有一级菜单")
    @GetMapping("/findFirstStageRoleResourcesByUID")
    public ResponseWrapper findFirstStageRoleResourcesByUID(@RequestParam String userId) {
        List<String> userCodes = new ArrayList<String>();
        userCodes.add(userId);
        List<UserDTO> byUserCode = userServer.findByUserCode(userCodes);
        String userLoginName = byUserCode.get(0).getUserLoginName();
        String userType = byUserCode.get(0).getUserType();
        UserDTO userDTO = userServer.findByUserLoginName(userType, userLoginName);
        List<String> userRole = userDTO.getUserRole();
        String[] roleCode=userRole.toArray(new String[userRole.size()]);
        List<ResourcePO> firstStageRoleResources = roleResourcesServer.findFirstStageRoleResources(roleCode);
        return ResponseWrapper.success( firstStageRoleResources );
    }

    @ApiOperation(value ="根据userId获取所有二级菜单")
    @GetMapping("/findSecondStageRoleResourcesByUID")
    public ResponseWrapper findSecondStageRoleResourcesByUID(@RequestParam String resourcesCode) {
        List<ResourcePO> secondStageRoleResources = roleResourcesServer.findSecondStageRoleResources( resourcesCode);
        return ResponseWrapper.success( secondStageRoleResources );
    }*/


    @ApiOperation(value = "根绝userId获取角色资源信息-树")
    @PostMapping("/userMenus")
    public ResponseWrapper findRoleResourcesTreeByUID(@RequestParam String userId) {
        try {
            // UserDTO userDTO = userServer.findByUserLoginName(userType, userName);
            List<String> userCodes = new ArrayList<String>();
            userCodes.add(userId);
            List<UserDTO> byUserCode = userServer.findByUserCode(userCodes);
            String userLoginName = byUserCode.get(0).getUserLoginName();
            String userType = byUserCode.get(0).getUserType();
            UserDTO userDTO = userServer.findByUserLoginName(userType, userLoginName);
            List<String> userRole = userDTO.getUserRole();
            String[] roleCode = userRole.toArray(new String[userRole.size()]);
            List<ResourcePO> child = roleResourcesServer.findRoleResourcesTree(roleCode, "RM1001003");
            return ResponseWrapper.success(child);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    @ApiOperation(value = "根据用户id和父级资源code获取菜单资源-树")
    @PostMapping("/userMenuList")
    public ResponseWrapper findUserMenuList(@RequestParam String resourceCode, @RequestParam String userId) {
        try {
            // UserDTO userDTO = userServer.findByUserLoginName(userType, userName);
            /*
            //20200526,wys:findByUserCode这个方法里面有太多无用的处理，如部门、角色等，换成另一个方法（但不改逻辑）
            //============================================================================
            List<String> userCodes = new ArrayList<String>();
            userCodes.add(userId);
            List<UserDTO> byUserCode = userServer.findByUserCode(userCodes);
            String userLoginName = byUserCode.get(0).getUserLoginName();
            String userType = byUserCode.get(0).getUserType();
            */
            UserDTO userDTO1 = userServer.findByUserCode(userId);
            String userLoginName = userDTO1.getUserLoginName();
            String userType = userDTO1.getUserType();
            //============================================================================
            UserDTO userDTO = userServer.findByUserLoginName(userType, userLoginName);
            List<String> userRole = userDTO.getUserRole();
            String[] roleCode = userRole.toArray(new String[userRole.size()]);
            List<ResourcePO> child = roleResourcesServer.findRoleResourcesTree(roleCode, resourceCode);
            return ResponseWrapper.success(child);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    @ApiOperation(value = "根据用户id和父级资源code获取菜单资源-树")
    @PostMapping("/userInfoMenuList")
    public ResponseWrapper findUserInfoMenuList(@RequestParam String resourceCode, @RequestParam String userId) {
        try {
            // UserDTO userDTO = userServer.findByUserLoginName(userType, userName);
            /*
            //20200526,wys:findByUserCode这个方法里面有太多无用的处理，如部门、角色等，换成另一个方法（但不改逻辑）
            //============================================================================
            List<String> userCodes = new ArrayList<String>();
            userCodes.add(userId);
            List<UserDTO> byUserCode = userServer.findByUserCode(userCodes);
            String userLoginName = byUserCode.get(0).getUserLoginName();
            String userType = byUserCode.get(0).getUserType();
            */
            UserDTO userDTO1 = userServer.findByUserCode(userId);
            String userLoginName = userDTO1.getUserLoginName();
            String userType = userDTO1.getUserType();
            //============================================================================
            UserDTO userDTO = userServer.findByUserLoginName(userType, userLoginName);
            List<String> userRole = userDTO.getUserRole();
            String[] roleCode = userRole.toArray(new String[userRole.size()]);
            List<ResourcePO> child = roleResourcesServer.findRoleResourcesTreeInfo(roleCode, resourceCode);
            return ResponseWrapper.success(child);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    @ApiOperation(value = "根据用户id和父级资源resourceCode获取菜单资源-列表")
    @PostMapping(value = "/buttonMenuList")
    public ResponseWrapper findButtonMenuList(@RequestParam String userId, @RequestParam String resourceCode) {
        List<String> userCodes = new ArrayList<String>();
        userCodes.add(userId);
        List<UserDTO> byUserCode = userServer.findByUserCode(userCodes);
        String userLoginName = byUserCode.get(0).getUserLoginName();
        String userType = byUserCode.get(0).getUserType();
        UserDTO userDTO = userServer.findByUserLoginName(userType, userLoginName);
        List<String> userRole = userDTO.getUserRole();
        String[] roleCode = userRole.toArray(new String[userRole.size()]);
        List<ResourcePO> child = roleResourcesServer.findRoleResourcesList(roleCode, resourceCode);
        return ResponseWrapper.success(child);
    }


}
