package com.unis.user.server.controller;

import com.unis.common.constant.CommonConstant;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.RedisUtil;
import com.unis.user.server.dto.OrgainzeDTO;
import com.unis.user.server.model.DepartmentPO;
import com.unis.user.server.model.OrgainzeVO;
import com.unis.user.server.model.SysZzjgPO;
import com.unis.user.server.model.UserPO;
import com.unis.user.server.server.OrgainzeServer;
import com.unis.user.server.untils.LsBeanUtils;
import com.unis.user.server.untils.ResponseWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

@RestController
@RequestMapping("/org")
@Slf4j
@Api(tags = "组织信息配置")
public class OrgainzeController {

    @Autowired
    private OrgainzeServer orgainzeServer;

    @Autowired
    private RedisUtil<OrgainzeVO> redisUtil;

    @ApiOperation(value = "根据组织编号获取本单位信息-非树")
    @GetMapping("/info")
    public ResponseWrapper info(String orgCode) {
        try {
            OrgainzeVO child = orgainzeServer.info(orgCode);
            return ResponseWrapper.success(child);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    @ApiOperation(value = "根据父级code获取下级列表")
    @RequestMapping(value = "/findByPid", method = {RequestMethod.POST, RequestMethod.GET})
    public ResponseWrapper findByPid(String parentCode) {
        try {
            List<OrgainzeVO> orgainzeVOS = orgainzeServer.findByParentCode(parentCode);
            return ResponseWrapper.success(orgainzeVOS);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    @ApiOperation(value = "根据组织编号获取本单位名字")
    @GetMapping("/findByCode")
    public ResponseWrapper findByCode(String orgCode) {
        try {
            String orgName = orgainzeServer.findByCode(orgCode);
            return ResponseWrapper.success(orgName);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }


    @ApiOperation(value = "根据组织编号获取上级组织信息")
    @GetMapping("/getParentOrg/{orgId}")
    public ResponseWrapper getParentInfo(@PathVariable String orgId) {
        try {
            String orgCode = orgId;
            if (orgCode.length() >= 5) {

                OrgainzeVO child = orgainzeServer.info(orgCode.substring(0, orgCode.length() - 3));
                return ResponseWrapper.success(child);
            } else {
                return ResponseWrapper.error("该机构已是顶级机构，没有上级");
            }

        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    @ApiOperation(value = "根据行政区划和机构类型查询机构")
    @GetMapping("/findByAreaCodeAndOrgType/{areaCode}/{orgType}")
    public ResponseWrapper findByAreaCodeAndOrgType(@PathVariable("areaCode") String areaCode, @PathVariable("orgType") String orgType) {
        try {
            List<OrgainzeVO> child = orgainzeServer.findByAreaCodeAndOrgType(areaCode, orgType);
            return ResponseWrapper.success(child);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }


    @ApiOperation(value = "添加组织机构信息", notes = "参数：组织类型对象")
    @PostMapping("/add")
    public ResponseWrapper add(@RequestBody OrgainzeDTO orgainzeDTO) {
        try {

            String orgCode = orgainzeServer.add(orgainzeDTO);
            return ResponseWrapper.success(orgCode);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error("请联系管理员！");
        }
    }

    @ApiOperation(value = "删除组织机构信息", notes = "参数：组织codes")
    @PostMapping("/delete")
    public ResponseWrapper delete(String[] orgCodes) {
        try {
            int res = orgainzeServer.delete(orgCodes);
            if (res > 0) {
                return ResponseWrapper.success("删除组织信息成功");
            }
            return ResponseWrapper.error("组织信息删除失败");
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
            return ResponseWrapper.error("请联系管理员！");
        }
    }

    @ApiOperation(value = "分页所有组织机构", notes = "参数：组织编号、组织名称，机构等级、当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(@RequestBody OrgainzeDTO orgainzeDTO, @PathVariable(value = "page") Integer page, @PathVariable Integer size) {
        try {

            Page<OrgainzeVO> voPage = orgainzeServer.findByPage(orgainzeDTO, page, size);
            return ResponseWrapper.success(200, "查询成功", voPage);
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
            return ResponseWrapper.error(500, "查询失败");
        }
    }

    @ApiOperation(value = "组织机构树", notes = "参数：当前组织code,null标识查询所有树,orgType组织类型编码")
    @PostMapping(value = "/tree")
    public ResponseWrapper tree(@RequestParam(value = "orgCode", required = false, defaultValue = "LS001") String orgCode,
                                @RequestParam(value = "orgType", defaultValue = "") String orgType,
                                @RequestParam(value = "pageName", required = false) String pageName) {
        try {
            OrgainzeVO result = null;
        	/*if(StringUtils.isEmpty(orgCode)) {
        		orgCode = "LS001";
        	}*/
            if (StringUtils.isEmpty(orgCode) || "null".equals(orgCode)) {
                orgCode = "LS001";
            }
            if (StringUtils.isEmpty(orgType) || "null".equals(orgType)) {
                orgType = "";
            }

            String redisKey = "org" + orgCode + "@" + orgType;

//            result = redisUtil.getObjectByJson(redisKey, OrgainzeVO.class);
//            if(null != result) {
//                return ResponseWrapper.success(200, "查询成功", result);
//            }

            OrgainzeVO orgainzeDTO = orgainzeServer.getTreeData(orgCode, orgType, pageName);
            if (orgainzeDTO == null) {
                return ResponseWrapper.error(500, "请输入正确的组织编号");
            }

            result = LsBeanUtils.copyProperties(orgainzeDTO, OrgainzeVO.class);
//            redisUtil.setObjectByJson(redisKey, result);

            return ResponseWrapper.success(200, "查询成功", orgainzeDTO);
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
            return ResponseWrapper.error(500, "查询失败");
        }
    }

    @ApiOperation(value = "组织机构树", notes = "参数：当前组织code,null标识查询所有树,orgType组织类型编码")
    @PostMapping(value = "/treeExcludeCompany")
    public ResponseWrapper treeExcludeCompany(String orgCode, String orgType) {
        try {
            OrgainzeVO result = null;
            if (StringUtils.isEmpty(orgCode) || "null".equals(orgCode)) {
                orgCode = "LS001";
            }
            if (StringUtils.isEmpty(orgType) || "null".equals(orgType)) {
                orgType = "";
            }
            String redisKey = "org" + orgCode + "@" + orgType;

            OrgainzeVO orgainzeDTO = orgainzeServer.getTreeData(orgCode, orgType);
            if (orgainzeDTO == null) {
                return ResponseWrapper.error(500, "请输入正确的组织编号");
            }

            //将企业去掉
            orgainzeDTO = orgainzeServer.excludeCompany(orgainzeDTO);

            result = LsBeanUtils.copyProperties(orgainzeDTO, OrgainzeVO.class);

            return ResponseWrapper.success(200, "查询成功", orgainzeDTO);
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
            return ResponseWrapper.error(500, "查询失败");
        }
    }

    @ApiOperation(value = "更新组织机构信息", notes = "参数：组织类型对象")
    @PostMapping("/update")
    public ResponseWrapper update(@RequestBody OrgainzeDTO orgainzeDTO) {
        try {
            int res = orgainzeServer.update(orgainzeDTO);
            if (res > 0) {
                return ResponseWrapper.success("更新组织信息成功");
            }
            if(res <0){
                return ResponseWrapper.error("该组织已存在");
            }
            return ResponseWrapper.error("组织信息更新失败");
        } catch (Exception e) {
            e.printStackTrace();
            log.info(e.getMessage());
            return ResponseWrapper.error("请联系管理员！");
        }
    }

    @ApiOperation(value = "根据机构code、单位code、角色code获得人信息", notes = "参数")
    @PostMapping("/getUserInfo")
    public ResponseWrapper getUserInfo(@RequestParam(value = "orgCode", required = false) String orgCode, @RequestParam(value = "departCode", required = false) String departCode, @RequestParam(value = "roleCode", required = false) String roleCode) {
        try {
            List<UserPO> child = orgainzeServer.getUserInfo(orgCode, departCode, roleCode);
            return ResponseWrapper.success(child);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    @ApiOperation(value = "组织机构包含部门树", notes = "参数：当前组织code,null标识查询所有树")
    @PostMapping(value = "/selectByEntity")
    public ResponseWrapper selectByEntity(@RequestBody com.unis.user.common.vo.org.OrgainzeVO orgainzeVO) {
        try {
            List<com.unis.user.common.vo.org.OrgainzeVO> orgainzeVOList = orgainzeServer.selectByEntity(orgainzeVO);
            return ResponseWrapper.success(200, "查询成功", orgainzeVOList);
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
            return ResponseWrapper.error(500, "查询失败");
        }
    }

    @ApiOperation(value = "组织机构包含部门树", notes = "参数：当前组织code,null标识查询所有树")
    @PostMapping(value = "/orgAndDepartTree")
    public ResponseWrapper orgAndDepart(String orgCode) {
        try {
            if (StringUtils.isEmpty(orgCode)) {
                orgCode = "LS";
            }
            List<OrgainzeVO> orgainzeDTO = orgainzeServer.orgAndDepartTree(orgCode);
            return ResponseWrapper.success(200, "查询成功", orgainzeDTO);
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
            return ResponseWrapper.error(500, "查询失败");
        }
    }

    @ApiOperation(value = "组织机构包含部门树修订版", notes = "参数：当前组织code,null标识查询所有树")
    @PostMapping(value = "/orgAndDepartTreeNew")
    public ResponseWrapper orgAndDeparts(@RequestParam(value = "orgCode", required = false) String orgCode) {
        try {
            if (StringUtils.isEmpty(orgCode)) {
                orgCode = "LS";
            }
            List<OrgainzeVO> orgainzeDTO = orgainzeServer.orgAndDepartTreeNew(orgCode);
            return ResponseWrapper.success(200, "查询成功", orgainzeDTO);
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
            return ResponseWrapper.error(500, "查询失败");
        }
    }


    @ApiOperation(value = "根据行政区划code查询单位信息", notes = "参数：areaCode（string，必填）：行政区划code")
    @PostMapping(value = "/findByDepartmentAreaCode")
    public ResponseWrapper findByDepartmentAreaCode(String areaCode) {
        try {
            List<DepartmentPO> departmentPOs = orgainzeServer.findByDepartmentAreaCode(areaCode);

            return ResponseWrapper.success(200, "查询成功", departmentPOs);
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
            return ResponseWrapper.error(500, "查询失败");
        }
    }

    @ApiOperation(value = "根据orgName查询orgAreaCode", notes = "参数：areaCode（string，必填）：行政区划code")
    @PostMapping(value = "/getOrgAreaCodeByOrgName/{orgName}")
    public ResponseWrapper getOrgAreaCodeByOrgName(@PathVariable String orgName) {
        try {
            String orgAreaCode = orgainzeServer.getOrgAreaCodeByOrgName(orgName);

            return ResponseWrapper.success(200, "查询成功", orgAreaCode);
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
            return ResponseWrapper.error(500, "查询失败");
        }
    }

    @ApiOperation(value = "根据组织名称查询组织信息", notes = "参数：orgName（string，必填）：orgName")
    @PostMapping(value = "/findByOrgName/{orgName}")
    public ResponseWrapper findByOrgName(@PathVariable String orgName) {
        try {
            OrgainzeVO orgainzeVO = orgainzeServer.findByOrgName(orgName);

            return ResponseWrapper.success(200, "查询成功", orgainzeVO);
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
            return ResponseWrapper.error(500, "查询失败");
        }
    }


    @ApiOperation(value = "根据orgCode查询orgName", notes = "参数：areaCode（string，必填）：行政区划code")
    @PostMapping(value = "/orgNameByCode/{code}")
    public ResponseWrapper orgNameByCode(@PathVariable String code) {
        try {
            String orgName = orgainzeServer.orgNameByCode(code);

            return ResponseWrapper.success(200, "查询成功", orgName);
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
            return ResponseWrapper.error(500, "查询失败");
        }
    }

    @ApiOperation(value = "根据bizType 和 orgType 获取所有单位信息----非树", notes = "参数")
    @PostMapping(value = "/getBizTypeAndOrgType/{bizType}/{orgType}")
    public ResponseWrapper getBizTypeAndOrgType(@PathVariable String bizType, @PathVariable String orgType) {
        try {
            List<OrgainzeVO> list = orgainzeServer.getBizTypeAndOrgType(orgType);
            return ResponseWrapper.success(200, "查询成功", list);
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
            return ResponseWrapper.error(500, "查询失败");
        }
    }

    @ApiOperation(value = "根据bizType 和 orgType 获取所有单位信息----非树", notes = "参数")
    @PostMapping(value = "getAllOrgDescendants/{bizType}/{orgType}/{orgId}")
    public ResponseWrapper getAllOrgDescendants(@PathVariable Integer bizType, @PathVariable String orgType, @PathVariable String orgId) {
        try {
            OrgainzeVO list = orgainzeServer.getAllOrgDescendants(orgType, orgId);
            return ResponseWrapper.success(200, "查询成功", list);
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
            return ResponseWrapper.error(500, "查询失败");
        }
    }

    @ApiOperation(value = "组织机构树", notes = "参数：当前组织code,null标识查询所有树,orgType组织类型编码")
    @PostMapping(value = "/getAllOrgDescendantsTree/{bizType}/{orgType}/{orgId}")
    public ResponseWrapper getAllOrgDescendantsTree(@PathVariable Integer bizType, @PathVariable String orgType, @PathVariable String orgId) {
        try {
            if (StringUtils.isEmpty(orgId)) {
                orgId = "LS";
            }
            if (StringUtils.isEmpty(orgType) || "null".equals(orgType)) {
                orgType = "";
            }
            OrgainzeVO orgainzeDTO = orgainzeServer.getTreeData(orgId, orgType);
            if (orgainzeDTO == null) {
                return ResponseWrapper.error(500, "请输入正确的组织编号");
            }
            return ResponseWrapper.success(200, "查询成功", orgainzeDTO);
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
            return ResponseWrapper.error(500, "查询失败");
        }
    }

    /**
     * 获取当前登录用户所在单位下的单位层级树信息
     *
     * @param bizType, orgType
     * @return the response wrapper
     * @auth YangZR
     */
    @ApiOperation(value = "获取当前登录用户所在单位下的单位层级树信息", notes = "获取当前登录用户所在单位下的单位层级树信息")
    @ApiImplicitParams({@ApiImplicitParam(name = "bizType", value = "业务种类，1：粮食业务，2：XX业务...", required = true),
            @ApiImplicitParam(name = "orgType", value = "单位类型，10：粮食局，20：粮科院，25：检验单位... 65  企业注册用户  75 省长责任制---外部用户", required = true)
    })
    @GetMapping("/getUserOrgInfoTree/{bizType}/{orgType}")
    public ResponseWrapper getUserOrgInfoTree(@PathVariable("bizType") Integer bizType,
                                              @PathVariable("orgType") String orgType) {
        try {
            /*UserDTO userDTO = sessionUtil.getUserInfo();
            if(null != userDTO) {
                String orgId = userDTO.getOrgCode();
                return getAllOrgDescendantsTree(bizType, orgType, orgId);
            }*/
            String orgCode = CurrentUtil.getOrgId();
            if (null != orgCode) {
                return getAllOrgDescendantsTree(bizType, orgType, orgCode);
            }
            return ResponseWrapper.success();
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查询单位的层级树信息", e.getMessage());
            return ResponseWrapper.error();
        }
    }

    /**
     * 获取当前登录用户所在单位下的单位层级树信息
     *
     * @return the response wrapper
     * @auth YangZR
     */
    /*@ApiOperation(value = "获取当前登录用户所在单位信息", notes = "获取当前登录用户所在单位信息")
    @GetMapping("/getUserOrgInfo")
    public ResponseWrapper getUserOrgInfo() {
        try {
            String orgCode = CurrentUtil.getOrgId();
            if(null != orgCode) {
                return getAllOrgDescendantsTree(bizType, orgType, orgCode);
            }
            return ResponseWrapper.success();
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查询单位的层级树信息", e.getMessage());
            return ResponseWrapper.error();
        }
    }*/
    @ApiOperation(value = "获取天津所有库点", notes = "")
    @GetMapping(value = "/getTreeData")
    public ResponseWrapper getTreeData(String zzbm) {
        try {
            if (StringUtils.isEmpty(zzbm) || "null".equals(zzbm)) {
                zzbm = "LS001019";
            }
            SysZzjgPO sysZzjgPO = orgainzeServer.getTreeDataNew(zzbm);
            if (sysZzjgPO == null) {
                return ResponseWrapper.error(500, "请输入正确的组织编号");
            }
            return ResponseWrapper.success(200, "查询成功", sysZzjgPO);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查询组织失败", e.getMessage());
            return ResponseWrapper.error(500, "查询失败");
        }
    }

    @ApiOperation(value = "获取天津所有库点3级(特殊处理部分购销公司)", notes = "")
    @GetMapping(value = "/getTreeDataOrganGouXiao")
    public ResponseWrapper getTreeDataGouXiao() {
        try {
            String zzbm = "LS001019";
            OrgainzeVO orgainzeVO = orgainzeServer.getTreeDataGouXiao(zzbm);
            if (orgainzeVO == null) {
                return ResponseWrapper.error(500, "请输入正确的组织编号");
            }
            return ResponseWrapper.success(200, "查询成功", orgainzeVO);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查询组织失败", e.getMessage());
            return ResponseWrapper.error(500, "查询失败");
        }
    }

    @ApiOperation(value = "获取天津自己下的库点", notes = "")
    @GetMapping(value = "/getTreeDataCompany")
    public ResponseWrapper getTreeDataCompany(@RequestParam(name="zzbm") String zzbm) {
        try {
            String root="LS001019";
            OrgainzeVO orgainzeVO = orgainzeServer.getTreeDataCompany(root,zzbm);
            if (orgainzeVO == null) {
                return ResponseWrapper.error(500, "请输入正确的组织编号");
            }
            return ResponseWrapper.success(200, "查询成功", orgainzeVO);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查询组织失败", e.getMessage());
            return ResponseWrapper.error(500, "查询失败");
        }
    }

    @ApiOperation(value = "获取天津所有库点2级(特殊处理部分购销公司)", notes = "")
    @GetMapping(value = "/getTreeDataOrganKudianGouXiao")
    public ResponseWrapper getTreeDataOrganKudianGouXiao(String zzbm) {
        try {
            List<OrgainzeVO> orgainzeVOList = orgainzeServer.getTreeDataOrganKudianGouXiao(zzbm);
            if (orgainzeVOList == null) {
                return ResponseWrapper.error(500, "请输入正确的组织编号");
            }
            return ResponseWrapper.success(200, "查询成功", orgainzeVOList);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查询组织失败", e.getMessage());
            return ResponseWrapper.error(500, "查询失败");
        }
    }

    @ApiOperation(value = "获取天津所有库点2级(特殊处理部分购销公司)", notes = "")
    @GetMapping(value = "/getTreeDataOrganGouXiaoLgd")
    public ResponseWrapper getTreeDataOrganGouXiaoLgd(String zzbm) {
        try {
            List<OrgainzeVO> orgainzeVOList = orgainzeServer.getTreeDataOrganGouXiao(zzbm);
            if (orgainzeVOList == null) {
                return ResponseWrapper.error(500, "请输入正确的组织编号");
            }
            return ResponseWrapper.success(200, "查询成功", orgainzeVOList);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查询组织失败", e.getMessage());
            return ResponseWrapper.error(500, "查询失败");
        }
    }

    @ApiOperation(value = "获取天津所有库点2级(特殊处理部分购销公司)(区储)", notes = "")
    @GetMapping(value = "/getTreeDataOrganGouXiaoLgdForQc")
    public ResponseWrapper getTreeDataOrganGouXiaoLgdForQc(String zzbm) {
        try {
            List<OrgainzeVO> orgainzeVOList = orgainzeServer.getTreeDataOrganGouXiaoForQc(zzbm);
            if (orgainzeVOList == null) {
                return ResponseWrapper.error(500, "请输入正确的组织编号");
            }
            return ResponseWrapper.success(200, "查询成功", orgainzeVOList);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查询组织失败", e.getMessage());
            return ResponseWrapper.error(500, "查询失败");
        }
    }

    @ApiOperation(value = "监督检查专属获取组织机构树", notes = "")
    @PostMapping(value = "/getJdjcTreeData")
    public ResponseWrapper getJdjcTreeData(String orgCode) {
        try {
            if (StringUtils.isEmpty(orgCode) || "null".equals(orgCode)) {
                orgCode = "LS001";
            }
            OrgainzeVO orgainzeDTO = orgainzeServer.getJdjcTreeData(orgCode);
            if (orgainzeDTO == null) {
                return ResponseWrapper.error(500, "请输入正确的组织编号");
            }
            return ResponseWrapper.success(200, "查询成功", orgainzeDTO);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查询组织失败", e.getMessage());
            return ResponseWrapper.error(500, "查询失败");
        }
    }

    /**
     * 功能描述: 获取各盟市下的所有企业
     *
     * @Param: [orgCode, orgType]
     * @Return: com.unis.user.server.model.OrgainzeVO
     * @Author: zoujieli
     * @Date: 2020-04-16 11:44
     */
    /*@ApiOperation(value = "各盟市下的企业树", notes = "参数：当前组织code,null标识查询所有树,orgType组织类型编码")
    @PostMapping(value = "/companyTree")
    public ResponseWrapper companyTree(String orgCode, String orgType) {
        try {
            if (StringUtils.isEmpty(orgCode) || "null".equals(orgCode)) {
                orgCode = "LS001";
            }
            if (StringUtils.isEmpty(orgType) || "null".equals(orgType)) {
                orgType = "";
            }
            OrgainzeVO orgainzeDTO = orgainzeServer.getCompanyTreeData(orgCode, orgType);
            if (orgainzeDTO == null) {
                return ResponseWrapper.error(500, "请输入正确的组织编号");
            }
            return ResponseWrapper.success(200, "查询成功", orgainzeDTO);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(500, "查询失败");
        }
    }*/

    @ApiOperation(value = "根据组织名称查询组织信息", notes = "参数：orgName（string，必填）：orgName")
    @PostMapping(value = "/findByOrgNameAndParentCode")
    public ResponseWrapper findByOrgNameAndParentCode(@RequestParam(value = "orgName") String orgName, @RequestParam(value = "parentCode") String parentCode) {
        try {
            OrgainzeVO orgainzeVO = orgainzeServer.findByOrgNameAndParentCode(orgName,parentCode);
            return ResponseWrapper.success(200, "查询成功", orgainzeVO);
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
            return ResponseWrapper.error(500, "查询失败");
        }
    }

    @ApiOperation(value = "获取本级以及下级列表")
    @PostMapping(value = "/findCurrentAndChilds")
    public ResponseWrapper findCurrentAndChilds(String orgCode) {
        try {
            List<OrgainzeVO> orgainzeVOS = orgainzeServer.findCurrentAndChilds(orgCode);
            return ResponseWrapper.success(orgainzeVOS);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    @ApiOperation(value = "获取发改委区粮办")
    @GetMapping(value = "/listDevAndRef")
    public ResponseWrapper listDevAndRef() {
        try {
            List<OrgainzeVO> orgainzeVOS = orgainzeServer.listDevAndRef();
            return ResponseWrapper.success(orgainzeVOS);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    @ApiOperation(value = "获取发改委区粮办 & 购销公司 & 储备库 & 子单位")
    @GetMapping(value = "/listGroupOrg")
    public ResponseWrapper listGroupOrg(@RequestParam(name="orgName", required = false) String orgName) {
        try {
            List<OrgainzeVO> res = orgainzeServer.listAcceptUnit(orgName);
            return ResponseWrapper.success(res);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

}
