package com.unis.user.server.controller;

import com.unis.common.utils.ResponseWrapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.unis.user.server.dto.OrgainzeNoticeDTO;
import com.unis.user.server.model.OrgainzeNoticeVO;
import com.unis.user.server.model.OrgainzeVO;
import com.unis.user.server.server.OrgainzeNoticeServer;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;

@RestController
@RequestMapping("/orgNotice")
@Slf4j
@Api(tags = "组织事件通知人员信息维护")
public class OrgainzeNoticeController {

	@Autowired
	private OrgainzeNoticeServer orgainzeNoticeServer;
	
	@ApiOperation( value = "根据组织通知人信息")
    @GetMapping("/info" )
	public ResponseWrapper info(String orgCode) {
    	try {
    		OrgainzeNoticeVO child = orgainzeNoticeServer.info(orgCode);
            return ResponseWrapper.success( child );
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
	}
	
	@ApiOperation( value = "添加或更新组织通知人信息",notes = "参数：组织事件通知实体类")
    @PostMapping("/save")
    public ResponseWrapper add(@RequestBody OrgainzeNoticeDTO orgainzeNoticeDTO) {
        try {
            int res = orgainzeNoticeServer.save(orgainzeNoticeDTO);
            if (res > 0) {
            	return ResponseWrapper.success("保存组织通知人信息成功");
            }
            return ResponseWrapper.error("保存组织通知人信息失败");
        } catch (Exception e) {
            return ResponseWrapper.error("请联系管理员！");
        }
    }
	
	@ApiOperation(value = "分页获取组织通知人信息", notes = "参数：组织编号")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(@RequestBody OrgainzeNoticeDTO orgainzeNoticeDTO, @PathVariable(value = "page") Integer page, @PathVariable Integer size) {
        try {
           
            Page<OrgainzeNoticeVO> voPage = orgainzeNoticeServer.findByPage(orgainzeNoticeDTO, page, size);
            return ResponseWrapper.success(200, "查询成功", voPage);
        } catch (Exception e) {
            return ResponseWrapper.error(500, "查询失败");
        }
    }
	
	@ApiOperation( value = "删除组织通知人信息",notes = "参数：组织codes")
    @PostMapping("/delete")
    public ResponseWrapper delete(Integer[] ids) {
        try {
            int res = orgainzeNoticeServer.delete(ids);
            if (res > 0) {
            	return ResponseWrapper.success("删除组织组织通知人信息成功");
            }
            return ResponseWrapper.error("组织通知人信息失败");
        } catch (Exception e) {
            return ResponseWrapper.error("请联系管理员！");
        }
    }
}
