package com.unis.user.server.controller;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.unis.user.server.dto.ParaConfigDTO;
import com.unis.user.server.model.ParaConfigVO;
import com.unis.user.server.server.ParaConfigServer;
import com.unis.user.server.untils.ResponseWrapper;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@RestController
@RequestMapping("/config")
@Api(tags = "参数信息配置")
public class ParaConfigController {
	
	@Autowired
	private ParaConfigServer paraConfigServer;
	
	@ApiOperation( value = "根据参数类型获取所有参数信息")
    @GetMapping("/fingParaConfigList/{paraCode}")
    public ResponseWrapper fingParaConfigList(@PathVariable String paraCode) {
        try {
            List<ParaConfigVO> child = paraConfigServer.fingParaConfigList(paraCode);
            return ResponseWrapper.success( child );
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }
	
	@ApiOperation( value = "根据参数code获取参数信息")
    @GetMapping("/fingParaConfig/{configCode}")
    public ResponseWrapper fingParaConfig(@PathVariable String configCode) {
        try {
            ParaConfigVO child = paraConfigServer.fingParaConfig(configCode);
            if(child==null) {
            	return ResponseWrapper.error( "该参数不存在，请确认参数code" );
            }
            return ResponseWrapper.success( child );
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }
	
	@ApiOperation( value = "添加参数信息",notes = "参数：字参数对象")
    @PostMapping("/add")
    public ResponseWrapper add(@RequestBody ParaConfigDTO paraConfigDTO) {
        try {
            int res = paraConfigServer.add(paraConfigDTO);
            if (res > 0) {
            	return ResponseWrapper.success("添加参数类型成功");
            }
            return ResponseWrapper.error("参数类型添加失败");
        } catch (Exception e) {
            return ResponseWrapper.error("请联系管理员！");
        }
    }
	
	@ApiOperation( value = "更新参数信息",notes = "参数：参数对象")
    @PostMapping("/update")
    public ResponseWrapper update(@RequestBody ParaConfigDTO paraConfigDTO) {
        try {
            int res = paraConfigServer.update(paraConfigDTO);
            if(res>0)
            return ResponseWrapper.success(200, "更新参数信息成功");
        } catch (Exception e) {
            return ResponseWrapper.error("请联系管理员！");
        }
		return ResponseWrapper.error("更新参数失败！");
    }
	
	@ApiOperation( value = "删除参数信息",notes = "参数：参数codes")
    @PostMapping("/delete")
    public ResponseWrapper delete(String[] configCodes) {
        try {
            int res = paraConfigServer.delete(configCodes);
            if (res > 0) {
                return ResponseWrapper.success("删除参数成功");
            }
            return ResponseWrapper.error("删除参数失败");
        } catch (Exception e) {
            return ResponseWrapper.error("请联系管理员！");
        }
    }
	
	@ApiOperation(value = "查询所有参数信息", notes = "参数：参数名称，参数code,参数配置值及极限值、当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(@RequestBody ParaConfigDTO paraConfigDTO, @PathVariable(value = "page") Integer page, @PathVariable Integer size) {
        try {
           
            Page<ParaConfigVO> voPage = paraConfigServer.findByPage(paraConfigDTO, page, size);
            return ResponseWrapper.success(200, "查询成功", voPage);
        } catch (Exception e) {
            return ResponseWrapper.error(500, "查询失败");
        }
    }
}
