package com.unis.user.server.controller;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.unis.user.server.dto.ParaDTO;
import com.unis.user.server.model.ParaVO;
import com.unis.user.server.server.ParaServer;
import com.unis.user.server.untils.ResponseWrapper;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@RestController
@RequestMapping("/para")
@Api(tags = "参数类型配置")
public class ParaController {
	
	@Autowired
	private ParaServer paraServer;

	@ApiOperation( value = "获取所有参数类型信息")
    @GetMapping("/fingParaList")
    public ResponseWrapper fingParaList() {
        try {
            List<ParaVO> child = paraServer.fingParaList();
            return ResponseWrapper.success( child );
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }
	
	@ApiOperation( value = "获取所有参数类型信息")
    @GetMapping("/fingParaInfo/{paraCode}")
    public ResponseWrapper fingParaInfo(@PathVariable String paraCode) {
        try {
            ParaVO child = paraServer.fingParaInfo(paraCode);
            return ResponseWrapper.success( child );
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }
	
	@ApiOperation( value = "更新参数类型",notes = "参数：参数类型对象")
    @PostMapping("/update")
    public ResponseWrapper update(@RequestBody ParaDTO paraDTO) {
        try {
            int res = paraServer.update(paraDTO);
            if(res>0)
                return ResponseWrapper.success(200, "更新参数信息成功");
        } catch (Exception e) {
            return ResponseWrapper.error("请联系管理员！");
        }
		return ResponseWrapper.error("更新参数失败！");
    }
	
	@ApiOperation( value = "添加参数类型",notes = "参数：参数类型对象")
    @PostMapping("/add")
    public ResponseWrapper add(@RequestBody ParaDTO paraDTO) {
        try {
            int res = paraServer.add(paraDTO);
            if (res > 0) {
            	return ResponseWrapper.success("添加参数类型成功");
            }
            return ResponseWrapper.error("参数类型添加失败");
        } catch (Exception e) {
            return ResponseWrapper.error("请联系管理员！");
        }
    }
	
	@ApiOperation( value = "删除参数类型信息",notes = "参数：参数类型code，多个逗号分开")
    @PostMapping("/delete")
    public ResponseWrapper delete(String[] paraCode) {
        try {
            paraServer.delete(paraCode);
            /*if (res > 0) {
            	return ResponseWrapper.success("删除参数类型成功");
            }*/
             return ResponseWrapper.success(200,"删除参数类型成功");
        } catch (Exception e) {
            return ResponseWrapper.error("请联系管理员！");
        }
    }
	
	@ApiOperation(value = "查询所有参数类型", notes = "参数：参数名称，参数code,表名及字段、当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(@RequestBody ParaDTO paraDTO, @PathVariable(value = "page") Integer page, @PathVariable Integer size) {
        try {
           
            Page<ParaVO> voPage = paraServer.findByPage(paraDTO, page, size);
            return ResponseWrapper.success(200, "查询成功", voPage);
        } catch (Exception e) {
            return ResponseWrapper.error(500, "查询失败");
        }
    }
}
