package com.unis.user.server.controller;


import com.unis.user.server.dto.ResourceDTO;
import com.unis.user.server.model.ResourcePO;
import com.unis.user.server.server.ResourceserServer;
import com.unis.user.server.untils.ResponseWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import java.util.List;
import java.util.Map;

/**
 * @ClassName: ResourceController
 * @Description: 菜单管理
 * @author huangshuai
 * @date 2019年1月15日 下午3:35:33
 * @version v1.0
 */
@RestController
@RequestMapping("/resource")
@Slf4j
@SuppressWarnings("all")
@Api(value = "菜单管理", tags = "菜单管理")
public class ResourceController {

	@Autowired
	private ResourceserServer resourceserServer;

	@ApiOperation(value = "添加菜单", notes = "参数：菜单对象")
	@PostMapping(value = "/save")
	public ResponseWrapper save(@RequestBody ResourceDTO resourceDTO) {
		try {
			boolean flag = resourceserServer.save(resourceDTO);
			if (!flag) {
				return ResponseWrapper.success(300, "用户名已存在");
			}
			return ResponseWrapper.success(200, "保存成功");
		} catch (Exception e) {
			log.error("保存对象，发生异常", e.getMessage());
			return ResponseWrapper.error(500, "保存失败");
		}
	}

	@ApiOperation(value = "更新用户", notes = "参数：用户对象")
	@PostMapping(value = "/update")
	public ResponseWrapper update(@RequestBody ResourceDTO resourceDTO) {
		try {
			boolean flag = resourceserServer.update(resourceDTO);
			if (flag) {
				return ResponseWrapper.success();
			}
			return ResponseWrapper.error();
		} catch (Exception e) {
			log.error("更新对象，发生异常", e.getMessage());
			return ResponseWrapper.error(500, "操作失败");
		}

	}


	/**
	 * 多选删除
	 *
	 * @param ids
	 *            the ids
	 * @return the response wrapper
	 */
	@ApiOperation(value = "删除用户", notes = "参数：用户id(可传入多个)")
	@DeleteMapping(value = "/deletes")
	public ResponseWrapper deletes(@RequestBody String[] ids) {
		try {
			Boolean flag = resourceserServer.deletes(ids);
			if (!flag) {
				return ResponseWrapper.error(300, "参数错误，删除失败");
			}
			return ResponseWrapper.success(200, "用户信息删除成功");
		} catch (Exception e) {
			log.error("删除对象，发生异常", e.getMessage());
			return ResponseWrapper.error(500, "用户信息删除失败");
		}
	}



	@ApiOperation(value = "查询所有菜单", notes = "")
	@ApiImplicitParams({ @ApiImplicitParam(name = "page", value = "起始页", required = true),
			@ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
	@PostMapping(value = "/findByPage/{page}/{size}")
	public ResponseWrapper findByPage(@RequestParam Integer status , @PathVariable(value = "page") Integer page, @PathVariable Integer size) {
		try {
			Map<String, Object> voPage = resourceserServer.findByPage(status, page, size);
			return ResponseWrapper.success(200, "查询成功", voPage);
		} catch (Exception e) {
			log.error("查询信息，发生异常", e.getMessage());
			return ResponseWrapper.error(500, "申请查询失败");
		}
	}


	/**
	 * 获取所有的叶子节点数据
	 *
	 * @return the response wrapper
	 */
	@ApiOperation(value = "获取所有的菜单层级数据。")
	@GetMapping("getTreeData")
	public ResponseWrapper getTreeData() {
		try {
			List<ResourcePO> treeData = resourceserServer.getTreeData();
			return ResponseWrapper.success(treeData);
		} catch (Exception e) {
			e.printStackTrace();
			log.error("获取菜单目录树失败{ }", e.getMessage());
			return ResponseWrapper.error();
		}
	}

}
