package com.unis.user.server.controller;

import java.util.ArrayList;
import java.util.List;

import com.unis.common.vo.base.PageResult;
import com.unis.user.server.feignclient.FlowGroupClient;
import com.unis.user.server.model.GroupVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.unis.user.server.dto.RoleInfoDTO;
import com.unis.user.server.model.RoleInfoVO;
import com.unis.user.server.server.RoleInfoServer;
import com.unis.user.server.untils.ResponseWrapper;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@RestController
@RequestMapping("/role")
@Api(tags = "角色信息维护")
public class RoleInfoController {

	@Autowired
	private RoleInfoServer roleInfoServer;

	@Autowired
    private FlowGroupClient flowGroupClient;

	@ApiOperation( value = "获取所有角色信息")
    @GetMapping("/fingRoleList")
    public ResponseWrapper fingRoleList() {
        try {
            List<RoleInfoVO> child = roleInfoServer.fingRoleList();
            return ResponseWrapper.success( child );
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    @ApiOperation( value = "获取所有角色信息")
    @GetMapping("/selectByEntity")
    public ResponseWrapper selectByEntity() {
        try {
            List<RoleInfoVO> child = roleInfoServer.selectByEntity();
            return ResponseWrapper.success( child );
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    @ApiOperation( value = "获取自己的和分配给自己的角色信息")
    @PostMapping("/selectMyByEntity")
    public ResponseWrapper selectMyByEntity(@RequestBody RoleInfoDTO roleInfoDto) {
        try {
            List<RoleInfoVO> child = roleInfoServer.selectMyByEntity(roleInfoDto);
            return ResponseWrapper.success( child );
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

	@ApiOperation( value = "根绝角色code获取角色信息")
    @GetMapping("/fingRoleByCode/{roleCode}")
    public ResponseWrapper fingRoleByCode(@PathVariable String roleCode) {
        try {
            RoleInfoVO child = roleInfoServer.findRoleByCode(roleCode);
            return ResponseWrapper.success( child );
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

	@ApiOperation( value = "添加角色信息")
    @PostMapping("/add")
    public ResponseWrapper add(@RequestBody  RoleInfoDTO roleInfoDto) {
        try {
        	int res = roleInfoServer.add(roleInfoDto);
            try {
                List<GroupVO> groupVOArrayList = new ArrayList<>();
                GroupVO groupVO = new GroupVO();
                groupVO.setId(roleInfoDto.getRoleName());
                groupVOArrayList.add(groupVO);
                flowGroupClient.group(groupVOArrayList);
            }catch (Exception e){
                e.getMessage();
            }
            if (res > 0) {
            	return ResponseWrapper.success("添加角色信息成功");
            }
            return ResponseWrapper.error("角色信息添加失败");
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

	@ApiOperation( value = "更新角色信息")
    @PostMapping("/update")
    public ResponseWrapper update(@RequestBody RoleInfoDTO roleInfoDto) {
        try {
        	int res = roleInfoServer.update(roleInfoDto);
            if (res > 0) {
            	return ResponseWrapper.success("更新角色信息成功");
            }
            return ResponseWrapper.error("角色信息更新失败");
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

	@ApiOperation( value = "删除角色信息")
    @PostMapping("/delete")
    public ResponseWrapper delete(String[] roleCodes) {
        try {
        	int res = roleInfoServer.delete(roleCodes);
            if (res > 0) {
            	return ResponseWrapper.success("删除角色信息成功");
            }
            return ResponseWrapper.error("角色信息删除失败");
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

	@ApiOperation(value = "分页查询角色信息", notes = "参数：角色名称，角色类型、当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(@RequestBody RoleInfoDTO roleInfoDto, @PathVariable(value = "page") Integer page, @PathVariable Integer size) {
        try {
            PageResult<RoleInfoVO> pageResult = roleInfoServer.findByPage(roleInfoDto, page, size);
            return ResponseWrapper.success(200, "查询成功", pageResult);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(500, "查询失败");
        }
    }
}
