package com.unis.user.server.controller;

import java.util.ArrayList;
import java.util.List;

import com.unis.common.utils.ResponseWrapper;
import com.unis.common.utils.vo.UserDTO;
import com.unis.user.server.model.RoleResourcesAddVO;
import com.unis.user.server.server.UserServer;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.web.bind.annotation.*;

import com.unis.user.server.dto.RoleResourcesDTO;
import com.unis.user.server.model.ResourcePO;
import com.unis.user.server.model.RoleResourcesVO;
import com.unis.user.server.server.RoleResourcesServer;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@RestController
@RequestMapping("/roleResources")
@Api(tags = "角色资源配置")
public class RoleResourcesController {

	@Autowired
	private RoleResourcesServer roleResourcesServer;
	@Autowired
	private UserServer userServer;

	@ApiOperation( value = "获取所有角色资源")
    public ResponseWrapper fingRoleResourcesList() {
        try {
            List<RoleResourcesVO> child = roleResourcesServer.findRoleResourcesList();
            return ResponseWrapper.success( child );
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

	@ApiOperation( value = "根绝角色code获取角色资源信息-非树")
    @GetMapping("/findRoleResourcesByCode/{roleCode}")
    public ResponseWrapper findRoleResourcesByCode(@PathVariable String roleCode) {
        try {
            List<RoleResourcesVO> child = roleResourcesServer.findRoleResourcesByCode(roleCode);
            return ResponseWrapper.success( child );
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }


	@ApiOperation( value = "根绝角色code获取角色资源信息-树")
	@PostMapping("/findRoleResourcesTree")
    public ResponseWrapper findRoleResourcesTree(String[] roleCode,String resourcesCode) {
        try {
        	List<ResourcePO> child = roleResourcesServer.findRoleResourcesTree(roleCode,resourcesCode);
            return ResponseWrapper.success( child );
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }
    @ApiOperation( value = "根绝角色用户类型和登录名获取角色资源信息-树")
	@PostMapping("/findRoleResourcesTreeByUID")
    public ResponseWrapper findRoleResourcesTreeByUID(@RequestParam String userId) {
        try {
            List<String> userCodes = new ArrayList<String>();
            userCodes.add(userId);
            List<UserDTO> byUserCode = userServer.findByUserCode(userCodes);
            String userLoginName = byUserCode.get(0).getUserLoginName();
            String userType = byUserCode.get(0).getUserType();
            UserDTO userDTO = userServer.findByUserLoginName(userType, userLoginName);
            List<String> userRole = userDTO.getUserRole();
            String[] roleCode=userRole.toArray(new String[userRole.size()]);
            List<ResourcePO> child = roleResourcesServer.findRoleResourcesTree(roleCode,"RM1001003");
            return ResponseWrapper.success( child );
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }
	
	
	@ApiOperation(value = "查询角色资源分页信息", notes = "参数：参数名称，参数code,表名及字段、当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(@RequestBody RoleResourcesDTO roleResourcesDTO, @PathVariable(value = "page") Integer page, @PathVariable Integer size) {
        try {
           
            Page<RoleResourcesVO> voPage = roleResourcesServer.findByPage(roleResourcesDTO, page, size);
            return ResponseWrapper.success(200, "查询成功", voPage);
        } catch (Exception e) {
            return ResponseWrapper.error(500, "查询失败");
        }
    }
	
	@ApiOperation( value = "添加角色资源信息类型",notes = "参数：角色资源对象")
    @PostMapping("/add")
    public ResponseWrapper add(@RequestBody RoleResourcesDTO roleResourcesDTO) {
        try {
            int res = roleResourcesServer.add(roleResourcesDTO);
            if (res > 0) {
            	return ResponseWrapper.success("添加角色资源成功");
            }
            return ResponseWrapper.error("角色资源添加失败");
        } catch (Exception e) {
            return ResponseWrapper.error("请联系管理员！");
        }
    }
	
	@ApiOperation( value = "更新角色资源信息",notes = "参数：资源code，多个逗号隔开,角色编号")
    @PostMapping("/addRoleResources")
    public ResponseWrapper addRoleResources(@RequestBody RoleResourcesAddVO roleResourcesAddVO) {
        try {
            int res = roleResourcesServer.addRoleResources(roleResourcesAddVO
                    .getResources().toArray(new String[]{}),roleResourcesAddVO.getRoleCode());
            if (res > 0) {
            	return ResponseWrapper.success("更新角色资源成功");
            }
            return ResponseWrapper.error("角色资源更新失败");
        } catch (Exception e) {
            return ResponseWrapper.error("请联系管理员！");
        }
    }
	
	@ApiOperation( value = "根据组织编号获取本单位信息-非树")
    @GetMapping("/delete/{roleCode}")
	public ResponseWrapper delete(@PathVariable String roleCode) {
    	try {
    		int child = roleResourcesServer.delete(roleCode);
    		if (child > 0) {
            	return ResponseWrapper.success("删除角色资源成功");
            }
    		return ResponseWrapper.error("角色资源删除失败");
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
	}
}
