package com.unis.user.server.controller;

import com.unis.common.utils.ResponseWrapper;
import com.unis.user.server.dto.AreaDTO;
import com.unis.user.server.dto.RoleInfoDTO;
import com.unis.user.server.dto.TransactionDTO;
import com.unis.user.server.feignclient.BaseServerClient;
import com.unis.user.server.feignclient.FlowGroupClient;
import com.unis.user.server.model.GroupVO;
import com.unis.user.server.model.RoleInfoVO;
import com.unis.user.server.model.TransactionPO;
import com.unis.user.server.server.AreaServer;
import com.unis.user.server.server.RoleInfoServer;
import com.unis.user.server.server.TransactionServer;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.util.AntPathMatcher;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.HandlerMapping;

import javax.servlet.http.HttpServletRequest;
import java.util.ArrayList;
import java.util.List;

@RestController
@RequestMapping("/transaction")
@Api(tags = "交易客户管理")
public class TransactionController {

    @Autowired
    private TransactionServer server;
    @Autowired
    private BaseServerClient baseServerClient;
    @Autowired
    private AreaServer areaServer;


    @ApiOperation(value = "交易客户注册")
    @PostMapping("/register")
    public ResponseWrapper register(@RequestBody TransactionDTO transactionDTO) {
        try {
            int i = server.register(transactionDTO);
            if (i == 0) {
                return ResponseWrapper.error("该企业已存在请使用企业帐号前往登录");
            } else if (i == 2) {
                return ResponseWrapper.error("该企业已存在请前往登录");
            } else {
                return ResponseWrapper.success("注册成功");
            }
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }



    @ApiOperation(value = "认证")
    @PostMapping("/authentication")
    public ResponseWrapper authentication(@RequestBody TransactionDTO transactionDTO) {
        try {
            server.authentication(transactionDTO);
            return ResponseWrapper.success("认证成功");

        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    @ApiOperation(value = "分页查询交易客户列表", notes = "参数：组织编号、组织名称，机构等级、当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(@RequestBody TransactionDTO transactionDTO, @PathVariable(value = "page") Integer page, @PathVariable Integer size) {
        try {

            Page<TransactionDTO> voPage = server.findByPage(transactionDTO, page, size);
            return ResponseWrapper.success(200, "查询成功", voPage);
        } catch (Exception e) {
            return ResponseWrapper.error(500, "查询失败");
        }
    }

    @ApiOperation(value = "查看")
    @GetMapping("/findById")
    public ResponseWrapper findById(@RequestParam String id) {
        try {
            TransactionPO transactionPO = server.findById(id);
            return ResponseWrapper.success(transactionPO);

        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    @ApiOperation(value = "通过企业名称查询是否存在")
    @GetMapping("/findByCompany")
    public ResponseWrapper findByCompany(@RequestParam(value = "companyName") String companyName) {
        try {
            ResponseWrapper compnay = baseServerClient.findByCompany(companyName);
            if (compnay.getData()!=null) {
                return ResponseWrapper.error("该企业名称已存在");
            }
            TransactionPO transactionPO = server.findByCompany(companyName);
            return ResponseWrapper.success(transactionPO);

        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    @ApiOperation(value = "通过统一社会信用代码查询信息")
    @GetMapping("/findByShxydm")
    public ResponseWrapper findByShxydm(@RequestParam String shxydm) {
        try {
            TransactionPO transactionPO = server.findByTyshxydm(shxydm);
            return ResponseWrapper.success(transactionPO);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }


    @ApiOperation(value = "通过统一社会信用代码查询是否存在")
    @GetMapping("/findByTyshxydm")
    public ResponseWrapper findByTyshxydm(@RequestParam String tyshxydm) {
        try {
            ResponseWrapper compnay = baseServerClient.findComanyByTyshxydm(tyshxydm);
            if (compnay.getData() != null) {
                return ResponseWrapper.success(200,"该社会信用代码已存在",null);
            }
            TransactionPO transactionPO = server.findByTyshxydm(tyshxydm);
            return ResponseWrapper.success(transactionPO);

        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }
    @ApiOperation(value = "通过手机号查询")
    @GetMapping("/findByPhone")
    public ResponseWrapper findByPhone(@RequestParam String phone) {
        try {

            TransactionPO transactionPO = server.findByLxfsAndStateCode(phone);
            return ResponseWrapper.success(transactionPO);

        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    @ApiOperation(value = "通过单位代码查询")
    @GetMapping("/findByDwdm")
    public ResponseWrapper findByDwdm(@RequestParam String Dwdm) {
        try {

            TransactionPO transactionPO = server.findByDwdmAndStateCode(Dwdm);
            return ResponseWrapper.success(transactionPO);

        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }
    @ApiOperation(value = "修改", notes = "参数：用户对象")
    @PutMapping(value = "/update")
    public ResponseWrapper update(@RequestBody TransactionDTO transactionDTO) {

        try {
            boolean flag = server.update(transactionDTO);
            if (flag) {
                return ResponseWrapper.success();
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            return ResponseWrapper.error(500, "操作失败");
        }
    }
    @ApiOperation(value = "审核", notes = "参数：用户对象")
    @PutMapping(value = "/approval")
    public ResponseWrapper approval(@RequestBody TransactionDTO transactionDTO) {
        try {
            boolean flag = server.approval(transactionDTO);
            if (flag) {
                return ResponseWrapper.success();
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            return ResponseWrapper.error(500, "操作失败");
        }
    }

    @ApiOperation( value = "获取所有区域")
    @GetMapping("/findArea")
    public ResponseWrapper findArea() {
        try {
            List<AreaDTO> child = areaServer.fingArea();
            return ResponseWrapper.success( child );
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }
}