package com.unis.user.server.controller;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.TypeReference;
import com.unis.common.base.BaseController;
import com.unis.common.constant.CommonConstant;
import com.unis.common.utils.*;

import com.unis.common.utils.vo.CurrentUserDTO;
import com.unis.common.utils.vo.ResultDTO;


import com.unis.common.utils.vo.UserDTO;
import com.unis.user.server.dto.*;
import com.unis.user.server.feignclient.FlowGroupClient;

import com.unis.user.server.model.*;
import com.unis.user.server.server.DepartmentServer;
import com.unis.user.server.server.OrgainzeServer;
import com.unis.user.server.server.TransactionServer;
import com.unis.user.server.server.UserServer;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;


/**
 * 功能描述：用户业务控制层
 *
 * @author
 * @data 2017年11月-19日
 * @time 14时20分
 */
@RestController
@RequestMapping("/user")
@Slf4j
@SuppressWarnings("all")
@Api(value = "用户管理处理层", tags = "用户管理处理层")
public class UserController extends BaseController {

    @Autowired
    private UserServer userServer;

    @Autowired
    private DepartmentServer departmentServer;

    @Autowired
    private OrgainzeServer orgainzeServer;

    @Autowired
    private FlowGroupClient flowGroupClient;

    @Autowired
    private TransactionServer transactionServer;

    /**
     * @return com.unis.sxls.user.units.ResponseWrapper
     * @Author yang yunhai
     * @Description: 根据deptCode模糊查询用户
     * @Date: * @param id
     */
    @ApiOperation(value = "根据code查询用户", notes = "参数：用户id  userCode")
    @PostMapping(value = "/getAllUser")
    public ResponseWrapper getAllUser(@RequestParam String deptCode) {
        try {

            List<UserPO> userDTOList = userServer.getAllUser(deptCode);
            if (ObjectUtils.equals(userDTOList, null)) {
                return ResponseWrapper.error();
            }
            return ResponseWrapper.success(200, "查找成功", userDTOList);
        } catch (Exception e) {
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "用户信息查询失败");
        }
    }

    /**
     * @return ResponseWrapper
     * @Author yang yunhai
     * @Description: 1、保存用户
     * @Date: 时间:2018/5/28 15:25
     * * @param dictVO
     */
    @ApiOperation(value = "添加或修改用户", notes = "参数：type（string，必填）：类型，new 新增 / edit 修改")
    @PostMapping(value = "/saveUserinfo/{type}")
    public ResponseWrapper saveUserinfo(@PathVariable String type, @RequestBody UserDTO userDTO) {
        ResponseWrapper resp=null;
        try {
            if (type.equals("new")) {
                UserDTO user=userServer.findByUserLoginName(userDTO.getUserLoginName());
                if(user==null){
                    if (userDTO.getIsDev() == null) {
                        userDTO.setIsDev(0); // jpa使数据库默认值失效
                    }
                    String userCode = userServer.save(userDTO);
                    try {
                        UserVO userVO = new UserVO();
                        userVO.setId(userCode);
                        userVO.setFirstName(userDTO.getUserName());
                        userVO.setLastName(userDTO.getCountyCode());
                        userVO.setEmail(userDTO.getCountyCode());
                        List<UserVO> voList = new ArrayList<>();
                        voList.add(userVO);
                        try {
                            flowGroupClient.user(voList);
                            //ids同步用户
                            if("1".equals(userDTO.getUserType())){
                                resp=userServer.addIdsUser(userDTO);
                            }
                        } catch (Exception e) {
                            log.error("工作流用户新增失败", e.getMessage());
                        }

                        String userRoleNameTwo = userDTO.getUserRoleNameTwo();
                        List<String> userRoleName = new ArrayList<>();
                        List<GroupVO> groupVOList = new ArrayList<>();

                        List<MembershipVO> membershipVOArrayList = new ArrayList<>();
                        String[] split = null;
                        if (userRoleNameTwo.contains(",")) {
                            split = userRoleNameTwo.split(",");
                            for (int i = 0; i < split.length; i++) {
                                MembershipVO membershipVO = new MembershipVO();
                                membershipVO.setUserId(userCode);
                                membershipVO.setGroupId(split[i]);
                                membershipVOArrayList.add(membershipVO);
                                userRoleName.add(split[i]);
                                GroupVO groupVO = new GroupVO();
                                groupVO.setId(split[i]);
                                groupVOList.add(groupVO);
                            }
                        } else {
                            MembershipVO membershipVO = new MembershipVO();
                            membershipVO.setUserId(userCode);
                            membershipVO.setGroupId(userRoleNameTwo);
                            membershipVOArrayList.add(membershipVO);
                            userRoleName.add(userRoleNameTwo);
                            GroupVO groupVO = new GroupVO();
                            groupVO.setId(userRoleNameTwo);
                            groupVOList.add(groupVO);
                        }
                        try {
                            flowGroupClient.group(groupVOList);
                            flowGroupClient.member(membershipVOArrayList);
                        } catch (Exception e) {
                            log.error("工作流用户新增失败", e.getMessage());
                        }

                    } catch (Exception e) {
                        log.error("工作流用户新增失败", e.getMessage());
                    }
                    ResponseWrapper responseWrapper= ResponseWrapper.success(200,"新增成功",userCode);
                    if(responseWrapper.isSuccess() && resp!=null){
                        resp.setData(userCode);
                        return resp;
                    }else{
                        return responseWrapper;
                    }
                }else{
                    return ResponseWrapper.duplicate();
                }
            } else {
                userServer.update(userDTO);
                try {
                    MembershipVO vo = new MembershipVO();
                    vo.setUserId(userDTO.getUserCode());
                    try {
                        flowGroupClient.deletemember(vo);
                    } catch (Exception e) {

                    }

                    UserVO userVO = new UserVO();
                    userVO.setId(userDTO.getUserCode());
                    userVO.setFirstName(userDTO.getUserName());
                    userVO.setLastName(userDTO.getCountyCode());
                    userVO.setEmail(userDTO.getCountyCode());
                    List<UserVO> voList = new ArrayList<>();
                    voList.add(userVO);
                    try {
                        flowGroupClient.user(voList);
                    } catch (Exception e) {

                    }

                    String userRoleNameTwo = userDTO.getUserRoleNameTwo();
                    List<String> userRoleName = new ArrayList<>();
                    List<GroupVO> groupVOList = new ArrayList<>();
                    List<MembershipVO> membershipVOArrayList = new ArrayList<>();
                    String[] split = null;
                    if (userRoleNameTwo.contains(",")) {
                        split = userRoleNameTwo.split(",");
                        for (int i = 0; i < split.length; i++) {
                            MembershipVO membershipVO = new MembershipVO();
                            membershipVO.setUserId(userDTO.getUserCode());
                            membershipVO.setGroupId(split[i]);
                            membershipVOArrayList.add(membershipVO);
                            userRoleName.add(split[i]);
                            GroupVO groupVO = new GroupVO();
                            groupVO.setId(split[i]);
                            groupVOList.add(groupVO);
                        }
                    } else {
                        MembershipVO membershipVO = new MembershipVO();
                        membershipVO.setUserId(userDTO.getUserCode());
                        membershipVO.setGroupId(userRoleNameTwo);
                        membershipVOArrayList.add(membershipVO);

                        userRoleName.add(userRoleNameTwo);
                        GroupVO groupVO = new GroupVO();
                        groupVO.setId(userRoleNameTwo);
                        groupVOList.add(groupVO);
                    }
                    try {
                        flowGroupClient.group(groupVOList);
                        flowGroupClient.member(membershipVOArrayList);
                    } catch (Exception e) {

                    }
                } catch (Exception e) {
                    log.error("工作流用户新增失败", e.getMessage());
                }
                return ResponseWrapper.success();
            }
        } catch (Exception e) {
            log.error("保存对象，发生异常", e.getMessage());
            e.printStackTrace();
            return ResponseWrapper.error( "保存失败");
        }
    }

    /**
     * @return ResponseWrapper
     * @Author yang yunhai
     * @Description: 1、保存用户
     * @Date: 时间:2018/5/28 15:25
     * * @param dictVO
     */
    @ApiOperation(value = "填写注册信息", notes = "")
    @PostMapping(value = "/registerCompany")
    public ResponseWrapper registerCompany(@RequestBody CompanyVO companyVO) {
        try {
            return userServer.registerCompany(companyVO);
        } catch (Exception e) {
            log.error("保存对象，发生异常", e);
            e.printStackTrace();
            return ResponseWrapper.error(500, "保存失败");
        }
    }

    /**
     * @return ResponseWrapper
     * @Author
     * @Description: 1、保存用户
     * @Date: 时间:2018/5/28 15:25
     * * @param dictVO
     */
    @ApiOperation(value = "交易管理注册", notes = "")
    @PostMapping(value = "/registerTransaction")
    public ResponseWrapper registerTransaction(@RequestBody TransactionDTO transactionDTO) {
        try {
            return userServer.registerTransaction(transactionDTO);
        } catch (Exception e) {
            log.error("保存对象，发生异常", e);
            e.printStackTrace();
            return ResponseWrapper.error(500, "保存失败");
        }
    }
    /**
     * @return com.unis.sxls.user.units.ResponseWrapper
     * @Author yang yunhai
     * @Description: 更新数据
     * @Date: 时间:2018/5/24 18:26
     * * @param dictVO
     */
    @ApiOperation(value = "更新用户", notes = "参数：用户对象")
    @PutMapping(value = "/update")
    public ResponseWrapper update(@RequestBody UserDTO userDTO) {
        String headerToken = RequestUtils.getHeaderToken();
        if (StringUtils.isEmpty(headerToken)) {
            return ResponseWrapper.deny();
        }
        try {
            boolean flag = userServer.update(userDTO);
            if (flag) {
                return ResponseWrapper.success();
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            log.error("更新对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "操作失败");
        }

    }

    /**
     * @return com.unis.sxls.user.units.ResponseWrapper
     * @Author yang yunhai
     * @Description: 根据id查询用户
     * @Date: 时间:2018/5/28 13:18
     * * @param id
     */
    @ApiOperation(value = "根据code查询用户", notes = "参数：用户id  userCode")
    @PostMapping(value = "/findByCode")
    public ResponseWrapper findByCode(@RequestBody List<String> userCodes) {
        try {
            String headerToken = RequestUtils.getHeaderToken();
            if (StringUtils.isEmpty(headerToken)) {
                return ResponseWrapper.deny();
            }
            List<UserDTO> userDTOList = userServer.findByUserCode(userCodes);
            if (ObjectUtils.equals(userDTOList, null)) {
                return ResponseWrapper.success();
            }
            return ResponseWrapper.success(200, "查找成功", userDTOList);
        } catch (Exception e) {
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "用户信息查询失败");
        }
    }

    /**
     * @return com.unis.sxls.user.units.ResponseWrapper
     * @Author yang yunhai
     * @Description: 根据id查询用户
     * @Date: 时间:2018/5/28 13:18
     * * @param id
     */
    @ApiOperation(value = "根据code查询用户", notes = "参数：用户id  userCode")
    @PostMapping(value = "/findUserInfoByCode")
    public ResponseWrapper findUserInfoByCode(@RequestParam String userCodes) {
        String headerToken = RequestUtils.getHeaderToken();
        if (StringUtils.isEmpty(headerToken)) {
            return ResponseWrapper.deny();
        }
        try {
            List<String> userCodes2 = null;
            if (userCodes != null && userCodes.length() > 0) {
                userCodes2 = JSONArray.parseArray(userCodes, String.class);
            }
            List<UserDTO> userDTOList = userServer.findByUserCode(userCodes2);
            if (ObjectUtils.equals(userDTOList, null)) {
                return ResponseWrapper.error();
            }
            return ResponseWrapper.success(200, "查找成功", userDTOList);
        } catch (Exception e) {
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "用户信息查询失败");
        }
    }

    /**
     * @return ResponseWrapper
     * @Author 蒋青茂
     * @Date: 时间:2018/5/25 15:10
     * * @param name
     */
    @ApiOperation(value = "根据登录名获取用户信息", notes = "参数：用户账号")
    @GetMapping(value = "/findByUsername/{userType}/{userLoginName}")
    public ResponseWrapper findByUsername(@RequestParam String userType, @RequestParam String userLoginName) {
        try {
            UserDTO userDTO = userServer.findByUserLoginName(userType,userLoginName);
            if (userDTO != null) {
                if (userDTO.getIsDisavled() != 0) {
                    return ResponseWrapper.error("用户已注销或停用");
                } else if (userType != null) {
                    if ("0".equals(userType)) {
                        String orgCode = userDTO.getOrgCode();

                        Integer checkCompany = userServer.checkCompany(orgCode);
                      /*    TransactionPO transactionPO1 = transactionServer.findByTyshxydm(CurrentUtil.getCreditCode());
                          if (transactionPO1==null){
                                userDTO.setQyzt(0);
                            }else {
                                userDTO.setQyzt(transactionPO1.getQyzt());
                            }*/
                        if (checkCompany == null) {
                            //交易客户接口
                           TransactionPO transactionPO = transactionServer.findByDwdm(userDTO.getUserLoginName());
                           if (transactionPO!=null){
                               userDTO.setQyzt(transactionPO.getQyzt());
                               return ResponseWrapper.success(userDTO);
                           }else {
                               return ResponseWrapper.error("不存在此帐号");
                           }
                        } else if (checkCompany.equals(0)) {

                            return ResponseWrapper.error("企业信息已注销,暂不能登录！");

                        } else if (checkCompany.equals(2)) {

                            return ResponseWrapper.error("企业信息正在审核中,暂不能登录！");

                        } else if (checkCompany.equals(3)) {

                            return ResponseWrapper.error("企业信息审核被驳回,暂不能登录！");
                        }
                    }
                    return ResponseWrapper.success(userDTO);
                } else {
                    return ResponseWrapper.error("用户不存在");
                }
            }
            return ResponseWrapper.error("用户不存在");
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e);
            return ResponseWrapper.error(500, "用户信息查询失败");
        }
    }

    /**
     * @return 返回的数据少, 只用于用户存在判断, PS, 既然userLoginName是 unique key
     * 干嘛查询的时候还要加上  userType  ?  智商捉急
     * * @param name
     */
    @ApiOperation(value = "根据登录名获取用户信息", notes = "参数：用户账号")
    @GetMapping(value = "/findByUserloginname/{userLoginName}")
    public ResponseWrapper findByUsername(@PathVariable String userLoginName) {
        try {
            UserDTO userDTO = userServer.findByUserLoginName(userLoginName);
            if (userDTO != null) {
                if (userDTO.getIsDisavled() == 0) {
                    return ResponseWrapper.success(userDTO);
                }
                return ResponseWrapper.error("用户已禁用或注销!");
            }
            return ResponseWrapper.error("用户不存在!");
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e);
            return ResponseWrapper.error(500, "用户信息查询失败");
        }
    }

   /* @ApiOperation(value = "获取当前用户信息", notes = "参数：无")
    @GetMapping(value = "/getCurrUserinfo")
    public ResponseWrapper getCurrUserinfo() {
        String desc = "获取当前用户信息";
        try {
            UserDTO userDTO = sessionUtil.getUserInfo();
            if (null == userDTO) {
                return ResponseWrapper.error("不存在该用户");
            }
            //用户所在机构层级
            Integer areaLevel = AreaCodeUtil.getAreaLevel(userDTO.getCountyCode());
            userDTO.setAreaLevel(Integer.parseInt(areaLevel.toString().replace("0", "")));
            return ResponseWrapper.success(200, desc + CommonConstant.SUCCESS, userDTO);
        } catch (Exception e) {
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "用户信息查询失败");
        }
    }*/

    @ApiOperation(value = "查询当前登陆用户信息", notes = "参数：无")
    @GetMapping(value = "/getUserInfo")
    public ResponseWrapper getUserInfo() {
        CurrentUserDTO userInfo = new CurrentUserDTO();
        try {
            userInfo.setId(currentUtils.getUserId());
            userInfo.setAccount(currentUtils.getAccount());
            userInfo.setName(currentUtils.getUserName());
            userInfo.setOrgId(currentUtils.getOrgId());
            String orgName = orgainzeServer.findByCode(userInfo.getOrgId());
            userInfo.setOrgName(orgName);
            userInfo.setAreaLevel(currentUtils.getUserAreaLevel());
            return ResponseWrapper.success(200, "查找成功", userInfo);
        } catch (NumberFormatException e) {
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "用户信息查询失败");
        }
    }


    /**
     * 多选删除
     *
     * @param ids the ids
     * @return the response wrapper
     */
    @ApiOperation(value = "删除用户", notes = "参数：用户id(可传入多个)")
    @DeleteMapping(value = "/deletes")
    public ResponseWrapper deletes(@RequestBody List<String> userCode) {
        try {
            String headerToken = RequestUtils.getHeaderToken();
            if (StringUtils.isEmpty(headerToken)) {
                return ResponseWrapper.deny();
            }
            Boolean flag = userServer.deletes(userCode);
            try {
                for (String s : userCode) {
                    MembershipVO membershipVO = new MembershipVO();
                    membershipVO.setUserId(s);
                    flowGroupClient.deletemember(membershipVO);
                }
            } catch (Exception e) {
                log.error("工作流删除用户失败", e.getMessage());
            }

            if (!flag) {
                return ResponseWrapper.error(300, "参数错误，删除失败");
            }
            return ResponseWrapper.success(200, "用户信息删除成功");
        } catch (Exception e) {
            log.error("删除对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "用户信息删除失败");
        }
    }

    /**
     * 冻结/解冻该账户
     *
     * @param
     * @return
     */
    @ApiOperation(value = "冻结用户", notes = "参数：用户id")
    @PostMapping(value = "/freezeUser")
    public ResponseWrapper freezeUser(String userCode) {
        try {
            boolean flag = userServer.freezeUser(userCode);
            if (flag) {
                return ResponseWrapper.success();
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            log.error("冻结用户，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "冻结/解冻失败");
        }
    }

    /**
     * @return ResponseWrapper
     * @Author 郭益华
     * @Description: 密码重置
     */
    @ApiOperation(value = "密码重置", notes = "参数Map：账号、旧密码、新密码")
    @PostMapping(value = "/resetPassword/{userCode}")
    public ResponseWrapper resetPassword(@PathVariable String userCode) {
        try {
            boolean flag = userServer.resetPassword(userCode);
            if (flag) {
                ResponseWrapper rw=userServer.modifyIdsPassword(userCode);
                return rw;
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            log.error("重置密码，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "修改异常");
        }
    }

    /**
     * @return com.unis.user.server.untils.ResponseWrapper
     * @Author yang yunhai
     * @Description:更改密码
     * @Date: 时间:2018/5/29 16:15
     */
    @ApiOperation(value = "更新密码", notes = "参数Map：账号、旧密码、新密码")
    @PostMapping(value = "/changeUserPasswd/{bizType}")
    public ResponseWrapper updatePassword(@RequestBody ChangeUserPasswdDTO dto, @PathVariable String bizType) {
        try {
            ResultDTO resultDTO = userServer.updatePassword(dto);
            if (resultDTO.getMsg() == "用户不存在！") {
                return ResponseWrapper.error(resultDTO.getMsg());
            }
            if (resultDTO.getMsg() == "旧密码错误!") {
                return ResponseWrapper.error(resultDTO.getMsg());
            }
            if (resultDTO.getMsg() == "新密码和确认密码不一致！") {
                return ResponseWrapper.error(resultDTO.getMsg());
            }
            return ResponseWrapper.success(200, "修改密码成功");
        } catch (Exception e) {
            log.error("更改密码，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "修改异常");
        }
    }

    /**
     * @return com.unis.user.server.untils.ResponseWrapper
     * @Author li.penghe
     * @Description:更改密码
     * @Date: 时间:2018/5/29 16:15
     */
    @ApiOperation(value = "找回密码", notes = "账号、新密码")
    @PostMapping(value = "/findPwd")
    public ResponseWrapper findPwd(@RequestBody FindUserPasswdDTO dto) {
        try {
            return userServer.updatePassword(dto);
        } catch (Exception e) {
            log.error("更改密码，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "修改异常");
        }
    }

    /**
     * @param
     * @param userPO
     * @return com.unis.sxls.user.units.ResponseWrapper
     * @Author yang yunhai
     * @Description: 有条件的查询，带分页，只包含未删除的
     * @Date: 时间:2018/5/24 10:17
     * * @param num
     */
    @ApiOperation(value = "查询所有用户", notes = "参数：用户名模糊查询、部门名模糊查询、当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(@RequestBody UserDTO dto, @PathVariable(value = "page") Integer page, @PathVariable Integer size) {
        try {
            String headerToken = RequestUtils.getHeaderToken();
            if (StringUtils.isEmpty(headerToken)) {
                return ResponseWrapper.deny();
            }
            //获取当前用户登陆信息
           /* Long id = RequestUtils.getAccoutID();
            declareVO.setCreateByPeople(id);*/
            Page<UserDTO> voPage = userServer.findByPage(dto, page, size);
            return ResponseWrapper.success(200, "查询成功", voPage);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查询信息，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "申请查询失败");
        }
    }

    /**
     * @param
     * @param userPO
     * @return com.unis.sxls.user.units.ResponseWrapper
     * @Author yang yunhai
     * @Description: 有条件的查询，带分页，只包含未删除的
     * @Date: 时间:2018/5/24 10:17
     * * @param num
     */
    @ApiOperation(value = "查询本部门下所有人员", notes = "参数：用户名模糊查询、当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findByDeptCode/{page}/{size}")
    public ResponseWrapper findByDeptCode(@RequestBody UserDTO dto, @PathVariable(value = "page") Integer page, @PathVariable Integer size) {
        try {
            Page<UserDTO> voPage = userServer.findByPage(dto, page, size);
            return ResponseWrapper.success(200, "查询成功", voPage);
        } catch (Exception e) {
            log.error("查询信息，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "申请查询失败");
        }
    }

    @ApiOperation(value = "保存或更新用户角色信息", notes = "参数：roleIdsVO")
    @PostMapping(value = "/saveUserRoles")
    public ResponseWrapper saveUserRoles(@RequestBody List<String> roleCodes, String userCode) {
        String headerToken = RequestUtils.getHeaderToken();
        if (StringUtils.isEmpty(headerToken)) {
            return ResponseWrapper.deny();
        }
        try {
            userServer.saveUserRoles(roleCodes, userCode);
            return ResponseWrapper.success(200, "保存成功！");
        } catch (Exception e) {
            log.error("保存失败，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败");
        }
    }

    @ApiOperation(value = "更新用户角色信息", notes = "参数：roleIdsVO")
    @PutMapping(value = "/updateUserRoles")
    public ResponseWrapper updateUserRoles(@RequestBody UserRoleDTO userRoleIdDTO) {
        String headerToken = RequestUtils.getHeaderToken();
        if (StringUtils.isEmpty(headerToken)) {
            return ResponseWrapper.deny();
        }
        try {
            userServer.deletedUserRoles(userRoleIdDTO.getUserCode());
            userServer.updateUserRoles(userRoleIdDTO);
            return ResponseWrapper.success(200, "保存成功！");
        } catch (Exception e) {
            log.error("保存失败，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败");
        }
    }

    @ApiOperation(value = "删除该用户下所有角色", notes = "参数：roleIdsVO")
    @DeleteMapping(value = "/deletedUserRoles")
    public ResponseWrapper deletedUserRoles(String userCode) {
        String headerToken = RequestUtils.getHeaderToken();
        if (StringUtils.isEmpty(headerToken)) {
            return ResponseWrapper.deny();
        }
        try {
            userServer.deletedUserRoles(userCode);
            return ResponseWrapper.success(200, "保存成功！");
        } catch (Exception e) {
            log.error("保存失败，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败");
        }
    }


    @ApiOperation(value = "通过部门编码获取用户", notes = "参数：")
    @GetMapping(value = "/findByDeptCode/{deptCode}")
    public ResponseWrapper findByDeptCode(@PathVariable(required = false) String deptCode) {
        try {
            List<UserPO> list = userServer.findByDeptCode(deptCode);
            return ResponseWrapper.success(list);
        } catch (Exception e) {
            log.error("查询失败，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "查询失败");
        }
    }



    @ApiOperation(value = "通过机构部门和职位获取当前审核人", notes = "参数：")
    @GetMapping(value = "/findBySectionChief")
    public ResponseWrapper findBySectionChief(
            @RequestParam(required = false) String deptCode,
            @RequestParam(required = false) String headship,
            @RequestParam(required = false) String orgcode
    ) {
        try {
            List<UserPO> list = userServer.findBySectionChief(deptCode, headship, orgcode);
            return ResponseWrapper.success(list);
        } catch (Exception e) {
            log.error("查询失败，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "查询失败");
        }
    }


    @ApiOperation(value = "获取所有用户", notes = "参数：")
    @GetMapping(value = "/getAllUser/{sign}")
    public ResponseWrapper findBySectionChief(@RequestParam(required = false) String sign) {
        String headerToken = RequestUtils.getHeaderToken();
        if (StringUtils.isEmpty(headerToken)) {
            return ResponseWrapper.deny();
        }
        try {
            List<UserPO> list = new ArrayList<>();
            if (sign == "0") {
                list = userServer.findAll(1);
            } else if (sign == "1") {
                list = userServer.findByUserTypeAndStateCode(1, 1);
            } else {
                list = userServer.findByUserTypeAndStateCode(2, 1);
            }
            return ResponseWrapper.success(list);
        } catch (Exception e) {
            log.error("查询失败，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "查询失败");
        }
    }

    /**
     * deptId （string，必填）：部门或机构ID
     * deptSign（string，必填）：0 部门、1组织
     *
     * @param orgCode
     * @param departCode
     * @param roleCode
     * @return
     */
    @ApiOperation(value = "根据用户类型，组织/部门获取用户", notes = "")
    @PostMapping("/findUser/{deptsign}/{deptId}")
    public ResponseWrapper findUser(@RequestParam String deptId, @RequestParam String deptSign, @RequestParam(value = "roleCode", required = false) String roleCode) {
        try {
            String headerToken = RequestUtils.getHeaderToken();
            if (StringUtils.isEmpty(headerToken)) {
                return ResponseWrapper.deny();
            }
            if (deptSign.equals("1")) {
                String orgCode = deptId;
                String departCode = "";
                List<UserPO> child = orgainzeServer.getUserInfo(orgCode, departCode, roleCode);
                return ResponseWrapper.success(child);
            } else {
                String orgCode = "";
                String departCode = deptId;
                List<UserPO> child = orgainzeServer.getUserInfo(orgCode, departCode, roleCode);
                return ResponseWrapper.success(child);
            }
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }
    /**
     * deptId （string，必填）：部门或机构ID
     * deptSign（string，必填）：0 部门、1组织
     *
     * @param orgCode
     * @param departCode
     * @param roleCode
     * @return
     */
    @ApiOperation(value = "根据用户类型，组织/部门获取用户", notes = "")
    @GetMapping("/findUsers")
    public ResponseWrapper findUsers(String deptSign,String deptId) {
        String headerToken = RequestUtils.getHeaderToken();
        if (StringUtils.isEmpty(headerToken)) {
            return ResponseWrapper.deny();
        }
        try {
                String orgCode = deptId;
                String departCode = "";
                List<UserPO> child = orgainzeServer.getUserInfos(orgCode, departCode);
                return ResponseWrapper.success(child);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

    /**
     * deptId （string，必填）：部门或机构ID
     * deptSign（string，必填）：0 部门、1组织
     *
     * @param orgCode
     * @param departCode
     * @param roleCode
     * @return
     */
    @ApiOperation(value = "根据用户类型，组织/部门获取用户", notes = "")
    @PostMapping("/findUserDeptId")
    public ResponseWrapper findUserDeptId(@RequestParam String deptId, @RequestParam String deptSign, @RequestParam(value = "roleCode", required = false) String roleCode) {
        try {
            if (deptSign.equals("1")) {
                String orgCode = deptId;
                String departCode = "";
                List<UserPO> child = orgainzeServer.getUserInfo(orgCode, departCode, roleCode);
                return ResponseWrapper.success(child);
            } else {
                String orgCode = "";
                String departCode = deptId;
                List<UserPO> child = orgainzeServer.getUserInfo(orgCode, departCode, roleCode);
                return ResponseWrapper.success(child);
            }
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }

  /*  @ApiOperation(value = "查询本部门处长信息", notes = "参数：")
    @GetMapping(value = "/findBySectionChief")
    public ResponseWrapper findBySectionChief() {
        try {
            String deptCode = sessionUtil.getDeptId();
            List<UserPO> list = userServer.findBySectionChief(deptCode);
            // UserDTO userDTO = sessionUtil.getUserInfo();
           // List<Map<String, Object>> list1 = userServer.findByLoginName(loginName,userDTO.getOrgCode());
            return ResponseWrapper.success(list);
        } catch (Exception e) {
            log.error("查询失败，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "查询失败");
        }
    }*/

   /* @ApiOperation(value = "查询副局长信息", notes = "参数：")
    @GetMapping(value = "/findByBureaus")
    public ResponseWrapper findByBureaus() {
        try {
            String deptCode = sessionUtil.getDeptId();
            String parentCode = deptCode.substring(0, deptCode.length() - 3);
            String deptCodenew = parentCode + "001";
            List<UserPO> list = userServer.findByBureaus(deptCodenew);
            // UserDTO userDTO = sessionUtil.getUserInfo();
            // List<Map<String, Object>> list1 = userServer.findByLoginName(loginName,userDTO.getOrgCode());
            return ResponseWrapper.success(list);
        } catch (Exception e) {
            log.error("查询失败，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "查询失败");
        }
    }*/

    /*@ApiOperation(value = "查询局长信息", notes = "参数：")
    @GetMapping(value = "/findByManager")
    public ResponseWrapper findByManager() {
        try {
            String deptCode = sessionUtil.getDeptId();
            String parentCode = deptCode.substring(0, deptCode.length() - 3);
            String deptCodenew = parentCode + "001";
            List<UserPO> list = userServer.findByManager(deptCodenew);
            // UserDTO userDTO = sessionUtil.getUserInfo();
            // List<Map<String, Object>> list1 = userServer.findByLoginName(loginName,userDTO.getOrgCode());
            return ResponseWrapper.success(list);
        } catch (Exception e) {
            log.error("查询失败，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "查询失败");
        }
    }*/

    @ApiOperation(value = "查询所有科室下的考勤人员", notes = "参数：loginName登录名")
    @GetMapping(value = "/findByAttendance")
    public ResponseWrapper findByAttendance() {
        try {
            List<DepartmentPO> list = new ArrayList<>();
            List list2 = new ArrayList();
            List<OrgainzeVO> orgainzeVOList = orgainzeServer.findByStateCode();
            for (OrgainzeVO ov : orgainzeVOList) {
                list = departmentServer.findByAttendance(ov.getOrgCode());
                List<Map<String, Object>> list1 = userServer.findByDeptName(list);
                list2.addAll(list1);
            }
            return ResponseWrapper.success(list2);
        } catch (Exception e) {
            log.error("保存失败，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败");
        }
    }


    @ApiOperation(value = "通过手机号获取用户信息", notes = "参数：手机号")
    @GetMapping(value = "/getUserInfoBymobile/{mobile}")
    public ResponseWrapper getUserInfoBymobile(@RequestParam String mobile) {
        try {
            UserDTO userDTO = userServer.getUserInfoBymobile(mobile);
            if (userDTO != null) {
                return ResponseWrapper.success(userDTO);
            }
            return ResponseWrapper.error("用户不存在");
        } catch (Exception e) {
            log.error("保存失败，发生异常", e);
            return ResponseWrapper.error(500, "保存失败");
        }
    }

    @ApiOperation(value = "通过姓名获取userCode", notes = "参数：手机号")
    @GetMapping(value = "/findByName/{userName}")
    public ResponseWrapper findByName(@RequestParam String userName) {
        try {
            UserPO userPO = userServer.findByName(userName);
            if (userPO != null) {
                return ResponseWrapper.success(userPO.getUserCode());
            }
            return ResponseWrapper.error("获取用户信息成功");
        } catch (Exception e) {
            log.error("获取用户信息失败", e.getMessage());
            return ResponseWrapper.error(500, "获取用户信息失败");
        }
    }

    @ApiOperation(value = "获取粮食局用户", notes = "参数：")
    @PostMapping(value = "/getByType")
    public ResponseWrapper getByType() {
        try {

            List<UserPO> userDTOList = userServer.getByType();
            if (ObjectUtils.equals(userDTOList, null)) {
                return ResponseWrapper.error();
            }
            return ResponseWrapper.success(200, "查找成功", userDTOList);
        } catch (Exception e) {
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "用户信息查询失败");
        }
    }

    @ApiOperation(value = "获取用户信息", notes = "参数：")
    @GetMapping(value = "/findByAccount/{account}")
    public ResponseWrapper findByAccount(@PathVariable String account, @RequestParam String bizType) {
        try {

            UserPO userPO = userServer.findByAccount(bizType, account);
            if (ObjectUtils.equals(userPO, null)) {
                return ResponseWrapper.error();
            }
            return ResponseWrapper.success(200, "查找成功", userPO);
        } catch (Exception e) {
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "用户信息查询失败");
        }
    }

    @ApiOperation(value = "获取企业用户", notes = "参数：")
    @GetMapping(value = "/getAllDept")
    public ResponseWrapper getAllDept() {
        try {

            List<UserPO> userDTOList = userServer.getAllDept();
            if (ObjectUtils.equals(userDTOList, null)) {
                return ResponseWrapper.error();
            }
            return ResponseWrapper.success(200, "查找成功", userDTOList);
        } catch (Exception e) {
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "用户信息查询失败");
        }
    }

    @ApiOperation(value = "通过角色获取用户信息", notes = "参数：")
    @GetMapping(value = "/getUserByRole")
    public ResponseWrapper getUserByRole(String[] roleCode) {
        try {

            List<UserRoleVO> userDTOList = userServer.getUserByRole(roleCode);
            if (ObjectUtils.equals(userDTOList, null)) {
                return ResponseWrapper.error();
            }
            for(UserRoleVO userRoleVO:userDTOList){
                UserDTO userDTO = userServer.findByUserCode(userRoleVO.getUserCode());
                if(null != userDTO) {
                    userRoleVO.setOrgCode(userDTO.getOrgCode());
                }
            }
            return ResponseWrapper.success(200, "查找成功", userDTOList);
        } catch (Exception e) {
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "用户信息查询失败");
        }
    }

    /**
     * 功能描述 根据用户code获取角色列表
     *
     * @param
     * @return
     * @author wangqiang
     * @date 2019/9/23 0023
     */
    @ApiOperation(value = "根据用户code获取角色列表", notes = "参数：用户id  userCode")
    @PostMapping(value = "/findUserRolesByCode")
    public ResponseWrapper findUserRolesByCode(@RequestParam String userCode) {
        try {

            List<String> userDTOList = userServer.findRoleInfoByUserCode(userCode);
            if (ObjectUtils.equals(userDTOList, null)) {
                return ResponseWrapper.error();
            }
            return ResponseWrapper.success(200, "查找成功", userDTOList);
        } catch (Exception e) {
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "用户信息查询失败");
        }
    }


    //根据用户账号查密码
    @ApiOperation(value = "根据用户账号查密码", notes = "参数：用户账号 account")
    @PostMapping(value = "/fingPwByAccount")
    public ResponseWrapper fingPwByAccount(@RequestParam String account) {
        try {

            String pw = userServer.fingPwByAccount(account);
            return ResponseWrapper.success(200, "查找成功", pw);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "用户密码查询失败");
        }
    }


    //wzadmin项目同步用户
    @ApiOperation(value = "wzadmin项目同步用户", notes = "casUserVO对象")
    @PostMapping(value = "/saveWzadmin")
    public HashMap<String, String> saveWzadmin(@RequestBody String json) {
        HashMap<String, String> map = new HashMap<>();
        log.info(json);
        try {
            CasObjectTO casObjectTO = JSON.parseObject(json, new TypeReference<CasObjectTO>() {
            });
            CasUserVO casUserVO;
            casUserVO = JSON.parseObject(casObjectTO.getUser().toString(), CasUserVO.class);
            UserDTO userDTO = userServer.selectByUserLoginName(casUserVO.getLoginname());
            if (userDTO == null) {
                UserDTO userDTO1 = new UserDTO();
                if (casUserVO.getOffice() != null && casUserVO.getOffice() != "") {
                    String orgCode = orgainzeServer.getOrgCodeByOrgName(casUserVO.getOffice());
                    if (orgCode != null) {
                        userDTO1.setOrgCode(orgCode);
                    }
                    userDTO1.setOrgName(casUserVO.getOffice());
                }
                userDTO1.setUserLoginName(casUserVO.getLoginname());
                userDTO1.setUserName(casUserVO.getName());
                userDTO1.setUserMail(casUserVO.getEmail());
                userDTO1.setUserMobile(casUserVO.getMobile());
                userDTO1.setUserTel(casUserVO.getPhone());
                userDTO1.setDeptName(casUserVO.getOffice());
                userDTO1.setUserType("1");
                userDTO1.setUserPassword(casUserVO.getUserPassword());
                //userDTO1.setUserPassword(EncryptUtil.generate("lscbj@123"));
                //通过orgCode获取部门编号deptCode
                if (StringUtils.isNotBlank(userDTO1.getOrgCode())) {
                    List<DepartmentPO> departmentPOS = departmentServer.findByOrgCode(userDTO1.getOrgCode());
                    if (departmentPOS != null && departmentPOS.size() > 0) {
                        userDTO1.setDeptCode(departmentPOS.get(0).getDeptCode());
                    }else {
                        userDTO1.setDeptCode("DP021");
                    }
                }
                String userCode = userServer.saveNoPassword(userDTO1);
                try {
                    UserVO userVO = new UserVO();
                    userVO.setId(userCode);
                    userVO.setFirstName(userDTO.getUserName());
                    userVO.setLastName(userDTO.getCountyCode());
                    userVO.setEmail(userDTO.getCountyCode());
                    List<UserVO> voList = new ArrayList<>();
                    voList.add(userVO);
                    try {
                        flowGroupClient.user(voList);
                    } catch (Exception e) {
                        e.printStackTrace();
                        log.error("工作流用户新增失败", e.getMessage());
                    }

                    String userRoleNameTwo = userDTO.getUserRoleNameTwo();
                    List<String> userRoleName = new ArrayList<>();
                    List<GroupVO> groupVOList = new ArrayList<>();

                    List<MembershipVO> membershipVOArrayList = new ArrayList<>();
                    String[] split = null;
                    if (userRoleNameTwo.contains(",")) {
                        split = userRoleNameTwo.split(",");
                        for (int i = 0; i < split.length; i++) {
                            MembershipVO membershipVO = new MembershipVO();
                            membershipVO.setUserId(userCode);
                            membershipVO.setGroupId(split[i]);
                            membershipVOArrayList.add(membershipVO);
                            userRoleName.add(split[i]);
                            GroupVO groupVO = new GroupVO();
                            groupVO.setId(split[i]);
                            groupVOList.add(groupVO);
                        }
                    } else {
                        MembershipVO membershipVO = new MembershipVO();
                        membershipVO.setUserId(userCode);
                        membershipVO.setGroupId(userRoleNameTwo);
                        membershipVOArrayList.add(membershipVO);
                        userRoleName.add(userRoleNameTwo);
                        GroupVO groupVO = new GroupVO();
                        groupVO.setId(userRoleNameTwo);
                        groupVOList.add(groupVO);
                    }
                    try {
                        if (groupVOList != null) {
                            flowGroupClient.group(groupVOList);
                        }
                        if (membershipVOArrayList != null) {
                            flowGroupClient.member(membershipVOArrayList);
                        }
                    } catch (Exception e) {
                        log.error("工作流用户新增失败", e.getMessage());
                    }

                } catch (Exception e) {
                    log.error("工作流用户新增失败", e.getMessage());
                }
                map.put("result", "success");
                map.put("message", "同步用户操作成功");
                return map;
            } else {
                if (casUserVO.getOffice() != null && casUserVO.getOffice() != "") {
                    String orgCode = orgainzeServer.getOrgCodeByOrgName(casUserVO.getOffice());
                    userDTO.setOrgCode(orgCode);
                    userDTO.setOrgName(casUserVO.getOffice());
                    //通过orgCode获取部门编号deptCode
                    if (StringUtils.isNotBlank(orgCode)) {
                        List<DepartmentPO> departmentPOS = departmentServer.findByOrgCode(orgCode);
                        if (departmentPOS != null && departmentPOS.size() > 0) {
                            userDTO.setDeptCode(departmentPOS.get(0).getDeptCode());
                        }else {
                            userDTO.setDeptCode("DP021");
                        }
                    }
                }
                userDTO.setUserTel(casUserVO.getPhone());
                userDTO.setUserMobile(casUserVO.getMobile());
                userDTO.setUserMail(casUserVO.getEmail());
                userDTO.setUserName(casUserVO.getName());
                userDTO.setDeptName(casUserVO.getOffice());
                userDTO.setUserType("1");
                userDTO.setUserPassword(casUserVO.getUserPassword());
                //userDTO.setUserPassword(EncryptUtil.generate("lscbj@123"));
                userServer.update(userDTO);
                try {
                    MembershipVO vo = new MembershipVO();
                    vo.setUserId(userDTO.getUserCode());
                    try {
                        flowGroupClient.deletemember(vo);
                    } catch (Exception e) {

                    }

                    UserVO userVO = new UserVO();
                    userVO.setId(userDTO.getUserCode());
                    userVO.setFirstName(userDTO.getUserName());
                    userVO.setLastName(userDTO.getCountyCode());
                    userVO.setEmail(userDTO.getCountyCode());
                    List<UserVO> voList = new ArrayList<>();
                    voList.add(userVO);
                    try {
                        flowGroupClient.user(voList);
                    } catch (Exception e) {

                    }

                    String userRoleNameTwo = userDTO.getUserRoleNameTwo();
                    List<String> userRoleName = new ArrayList<>();
                    List<GroupVO> groupVOList = new ArrayList<>();
                    List<MembershipVO> membershipVOArrayList = new ArrayList<>();
                    String[] split = null;
                    if (userRoleNameTwo != null && userRoleNameTwo.contains(",")) {
                        split = userRoleNameTwo.split(",");
                        for (int i = 0; i < split.length; i++) {
                            MembershipVO membershipVO = new MembershipVO();
                            membershipVO.setUserId(userDTO.getUserCode());
                            membershipVO.setGroupId(split[i]);
                            membershipVOArrayList.add(membershipVO);
                            userRoleName.add(split[i]);
                            GroupVO groupVO = new GroupVO();
                            groupVO.setId(split[i]);
                            groupVOList.add(groupVO);
                        }
                    } else {
                        MembershipVO membershipVO = new MembershipVO();
                        membershipVO.setUserId(userDTO.getUserCode());
                        membershipVO.setGroupId(userRoleNameTwo);
                        membershipVOArrayList.add(membershipVO);

                        userRoleName.add(userRoleNameTwo);
                        GroupVO groupVO = new GroupVO();
                        groupVO.setId(userRoleNameTwo);
                        groupVOList.add(groupVO);
                    }
                    try {
                        if (groupVOList != null) {
                            flowGroupClient.group(groupVOList);
                        }
                        if (membershipVOArrayList != null) {
                            flowGroupClient.member(membershipVOArrayList);
                        }

                    } catch (Exception e) {

                    }
                } catch (Exception e) {
                    log.error("工作流用户新增失败", e.getMessage());
                }
                map.put("result", "success");
                map.put("message", "同步用户操作成功");
                return map;
            }
        } catch (Exception e) {
            log.error("保存对象，发生异常", e.getMessage());
            e.printStackTrace();
            map.put("result", "failed");
            map.put("message", "同步用户操作失败");
            return map;
        }

    }

    /**
     * @Author LGD
     * @Description: 根据AreaCode查询区粮办用户
     * @Date: 时间:2018/5/28 13:18
     * * @param id
     */
    @ApiOperation(value = "根据AreaCode查询区粮办用户", notes = "参数：用户List<String>")
    @PostMapping(value = "/findUserByAreaCode")
    public ResponseWrapper findUserByAreaCode(@RequestBody List<String> areaCodes) {
        try {
            List<UserPO> users = userServer.findUserByAreaCode(areaCodes);
            if (ObjectUtils.equals(users, null)) {
                return ResponseWrapper.success();
            }
            return ResponseWrapper.success(200, "查找成功", users);
        } catch (Exception e) {
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "用户信息查询失败");
        }
    }

    @ApiOperation(value = "根据deptid查询所有人", notes = "参数：orgCode")
    @PostMapping(value = "/findByDeptids")
    public ResponseWrapper findByDeptids(@RequestParam String depts) {
        try {
            List <OrgainzeVO> list = userServer.findByDeptids(depts);
            return ResponseWrapper.success(200, "查询成功", list);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(500, "查询失败");
        }
    }


    @ApiOperation(value = "查询本级组织下的职务人员", notes = "参数：orgCode,headShip")
    @PostMapping(value = "/findByHeadshipAndOrgCode")
    public ResponseWrapper findByHeadshipAndOrgCode(@RequestParam String headShip,@RequestParam String orgCode) {
        try {
            List <UserPO> list = userServer.findByHeadshipAndOrgCode(headShip,orgCode);
            return ResponseWrapper.success(200, "查询成功", list);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(500, "查询失败");
        }
    }

    @ApiOperation(value = "查询本级组织下的职务人员", notes = "参数：orgCode,headShip")
    @PostMapping(value = "/findByHeadshipsAndOrgCode")
    public ResponseWrapper findByHeadshipsAndOrgCode(@RequestParam List<String> headShip,@RequestParam String orgCode) {
        try {
            List <UserPO> list = userServer.findByHeadshipAndOrgCode(headShip,orgCode);
            return ResponseWrapper.success(200, "查询成功", list);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(500, "查询失败");
        }
    }

    @ApiOperation(value = "根据资源获取拥有该资源的用户。")
    @GetMapping("/listUserByResourceCode")
    public ResponseWrapper listUserByResourceCode(@RequestParam("resourceCode") String resourceCode) {
        try {
            List<UserRoleVO> treeData = userServer.listUserByResourceCode(resourceCode);
            return ResponseWrapper.success(treeData);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("获取菜单目录树失败{ }", e.getMessage());
            return ResponseWrapper.error(e.getMessage());
        }
    }
}
