/*
 * PlugDeviceController.java
 * 版权所有 © 2011-2017 ??????????????
 * Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
 * 2019-11-20 created by lipenghe with LAPTOP-IJQ2SDFV
 */
package com.unis.user.server.controller.plug;

import com.unis.common.constant.BaseStatusConstant;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.common.vo.groups.InsertGroup;
import com.unis.common.vo.groups.UpdateGroup;
import com.unis.user.common.vo.org.OrgainzeVO;
import com.unis.user.common.vo.plug.PlugDeviceListVO;
import com.unis.user.common.vo.plug.PlugDeviceShowVO;
import com.unis.user.common.vo.plug.PlugDeviceVO;
import com.unis.user.server.service.PlugDeviceService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

//import org.springframework.web.bind.annotation.GetMapping;

/**
 * PLUG_DEVICE-视频监控表
 * @author lipenghe at 2019-11-20 20:03:13
 */
@RestController
@RequestMapping("/manager/plug")
@Api( tags = "视频监控表")
public class PlugDeviceController {

    @Autowired
    private PlugDeviceService plugDeviceService;

    @ApiOperation(value = "视频监控设备---视频监控表---新增", notes = "视频监控设备")
    @PostMapping("/plugDevice/insertEntitySelective")
    public ResponseWrapper insertEntitySelective(
        @Validated({InsertGroup.class}) @RequestBody PlugDeviceVO plugDeviceVO
        , BindingResult bindingResult) {
        if(bindingResult.hasErrors()){
            return ResponseWrapper.validateFail(bindingResult.getAllErrors());
        }else{
            return plugDeviceService.insertEntitySelectiveResult(plugDeviceVO);
        }
    }

    @ApiOperation(value = "视频监控设备---视频监控表---修改", notes = "视频监控设备")
    @PostMapping("/plugDevice/updateByEntitySelective")
    public ResponseWrapper updateByEntitySelective(
        @Validated({UpdateGroup.class}) @RequestBody PlugDeviceVO plugDeviceVO
        , BindingResult bindingResult) {
        if(bindingResult.hasErrors()){
            return ResponseWrapper.validateFail(bindingResult.getAllErrors());
        }else{
            return plugDeviceService.updateByEntitySelectiveResult(plugDeviceVO,null);
        }
    }

    @ApiOperation(value = "视频监控设备---视频监控表---更新状态", notes = "视频监控设备")
    @PostMapping("/plugDevice/updateStatusByEntity")
    public ResponseWrapper updateStatusByEntity(
        @RequestBody PlugDeviceVO plugDeviceVO) {
        if(plugDeviceVO!=null){
            return plugDeviceService.updateStatusByEntityResult(plugDeviceVO,null);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "视频监控设备---视频监控表---删除", notes = "视频监控设备")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "id", value = "id#<唯一>备用主键", dataType = "Integer", paramType = "header")
        ,@ApiImplicitParam(name = "idStr", value = "id字符串#<唯一>备用主键", dataType = "String", paramType = "header")
        ,@ApiImplicitParam(name = "devid", value = "设备id#<主键><唯一><非空>主键", dataType = "String", paramType = "header")
    })
    @PostMapping("/plugDevice/deleteByEntity")
    public ResponseWrapper deleteByEntity(
        @RequestBody PlugDeviceShowVO plugDeviceShowVO){
        if(plugDeviceShowVO!=null){
            PlugDeviceVO plugDeviceVO= JsonUtils.parse(
                JsonUtils.serialize(plugDeviceShowVO), PlugDeviceVO.class);
            plugDeviceVO.setStatus(BaseStatusConstant.STATUS_DELETED);
            return plugDeviceService.deleteByEntityResult(plugDeviceVO,null);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "视频监控设备---视频监控表---分页查询列表,pageSize,pageNum从url传", notes = "视频监控设备")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "pageSize", value = "分页大小", dataType = "int", paramType = "query")
        ,@ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query")
        ,@ApiImplicitParam(name = "parentId", value = "上级单位ID#<检索>此处是粮库ID", dataType = "String", paramType = "header")
        ,@ApiImplicitParam(name = "parentName", value = "上级单位名#<检索>", dataType = "String", paramType = "header")
        ,@ApiImplicitParam(name = "devName", value = "设备名称#<检索>", dataType = "String", paramType = "header")
        ,@ApiImplicitParam(name = "devAddress", value = "设备位置#<检索>如X粮库东北角", dataType = "String", paramType = "header")
        ,@ApiImplicitParam(name = "devChannel", value = "设备通道#<检索>", dataType = "String", paramType = "header")
        ,@ApiImplicitParam(name = "ipv4Address", value = "设备IPV4#<检索>", dataType = "String", paramType = "header")
    })
    @PostMapping("/plugDevice/selectPageByEntity")
    public ResponseWrapper selectPageByEntity(
        @RequestParam(value = "pageNum", defaultValue = "1") int pageNum
        ,@RequestParam(value = "pageSize", defaultValue = "10") int pageSize
        ,@RequestBody PlugDeviceListVO plugDeviceListVO) {
        PlugDeviceVO plugDeviceVO= JsonUtils.parse(
            JsonUtils.serialize(plugDeviceListVO), PlugDeviceVO.class);
        return plugDeviceService.selectPageByEntityResult(pageNum,pageSize
            , plugDeviceVO,"DEVID DESC");
    }

    @ApiOperation(value = "视频监控设备---视频监控表---查询列表", notes = "视频监控设备")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "pageSize", value = "分页大小", dataType = "int", paramType = "query")
        ,@ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query")
        ,@ApiImplicitParam(name = "parentId", value = "上级单位ID#<检索>此处是粮库ID", dataType = "String", paramType = "header")
        ,@ApiImplicitParam(name = "parentName", value = "上级单位名#<检索>", dataType = "String", paramType = "header")
        ,@ApiImplicitParam(name = "devName", value = "设备名称#<检索>", dataType = "String", paramType = "header")
        ,@ApiImplicitParam(name = "devAddress", value = "设备位置#<检索>如X粮库东北角", dataType = "String", paramType = "header")
        ,@ApiImplicitParam(name = "devChannel", value = "设备通道#<检索>", dataType = "String", paramType = "header")
        ,@ApiImplicitParam(name = "ipv4Address", value = "设备IPV4#<检索>", dataType = "String", paramType = "header")
    })
    @PostMapping("/plugDevice/selectByEntity")
    public ResponseWrapper selectByEntity(
        @RequestBody PlugDeviceListVO plugDeviceListVO) {
        PlugDeviceVO plugDeviceVO= JsonUtils.parse(
            JsonUtils.serialize(plugDeviceListVO), PlugDeviceVO.class);
        return plugDeviceService.selectByEntityResult(plugDeviceVO);
    }

    @ApiOperation(value = "视频监控设备---视频监控表---树形结构", notes = "视频监控设备")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "orgCode", value = "机构编码", dataType = "String", paramType = "header")
    })
    @PostMapping("/plugDevice/selectTreeByEntity")
    public ResponseWrapper selectTreeByEntity(
        @RequestBody OrgainzeVO orgainzeVO) {
        if(StringUtils.isEmpty(orgainzeVO.getOrgCode())){
            orgainzeVO.setParentCode("LS");
        }
        return plugDeviceService.selectTreeByEntityResult(orgainzeVO);
    }

    @ApiOperation(value = "视频监控设备---视频监控表---查询详情", notes = "视频监控设备")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "id", value = "id#<唯一>备用主键", dataType = "Integer", paramType = "header")
        ,@ApiImplicitParam(name = "idStr", value = "id字符串#<唯一>备用主键", dataType = "String", paramType = "header")
        ,@ApiImplicitParam(name = "devid", value = "设备id#<主键><唯一><非空>主键", dataType = "String", paramType = "header")
    })
    @PostMapping("/plugDevice/selectById")
    public ResponseWrapper selectById(
        @RequestBody PlugDeviceShowVO plugDeviceShowVO){
        if(plugDeviceShowVO!=null){
            PlugDeviceVO plugDeviceVO= JsonUtils.parse(
                JsonUtils.serialize(plugDeviceShowVO), PlugDeviceVO.class);
            return plugDeviceService.selectByIdResult(plugDeviceVO);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "视频监控设备---视频监控表---(重新)启动推流", notes = "视频监控设备")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "id", value = "id#<唯一>备用主键", dataType = "Integer", paramType = "header")
        ,@ApiImplicitParam(name = "idStr", value = "id字符串#<唯一>备用主键", dataType = "String", paramType = "header")
        ,@ApiImplicitParam(name = "devid", value = "设备id#<主键><唯一><非空>主键", dataType = "String", paramType = "header")
    })
    @PostMapping("/plugDevice/startById")
    public ResponseWrapper startById(
        @RequestBody PlugDeviceShowVO plugDeviceShowVO){
        if(plugDeviceShowVO!=null){
            PlugDeviceVO plugDeviceVO= JsonUtils.parse(
                JsonUtils.serialize(plugDeviceShowVO), PlugDeviceVO.class);
            return plugDeviceService.startByIdResult(plugDeviceVO);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "视频监控设备---视频监控表---停止推流", notes = "视频监控设备")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "id#<唯一>备用主键", dataType = "Integer", paramType = "header")
            ,@ApiImplicitParam(name = "idStr", value = "id字符串#<唯一>备用主键", dataType = "String", paramType = "header")
            ,@ApiImplicitParam(name = "devid", value = "设备id#<主键><唯一><非空>主键", dataType = "String", paramType = "header")
    })
    @PostMapping("/plugDevice/stopById")
    public ResponseWrapper stopById(
            @RequestBody PlugDeviceShowVO plugDeviceShowVO){
        if(plugDeviceShowVO!=null){
            PlugDeviceVO plugDeviceVO= JsonUtils.parse(
                    JsonUtils.serialize(plugDeviceShowVO), PlugDeviceVO.class);
            return plugDeviceService.stopByIdResult(plugDeviceVO);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "视频监控设备---视频监控表---初始化数据", notes = "视频监控设备")
    @PostMapping("/plugDevice/selectInitData")
    public ResponseWrapper selectInitData(
        @RequestBody PlugDeviceVO plugDeviceVO){
        if(plugDeviceVO!=null){
            return plugDeviceService.selectInitDataResult(plugDeviceVO);
        }else{
            return ResponseWrapper.invalid();
        }
    }
}
