/*
 * UserRoleReletedController.java
 * 版权所有 © 2011-2017 北京神舟良实信息技术有限公司
 * Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
 * 2020-07-06 created by lipenghe with LAPTOP-IJQ2SDFV
 */
package com.unis.user.server.controller.role;

import com.unis.common.constant.BaseStatusConstant;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.common.vo.groups.InsertGroup;
import com.unis.common.vo.groups.UpdateGroup;
import com.unis.user.common.vo.role.UserRoleReletedListVO;
import com.unis.user.common.vo.role.UserRoleReletedShowVO;
import com.unis.user.common.vo.role.UserRoleReletedVO;
import com.unis.user.server.service.UserRoleReletedService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

//import org.springframework.web.bind.annotation.GetMapping;

/**
 * SYS_USER_ROLE_RELATED-角色关联
 * @author lipenghe at 2020-07-06 15:51:36
 */
@RestController
@RequestMapping("/manager/role")
@Api( tags = "角色关联---角色关联")
public class UserRoleReletedController {

    @Autowired
    private UserRoleReletedService userRoleReletedService;

    @ApiOperation(value = "角色关联---角色关联---选择性插入字段", notes = "角色关联")
    @PostMapping("/userRoleReleted/insertEntitySelective")
    public ResponseWrapper insertEntitySelective(
        @Validated({InsertGroup.class}) @RequestBody UserRoleReletedVO roleReletedVO
        , BindingResult bindingResult) {
        if(bindingResult.hasErrors()){
            return ResponseWrapper.validateFail(bindingResult.getAllErrors());
        }else{
            return userRoleReletedService.insertEntitySelectiveResult(roleReletedVO);
        }
    }

    @ApiOperation(value = "角色关联---角色关联----根据实体不为空的属性,选择性更新字段", notes = "角色关联")
    @PostMapping("/userRoleReleted/updateByEntitySelective")
    public ResponseWrapper updateByEntitySelective(
        @Validated({UpdateGroup.class}) @RequestBody UserRoleReletedVO roleReletedVO
        , BindingResult bindingResult) {
        if(bindingResult.hasErrors()){
            return ResponseWrapper.validateFail(bindingResult.getAllErrors());
        }else{
            return userRoleReletedService.updateByEntitySelectiveResult(roleReletedVO,null);
        }
    }

    @ApiOperation(value = "角色关联---角色关联---更改状态", notes = "角色关联")
    @PostMapping("/userRoleReleted/updateStatusByEntity")
    public ResponseWrapper updateStatusByEntity(
        @RequestBody UserRoleReletedVO roleReletedVO) {
        if(roleReletedVO!=null){
            return userRoleReletedService.updateStatusByEntityResult(roleReletedVO,null);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "角色关联---角色关联---[真删除]根据实体的某些属性进行单条或者批量删除", notes = "角色关联")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "id", value = "id#<唯一>备用主键", dataType = "Integer", paramType = "header")
        ,@ApiImplicitParam(name = "idStr", value = "id字符串#<唯一>备用主键", dataType = "String", paramType = "header")
        ,@ApiImplicitParam(name = "roleRelatedId", value = "角色关联表主键#<主键><唯一><非空>", dataType = "Integer", paramType = "header")
    })
    @PostMapping("/userRoleReleted/deleteByEntity")
    public ResponseWrapper deleteByEntity(
        @RequestBody UserRoleReletedShowVO roleReletedShowVO){
        if(roleReletedShowVO!=null){
            UserRoleReletedVO roleReletedVO= JsonUtils.parse(
                JsonUtils.serialize(roleReletedShowVO), UserRoleReletedVO.class);
            roleReletedVO.setStatus(Integer.valueOf(BaseStatusConstant.STATUS_DELETED));
            return userRoleReletedService.deleteByEntityResult(roleReletedVO,null);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "角色关联---角色关联---根据实体(唯一标示)查询一条数据", notes = "角色关联")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "id", value = "id#<唯一>备用主键", dataType = "Integer", paramType = "header")
        ,@ApiImplicitParam(name = "idStr", value = "id字符串#<唯一>备用主键", dataType = "String", paramType = "header")
        ,@ApiImplicitParam(name = "roleRelatedId", value = "角色关联表主键#<主键><唯一><非空>", dataType = "Integer", paramType = "header")
    })
    @PostMapping("/userRoleReleted/selectById")
    public ResponseWrapper selectById(
        @RequestBody UserRoleReletedShowVO roleReletedShowVO){
        if(roleReletedShowVO!=null){
            UserRoleReletedVO roleReletedVO= JsonUtils.parse(
                JsonUtils.serialize(roleReletedShowVO), UserRoleReletedVO.class);
            return userRoleReletedService.selectByIdResult(roleReletedVO);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "角色关联---角色关联---根据实体的某些属性查询分页数据,pageSize,pageNum从url传", notes = "角色关联")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "pageSize", value = "分页大小", dataType = "int", paramType = "query")
        ,@ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query")
    })
    @PostMapping("/userRoleReleted/selectPageByEntity")
    public ResponseWrapper selectPageByEntity(
        @RequestParam(value = "pageNum", defaultValue = "1") int pageNum
        ,@RequestParam(value = "pageSize", defaultValue = "10") int pageSize
        ,@RequestBody UserRoleReletedListVO roleReletedListVO) {
        UserRoleReletedVO roleReletedVO= JsonUtils.parse(
            JsonUtils.serialize(roleReletedListVO), UserRoleReletedVO.class);
        return userRoleReletedService.selectPageByEntityResult(pageNum,pageSize
            , roleReletedVO,"ROLE_RELATED_ID DESC");
    }

    @ApiOperation(value = "角色关联---角色关联---根据实体的某些属性查询列表", notes = "角色关联")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "pageSize", value = "分页大小", dataType = "int", paramType = "query")
        ,@ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query")
    })
    @PostMapping("/userRoleReleted/selectByEntity")
    public ResponseWrapper selectByEntity(
        @RequestBody UserRoleReletedListVO roleReletedListVO) {
        UserRoleReletedVO roleReletedVO= JsonUtils.parse(
            JsonUtils.serialize(roleReletedListVO), UserRoleReletedVO.class);
        return userRoleReletedService.selectByEntityResult(roleReletedVO);
    }

    @ApiOperation(value = "角色关联---角色关联---初始化数据", notes = "角色关联")
    @PostMapping("/userRoleReleted/selectInitData")
    public ResponseWrapper selectInitData(
        @RequestBody UserRoleReletedVO roleReletedVO){
        if(roleReletedVO!=null){
            return userRoleReletedService.selectInitDataResult(roleReletedVO);
        }else{
            return ResponseWrapper.invalid();
        }
    }
}
