/*
 * OrgainzeDomain.java
 * 版权所有 © 2011-2017 ??????????????
 * Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
 * 2019-11-20 20:51:22 created by lipenghe with LAPTOP-IJQ2SDFV
 */
package com.unis.user.server.domain.org;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.unis.common.utils.EntityUtil;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.user.common.vo.org.OrgainzeVO;
import com.unis.user.server.dao.OrgainzeDao;
import com.unis.user.server.domain.common.CommonDomain;
import com.unis.user.server.entity.org.OrgainzeDO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * SYS_ORGAINZE-
 * DO处理自身,VO处理包括子表
 * @author lipenghe at 2019-11-20 20:51:22
 */
@Component
@Transactional
public class OrgainzeDomain {

    @Autowired
    OrgainzeDao orgainzeDao;

    @Autowired
    CommonDomain commonDomain;
   /**
    * 通用的插入处理
    * @param entity    <>对象
    */
    private void buildInsertData(OrgainzeDO entity){
        String pk=null;
        //当前为主表
        pk= commonDomain.selectByTableNameAndAttr(EntityUtil.getTableName(OrgainzeDO.class)
        ,"ORG_CODE", "OR", 8);
        entity.setOrgCode(pk);
        entity.buildInsertData(pk);
    }

   /**
    * 通用的更新处理
    * @param entity    <>对象
    */
    private void buildUpdateData(OrgainzeDO entity){
        entity.buildUpdateData();
    }

    /**
    * 通用的返回数据处理
    * @param orgainzeVO    <>对象
    */
    private OrgainzeVO buildResult(OrgainzeVO orgainzeVO){
        OrgainzeVO orgainzeVOResult=new OrgainzeVO();
        orgainzeVOResult.setOrgCode(orgainzeVO.getOrgCode());
        return orgainzeVOResult;
    }

    /**
     * <SYS_ORGAINZE->插入全部字段
     * @param entity    <>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV 
     */
    public int insertEntity(OrgainzeDO entity) {
        buildInsertData(entity);
        return orgainzeDao.insert(entity);
    }

    /**
     * <SYS_ORGAINZE->插入全部字段
     * @param orgainzeVO    <>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper insertEntity(OrgainzeVO orgainzeVO) {
        //有属性操作则优先在vo处理
        OrgainzeDO entity= JsonUtils.parse(
            JsonUtils.serialize(orgainzeVO),OrgainzeDO.class);
        int num= insertEntity(entity);
        if(num>0){
            //主键设置回去
            orgainzeVO.setOrgCode(entity.getOrgCode());
            return ResponseWrapper.success(buildResult(orgainzeVO));
        }
        return ResponseWrapper.fail();
    }

    /**
     * <SYS_ORGAINZE->插入全部字段,可删除部分字段改为选择性插入
     * @param entity    <>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV 
     */
    public int insertEntitySelective(OrgainzeDO entity) {
        buildInsertData(entity);
        return orgainzeDao.insertSelective(entity);
    }

    /**
     * <SYS_ORGAINZE->插入全部字段,可删除部分字段改为选择性插入
     * @param orgainzeVO    <>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper insertEntitySelective(OrgainzeVO orgainzeVO) {
        //有属性操作则优先在vo处理
        OrgainzeDO entity= JsonUtils.parse(
            JsonUtils.serialize(orgainzeVO),OrgainzeDO.class);
        int num= insertEntitySelective(entity);
        if(num>0){
            //主键设置回去
            orgainzeVO.setOrgCode(entity.getOrgCode());
            return ResponseWrapper.success(buildResult(orgainzeVO));
        }
        return ResponseWrapper.fail();
    }

    /**
     * <SYS_ORGAINZE->更改状态
     * @param entity    <>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV 
     */
    public int updateStatusByEntity(OrgainzeDO entity) {
        return orgainzeDao.updateStatusByEntity(entity);
    }

    /**
     * <SYS_ORGAINZE->更改状态
     * @param orgainzeVO    <>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateStatusByEntity(OrgainzeVO orgainzeVO) {
        //有属性操作则优先在vo处理
        OrgainzeDO entity= JsonUtils.parse(
            JsonUtils.serialize(orgainzeVO),OrgainzeDO.class);
        int num= updateStatusByEntity(entity);
        if(num>0){
            //主键设置回去(此处实际不需要)
            orgainzeVO.setOrgCode(entity.getOrgCode());
            return ResponseWrapper.success(buildResult(orgainzeVO));
        }
        return ResponseWrapper.fail();
    }

    /**
     * <SYS_ORGAINZE->根据实体更新单条或者多条数据
     * @param entity    <>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV 
     */
    public int updateByEntity(OrgainzeDO entity) {
        buildUpdateData(entity);
        return orgainzeDao.updateByEntity(entity);
    }

    /**
     * <SYS_ORGAINZE->根据实体更新单条或者多条数据
     * @param orgainzeVO    <>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateByEntity(OrgainzeVO orgainzeVO) {
        //有属性操作则优先在vo处理
        OrgainzeDO entity= JsonUtils.parse(
            JsonUtils.serialize(orgainzeVO),OrgainzeDO.class);
        int num= updateByEntity(entity);
        if(num>0){
            //主键设置回去(此处实际不需要)
            orgainzeVO.setOrgCode(entity.getOrgCode());
            return ResponseWrapper.success(buildResult(orgainzeVO));
        }
        return ResponseWrapper.fail();
    }

    /**
     * <SYS_ORGAINZE->根据实体选择性更新
     * @param entity    <>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV 
     */
    public int updateByEntitySelective(OrgainzeDO entity) {
        buildUpdateData(entity);
        return orgainzeDao.updateByEntitySelective(entity);
    }

    /**
     * <SYS_ORGAINZE->根据实体选择性更新(存在则更新,不存在则插入,其余删除)
     * @param orgainzeVO    <>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateByEntitySelective(OrgainzeVO orgainzeVO) {
        //此处是直接更新,较为繁琐,适用于子表数据有关联(被其他数据使用),缺少排序在字段会出现顺序与修改数据的顺序不一致的问题,
        //有属性操作则优先在vo处理
        OrgainzeDO entity= JsonUtils.parse(
            JsonUtils.serialize(orgainzeVO),OrgainzeDO.class);
        int num= updateByEntitySelective(entity);
        if(num>0){
            //主键设置回去(此处实际不需要)
            orgainzeVO.setOrgCode(entity.getOrgCode());
            return ResponseWrapper.success(buildResult(orgainzeVO));
        }
        return ResponseWrapper.fail();
    }

    /**
     * <SYS_ORGAINZE->根据实体单条或者批量删除
     * @param orgainzeVO    <>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper deleteByEntity(OrgainzeVO orgainzeVO) {
        int num= orgainzeDao.deleteByEntity(orgainzeVO);
        return ResponseWrapper.choose(num);
    }

    /**
    * <SYS_ORGAINZE->根据实体单条或者批量删除
    * @param entity    <>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public int deleteByEntity(OrgainzeDO entity) {
        OrgainzeVO orgainzeVO= JsonUtils.parse(
            JsonUtils.serialize(entity),OrgainzeVO.class);
        return orgainzeDao.deleteByEntity(orgainzeVO);
    }

    /**
     * <SYS_ORGAINZE->根据实体假删除,根据实体属性单条或批量删除只是改变了状态不在页面显示,数据仍存在
     * @param orgainzeVO    <>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper deleteShamByEntity(OrgainzeVO orgainzeVO) {
        //自行在controller设置状态,则可删除,亦可还原
        int num= orgainzeDao.deleteShamByEntity(orgainzeVO);
        return ResponseWrapper.choose(num);
    }

    /**
    * <SYS_ORGAINZE->根据实体假删除,根据实体属性单条或批量删除只是改变了状态不在页面显示,数据仍存在
    * @param entity    <>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public int deleteShamByEntity(OrgainzeDO entity) {
        OrgainzeVO orgainzeVO= JsonUtils.parse(
            JsonUtils.serialize(entity),OrgainzeVO.class);
        return orgainzeDao.deleteShamByEntity(orgainzeVO);
    }

    /**
     * <SYS_ORGAINZE->根据实体查询数量
     * @param orgainzeVO    <>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV 
     */
    public int selectCountByEntity(OrgainzeVO orgainzeVO) {
        int num= orgainzeDao.selectCountByEntity(orgainzeVO);
        return num;
    }

    /**
     * <SYS_ORGAINZE->根据实体(唯一标示)查询一条数据
     * @param orgainzeVO    <>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public OrgainzeVO selectById(OrgainzeVO orgainzeVO) {
        OrgainzeVO orgainzeVODb= orgainzeDao.selectById(orgainzeVO);
        return orgainzeVODb;
    }

    /**
    * <SYS_ORGAINZE->根据实体(唯一标示)查询一条数据
    * @param entity    <>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public OrgainzeVO selectById(OrgainzeDO entity) {
        OrgainzeVO orgainzeVO= JsonUtils.parse(
            JsonUtils.serialize(entity),OrgainzeVO.class);
        return orgainzeDao.selectById(orgainzeVO);
    }

    /**
     * <SYS_ORGAINZE->根据实体查询分页列表
     * @param orgainzeVO    <>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV 
     */
    public Page<OrgainzeVO> selectPageByEntity(int pageNo, int pageSize
        , OrgainzeVO orgainzeVO, String order) {
        PageHelper.startPage(pageNo,pageSize,order);
        return orgainzeDao.selectPageByEntity(orgainzeVO);
    }

    /**
    * <SYS_ORGAINZE->根据实体查询列表
    * @param orgainzeVO    <>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public List<OrgainzeVO> selectByEntity(OrgainzeVO orgainzeVO) {
        return orgainzeDao.selectByEntity(orgainzeVO);
    }

    /**
    * <SYS_ORGAINZE->根据实体树形结构
    * @param orgainzeVO    <>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public List<OrgainzeVO> selectTreeByEntity(OrgainzeVO orgainzeVO) {
        return orgainzeDao.selectTreeByEntity(orgainzeVO);
    }

    /**
     * <SYS_ORGAINZE->根据实体查询列表
     * @param entity    <>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public List<OrgainzeVO> selectByEntity(OrgainzeDO entity) {
        OrgainzeVO orgainzeVO= JsonUtils.parse(
            JsonUtils.serialize(entity),OrgainzeVO.class);
        return orgainzeDao.selectByEntity(orgainzeVO);
    }

}
