/*
 * PlugDeviceDomain.java
 * 版权所有 © 2011-2017 ??????????????
 * Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
 * 2019-11-20 19:45:42 created by lipenghe with LAPTOP-IJQ2SDFV
 */
package com.unis.user.server.domain.plug;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.unis.common.utils.EntityUtil;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.user.common.vo.plug.PlugDeviceVO;
import com.unis.user.server.dao.PlugDeviceDao;
import com.unis.user.server.domain.common.CommonDomain;
import com.unis.user.server.entity.plug.PlugDeviceDO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * PLUG_DEVICE-视频监控表
 * DO处理自身,VO处理包括子表
 * @author lipenghe at 2019-11-20 19:45:42
 */
@Component
@Transactional
public class PlugDeviceDomain {

    @Autowired
    PlugDeviceDao plugDeviceDao;

    @Autowired
    CommonDomain commonDomain;
   /**
    * 通用的插入处理
    * @param entity    <视频监控表>对象
    */
    private void buildInsertData(PlugDeviceDO entity){
        String pk=null;
        //当前为主表
        pk= commonDomain.selectByTableNameAndAttr(EntityUtil.getTableName(PlugDeviceDO.class)
        ,"DEVID", "DE", 8);
        entity.setDevid(pk);
        entity.buildInsertData(pk);
    }

   /**
    * 通用的更新处理
    * @param entity    <视频监控表>对象
    */
    private void buildUpdateData(PlugDeviceDO entity){
        entity.buildUpdateData();
    }

    /**
    * 通用的返回数据处理
    * @param plugDeviceVO    <视频监控表>对象
    */
    private PlugDeviceVO buildResult(PlugDeviceVO plugDeviceVO){
        PlugDeviceVO plugDeviceVOResult=new PlugDeviceVO();
        plugDeviceVOResult.setDevid(plugDeviceVO.getDevid());
        return plugDeviceVOResult;
    }

    /**
     * <PLUG_DEVICE-视频监控表>插入全部字段
     * @param entity    <视频监控表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV 
     */
    public int insertEntity(PlugDeviceDO entity) {
        buildInsertData(entity);
        return plugDeviceDao.insert(entity);
    }

    /**
     * <PLUG_DEVICE-视频监控表>插入全部字段
     * @param plugDeviceVO    <视频监控表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper insertEntity(PlugDeviceVO plugDeviceVO) {
        //有属性操作则优先在vo处理
        PlugDeviceDO entity= JsonUtils.parse(
            JsonUtils.serialize(plugDeviceVO), PlugDeviceDO.class);
        int num= insertEntity(entity);
        if(num>0){
            //主键设置回去
            plugDeviceVO.setDevid(entity.getDevid());
            return ResponseWrapper.success(buildResult(plugDeviceVO));
        }
        return ResponseWrapper.fail();
    }

    /**
     * <PLUG_DEVICE-视频监控表>插入全部字段,可删除部分字段改为选择性插入
     * @param entity    <视频监控表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV 
     */
    public int insertEntitySelective(PlugDeviceDO entity) {
        buildInsertData(entity);
        return plugDeviceDao.insertSelective(entity);
    }

    /**
     * <PLUG_DEVICE-视频监控表>插入全部字段,可删除部分字段改为选择性插入
     * @param plugDeviceVO    <视频监控表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper insertEntitySelective(PlugDeviceVO plugDeviceVO) {
        //有属性操作则优先在vo处理
        PlugDeviceDO entity= JsonUtils.parse(
            JsonUtils.serialize(plugDeviceVO), PlugDeviceDO.class);
        int num= insertEntitySelective(entity);
        if(num>0){
            //主键设置回去
            plugDeviceVO.setDevid(entity.getDevid());
            return ResponseWrapper.success(buildResult(plugDeviceVO));
        }
        return ResponseWrapper.fail();
    }

    /**
     * <PLUG_DEVICE-视频监控表>更改状态
     * @param entity    <视频监控表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV 
     */
    public int updateStatusByEntity(PlugDeviceDO entity) {
        return plugDeviceDao.updateStatusByEntity(entity);
    }

    /**
     * <PLUG_DEVICE-视频监控表>更改状态
     * @param plugDeviceVO    <视频监控表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateStatusByEntity(PlugDeviceVO plugDeviceVO) {
        //有属性操作则优先在vo处理
        PlugDeviceDO entity= JsonUtils.parse(
            JsonUtils.serialize(plugDeviceVO), PlugDeviceDO.class);
        int num= updateStatusByEntity(entity);
        if(num>0){
            //主键设置回去(此处实际不需要)
            plugDeviceVO.setDevid(entity.getDevid());
            return ResponseWrapper.success(buildResult(plugDeviceVO));
        }
        return ResponseWrapper.fail();
    }

    /**
     * <PLUG_DEVICE-视频监控表>根据实体更新单条或者多条数据
     * @param entity    <视频监控表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV 
     */
    public int updateByEntity(PlugDeviceDO entity) {
        buildUpdateData(entity);
        return plugDeviceDao.updateByEntity(entity);
    }

    /**
     * <PLUG_DEVICE-视频监控表>根据实体更新单条或者多条数据
     * @param plugDeviceVO    <视频监控表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateByEntity(PlugDeviceVO plugDeviceVO) {
        //有属性操作则优先在vo处理
        PlugDeviceDO entity= JsonUtils.parse(
            JsonUtils.serialize(plugDeviceVO), PlugDeviceDO.class);
        int num= updateByEntity(entity);
        if(num>0){
            //主键设置回去(此处实际不需要)
            plugDeviceVO.setDevid(entity.getDevid());
            return ResponseWrapper.success(buildResult(plugDeviceVO));
        }
        return ResponseWrapper.fail();
    }

    /**
     * <PLUG_DEVICE-视频监控表>根据实体选择性更新
     * @param entity    <视频监控表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV 
     */
    public int updateByEntitySelective(PlugDeviceDO entity) {
        buildUpdateData(entity);
        return plugDeviceDao.updateByEntitySelective(entity);
    }

    /**
     * <PLUG_DEVICE-视频监控表>根据实体选择性更新(存在则更新,不存在则插入,其余删除)
     * @param plugDeviceVO    <视频监控表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateByEntitySelective(PlugDeviceVO plugDeviceVO) {
        //此处是直接更新,较为繁琐,适用于子表数据有关联(被其他数据使用),缺少排序在字段会出现顺序与修改数据的顺序不一致的问题,
        //有属性操作则优先在vo处理
        PlugDeviceDO entity= JsonUtils.parse(
            JsonUtils.serialize(plugDeviceVO), PlugDeviceDO.class);
        int num= updateByEntitySelective(entity);
        if(num>0){
            //主键设置回去(此处实际不需要)
            plugDeviceVO.setDevid(entity.getDevid());
            return ResponseWrapper.success(buildResult(plugDeviceVO));
        }
        return ResponseWrapper.fail();
    }

    /**
     * <PLUG_DEVICE-视频监控表>根据实体单条或者批量删除
     * @param plugDeviceVO    <视频监控表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper deleteByEntity(PlugDeviceVO plugDeviceVO) {
        int num= plugDeviceDao.deleteByEntity(plugDeviceVO);
        return ResponseWrapper.choose(num);
    }

    /**
    * <PLUG_DEVICE-视频监控表>根据实体单条或者批量删除
    * @param entity    <视频监控表>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public int deleteByEntity(PlugDeviceDO entity) {
        PlugDeviceVO plugDeviceVO= JsonUtils.parse(
            JsonUtils.serialize(entity), PlugDeviceVO.class);
        return plugDeviceDao.deleteByEntity(plugDeviceVO);
    }

    /**
     * <PLUG_DEVICE-视频监控表>根据实体假删除,根据实体属性单条或批量删除只是改变了状态不在页面显示,数据仍存在
     * @param plugDeviceVO    <视频监控表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper deleteShamByEntity(PlugDeviceVO plugDeviceVO) {
        //自行在controller设置状态,则可删除,亦可还原
        int num= plugDeviceDao.deleteShamByEntity(plugDeviceVO);
        return ResponseWrapper.choose(num);
    }

    /**
    * <PLUG_DEVICE-视频监控表>根据实体假删除,根据实体属性单条或批量删除只是改变了状态不在页面显示,数据仍存在
    * @param entity    <视频监控表>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public int deleteShamByEntity(PlugDeviceDO entity) {
        PlugDeviceVO plugDeviceVO= JsonUtils.parse(
            JsonUtils.serialize(entity), PlugDeviceVO.class);
        return plugDeviceDao.deleteShamByEntity(plugDeviceVO);
    }

    /**
     * <PLUG_DEVICE-视频监控表>根据实体查询数量
     * @param plugDeviceVO    <视频监控表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV 
     */
    public int selectCountByEntity(PlugDeviceVO plugDeviceVO) {
        int num= plugDeviceDao.selectCountByEntity(plugDeviceVO);
        return num;
    }

    /**
     * <PLUG_DEVICE-视频监控表>根据实体(唯一标示)查询一条数据
     * @param plugDeviceVO    <视频监控表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public PlugDeviceVO selectById(PlugDeviceVO plugDeviceVO) {
        PlugDeviceVO plugDeviceVODb= plugDeviceDao.selectById(plugDeviceVO);
        return plugDeviceVODb;
    }

    /**
    * <PLUG_DEVICE-视频监控表>根据实体(唯一标示)查询一条数据
    * @param entity    <视频监控表>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public PlugDeviceVO selectById(PlugDeviceDO entity) {
        PlugDeviceVO plugDeviceVO= JsonUtils.parse(
            JsonUtils.serialize(entity), PlugDeviceVO.class);
        return plugDeviceDao.selectById(plugDeviceVO);
    }

    /**
     * <PLUG_DEVICE-视频监控表>根据实体查询分页列表
     * @param plugDeviceVO    <视频监控表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV 
     */
    public Page<PlugDeviceVO> selectPageByEntity(int pageNo, int pageSize
        , PlugDeviceVO plugDeviceVO, String order) {
        PageHelper.startPage(pageNo,pageSize,order);
        return plugDeviceDao.selectPageByEntity(plugDeviceVO);
    }

    /**
    * <PLUG_DEVICE-视频监控表>根据实体查询列表
    * @param plugDeviceVO    <视频监控表>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public List<PlugDeviceVO> selectByEntity(PlugDeviceVO plugDeviceVO) {
        return plugDeviceDao.selectByEntity(plugDeviceVO);
    }

    /**
     * <PLUG_DEVICE-视频监控表>根据实体查询列表
     * @param entity    <视频监控表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public List<PlugDeviceVO> selectByEntity(PlugDeviceDO entity) {
        PlugDeviceVO plugDeviceVO= JsonUtils.parse(
            JsonUtils.serialize(entity), PlugDeviceVO.class);
        return plugDeviceDao.selectByEntity(plugDeviceVO);
    }

}
