/*
 * RoleDomain.java
 * 版权所有 © 2011-2017 北京神舟良实信息技术有限公司
 * Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
 * 2020-07-06 17:12:10 created by lipenghe with LAPTOP-IJQ2SDFV
 */
package com.unis.user.server.domain.role;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.unis.common.utils.EntityUtil;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.user.common.vo.role.RoleVO;
import com.unis.user.server.dao.RoleDao;
import com.unis.user.server.domain.common.CommonDomain;
import com.unis.user.server.dto.RoleInfoDTO;
import com.unis.user.server.entity.role.RoleDO;
import com.unis.user.server.model.RoleInfoVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * SYS_ROLE_INFO-角色
 * DO处理自身,VO处理包括子表
 * @author lipenghe at 2020-07-06 17:12:10
 */
@Component
@Transactional
public class RoleDomain {

    @Autowired
    RoleDao roleDao;

    @Autowired
    CommonDomain commonDomain;
   /**
    * 通用的插入处理
    * @param entity    <角色>对象
    */
    private void buildInsertData(RoleDO entity){
        String pk=null;
        //当前为主表
        pk= commonDomain.selectByTableNameAndAttr(EntityUtil.getTableName(RoleDO.class), "ROLE_CODE", "RO", 8);
        entity.setRoleCode(pk);
        entity.buildInsertData(pk);
    }

   /**
    * 通用的更新处理
    * @param entity    <角色>对象
    */
    private void buildUpdateData(RoleDO entity){
        entity.buildUpdateData();
    }

    /**
    * 通用的返回数据处理
    * @param roleVO    <角色>对象
    */
    private RoleVO buildResult(RoleVO roleVO){
        RoleVO roleVOResult=new RoleVO();
        roleVOResult.setRoleCode(roleVO.getRoleCode());
        return roleVOResult;
    }

    /**
    * 通用的数据处理
    * @param roleVO    <角色>对象
    */
    private void buildData(RoleVO roleVO){
        //RoleVO roleVODb= selectById(roleVO);
    }

    /**
    * <SYS_ROLE_INFO-角色>非主键的业务唯一属性校验
    * @param roleVO    <角色>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public ResponseWrapper uniqueCheck(RoleVO roleVO) {
        return ResponseWrapper.success();
    }

    /**
     * <SYS_ROLE_INFO-角色>插入全部字段
     * @param entity    <角色>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int insertEntity(RoleDO entity) {
        buildInsertData(entity);
        return roleDao.insert(entity);
    }

    /**
     * <SYS_ROLE_INFO-角色>插入全部字段
     * @param roleVO    <角色>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper insertEntity(RoleVO roleVO) {
        ResponseWrapper responseWrapper= uniqueCheck(roleVO);
        if(responseWrapper.isSuccess()){
            buildData(roleVO);
            //有属性操作则优先在vo处理
            RoleDO entity= JsonUtils.parse(
                JsonUtils.serialize(roleVO), RoleDO.class);
            int num= insertEntity(entity);
            if(num>0){
                //主键设置回去
                roleVO.setRoleCode(entity.getRoleCode());
                return ResponseWrapper.success(buildResult(roleVO));
            }
            return ResponseWrapper.fail();
        }else{
            return responseWrapper;
        }
    }

    /**
     * <SYS_ROLE_INFO-角色>选择性插入字段
     * @param entity    <角色>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int insertEntitySelective(RoleDO entity) {
        buildInsertData(entity);
        return roleDao.insertSelective(entity);
    }

    /**
     * <SYS_ROLE_INFO-角色>选择性插入字段
     * @param roleVO    <角色>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper insertEntitySelective(RoleVO roleVO) {
        ResponseWrapper responseWrapper= uniqueCheck(roleVO);
        if(responseWrapper.isSuccess()){
            buildData(roleVO);
            //有属性操作则优先在vo处理
            RoleDO entity= JsonUtils.parse(
                JsonUtils.serialize(roleVO), RoleDO.class);
            int num= insertEntitySelective(entity);
            if(num>0){
                //主键设置回去
                roleVO.setRoleCode(entity.getRoleCode());
                return ResponseWrapper.success(buildResult(roleVO));
            }
            return ResponseWrapper.fail();
        }else{
            return responseWrapper;
        }
    }

    /**
     * <SYS_ROLE_INFO-角色>更改状态
     * @param entity    <角色>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int updateStatusByEntity(RoleDO entity) {
        buildUpdateData(entity);
        return roleDao.updateStatusByEntity(entity);
    }

    /**
     * <SYS_ROLE_INFO-角色>更改状态
     * @param roleVO    <角色>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateStatusByEntity(RoleVO roleVO) {
        ResponseWrapper responseWrapper= uniqueCheck(roleVO);
        if(responseWrapper.isSuccess()){
            buildData(roleVO);
            //有属性操作则优先在vo处理
            RoleDO entity= JsonUtils.parse(
                JsonUtils.serialize(roleVO), RoleDO.class);
            int num= updateStatusByEntity(entity);
            if(num>0){
                //主键设置回去(此处实际不需要)
                roleVO.setRoleCode(entity.getRoleCode());
                return ResponseWrapper.success(buildResult(roleVO));
            }else{
                return ResponseWrapper.fail();
            }
        }else{
            return responseWrapper;
        }
    }

    /**
     * <SYS_ROLE_INFO-角色>根据实体某些属性更新全部字段
     * @param entity    <角色>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int updateByEntity(RoleDO entity) {
        buildUpdateData(entity);
        return roleDao.updateByEntity(entity);
    }

    /**
     * <SYS_ROLE_INFO-角色>根据实体某些属性更新全部字段
     * @param roleVO    <角色>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateByEntity(RoleVO roleVO) {
        ResponseWrapper responseWrapper= uniqueCheck(roleVO);
        if(responseWrapper.isSuccess()){
            buildData(roleVO);
            //有属性操作则优先在vo处理
            RoleDO entity= JsonUtils.parse(
                JsonUtils.serialize(roleVO), RoleDO.class);
            int num= updateByEntity(entity);
            if(num>0){
                //主键设置回去(此处实际不需要)
                roleVO.setRoleCode(entity.getRoleCode());
                return ResponseWrapper.success(buildResult(roleVO));
            }
            return ResponseWrapper.fail();
        }else{
            return responseWrapper;
        }
    }

    /**
     * <SYS_ROLE_INFO-角色>根据实体不为空的属性,选择性更新字段
     * @param entity    <角色>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int updateByEntitySelective(RoleDO entity) {
        buildUpdateData(entity);
        return roleDao.updateByEntitySelective(entity);
    }

    /**
     * <SYS_ROLE_INFO-角色>根据实体不为空的属性,选择性更新字段(存在则更新,不存在则插入,其余删除)
     * @param roleVO    <角色>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateByEntitySelective(RoleVO roleVO) {
        ResponseWrapper responseWrapper= uniqueCheck(roleVO);
        if(responseWrapper.isSuccess()){
            buildData(roleVO);
            //此处是直接更新,较为繁琐,适用于子表数据有关联(被其他数据使用),缺少排序在字段会出现顺序与修改数据的顺序不一致的问题,
            //有属性操作则优先在vo处理
            RoleDO entity= JsonUtils.parse(
                JsonUtils.serialize(roleVO), RoleDO.class);
            int num= updateByEntitySelective(entity);
            if(num>0){
                //主键设置回去(此处实际不需要)
                roleVO.setRoleCode(entity.getRoleCode());
                return ResponseWrapper.success(buildResult(roleVO));
            }
            return ResponseWrapper.fail();
        }else{
            return responseWrapper;
        }
    }

    /**
     * <SYS_ROLE_INFO-角色>[真删除]根据实体的某些属性进行单条或者批量删除
     * @param roleVO    <角色>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper deleteByEntity(RoleVO roleVO) {
        int num= roleDao.deleteByEntity(roleVO);
        return ResponseWrapper.choose(num);
    }

    /**
    * <SYS_ROLE_INFO-角色>[真删除]根据实体的某些属性进行单条或者批量删除
    * @param entity    <角色>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public int deleteByEntity(RoleDO entity) {
        RoleVO roleVO= JsonUtils.parse(
            JsonUtils.serialize(entity), RoleVO.class);
        return roleDao.deleteByEntity(roleVO);
    }

    /**
     * <SYS_ROLE_INFO-角色>[假删除]根据实体的某些属性进行单条或者批量删除,根据实体属性单条或批量删除只是改变了状态不在页面显示,数据仍存在
     * @param roleVO    <角色>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper deleteShamByEntity(RoleVO roleVO) {
        //自行在controller设置状态,则可删除,亦可还原
        int num= roleDao.deleteShamByEntity(roleVO);
        return ResponseWrapper.choose(num);
    }

    /**
    * <SYS_ROLE_INFO-角色>[假删除]根据实体的某些属性进行单条或者批量删除,根据实体属性单条或批量删除只是改变了状态不在页面显示,数据仍存在
    * @param entity    <角色>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public int deleteShamByEntity(RoleDO entity) {
        RoleVO roleVO= JsonUtils.parse(
            JsonUtils.serialize(entity), RoleVO.class);
        return roleDao.deleteShamByEntity(roleVO);
    }

    /**
     * <SYS_ROLE_INFO-角色>根据实体的某些属性查询数量
     * @param roleVO    <角色>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int selectCountByEntity(RoleVO roleVO) {
        int num= roleDao.selectCountByEntity(roleVO);
        return num;
    }

    /**
     * <SYS_ROLE_INFO-角色>根据实体的业务唯一属性(且非指定主键数据)判断是否存在
     * @param roleVO    <角色>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int selectExistsByEntity(RoleVO roleVO) {
        int num= roleDao.selectExistsByEntity(roleVO);
        return num;
    }

    /**
     * <SYS_ROLE_INFO-角色>根据实体(唯一标示)查询一条数据
     * @param roleVO    <角色>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public RoleVO selectById(RoleVO roleVO) {
        RoleVO roleVODb= roleDao.selectById(roleVO);
        return roleVODb;
    }

    /**
    * <SYS_ROLE_INFO-角色>根据实体(唯一标示)查询一条数据
    * @param entity    <角色>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public RoleVO selectById(RoleDO entity) {
        RoleVO roleVO= JsonUtils.parse(
            JsonUtils.serialize(entity), RoleVO.class);
        return roleDao.selectById(roleVO);
    }

    /**
     * <SYS_ROLE_INFO-角色>根据实体的某些属性查询分页数据
     * @param roleVO    <角色>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    /*public Page<RoleVO> selectPageByEntity(int pageNo, int pageSize
        , RoleVO roleVO, String order) {
        PageHelper.startPage(pageNo,pageSize,order);
        return roleDao.selectPageByEntity(roleVO);
    }*/

    /**
     * <SYS_ROLE_INFO-角色>根据实体的某些属性查询分页数据
     * @param roleInfoVO    <角色>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public Page<RoleInfoVO> selectPageByEntity(int pageNo, int pageSize, RoleInfoVO roleInfoVO, String order) {
        PageHelper.startPage(pageNo,pageSize,order);
        return roleDao.selectPageByEntity(roleInfoVO);
    }

    /**
    * <SYS_ROLE_INFO-角色>根据实体的某些属性查询列表
    * @param roleInfoVO    <角色>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public List<RoleInfoVO> selectByEntity(RoleInfoVO roleInfoVO) {
        return roleDao.selectByEntity(roleInfoVO);
    }

    /**
     * <SYS_ROLE_INFO-角色>根据实体的某些属性查询列表
     * @param entity    <角色>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public List<RoleInfoVO> selectByEntity(RoleDO entity) {
        RoleInfoVO roleVO= JsonUtils.parse(
            JsonUtils.serialize(entity), RoleInfoVO.class);
        return roleDao.selectByEntity(roleVO);
    }

}
