/*
 * UserRoleReletedDomain.java
 * 版权所有 © 2011-2017 北京神舟良实信息技术有限公司
 * Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
 * 2020-07-06 15:41:41 created by lipenghe with LAPTOP-IJQ2SDFV
 */
package com.unis.user.server.domain.role;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.user.common.vo.role.UserRoleReletedVO;
import com.unis.user.server.dao.UserRoleReletedDao;
import com.unis.user.server.entity.role.UserRoleReletedDO;
import com.unis.user.server.untils.IdWorker;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * SYS_USER_ROLE_RELATED-角色关联
 * DO处理自身,VO处理包括子表
 * @author lipenghe at 2020-07-06 15:41:41
 */
@Component
@Transactional
public class UserRoleReletedDomain {

    @Autowired
    UserRoleReletedDao userRoleReletedDao;

    @Autowired
    IdWorker idWorker;

   /**
    * 通用的插入处理
    * @param entity    <角色关联>对象
    */
    private void buildInsertData(UserRoleReletedDO entity){
        long pk=idWorker.nextId();
        entity.setRoleRelatedId(pk);
        entity.buildInsertData();
    }

   /**
    * 通用的更新处理
    * @param entity    <角色关联>对象
    */
    private void buildUpdateData(UserRoleReletedDO entity){
        entity.buildUpdateData();
    }

    /**
    * 通用的返回数据处理
    * @param roleReletedVO    <角色关联>对象
    */
    private UserRoleReletedVO buildResult(UserRoleReletedVO roleReletedVO){
        UserRoleReletedVO roleReletedVOResult=new UserRoleReletedVO();
        roleReletedVOResult.setRoleRelatedId(roleReletedVO.getRoleRelatedId());
        return roleReletedVOResult;
    }

    /**
    * 通用的数据处理
    * @param roleReletedVO    <角色关联>对象
    */
    private void buildData(UserRoleReletedVO roleReletedVO){
        //UserRoleReletedVO roleReletedVODb= selectById(roleReletedVO);
    }

    /**
    * <SYS_USER_ROLE_RELATED-角色关联>非主键的业务唯一属性校验
    * @param roleReletedVO    <角色关联>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public ResponseWrapper uniqueCheck(UserRoleReletedVO roleReletedVO) {
        boolean bl=true;
        //非主键的业务唯一数据校验
        if((roleReletedVO.getId() !=null)
            || (StringUtils.isNotEmpty(roleReletedVO.getIdStr()))){
            int num= userRoleReletedDao.selectExistsByEntity(roleReletedVO);
            bl = num==0;
        }
        if(bl){
            return ResponseWrapper.success();
        }else{
            return ResponseWrapper.fail();
        }
    }

    /**
     * <SYS_USER_ROLE_RELATED-角色关联>插入全部字段
     * @param entity    <角色关联>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int insertEntity(UserRoleReletedDO entity) {
        buildInsertData(entity);
        return userRoleReletedDao.insert(entity);
    }

    /**
     * <SYS_USER_ROLE_RELATED-角色关联>插入全部字段
     * @param roleReletedVO    <角色关联>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper insertEntity(UserRoleReletedVO roleReletedVO) {
        ResponseWrapper responseWrapper= uniqueCheck(roleReletedVO);
        if(responseWrapper.isSuccess()){
            buildData(roleReletedVO);
            //有属性操作则优先在vo处理
            UserRoleReletedDO entity= JsonUtils.parse(
                JsonUtils.serialize(roleReletedVO), UserRoleReletedDO.class);
            int num= insertEntity(entity);
            if(num>0){
                //主键设置回去
                roleReletedVO.setRoleRelatedId(entity.getRoleRelatedId());
                return ResponseWrapper.success(buildResult(roleReletedVO));
            }
            return ResponseWrapper.fail();
        }else{
            return responseWrapper;
        }
    }

    /**
     * <SYS_USER_ROLE_RELATED-角色关联>选择性插入字段
     * @param entity    <角色关联>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int insertEntitySelective(UserRoleReletedDO entity) {
        buildInsertData(entity);
        return userRoleReletedDao.insertSelective(entity);
    }

    /**
     * <SYS_USER_ROLE_RELATED-角色关联>选择性插入字段
     * @param roleReletedVO    <角色关联>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper insertEntitySelective(UserRoleReletedVO roleReletedVO) {
        ResponseWrapper responseWrapper= uniqueCheck(roleReletedVO);
        if(responseWrapper.isSuccess()){
            buildData(roleReletedVO);
            //有属性操作则优先在vo处理
            UserRoleReletedDO entity= JsonUtils.parse(
                JsonUtils.serialize(roleReletedVO), UserRoleReletedDO.class);
            int num= insertEntitySelective(entity);
            if(num>0){
                //主键设置回去
                roleReletedVO.setRoleRelatedId(entity.getRoleRelatedId());
                return ResponseWrapper.success(buildResult(roleReletedVO));
            }
            return ResponseWrapper.fail();
        }else{
            return responseWrapper;
        }
    }

    /**
     * <SYS_USER_ROLE_RELATED-角色关联>更改状态
     * @param entity    <角色关联>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int updateStatusByEntity(UserRoleReletedDO entity) {
        buildUpdateData(entity);
        return userRoleReletedDao.updateStatusByEntity(entity);
    }

    /**
     * <SYS_USER_ROLE_RELATED-角色关联>更改状态
     * @param roleReletedVO    <角色关联>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateStatusByEntity(UserRoleReletedVO roleReletedVO) {
        ResponseWrapper responseWrapper= uniqueCheck(roleReletedVO);
        if(responseWrapper.isSuccess()){
            buildData(roleReletedVO);
            //有属性操作则优先在vo处理
            UserRoleReletedDO entity= JsonUtils.parse(
                JsonUtils.serialize(roleReletedVO), UserRoleReletedDO.class);
            int num= updateStatusByEntity(entity);
            if(num>0){
                //主键设置回去(此处实际不需要)
                roleReletedVO.setRoleRelatedId(entity.getRoleRelatedId());
                return ResponseWrapper.success(buildResult(roleReletedVO));
            }else{
                return ResponseWrapper.fail();
            }
        }else{
            return responseWrapper;
        }
    }

    /**
     * <SYS_USER_ROLE_RELATED-角色关联>根据实体某些属性更新全部字段
     * @param entity    <角色关联>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int updateByEntity(UserRoleReletedDO entity) {
        buildUpdateData(entity);
        return userRoleReletedDao.updateByEntity(entity);
    }

    /**
     * <SYS_USER_ROLE_RELATED-角色关联>根据实体某些属性更新全部字段
     * @param roleReletedVO    <角色关联>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateByEntity(UserRoleReletedVO roleReletedVO) {
        ResponseWrapper responseWrapper= uniqueCheck(roleReletedVO);
        if(responseWrapper.isSuccess()){
            buildData(roleReletedVO);
            //有属性操作则优先在vo处理
            UserRoleReletedDO entity= JsonUtils.parse(
                JsonUtils.serialize(roleReletedVO), UserRoleReletedDO.class);
            int num= updateByEntity(entity);
            if(num>0){
                //主键设置回去(此处实际不需要)
                roleReletedVO.setRoleRelatedId(entity.getRoleRelatedId());
                return ResponseWrapper.success(buildResult(roleReletedVO));
            }
            return ResponseWrapper.fail();
        }else{
            return responseWrapper;
        }
    }

    /**
     * <SYS_USER_ROLE_RELATED-角色关联>根据实体不为空的属性,选择性更新字段
     * @param entity    <角色关联>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int updateByEntitySelective(UserRoleReletedDO entity) {
        buildUpdateData(entity);
        return userRoleReletedDao.updateByEntitySelective(entity);
    }

    /**
     * <SYS_USER_ROLE_RELATED-角色关联>根据实体不为空的属性,选择性更新字段(存在则更新,不存在则插入,其余删除)
     * @param roleReletedVO    <角色关联>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateByEntitySelective(UserRoleReletedVO roleReletedVO) {
        ResponseWrapper responseWrapper= uniqueCheck(roleReletedVO);
        if(responseWrapper.isSuccess()){
            buildData(roleReletedVO);
            //此处是直接更新,较为繁琐,适用于子表数据有关联(被其他数据使用),缺少排序在字段会出现顺序与修改数据的顺序不一致的问题,
            //有属性操作则优先在vo处理
            UserRoleReletedDO entity= JsonUtils.parse(
                JsonUtils.serialize(roleReletedVO), UserRoleReletedDO.class);
            int num= updateByEntitySelective(entity);
            if(num>0){
                //主键设置回去(此处实际不需要)
                roleReletedVO.setRoleRelatedId(entity.getRoleRelatedId());
                return ResponseWrapper.success(buildResult(roleReletedVO));
            }
            return ResponseWrapper.fail();
        }else{
            return responseWrapper;
        }
    }

    /**
     * <SYS_USER_ROLE_RELATED-角色关联>[真删除]根据实体的某些属性进行单条或者批量删除
     * @param roleReletedVO    <角色关联>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper deleteByEntity(UserRoleReletedVO roleReletedVO) {
        int num= userRoleReletedDao.deleteByEntity(roleReletedVO);
        return ResponseWrapper.choose(num);
    }

    /**
    * <SYS_USER_ROLE_RELATED-角色关联>[真删除]根据实体的某些属性进行单条或者批量删除
    * @param entity    <角色关联>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public int deleteByEntity(UserRoleReletedDO entity) {
        UserRoleReletedVO roleReletedVO= JsonUtils.parse(
            JsonUtils.serialize(entity), UserRoleReletedVO.class);
        return userRoleReletedDao.deleteByEntity(roleReletedVO);
    }

    /**
     * <SYS_USER_ROLE_RELATED-角色关联>[假删除]根据实体的某些属性进行单条或者批量删除,根据实体属性单条或批量删除只是改变了状态不在页面显示,数据仍存在
     * @param roleReletedVO    <角色关联>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper deleteShamByEntity(UserRoleReletedVO roleReletedVO) {
        //自行在controller设置状态,则可删除,亦可还原
        int num= userRoleReletedDao.deleteShamByEntity(roleReletedVO);
        return ResponseWrapper.choose(num);
    }

    /**
    * <SYS_USER_ROLE_RELATED-角色关联>[假删除]根据实体的某些属性进行单条或者批量删除,根据实体属性单条或批量删除只是改变了状态不在页面显示,数据仍存在
    * @param entity    <角色关联>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public int deleteShamByEntity(UserRoleReletedDO entity) {
        UserRoleReletedVO roleReletedVO= JsonUtils.parse(
            JsonUtils.serialize(entity), UserRoleReletedVO.class);
        return userRoleReletedDao.deleteShamByEntity(roleReletedVO);
    }
        /**
     * <SYS_USER_ROLE_RELATED-角色关联>根据实体的某些属性查询数量
     * @param roleReletedVO    <角色关联>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int selectCountByEntity(UserRoleReletedVO roleReletedVO) {
        int num= userRoleReletedDao.selectCountByEntity(roleReletedVO);
        return num;
    }

    /**
     * <SYS_USER_ROLE_RELATED-角色关联>根据实体的业务唯一属性(且非指定主键数据)判断是否存在
     * @param roleReletedVO    <角色关联>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int selectExistsByEntity(UserRoleReletedVO roleReletedVO) {
        int num= userRoleReletedDao.selectExistsByEntity(roleReletedVO);
        return num;
    }

    /**
     * <SYS_USER_ROLE_RELATED-角色关联>根据实体(唯一标示)查询一条数据
     * @param roleReletedVO    <角色关联>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public UserRoleReletedVO selectById(UserRoleReletedVO roleReletedVO) {
        UserRoleReletedVO roleReletedVODb= userRoleReletedDao.selectById(roleReletedVO);
        return roleReletedVODb;
    }

    /**
    * <SYS_USER_ROLE_RELATED-角色关联>根据实体(唯一标示)查询一条数据
    * @param entity    <角色关联>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public UserRoleReletedVO selectById(UserRoleReletedDO entity) {
        UserRoleReletedVO roleReletedVO= JsonUtils.parse(
            JsonUtils.serialize(entity), UserRoleReletedVO.class);
        return userRoleReletedDao.selectById(roleReletedVO);
    }

    /**
     * <SYS_USER_ROLE_RELATED-角色关联>根据实体的某些属性查询分页数据
     * @param roleReletedVO    <角色关联>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public Page<UserRoleReletedVO> selectPageByEntity(int pageNo, int pageSize
        , UserRoleReletedVO roleReletedVO, String order) {
        PageHelper.startPage(pageNo,pageSize,order);
        return userRoleReletedDao.selectPageByEntity(roleReletedVO);
    }

    /**
    * <SYS_USER_ROLE_RELATED-角色关联>根据实体的某些属性查询列表
    * @param roleReletedVO    <角色关联>对象
    * @author lipenghe with LAPTOP-IJQ2SDFV
    */
    public List<UserRoleReletedVO> selectByEntity(UserRoleReletedVO roleReletedVO) {
        return userRoleReletedDao.selectByEntity(roleReletedVO);
    }

    /**
     * <SYS_USER_ROLE_RELATED-角色关联>根据实体的某些属性查询列表
     * @param entity    <角色关联>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public List<UserRoleReletedVO> selectByEntity(UserRoleReletedDO entity) {
        UserRoleReletedVO roleReletedVO= JsonUtils.parse(
            JsonUtils.serialize(entity), UserRoleReletedVO.class);
        return userRoleReletedDao.selectByEntity(roleReletedVO);
    }

}
