package com.unis.user.server.feignclient;
import com.alibaba.fastjson.JSONObject;

import com.unis.base.common.vo.DKdxxsjyVO;
import com.unis.common.utils.ResponseWrapper;
import com.unis.user.common.vo.CompanyQueryVO;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.*;

/**
 * @author lidiaoquan
 * @version 1.0
 * @Title: BaseServerClient
 * @ProjectName cblservice
 * @Description: 公共基础服务
 * @date 2019年8月14日 下午2:45:17
 */
@FeignClient("base-server")
@Component
public interface BaseServerClient {

    /**
     * 根据企业机构代码查询企业
     *
     * @param qyjgdm
     * @return
     */
    @GetMapping(value = "/organization/{qyjgdm}")
    @ApiOperation(value = "根据企业机构代码查询企业", notes = "参数：企业机构代码")
    public ResponseWrapper selectQy(@RequestParam("qyjgdm") String qyjgdm);

    /**
     * @return 库点信息列表
     * @author huangxing
     * @Description 获取库点列表
     */
    @ApiOperation(value = "获取库点信息列表", notes = "参数：库点名称，粮库类别，企业编号，企业名称，库点企业性质")
    @PostMapping(value = "/dKdxxsjy/getDKdxxsjyList")
    public ResponseWrapper getDKdxxsjyList(@RequestBody JSONObject dKdxxsjyVO);

    /**
     * @param
     * @return 粮食库存列表
     * @author zhengbodang
     * @Description 获取粮食库存列表
     */
    @ApiOperation(value = "粮食库存列表", notes = "参数：")
    @PostMapping(value = "/lskcxx/getTyLskcxxList")
    public ResponseWrapper getTyLskcxxList(@RequestBody JSONObject tyLskcxxVO);

    /**
     * @param
     * @return 粮食库存列表
     * @author zhengbodang
     * @Description 根据库点编号获取仓房列表
     */
    @ApiOperation(value = "根据库点编号获取仓房列表", notes = "参数：")
    @PostMapping(value = "/dCfxxsjy/getDCfxxxsjyList")
    public ResponseWrapper getDCfxxxsjyList(@RequestBody JSONObject tyLskcxxVO);

    /**
     * @param
     * @return 粮食库存列表
     * @author zhengbodang
     * @Description 根据库点编号获取油罐信息列表
     */
    @ApiOperation(value = "根据库点编号获取油罐信息列表", notes = "参数：kddm")
    @PostMapping(value = "/dYgxxsjy/getDYgxxxsjyList")
    public ResponseWrapper getDYgxxxsjyList(@RequestBody JSONObject tyLskcxxVO);


    @ApiOperation(value = "获取库点信息列表", notes = "参数：统一社会信用代码")
    @GetMapping(value = "/sinkpointList/{tyshxydm}")
    public ResponseWrapper getDKdxxsjyInfoBytyshxydm(@PathVariable("tyshxydm") String tyshxydm);

    @ApiOperation(value = "通过统一社会信用代码查询企业", notes = "通过统一社会信用代码查询企业")
    @GetMapping(value = "/company/{tyshxydm}")
    ResponseWrapper findComanyByTyshxydm(@PathVariable("tyshxydm") String tyshxydm);

    @ApiOperation(value = "通过企业名称查询企业", notes = "通过企业名称查询企业")
    @GetMapping(value = "/findByCompany/{qymc}")
    ResponseWrapper findByCompany(@PathVariable("qymc")String qymc);

    @ApiOperation(value = "获取企业信息列表", notes = "参数：社会统一行政编码，企业名称，企业类型，企业性质，法定代表人，企业状态")
    @PostMapping(value = "/companyList")
    ResponseWrapper getCompanyList(@RequestBody CompanyQueryVO companyQueryVO);

    @ApiOperation(value = "获取库点信息列表,带组织机构id", notes = "参数：库点名称，粮库类别，企业编号，企业名称，库点企业性质")
    @PostMapping(value = "/selectKdxx")
    public ResponseWrapper selectKdxx(@RequestBody DKdxxsjyVO dKdxxsjyVO);
    @ApiOperation(value = "获取库点信息列表,带组织机构id", notes = "参数：库点名称，粮库类别，企业编号，企业名称，库点企业性质")

    @PostMapping(value = "/selectKdxxLgd")
    ResponseWrapper selectKdxxLgd(@RequestBody DKdxxsjyVO dKdxxsjyVO);
    @PostMapping(value = "/selectKdxxLgdForQc")
    ResponseWrapper selectKdxxLgdForQc(@RequestBody DKdxxsjyVO dKdxxsjyVO);
/*
    com.unis.user.server.untils.ResponseWrapper getCompanyInfoByDwdm(String dwdm);
*/
}
