package com.unis.user.server.model;

import com.alibaba.fastjson.annotation.JSONField;
import com.fasterxml.jackson.annotation.JsonFormat;
import lombok.Getter;
import lombok.Setter;
import org.springframework.format.annotation.DateTimeFormat;

import javax.persistence.*;
import java.io.Serializable;
import java.util.Date;

/**
 * 基础实体类
 * 所有继承该实体类的实体在映射成表的时候会自动加入该类中的字段
 *
 * @author Garfield
 */
@Getter
@Setter
@MappedSuperclass
public abstract class BaseEntity implements Serializable {


    @Version
    @JSONField(serialize = false)
    private Integer version;
    /**
     * -- 状态，1：正常，0：已作废
     */
    @JSONField(serialize = false)
    private Integer stateCode = 1;
    /**
     * 创建时间
     */
    @Temporal(TemporalType.TIMESTAMP)
    @JSONField(serialize = false, format = "yyyy-MM-dd HH:mm:ss")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date createDate;
    /**
     * 创建人编码
     */
    @JSONField(serialize = false)
    private String creatorCode;
    /**
     * 创建人
     */
    @JSONField(serialize = false)
    private String creator;
    /**
     * 更新时间
     */
    @Temporal(TemporalType.TIMESTAMP)
    @JSONField(serialize = false, format = "yyyy-MM-dd HH:mm:ss")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date refreshTime;
    /**
     * 更新人
     */
    @JSONField(serialize = false)
    private String refresher;

    /**
     * 更新人编码
     */
    @JSONField(serialize = false)
    private String refresherCode;

    /**
     * 备注
     */
    private String remark;

}
