package com.unis.user.server.model;


import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;

import javax.persistence.*;
import java.sql.Clob;
import java.util.Date;


/**
 * 功能描述：用户实体类
 *
 * @author
 * @data 2017年11月-19日
 * @time 14时20分
 * @JsonIgnoreProperties jsonplugin用的是java的内审机制.hibernate会给被管理的pojo加入一个hibernateLazyInitializer属性，
 * jsonplugin通过java的反射机制将pojo转换成json，会把hibernateLazyInitializer也拿出来操作,但是hibernateLazyInitializer无法由反射得到
 * 此注解可以忽略属性，many-to-one 时，加在one上面
 */
@Getter
@Setter
@ToString
@Entity
@Table(name = "SYS_USER_INFO")
@JsonIgnoreProperties(ignoreUnknown = true)
@SuppressWarnings("all")
public class UserPO extends BaseEntity {


    //用户代码 (U201809000001)
    @Id
    @Column(name = "USER_CODE", length = 32)
    private String userCode;

    //登录名称
    @Column(name = "USER_LOGINNAME", length = 32)
    private String userLoginName;

    //用户实际姓名
    @Column(name = "USER_NAME", length = 32)
    private String userName;

    //手机 唯一性校验
    @Column(name = "USER_MOBILE",length = 11)
    private String userMobile;

    //用户类型: 1 个人; 2 集团用户
    @Column(name = "USER_TYPE")
    private String userType;

    //密码	MD5加密
    @Column(name = "USER_PASSWORD",length = 64)
    private String userPassword;

    //性别
    @Column(name = "USER_SEX", length = 10)
    private String userSex;

    //用户头像信息
    @Column(name = "USER_IMGURL", length = 256)
    private String userImgurl;

    //用户职务
    @Column(name = "USER_TITLE", length = 64)
    private String userTitle;

    //户籍地址
    @Column(name = "RESIDENCE_ADDRESS", length = 255)
    private String residenceAddress;

    //现住址
    @Column(name = "CURRENT_ADDRESS",length = 255)
    private String currentAddress;

    //教育水平 10200001 本科；10200002 硕士； 10200003 博士；10200004 大专；10200005 中专；10200006 初中及以下
    @Column(name = "USER_EDUCATION",length = 10)
    private String userEducation;

    //所学专业
    @Column(name = "SPECIALITY", length = 50)
    private String speciality;

    //政治面貌 10210001 中共党员；10210002 其他党派；10210003 群众；
    @Column(name = "POLITICAL_STATUS", length = 12)
    private String politicalStatus;

    //所属部门编码
    @Column(name = "DEPT_CODE", length = 32)
    private String deptCode;

    //入职日期
    @Column(name = "ENTER_DATE")
    private Date enterDate;

    //离职标志(10220001-在职 10220002-离职 10220003-返聘 10220004-兼职)
    @Column(name = "IS_DIMISSION", length = 10)
    private String isDimission;

    // 离职日期
    @Column(name = "DIMISSION_DATE")
    private Date dimissionDate;

    //-- 职务   1023001 员工 10230002 部门经理 10230003 三级管理岗 10230004 二级管理岗 10230005 一级管理岗
    @Column(name = "HEADSHIP",length = 10)
    private String headship;

    //工作职责
    @Column(name = "BUTY")
    private String buty;

    //证件类型：10430001 身份证；10430002 护照；10430003 户口本；10430004 驾照
    @Column(name = "USER_CERTTYPE",length = 12)
    private String userCerttype;

    //证件号码
    @Column(name = "USER_CERTNO",length = 32)
    private String userCertno;

    //区域编码
    @Column(name = "COUNTY_CODE",length = 6)
    private String countyCode;

    //地址
    @Column(name = "USER_ADDRESS",length = 255)
    private String userAddress;

    //邮编
    @Column(name = "USER_POST",length = 6)
    private String userPost;

    //电话
    @Column(name = "USER_TEL",length = 18)
    private String userTel;

    //EMAIL
    @Column(name = "USER_MAIL",length = 100)
    private String userMail;

  //EMAIL
    @Column(name = "org_code",length = 100)
    private String orgCode;

    //是否禁用 0:未禁用；1：禁用；
    @Column(name = "IS_DISABLED",length = 1)
    private Integer isDisavled=0;

    //区域名
    @Column(name = "AREA_NAME")
    private String areaName;

    //区域名
    @Column(name = "DEPT_CODEN")
    private Clob deptCoden;

    //用户标示,1管理员,默认0
    @Column(name = "USER_MARK")
    private String userMark="0";

    //编制类型
    @Column(name = "bzlx")
    private String bzlx;

    /** 签章*/
    @Column(name = "seals")
    private String seals;

    @Column(name = "is_dev")
    /** 测试账号 0 正常账号 <br/>1 开发用*/
    private Integer isDev;
}
