package com.unis.user.server.repository;


import com.unis.user.server.model.DepartmentPO;
import com.unis.user.server.model.UserPO;
import org.springframework.data.domain.Sort;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.JpaSpecificationExecutor;
import org.springframework.stereotype.Repository;

import java.io.Serializable;
import java.util.List;

/**
 */
@Repository
public interface DepartmentRepository extends JpaRepository<DepartmentPO, Serializable>, JpaSpecificationExecutor<DepartmentPO> {

    /**
     * 根据部门编码查询详细信息
     * @param deptCode
     * @param i
     * @return
     */
    DepartmentPO findByDeptCodeAndStateCode(String deptCode, int i);

    /**
	 * 根据部门名称查询是否存在
	 * @param deptName
	 * @param i
	 * @return
	 */
	DepartmentPO findByDeptNameAndStateCode(String deptName, int i);

	/**
	 * 根据部门名称查询是否存在
	 * @param deptName
	 * @param i
	 * @return
	 */
	List<DepartmentPO> findByParentCodeAndDeptNameAndStateCode(String parentCode, String deptName, int i);


    /***
     * 删除
     * @param deptCode
     * @param i
     * @return
     */
    List<DepartmentPO> findByDeptCodeInAndStateCode(List<String> deptCode, int i);

    List<DepartmentPO> findByParentCodeAndStateCode(String s, int i, Sort sort);

	/**
	 * @param orgCode
	 * @param sort 
	 * @param i
	 * @return根据组织信息获取下级部门
	 */
	List<DepartmentPO> findByOrgCodeAndStateCode(String orgCode, int stateCode, Sort sort);

	List<DepartmentPO> findByOrgCodeAndDeptTypeAndStateCode(String orgCode,String deptType, int stateCode, Sort sort);

	/**
	 * @param resources
	 * @param i
	 * @param sort
	 * @return根据组织信息获取部门信息
	 */
	List<DepartmentPO> findByOrgCodeInAndStateCode(String[] resources, int i, Sort sort);

	List<DepartmentPO> findByOrgCodeAndStateCodeAndParentCode(String orgCode, int i, String string, Sort sort);

	/**
	 * @param orgCode
	 * @return根据组织查询部门
	 */
	List<DepartmentPO> findByOrgCodeLike(String orgCode);

	List<DepartmentPO> findByDeptCodeLike(String string);

    List<DepartmentPO> findByStateCode(int i);


	List<DepartmentPO> findByStateCodeAndParentCode(int i, String string);

    DepartmentPO findByDeptNameAndOrgCodeAndStateCode(String deptName, String orgCode, int i);

	DepartmentPO findByOrgCodeAndDeptNameAndParentCodeAndStateCode(String orgCode, String deptName, String dp, int i);
}
