package com.unis.user.server.repository;

import com.unis.user.server.model.OrgainzeVO;
import org.springframework.data.domain.Sort;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.JpaSpecificationExecutor;
import org.springframework.data.jpa.repository.Modifying;
import org.springframework.data.jpa.repository.Query;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import java.io.Serializable;
import java.util.List;

@Repository
@Transactional(propagation = Propagation.NESTED, rollbackFor = Exception.class)
public interface OrgainzeRepository extends JpaRepository<OrgainzeVO,Serializable>,JpaSpecificationExecutor <OrgainzeVO>{

	/**
	 * @param orgCode
	 * @return 根据组织编号获取组织信息
	 */
	OrgainzeVO findByOrgCodeAndStateCode(String orgCode,Integer stateCode);

	List<OrgainzeVO> findByOrgLevelAndStateCode(String orgCode,Integer stateCode);

	/**
	 * @param orgCode
	 * @param userName
	 * @param userId
	 * @return根据code删除组织信息
	 */
	@Modifying
	@Query(value="update SYS_ORGAINZE "
			+ "set REFRESHER = ?2,"
			+ "REFRESHER_CODE = ?3,"
			+ "STATE_CODE = 0,"
			+ "REFRESH_TIME = now()"
			+ " where ORG_CODE = ?1",nativeQuery = true)
	int deleteByOrgCode(String orgCode, String userName, String userId);

	/**
	 * @param orgCode
	 * @param stateCode
	 * @param sort
	 * @return 根据父节点获取组织信息
	 */
	List<OrgainzeVO> findByParentCodeAndStateCode(String orgCode, Integer stateCode, Sort sort);

	/**
	 * @param orgName
	 * @param stateCode
	 * @return根据组织名称查询组织是否存在
	 */
	OrgainzeVO findByOrgNameAndStateCode(String orgName, Integer stateCode);

	/**
	 * @param areaCode
	 * @param i
	 * @param sort
	 * @return根据区域编码获取组织者信息
	 */
	List<OrgainzeVO> findByCountyCodeAndStateCode(String areaCode, int i, Sort sort);

	/**
	 * @param orgCode
	 * @param stateCode
	 * @param sort
	 * @return 根据父节点以及组织类型获取组织信息
	 */
	List<OrgainzeVO> findByParentCodeAndStateCodeAndOrgType(String orgCode, int stateCode, String orgType, Sort sort);

	/**
	 * 查询未删除得所有机构
	 * @param i
	 * @return
	 */
	List<OrgainzeVO> findByStateCode(int i);

	OrgainzeVO findByOrgCodeAndStateCodeAndOrgTypeLike(String orgCode, int i, String string);

	List<OrgainzeVO> findByParentCodeAndStateCodeAndOrgTypeLike(String orgCode, int i, String string, Sort sort);

	List<OrgainzeVO> findByOrgTypeAndStateCode(String orgType, int i);

	OrgainzeVO findByOrgTypeAndStateCodeAndOrgCode(String orgType, int i,String orgId);

	@Modifying
	@Query(value="select * from sys_orgainze t " +
			"where t.org_name like '__区%' " +
			"and t.state_code='1' " +
			"union " +
			"select * from sys_orgainze t " +
			"where t.org_name = '天津利达粮油有限公司' " +
			"and t.state_code='1' " +
			"union " +
			"select * from sys_orgainze t " +
			"where t.org_name = '天津市粮食储备有限公司' " +
			"and t.state_code='1' " +
			"union " +
			"select * from sys_orgainze t " +
			"where t.org_name like '滨海新区%' " +
			"and t.state_code='1'",nativeQuery = true)
	List<OrgainzeVO> findOrgInfo(String orgCode);

	/**
	 * 根据行政区域和机构类型查询数据
	 * @param areaCode
	 * @param orgType
	 * @param string
	 * @return
	 */
	List<OrgainzeVO> findByCountyCodeAndOrgTypeAndStateCode(String areaCode, String orgType, Integer string);

	/**
	 *
	 * @param orgName
	 * @param i
	 * @param parentCode
	 * @return根据组织名称查询组织
	 */
	OrgainzeVO findByOrgNameAndStateCodeAndParentCode(String orgName, Integer i, String parentCode);

	@Modifying
	@Query(value = "select * FROM sys_orgainze " +
			"where state_code='1' " +
			"and org_code like ?% order  by org_code",nativeQuery = true)
	List<OrgainzeVO> findCurrentAndChilds(String orgCode);

    @Modifying
    @Query(value = "select * from sys_orgainze where org_level = '10180007' and  org_type = '10190001' and state_code = 1 order by order_by ", nativeQuery = true)
    List<OrgainzeVO> listDevAndRef();

    @Modifying
    @Query(value = "select * FROM sys_orgainze " +
            "where state_code='1' " +
            "start with parent_code like ?%  " +
            "order by org_code ",nativeQuery = true)
    List<OrgainzeVO> listAllChild(String orgCode);


    List<OrgainzeVO> findByOrgLevelAndOrgTypeAndStateCode(String orgLevel, String orgType,Integer stateCode);

    @Modifying
    @Query(value = "select * FROM sys_orgainze " +
            "where state_code='1' and org_level = '10180005' and parent_code = 'LS001'" +
            "order by order_by, org_code ",nativeQuery = true)
    List<OrgainzeVO> listChildUnit();

    List<OrgainzeVO> findByOrgLevelAndOrgTypeAndStateCode(String orgLevel, String orgType,Integer stateCode, Sort sort);

    @Modifying
    @Query(value = "select * FROM sys_orgainze " +
            "where state_code='1' and org_level in('10180008', '10180009')  and org_type = '10190008'" +
            "order by order_by, org_code ",nativeQuery = true)
    List<OrgainzeVO> listWarehouse();

    @Modifying
    @Query(value = "select * from sys_orgainze where state_code = 1 and org_level = ?1 and parent_code = ?2 order by order_by", nativeQuery = true)
    List<OrgainzeVO> listByOrgLevelAndParentOrg(String orgLevel, String parentCode);
}


