package com.unis.user.server.repository;

import com.unis.user.server.model.ParaConfigVO;

import org.springframework.data.domain.Sort;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.JpaSpecificationExecutor;
import org.springframework.data.jpa.repository.Modifying;
import org.springframework.data.jpa.repository.Query;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import java.io.Serializable;
import java.util.List;

@Repository
@Transactional(propagation = Propagation.NESTED, rollbackFor = Exception.class)
public interface ParaConfigRepository extends JpaRepository<ParaConfigVO,Serializable>,JpaSpecificationExecutor <ParaConfigVO>{

	/**
	 * @param paraCode
	 * @param i
	 * @return 根据参数类型Code获取参数信息
	 */
	List<ParaConfigVO> findParaConfigByParaCodeAndStateCode(String paraCode, Integer i, Sort sort);

	/**
	 * @param configCode
	 * @return根据参数code获取参数信息
	 */
	ParaConfigVO findByConfigCodeAndStateCode(String configCode, Integer i);

	/**
	 * @param configCode
	 * @param configName
	 * @param configValue
	 * @param configLastValue
	 * @param configNameEn
	 * @param pym
	 * @param orderBy
	 * @param userId
	 * @param userName
	 * @return更新参数表信息
	 */
	@Modifying
	@Query(value="update BAS_PARA_CONFIG "
			+ "set CONFIG_NAME = ?2, "
			+ "CONFIG_VALUE = ?3, "
			+ "CONFIG_LAST_VALUE = ?4, "
			+ "CONFIG_NAME_EN = ?5, "
			+ "PYM = ?6, "
			+ "ORDER_BY = ?7, "
			+ "REFRESHER = ?9, "
			+ "REFRESHER_CODE = ?8, "
			+ "REFRESH_TIME = now() "
			+ " where CONFIG_CODE = ?1",nativeQuery = true)
	public void upByConfigCode(String configCode, String configName, String configValue, String configLastValue, String configNameEn,
			String pym, String orderBy, String userId, String userName);
	/**
	 * @param config
	 * @param userName
	 * @param userId
	 * @return删除字典信息
	 */
	@Modifying
	@Query(value="delete BAS_PARA_CONFIG where CONFIG_CODE = ?1",nativeQuery = true)
	int deleteByConfigCode(String config);

}


