package com.unis.user.server.repository;

import com.unis.user.server.model.ParaConfigVO;
import com.unis.user.server.model.ParaVO;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.JpaSpecificationExecutor;
import org.springframework.data.jpa.repository.Modifying;
import org.springframework.data.jpa.repository.Query;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import java.io.Serializable;
import java.util.List;

@Repository
@Transactional(propagation = Propagation.NESTED, rollbackFor = Exception.class)
public interface ParaRepository extends JpaRepository<ParaVO,Serializable>,JpaSpecificationExecutor <ParaVO>{

	/**
	 * @param paraVO
	 * @return根据paracode获取参数
	 */

	ParaVO findByParaCode(String paraCode);


	/**
	 * @param paraCode
	 * @param paraName
	 * @param tableName
	 * @param tableField
	 * @param userName 
	 * @param userId 
	 * @return删除信息
	 */
	@Modifying
	@Query(value="update BAS_PARAMETER set TABLE_NAME = ?3 , PARA_NAME = ?2 , TABLE_FIELD = ?4 , REFRESHER = ?6,REFRESHER_CODE = ?5,REFRESH_TIME = now() where PARA_CODE = ?1",nativeQuery = true)
	int update(String paraCode,String paraName, String tableName, String tableField, String userId, String userName);

	/**
	 * @param para
	 * @return进行批量删除
	 */
	@Transactional
	@Modifying(clearAutomatically = true)
	@Query(value="delete BAS_PARAMETER where PARA_CODE = ?1",nativeQuery = true)
	void deleteByParaCode(String para);


	/**
	 * @param string
	 * @return查询所有可以使用的参数类型
	 */
	List<ParaVO> findByStateCode(Integer status);


	ParaVO findByParaCodeAndStateCode(String paraCode, Integer i);

}


