package com.unis.user.server.repository;

import java.io.Serializable;
import java.util.List;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.JpaSpecificationExecutor;
import org.springframework.data.jpa.repository.Modifying;
import org.springframework.data.jpa.repository.Query;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import com.unis.user.server.model.RoleResourcesVO;


@Repository
@Transactional(propagation = Propagation.NESTED, rollbackFor = Exception.class)
public interface RoleResourcesRepository extends JpaRepository<RoleResourcesVO,Serializable>,JpaSpecificationExecutor <RoleResourcesVO>{

	/**
	 * @param i
	 * @return 查询所有角色资源信息
	 */
	List<RoleResourcesVO> findByStateCode(int i);

	/**
	 * @param roleCode
	 * @param i
	 * @return根据角色编号获取角色资源关联信息
	 */
	List<RoleResourcesVO> findByRoleCodeAndStateCode(String roleCode, Integer i);

	/**
	 * @param roleCode
	 * @param i
	 * @param resourcesCode
	 * @return根据角色编号资源编号获取资源信息
	 */
	RoleResourcesVO findByRoleCodeAndStateCodeAndResourceCode(String roleCode, int i, String resourcesCode);

	/**
	 * @param roleCode
	 * @return根据roleCode删除信息
	 */

	@Modifying
	@Query(value="delete from  SYS_ROLE_RESOURCE where ROLE_CODE = ?",nativeQuery = true)
	int delete(String roleCode);

	/**
	 * @param roleCode
	 * @param i
	 * @return根据角色编号获取角色资源关联信息
	 */
	List<RoleResourcesVO> findByRoleCodeInAndStateCode(String[] roleCode, Integer i);

	/**
	 * @param roleCode
	 * @param i
	 * @param resourcesCode
	 * @return
	 */
	@Modifying(clearAutomatically = true)
	@Query(value = "SELECT * FROM SYS_ROLE_RESOURCE WHERE" +
			"  RESOURCE_CODE IN ( SELECT RESOURCE_CODE FROM SYS_RESOURCE_INFO where RESOURCE_CODE like ?1%  and STATE_CODE = ?2  ) and ROLE_CODE in (?3) or RESOURCE_CODE = 'RM1001'",nativeQuery = true)
	List<RoleResourcesVO> findByRoleCodeInAndStateCodenew(String resourcesCode, int i,String[] roleCode);

	@Modifying(clearAutomatically = true)
	@Query(value = "delete from SYS_ROLE_RESOURCE where ROLE_CODE =?1",nativeQuery = true)
    void deleteByRoleCode(String roleCode);
}
