package com.unis.user.server.repository;


import com.unis.user.server.model.UserPO;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.JpaSpecificationExecutor;
import org.springframework.data.jpa.repository.Modifying;
import org.springframework.data.jpa.repository.Query;
import org.springframework.stereotype.Repository;

import java.io.Serializable;
import java.util.List;

/**
 * 功能描述：用户处理层示例
 * @author 李兵
 * @date  2017年09月14日
 */
@Repository
public interface UserRepository extends JpaRepository<UserPO, Serializable>, JpaSpecificationExecutor<UserPO> {


    /**
     * 根据ID查询
     *
     * @param id
     * @param isDeleted
     * @return com.unis.user.server.model.UserPO
     * @date 2018/7/4
     */
    UserPO findByUserCodeAndStateCode(String userCode, Integer stateCode);

    /**
     * 蒋青茂
     * 根据用户名查询账号
     */
    UserPO findByUserTypeAndUserLoginNameAndStateCode(String userType, String userLoginName, Integer stateCode);


    List<UserPO> findByUserCodeInAndStateCode(List<String> userCode, Integer stateCode);

    /**
     * @param stateCode
     * @return
     * @Description: 查询所有账号
     * @date 2018年8月23日, 下午5:21:15
     * @author tiechanglong
     * @version v1.0
     */
    List<UserPO> findByStateCode(Integer stateCode);

    UserPO findByUserLoginNameAndStateCode(String userLoginName, int i);

    /**
     * @param resources
     * @return 根据部门数据查询用户信息
     */
    List<UserPO> findByDeptCodeIn(String[] resources);

    /**
     * @param code
     * @return根据部门code获取用户信息
     */
    List<UserPO> findByDeptCode(String code);

    /**
     * @param resources
     * @return根据用户code获取用户信息
     */
    List<UserPO> findByUserCodeIn(String[] resources);


    List<UserPO> findByDeptCodeAndStateCode(String deptCode, int i);

    List<UserPO> findByDeptCodeAndHeadshipGreaterThanAndStateCode(String deptCode,String headShip, int i);


    /**
     * @param departs
     * @param users
     * @param i
     * @param sort
     * @return 根据部门角色查询信息
     */
    List<UserPO> findByDeptCodeInAndUserCodeInAndStateCode(String[] departs, String[] users, int i);
 
    /**
     * @param departs
     * @param i
     * @param sort
     * @return根据部门查询信息
     */
    List<UserPO> findByDeptCodeInAndStateCode(String[] departs, int i);
 
    /**
     * @param users
     * @param i
     * @param sort
     * @return根据用户code查询
     */
    List<UserPO> findByUserCodeInAndStateCode(String[] users, int i);

	/**
	 * @param mobile
	 * @param i
	 * @return 根据用户手机号获取用户信息
	 */
	UserPO findByUserMobileAndStateCode(String mobile, int i);

    /**
     * 查询处长信息 副局长 局长
     * @param deptCode
     * @return
     */
   /* @Modifying
    @Query(value="select * from  SYS_USER_INFO where DEPT_CODE = ?1 and HEADSHIP ='10230006'",nativeQuery = true)*/
    List<UserPO> findByDeptCodeAndStateCodeAndHeadship(String deptCode,int i,String headShip);

    @Modifying(clearAutomatically = true)
    @Query(value = "delete from SYS_USER_INFO where USER_CODE = ?1 ", nativeQuery = true)
    void updateByCode(String userCode);

    UserPO findByUserNameAndStateCode(String userName, int i);

    List<UserPO> findByUserTypeAndStateCode(int i, int i1);

    @Modifying(clearAutomatically = true)
    @Query(value = "select *  from SYS_USER_INFO where  DEPT_CODE like  '%DP001%' " , nativeQuery = true)
	List<UserPO> getAllUser(String deptCode);

    @Modifying(clearAutomatically = true)
    @Query(value = "select *  from SYS_USER_INFO where  USER_TYPE =?1 " , nativeQuery = true)
	List<UserPO> getByType(String type);

	UserPO findByUserTypeAndUserLoginName(String bizType, String account);


	//根据账号查密码
    @Query(value = "SELECT USER_PASSWORD FROM SYS_USER_INFO WHERE USER_TYPE='1'  AND USER_LOGINNAME=?1 ",nativeQuery = true)
    String fingPwByAccount(String account);

    List<UserPO> findByHeadshipLessThanEqualAndOrgCodeAndStateCode(String headShip, String orgCode, int i);

    List<UserPO> findByHeadshipAndOrgCodeAndStateCode(String headship, String orgCode, int i);

    List<UserPO> findByHeadshipAndStateCode(String headship, int i);
}
