package com.unis.user.server.repository;


import com.unis.user.server.dto.RoleInfoDTO;
import com.unis.user.server.model.UserPO;
import com.unis.user.server.model.UserRoleVO;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.JpaSpecificationExecutor;
import org.springframework.data.jpa.repository.Modifying;
import org.springframework.data.jpa.repository.Query;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import java.io.Serializable;
import java.util.List;

/**
 * 功能描述：用户处理层示例
 * @author 李兵
 * @date  2017年09月14日
 */
@Repository

@Transactional(propagation = Propagation.NESTED, rollbackFor = Exception.class)
public interface UserRoleRepository extends JpaRepository<UserRoleVO, Serializable>, JpaSpecificationExecutor<UserRoleVO> {

    List<UserRoleVO> findByUserCodeAndStateCode(String userCode, int i);

    @Modifying(clearAutomatically = true)
    @Query(value = "delete from SYS_USER_ROLES where USER_CODE =?1",nativeQuery = true)
    void deleteByUserCode(String userCode);

    @Modifying(clearAutomatically = true)
    @Query(value = "delete from SYS_USER_ROLES where USER_CODE =?1 and ROLE_CODE=?2",nativeQuery = true)
    void deleteByUserCodeAndRoleCode(String userCode,String roleCode);

    @Modifying(clearAutomatically = true)
    @Query(value = "select ROLE_CODE from SYS_USER_ROLES where USER_CODE = ?1",nativeQuery = true)
    List<String> findByUserCode(String userCode);

	/**
	 * @param code
	 * @return根据rolecode获取角色用户信息
	 */
	List<UserRoleVO> findByRoleCode(String code);

    @Modifying(clearAutomatically = true)
    @Query(value = "delete from SYS_USER_ROLES where ROLE_CODE =?1",nativeQuery = true)
    void deleteByRoleCode(String roleCode);

    List<UserRoleVO>  findByRoleCodeInAndStateCode(String[] roleCode, int i);

}
