package com.unis.user.server.server;

import java.util.ArrayList;
import java.util.List;

import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Predicate;
import javax.persistence.criteria.Root;

import com.unis.user.server.dao.AreaDao;
import com.unis.user.server.model.AreaAllVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Sort;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.stereotype.Service;

import com.unis.user.server.dto.AreaDTO;
import com.unis.user.server.model.AreaCityVO;
import com.unis.user.server.model.AreaCountyVO;
import com.unis.user.server.model.AreaVO;
import com.unis.user.server.repository.AreaCityRepository;
import com.unis.user.server.repository.AreaCountyRepository;
import com.unis.user.server.repository.AreaRepository;
import com.unis.user.server.untils.LsBeanUtils;

@Service
public class AreaServer {
	
	@Autowired
	private AreaRepository areaRepository;
	
	@Autowired
	private AreaCountyRepository areaCountyRepository;
	
	@Autowired
	private AreaCityRepository areaCityRepository;

	@Autowired
	private AreaDao areaDao;

	public List<AreaDTO> fingAreaTree() {
		List<AreaDTO> areaDTOs = new ArrayList<AreaDTO>();
		Sort sort = new Sort(Sort.Direction.ASC, "provinCode");
		Specification<AreaVO> specification = new Specification<AreaVO>() {

			@Override
			public Predicate toPredicate(Root<AreaVO> root, CriteriaQuery<?> query, CriteriaBuilder criteriaBuilder) {
				query.groupBy(root.get("provinCode"),root.get("provinName"));
				return query.getRestriction();
			}};
		List<AreaVO> list = areaRepository.findAll(specification,sort);//查询省级列表
		for(AreaVO areaVO:list) {
			AreaDTO dto = new AreaDTO();
			dto.setCountyCode(areaVO.getProvinCode());
			dto.setCountyName(areaVO.getProvinName());
			//dto.setChildren(findCountyQ(dto));
			dto.setChildren(new ArrayList<AreaDTO>());
			areaDTOs.add(dto);
		}
		return areaDTOs;
	}

	public List<AreaDTO> fingArea() {
		List<AreaDTO> areaDTOs = new ArrayList<AreaDTO>();
		Sort sort = new Sort(Sort.Direction.ASC, "provinCode");
		Specification<AreaVO> specification = new Specification<AreaVO>() {

			@Override
			public Predicate toPredicate(Root<AreaVO> root, CriteriaQuery<?> query, CriteriaBuilder criteriaBuilder) {
				query.groupBy(root.get("provinCode"),root.get("provinName"));
				return query.getRestriction();
			}};
		List<AreaVO> list = areaRepository.findAll(specification,sort);//查询省级列表
		for(AreaVO areaVO:list) {
			AreaDTO dto = new AreaDTO();
			dto.setCountyCode(areaVO.getProvinCode());
			dto.setCountyName(areaVO.getProvinName());
			dto.setChildren(findCountyQ(dto));
			//dto.setChildren(new ArrayList<AreaDTO>());
			areaDTOs.add(dto);
		}
		return areaDTOs;
	}

	/**
	 * @param dto2
	 * @return根据省列表
	 */
	public List<AreaDTO> findCounty(AreaDTO areaVO) {
		List<AreaDTO> areaDTOs = new ArrayList<AreaDTO>();
		Sort sort = new Sort(Sort.Direction.ASC, "countyCode");

		Specification<AreaCountyVO> specification = new Specification<AreaCountyVO>() {
			@Override
			public Predicate toPredicate(Root<AreaCountyVO> root, CriteriaQuery<?> query, CriteriaBuilder criteriaBuilder) {
				Predicate predicate = null;
				predicate = criteriaBuilder.like(root.get("countyCode").as(String.class),areaVO.getCountyCode().substring(0, 4) + "%");
				query.where(predicate);
				query.groupBy(root.get("countyCode"),root.get("countyName"));
				return query.getRestriction();
			}
		};
		List<AreaCountyVO> countyVOs = areaCountyRepository.findAll(specification, sort);
		for(AreaCountyVO dto:countyVOs) {
			AreaDTO areaDTO = LsBeanUtils.copyProperties(dto, AreaDTO.class);
			areaDTOs.add(areaDTO);
		}
		return areaDTOs;//返回的是
	}

	/**
	 * @param dto2
	 * @return根据区列表
	 */
	public List<AreaDTO> findCountyQ(AreaDTO areaVO) {
		List<AreaDTO> areaDTOs = new ArrayList<AreaDTO>();
		Sort sort = new Sort(Sort.Direction.ASC, "countyCode");

		Specification<AreaCountyVO> specification = new Specification<AreaCountyVO>() {
			@Override
			public Predicate toPredicate(Root<AreaCountyVO> root, CriteriaQuery<?> query, CriteriaBuilder criteriaBuilder) {
				Predicate predicate = null;
				predicate = criteriaBuilder.like(root.get("countyCode").as(String.class),areaVO.getCountyCode().substring(0, 3) + "%");
				query.where(predicate);
				query.groupBy(root.get("countyCode"),root.get("countyName"));
				return query.getRestriction();
			}
		};
		List<AreaCountyVO> countyVOs = areaCountyRepository.findAll(specification, sort);
		for(AreaCountyVO dto:countyVOs) {
			AreaDTO areaDTO = LsBeanUtils.copyProperties(dto, AreaDTO.class);
			areaDTOs.add(areaDTO);
		}
		return areaDTOs;//返回的是
	}


	public List<AreaDTO> findCity(AreaDTO dto2) {
		List<AreaDTO> areaDTOs = new ArrayList<AreaDTO>();
		Sort sort = new Sort(Sort.Direction.ASC, "cityCode");
		Specification<AreaCityVO> specification = new Specification<AreaCityVO>() {
			
			@Override
			public Predicate toPredicate(Root<AreaCityVO> root, CriteriaQuery<?> query, CriteriaBuilder criteriaBuilder) {
				Predicate predicate = null;
				predicate = criteriaBuilder.like(root.get("cityCode").as(String.class),dto2.getCountyCode().substring(0, 2) + "%00");
				query.where(predicate);
				query.groupBy(root.get("cityCode"),root.get("cityName"));
				return query.getRestriction();
			}
		};
		List<AreaCityVO> cityVOs = areaCityRepository.findAll(specification, sort);
		for(AreaCityVO cityVO:cityVOs) {
			AreaDTO dto1 = new AreaDTO();
			dto1.setCountyCode(cityVO.getCityCode());
			dto1.setCountyName(cityVO.getCityName());
//			dto1.setChildren(findCounty(dto1));

			dto1.setChildren(new ArrayList<AreaDTO>());
			areaDTOs.add(dto1);
		}
		return areaDTOs;//返回的是
	}

	public List<AreaDTO> findCityOr(AreaDTO dto2) {
		String tem = dto2.getCountyCode().substring(0,4)+"00";
		dto2.setCountyCode(tem);
		List<AreaDTO> areaDTOs = new ArrayList<AreaDTO>();
		Sort sort = new Sort(Sort.Direction.ASC, "cityCode");
		Specification<AreaCityVO> specification = new Specification<AreaCityVO>() {

			@Override
			public Predicate toPredicate(Root<AreaCityVO> root, CriteriaQuery<?> query, CriteriaBuilder criteriaBuilder) {
				Predicate predicate = null;
				predicate = criteriaBuilder.like(root.get("cityCode").as(String.class),dto2.getCountyCode().substring(0, 2) + "%00");
				query.where(predicate);
				query.groupBy(root.get("cityCode"),root.get("cityName"));
				return query.getRestriction();
			}
		};
		List<AreaCityVO> cityVOs = areaCityRepository.findAll(specification, sort);
		if(dto2.getCountyCode().substring(2,6).equals("0000")){
			for(AreaCityVO cityVO:cityVOs) {
				AreaDTO dto1 = new AreaDTO();
				dto1.setCountyCode(cityVO.getCityCode());
				dto1.setCountyName(cityVO.getCityName());
//			dto1.setChildren(findCounty(dto1));

				dto1.setChildren(new ArrayList<AreaDTO>());
				areaDTOs.add(dto1);
			}
		}else{
			AreaDTO dto1 = new AreaDTO();
			for(AreaCityVO cityVO:cityVOs) {
				if (cityVO.getCityCode().equals(dto2.getCountyCode())){
					dto1.setCountyCode(cityVO.getCityCode());
					dto1.setCountyName(cityVO.getCityName());
//			dto1.setChildren(findCounty(dto1));
					break;
				}
			}
			dto1.setChildren(new ArrayList<AreaDTO>());
			areaDTOs.add(dto1);
		}
		return areaDTOs;//返回的是
	}

	public List<AreaVO> findProvinCode(String countyCode) {
		Specification<AreaVO> specification = new Specification<AreaVO>() {
			@Override
			public Predicate toPredicate(Root<AreaVO> root, CriteriaQuery<?> query, CriteriaBuilder criteriaBuilder) {
				List<Predicate> list = new ArrayList<Predicate>();
				list.add(criteriaBuilder.like(root.get("provinCode").as(String.class), countyCode));
				query.groupBy(root.get("provinCode"),root.get("provinName"));
				return query.where(criteriaBuilder.and(list.toArray(new Predicate[list.size()]))).getRestriction();
			}};
		return areaRepository.findAll(specification);
	}

	public List<AreaCityVO> findCityCode(String countyCode) {
		// TODO Auto-generated method stub
		Specification<AreaCityVO> specification = new Specification<AreaCityVO>() {
			@Override
			public Predicate toPredicate(Root<AreaCityVO> root, CriteriaQuery<?> query, CriteriaBuilder criteriaBuilder) {
				List<Predicate> list = new ArrayList<Predicate>();
				list.add(criteriaBuilder.like(root.get("cityCode").as(String.class), countyCode));
				query.groupBy(root.get("cityCode"),root.get("cityName"));
				return query.where(criteriaBuilder.and(list.toArray(new Predicate[list.size()]))).getRestriction();
			}};
		return areaCityRepository.findAll(specification);
	}

	public List<AreaCountyVO> findCountyCode(String countyCode) {
		// TODO Auto-generated method stub
		Specification<AreaCountyVO> specification = new Specification<AreaCountyVO>() {
			@Override
			public Predicate toPredicate(Root<AreaCountyVO> root, CriteriaQuery<?> query, CriteriaBuilder criteriaBuilder) {
				List<Predicate> list = new ArrayList<Predicate>();
				list.add(criteriaBuilder.like(root.get("countyCode").as(String.class), countyCode));
				query.groupBy(root.get("countyCode"),root.get("countyName"));
				return query.where(criteriaBuilder.and(list.toArray(new Predicate[list.size()]))).getRestriction();
			}};
		return areaCountyRepository.findAll(specification);
	}

	public List<AreaAllVO> getProvinByAreaName(String areaName) {
		List<AreaAllVO> list  = areaDao.getProvinByAreaName(areaName) ;
		return list;
	}

	public List<AreaAllVO> getCityByAreaName(String areaName) {
		List<AreaAllVO> list  = areaDao.findCountyInfo(areaName) ;
		List<AreaAllVO> cityList  = areaDao.findCityInfo(areaName) ;
		list.addAll(cityList);
		return list;
	}

}
