package com.unis.user.server.server;


import com.unis.common.utils.EncryptUtil;
import com.unis.common.utils.ResponseWrapper;
import com.unis.user.server.dto.ChangeUserPasswdDTO;
import com.unis.user.server.dto.DepartmentDTO;
import com.unis.user.server.model.DepartmentPO;
import com.unis.user.server.model.OrgainzeVO;

import com.unis.user.server.model.UserPO;
import com.unis.user.server.repository.BaseRepository;
import com.unis.user.server.repository.DepartmentRepository;
import com.unis.user.server.repository.UserRepository;
import com.unis.user.server.untils.LsBeanUtils;
import com.unis.user.server.untils.UpdateTool;
import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.stereotype.Service;

import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Predicate;
import javax.persistence.criteria.Root;
import java.util.ArrayList;
import java.util.List;

/**
 *
 * 部门管理数据服务
 */
@Service
public class DepartmentServer {
	@Autowired
	private DepartmentRepository repository;
	@Autowired
	private BaseRepository baseRepository;
	@Autowired
	private UserRepository userRepository;
	@Autowired
	private ParaConfigServer paraConfigServer;
	@Autowired
	private OrgainzeServer orgainzeServer;

	/***
	 * 根据部门编码查询
	 * @param deptCode
	 * @return
	 */
	public DepartmentPO findByDeptCode(String deptCode) {
		return repository.findByDeptCodeAndStateCode(deptCode, 1);
	}

	/***
	 * 保存部门名称
	 * @param departmentDTO
	 */
	public String save(DepartmentDTO departmentDTO) {
		if (departmentDTO.getParentCode() == null) {
			//2019-10-11 10:14:25 添加同一组织下名称唯一校验 如果parentcode等于空  则看当前组织下 有无同名   否则走下面
			DepartmentPO departmentPO = repository.findByOrgCodeAndDeptNameAndParentCodeAndStateCode(departmentDTO.getOrgCode(), departmentDTO.getDeptName(),"DP", 1);
			//List<DepartmentPO> list = repository.findByParentCodeAndDeptNameAndStateCode("DP",departmentDTO.getDeptName(), 1);
			if(departmentPO!=null){
				return null;
			}else{
				String depCode = baseRepository.selectByTableNameAndAttr("SYS_DEPARTMENT", "DEPT_CODE", "DP", 3);
				DepartmentPO po = LsBeanUtils.copyProperties(departmentDTO, DepartmentPO.class);
				po.setDeptCode(depCode);
				po.setParentCode("DP");
				repository.saveAndFlush(po);
				return po.getDeptCode();
			}
		} else {
			//2019-10-11 10:14:25 添加同一组织下名称唯一校验
			DepartmentPO departmentPO = repository.findByOrgCodeAndDeptNameAndParentCodeAndStateCode(departmentDTO.getOrgCode(),departmentDTO.getDeptName(),departmentDTO.getParentCode(),1);
			if(departmentPO!=null){
				return null;
			}else{
				String depCode = baseRepository.selectByTableNameAndAttr("SYS_DEPARTMENT", "DEPT_CODE", departmentDTO.getParentCode(), 3);
				DepartmentPO po = LsBeanUtils.copyProperties(departmentDTO, DepartmentPO.class);
				po.setDeptCode(depCode);
				po.setParentCode(departmentDTO.getParentCode());
				repository.saveAndFlush(po);
				return po.getDeptCode();
			}
		}
	}

	/**
	 * 根据部门编号删除
	 *
	 * @param deptCode
	 */
	public void deleted(List<String> deptCode) {
		List<DepartmentPO> userPOList = repository.findByDeptCodeInAndStateCode(deptCode, 1);
		for (DepartmentPO departmentPO : userPOList) {
			departmentPO.setStateCode(0);
			repository.saveAndFlush(departmentPO);
		}
	}

	/**
	 * 修改
	 *
	 * @param departmentDTO
	 */
	public void update(DepartmentDTO departmentDTO) {
		DepartmentPO departmentPO = repository.findByDeptCodeAndStateCode(departmentDTO.getDeptCode(), 1);
		DepartmentPO departmentPO1 = LsBeanUtils.copyProperties(departmentDTO, DepartmentPO.class);
		UpdateTool.copyNullProperties(departmentPO, departmentPO1);
		repository.save(departmentPO1);
	}

	/**
	 * 查询上级部门信息
	 *
	 * @param departmentDTO the department vo
	 * @return the response wrapper
	 */
	public DepartmentPO findByParentDep(DepartmentDTO departmentDTO) {
		String deptCode = departmentDTO.getDeptCode();
		deptCode = deptCode.substring(0, deptCode.length() - 3);
		return repository.findByDeptCodeAndStateCode(deptCode, 1);
	}

	/**
	 * 获取分类信息
	 *
	 * @return the response wrapper
	 */
	public List<DepartmentPO> getTreeData() {
		List treeDataList = new ArrayList();
		Sort sort = new Sort(Sort.Direction.ASC, "orderBy");
		List<DepartmentPO> list = repository.findByParentCodeAndStateCode("DP", 1, sort);
		for (DepartmentPO departmentPO : list) {
			DepartmentPO tree = this.getTree(departmentPO.getDeptCode());
			treeDataList.add(tree);
		}
		return treeDataList;
	}


	/**
	 * 获取左侧导航
	 *
	 * @param depCode the depCode
	 * @return the response wrapper
	 */
	public DepartmentPO getTree(String depCode) {
		DepartmentPO departmentPO = repository.findByDeptCodeAndStateCode(depCode, 1);
		Sort sort = new Sort(Sort.Direction.ASC, "orderBy");
		List<DepartmentPO> list = repository.findByParentCodeAndStateCode(departmentPO.getDeptCode(), 1, sort);
		if(list.size()>0) {
			for (DepartmentPO dv : list) {
				//递归计算
				DepartmentPO departmentPO1 = getTree(dv.getDeptCode());
				departmentPO.getChildren().add(departmentPO1);
			}
		} else {
			departmentPO.setChildren(null);
		}

		return departmentPO;
	}

	public List<DepartmentPO> findByOrgCode(String orgCode) {
		List treeDataList = new ArrayList();
		Sort sort = new Sort(Sort.Direction.ASC, "orderBy");
		List<DepartmentPO> departmentPOs = repository.findByOrgCodeAndStateCodeAndParentCode(orgCode, 1,"DP", sort);
		for (DepartmentPO departmentPO : departmentPOs) {
			departmentPO.setDeptTypeName(paraConfigServer.getConfigName(departmentPO.getDeptType()));
			DepartmentPO tree = this.getTree(departmentPO.getDeptCode());
			treeDataList.add(tree);
		}
		return treeDataList;
	}

	public List<DepartmentPO> findByOrgCodeFindUser(String orgCode) {
		List treeDataList = new ArrayList();
		Sort sort = new Sort(Sort.Direction.ASC, "orderBy");
		List<DepartmentPO> departmentPOs = repository.findByOrgCodeAndStateCodeAndParentCode(orgCode, 1,"DP", sort);
		for (DepartmentPO departmentPO : departmentPOs) {
			departmentPO.setDeptTypeName(paraConfigServer.getConfigName(departmentPO.getDeptType()));
			DepartmentPO tree = this.getTree(departmentPO.getDeptCode());
			treeDataList.add(tree);
			List<UserPO> userPOS = userRepository.findByDeptCodeAndHeadshipGreaterThanAndStateCode(departmentPO.getDeptCode(),"10230006", 1);
			departmentPO.setUserList(userPOS);
		}
		return treeDataList;
	}

	public List<DepartmentPO> findByOrgCodenNew() {
		List treeDataList = new ArrayList();
		Sort sort = new Sort(Sort.Direction.ASC, "orderBy");
		List<DepartmentPO> departmentPOs = repository.findByStateCodeAndParentCode(1,"DP");
		for (DepartmentPO departmentPO : departmentPOs) {
			departmentPO.setDeptTypeName(paraConfigServer.getConfigName(departmentPO.getDeptType()));
			DepartmentPO tree = this.getTree(departmentPO.getDeptCode());
			treeDataList.add(tree);
		}
		return treeDataList;
	}

	/**
	 * 查询所有部门列表
	 *
	 * @return
	 */
	public List<DepartmentPO> findByAttendance(String orgCode) {
		return repository.findByOrgCodeAndStateCode(orgCode, 1, Sort.unsorted());
	}

	/**
	 * 获取分类信息
	 *
	 * @return the response wrapper
	 */
	public List<DepartmentPO> getTreeData(String orgCode) {
		List treeDataList = new ArrayList();
		Sort sort = new Sort(Sort.Direction.ASC, "orderBy");
		List<DepartmentPO> list = repository.findByOrgCodeAndStateCode(orgCode, 1, sort);
		for (DepartmentPO departmentPO : list) {
			DepartmentPO tree = this.getTree(departmentPO.getDeptCode());
			treeDataList.add(tree);
		}
		return treeDataList;
	}

	private OrgainzeVO getTreeOrg(String deptCode) {
		DepartmentPO departmentPO = repository.findByDeptCodeAndStateCode(deptCode, 1);
		OrgainzeVO orgainzeVO = new OrgainzeVO();
		if(departmentPO!=null) {
			orgainzeVO.setOrgName(departmentPO.getDeptName());
			orgainzeVO.setOrgCode(departmentPO.getDeptCode());
			orgainzeVO.setIsDept(2);
			orgainzeVO.setOrgType(departmentPO.getDeptType());
		}
		Sort sort = new Sort(Sort.Direction.ASC, "orderBy");
		List<DepartmentPO> list = repository.findByParentCodeAndStateCode(departmentPO.getDeptCode(), 1, sort);
		if(list.size()>0) {
			for (DepartmentPO dv : list) {
				//递归计算
				OrgainzeVO departmentPO1 = getTreeOrg(dv.getDeptCode());
				orgainzeVO.getChildren().add(departmentPO1);
			}
		} else {
			orgainzeVO.setChildren(null);
		}

		return orgainzeVO;
	}

	public List<OrgainzeVO> getTreeDataOrg(String orgCode) {
		List<OrgainzeVO> treeDataList = new ArrayList<>();
		Sort sort = new Sort(Sort.Direction.ASC, "orderBy");
		List<DepartmentPO> list = repository.findByOrgCodeAndStateCodeAndParentCode(orgCode, 1,"DP", sort);
		for (DepartmentPO departmentPO : list) {
//			DepartmentPO tree = this.getTree(departmentPO.getDeptCode());
            OrgainzeVO vo = this.getTreeOrg(departmentPO.getDeptCode());
			treeDataList.add(vo);
		}
		return treeDataList;
	}

	public List<DepartmentPO> getAllDept() {
		return repository.findByStateCode(1);
	}

	/**
	 * 获取分类信息
	 *
	 * @return the response wrapper
	 */
	public List<DepartmentPO> findByParentCodeAndStateCode(String parentCode) {
		Sort sort = new Sort(Sort.Direction.ASC, "orderBy");
		return repository.findByParentCodeAndStateCode(parentCode, 1, sort);
	}

	public DepartmentPO findByDeptName(String deptName,String orgCode) {
		return repository.findByDeptNameAndOrgCodeAndStateCode(deptName,orgCode,1);
	}

	public ResponseWrapper findByOrgCodeTree(String orgCode) {
		//查询部门下面的机构
		List<DepartmentPO> treeList = null;
		Sort sort = new Sort(Sort.Direction.ASC, "orderBy");
		treeList = repository.findByOrgCodeAndStateCode(orgCode, 1,sort);
			// 获取子节点
		for(DepartmentPO department:treeList){
			department.setUserList(findUserByCode(department.getDeptCode()));
			List<DepartmentPO> childrenlist = repository.findByParentCodeAndStateCode(department.getDeptCode(),1,sort);
			// 有子节点,获取子节点的下级节点
			if (childrenlist.size() > 0) {
				for(DepartmentPO po : childrenlist){
					List<DepartmentPO> childrens= repository.findByParentCodeAndStateCode(po.getDeptCode(),1,sort);
					po.setUserList(findUserByCode(po.getDeptCode()));
					if(childrens.size()>0){
						childrens.remove(po);
						po.setChildren(childrens);
					}
				}
			}
			department.setChildren(childrenlist);
		}


		return ResponseWrapper.success(treeList);
	}

	public List<UserPO> findUserByCode(String orgCode) {
		List<UserPO> list = userRepository.findByDeptCodeAndStateCode(orgCode,1);
		return list;
	}


	public List<DepartmentPO> getChildrenNodeModelue(List<DepartmentPO> nodes) {
		Sort sort = new Sort(Sort.Direction.ASC, "orderBy");
		for (DepartmentPO node : nodes) {
			// 获取子节点
			List<DepartmentPO> childrenlist =  repository.findByParentCodeAndStateCode(node.getDeptCode(),1,sort);
			// 有子节点,获取子节点的下级节点
			if (childrenlist.size() > 0) {
				for(DepartmentPO node1 : childrenlist){
					List<DepartmentPO> childrens=  repository.findByParentCodeAndStateCode(node1.getDeptCode(),1,sort);
					if(childrens.size()>0){
						node1.setChildren(childrens);
					}
				}
			}
			node.setChildren(childrenlist);
		}
		return nodes;
	}

    public List<OrgainzeVO> findByOrgCodes(List<String> orgCodes,String deptType) {
		List<OrgainzeVO> orgainzeVOList = new ArrayList<>();
		Sort sort = new Sort(Sort.Direction.ASC, "orderBy");
		for (String orgcode:orgCodes){
			OrgainzeVO orgainzeVO = orgainzeServer.findByOrgCodeAndStateCode(orgcode,1,sort);
			List<DepartmentPO> departmentPOList = repository.findByOrgCodeAndDeptTypeAndStateCode(orgcode, deptType,1, sort);
			orgainzeVO.setDepartList(departmentPOList);
			orgainzeVOList.add(orgainzeVO);
		}
		return orgainzeVOList;
    }
}
