package com.unis.user.server.server;

import java.util.ArrayList;
import java.util.List;

import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Predicate;
import javax.persistence.criteria.Root;

import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.stereotype.Service;

import com.unis.common.base.BaseService;
import com.unis.common.utils.UpdateTool;
import com.unis.user.server.dto.OrgainzeNoticeDTO;
import com.unis.user.server.model.OrgainzeNoticeVO;
import com.unis.user.server.model.OrgainzeVO;
import com.unis.user.server.model.ParaVO;
import com.unis.user.server.model.UserPO;
import com.unis.user.server.repository.BaseRepository;
import com.unis.user.server.repository.OrgainzeNoticeRepository;
import com.unis.user.server.repository.OrgainzeRepository;
import com.unis.user.server.repository.UserRepository;
import com.unis.user.server.untils.LsBeanUtils;

@Service
public class OrgainzeNoticeServer extends BaseService {
	
	@Autowired
	private OrgainzeNoticeRepository orgainzeNoticeRepository;
	
	@Autowired
	private BaseRepository baseRepository;
	
	@Autowired
	private UserRepository repository;
	
	@Autowired
	private OrgainzeRepository orgainzeRepository;

	public int save(OrgainzeNoticeDTO orgainzeNoticeDTO) {
		if(orgainzeNoticeDTO.getId()==0) {
			orgainzeNoticeDTO.setId(baseRepository.selectIdByTableNameAndAttr("SYS_ORGAINZE_NOTICE", "id"));
		}
		OrgainzeNoticeVO noticeVO = LsBeanUtils.copyProperties(orgainzeNoticeDTO, OrgainzeNoticeVO.class);
		OrgainzeNoticeVO orgainzeNoticeVO = orgainzeNoticeRepository.findByIdAndStateCode(orgainzeNoticeDTO.getId(),1);
		if(orgainzeNoticeVO!=null) {
			UpdateTool.copyNullProperties(orgainzeNoticeVO, noticeVO);
		}
		orgainzeNoticeRepository.save(noticeVO);
		return 1;
	}

	public Page<OrgainzeNoticeVO> findByPage(OrgainzeNoticeDTO orgainzeNoticeDTO, Integer page, Integer size) {
		PageRequest pageable = PageRequest.of( (page - 1), size, Sort.Direction.ASC, "orgCode" );
		Specification<OrgainzeNoticeVO> specification = new Specification<OrgainzeNoticeVO>() {
			@Override
			public Predicate toPredicate(Root<OrgainzeNoticeVO> root, CriteriaQuery<?> query, CriteriaBuilder cb) {
				List<Predicate> list = new ArrayList<Predicate>();
				//参数编号
				if (StringUtils.isNotBlank(orgainzeNoticeDTO.getOrgCode())) {
					list.add( cb.like( root.get( "orgCode" ).as( String.class ), "%" + orgainzeNoticeDTO.getOrgCode() + "%" ) );
				}
				if (StringUtils.isNotBlank(orgainzeNoticeDTO.getNoticeType())) {
					list.add( cb.like( root.get( "noticeType" ).as( String.class ), "%" + orgainzeNoticeDTO.getNoticeType() + "%" ) );
				}
				list.add( cb.equal( root.get( "stateCode" ).as( Integer.class ), 1) );
				return cb.and( list.toArray( new Predicate[list.size()] ) );
			}
		};
		Page<OrgainzeNoticeVO> page2 = orgainzeNoticeRepository.findAll(specification, pageable);
		List<OrgainzeNoticeVO> list = page2.getContent();
		for(int i =0;i<list.size();i++) {
			OrgainzeNoticeVO noticeVO = list.get(i);
			UserPO po = repository.findByUserCodeAndStateCode(noticeVO.getUserCode(), 1);
			if(po!=null) {
				noticeVO.setUserMobile(po.getUserMobile());
				noticeVO.setUserMail(po.getUserMail());
			}
		
			OrgainzeVO orgainzeVO = orgainzeRepository.findByOrgCodeAndStateCode(noticeVO.getOrgCode(), 1);

			if(orgainzeVO!=null) {
				noticeVO.setOrgName(orgainzeVO.getOrgName());
			}
		}
		return page2;
	}

	public int delete(Integer[] ids) {
		// TODO Auto-generated method stub
		return orgainzeNoticeRepository.delete(ids,"text","test");
	}

	public OrgainzeNoticeVO info(String orgCode) {
		// TODO Auto-generated method stub
		OrgainzeNoticeVO noticeVO = orgainzeNoticeRepository.findByOrgCodeAndStateCode(orgCode,1);
		if(noticeVO!=null) {
			UserPO po = repository.findByUserCodeAndStateCode(noticeVO.getUserCode(), 1);
			OrgainzeVO orgainzeVO = orgainzeRepository.findByOrgCodeAndStateCode(orgCode, 1);
			if(po!=null) {
				noticeVO.setUserMobile(po.getUserMobile());
				noticeVO.setUserMail(po.getUserMail());
			}
			if(orgainzeVO!=null) {
				noticeVO.setOrgName(orgainzeVO.getOrgName());
			}
		}
		
		return noticeVO;
	}

}
