package com.unis.user.server.server;

import com.alibaba.fastjson.JSONObject;
import com.unis.base.common.vo.DKdxxsjyVO;
import com.unis.common.base.BaseService;
import com.unis.common.config.RabbitObjectTO;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.common.utils.UpdateTool;
import com.unis.common.utils.rabbitmq.IMessageProvider;
import com.unis.user.server.config.Action;
import com.unis.user.server.domain.org.OrgainzeDomain;
import com.unis.user.server.dto.DepartmentDTO;
import com.unis.user.server.dto.OrgainzeDTO;
import com.unis.user.server.dto.OrganizationDTO;
import com.unis.user.server.feignclient.BaseServerClient;
import com.unis.user.server.model.*;
import com.unis.user.server.repository.*;
import com.unis.user.server.untils.LsBeanUtils;
import lombok.extern.log4j.Log4j2;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.stereotype.Service;

import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Predicate;
import javax.persistence.criteria.Root;
import java.util.*;
import java.util.stream.Collectors;

@Log4j2
@Service
public class OrgainzeServer extends BaseService {

    private final String GRAIN_UNIT_CODE = "10190001";//10 粮食局
//    @Value("${font.orgcode}")
//    private String GRAIN_UNIT_CODE;

    @Value("${gxgsOrgLevel}")
    private String gxgsOrgLevel;

    @Value("${gouxiaoSpecial}")
    private String gouxiaoSpecial;

    @Value("${chu-bei}")
    private String chuBei;
    @Value("${liang-ku-level}")
    private String liangKuLevel;

    @Autowired
    private BaseRepository baseRepository;

    @Autowired
    private OrgainzeRepository orgainzeRepository;

    @Autowired
    private SyszzjgRepository syszzjgRepository;

    @Autowired
    private UserRepository userRepository;

    @Autowired
    private DepartmentRepository repository;

    @Autowired
    private ParaConfigServer paraConfigServer;

    @Autowired
    private UserRoleRepository userRoleRepository;

    @Autowired
    private DepartmentServer server;

    @Autowired
    private IMessageProvider iMessageProvider;

    @Autowired
    private OrgainzeDomain orgainzeDomain;

    @Autowired
    private BaseServerClient baseServiceClient;

    public String selectMaxCode(String pro, Integer i) {
        return baseRepository.selectByTableNameAndAttr("SYS_ORGAINZE", "ORG_CODE", pro, i);
    }

    public OrgainzeVO info(String orgCode) {
        OrgainzeVO orgainzeVO = orgainzeRepository.findByOrgCodeAndStateCode(orgCode, 1);
        orgainzeVO.setOrgLevelName(paraConfigServer.getConfigName(orgainzeVO.getOrgLevel()));
        orgainzeVO.setOrgTypeName(paraConfigServer.getConfigName(orgainzeVO.getOrgType()));
        return orgainzeVO;
    }

    public String add(OrgainzeDTO orgainzeDTO) {
        OrgainzeVO orgainzeVO = orgainzeRepository.findByOrgNameAndStateCode(orgainzeDTO.getOrgName(), 1);
        if (orgainzeVO != null) {
            return "该组织已存在";
        }
        OrgainzeVO vo = new OrgainzeVO();
        UpdateTool.copyNullProperties(orgainzeDTO, vo);
        if (StringUtils.isEmpty(orgainzeDTO.getParentCode())) {
            vo.setOrgCode(baseRepository.selectByTableNameAndAttr("SYS_ORGAINZE", "ORG_CODE", "LS", 3));
        } else {

            vo.setOrgCode(baseRepository.selectByTableNameAndAttr("SYS_ORGAINZE", "ORG_CODE",
                    orgainzeDTO.getParentCode(), 3));
        }
        DepartmentDTO departmentDTO = new DepartmentDTO();
        departmentDTO.setDeptName(vo.getOrgName());
        departmentDTO.setOrgCode(vo.getOrgCode());
        departmentDTO.setCountyCode(vo.getCountyCode());
        server.save(departmentDTO);
        vo.setCreator("test");
        vo.setCreatorCode("test");
        vo.setCreateDate(new Date());
        //vo.setOrgType("10190005");//组织类型默认为企业
        //10190008 区长责任制外部单位类型
        if(StringUtils.isEmpty(vo.getOrgType()) || vo.getOrgType().contentEquals("10190008") == false) {
            vo.setOrgType("10190005");	//为空或者 非区长责任制外部单位 时   组织类型默认为企业
        }
        orgainzeRepository.save(vo);
        //setMqForGrainOrg(vo, Action.ORG_ADD);
        return vo.getOrgCode();
    }

    public Page<OrgainzeVO> findByPage(OrgainzeDTO orgainzeDTO, Integer page, Integer size) {
        PageRequest pageable = PageRequest.of((page - 1), size, Sort.Direction.ASC, "orgCode");
        Specification<OrgainzeVO> specification = new Specification<OrgainzeVO>() {
            @Override
            public Predicate toPredicate(Root<OrgainzeVO> root, CriteriaQuery<?> query, CriteriaBuilder cb) {
                List<Predicate> list = new ArrayList<Predicate>();
                // 组织编号
                if (StringUtils.isNotBlank(orgainzeDTO.getOrgCode())) {
                    list.add(cb.like(root.get("orgCode").as(String.class), "%" + orgainzeDTO.getOrgCode() + "%"));
                }
                // 组织名称
                if (StringUtils.isNotBlank(orgainzeDTO.getOrgName())) {
                    list.add(cb.like(root.get("orgName").as(String.class), "%" + orgainzeDTO.getOrgName() + "%"));
                }
                // 组织等级
                if (StringUtils.isNotBlank(orgainzeDTO.getOrgLevel())) {
                    list.add(cb.equal(root.get("orgLevel").as(String.class), orgainzeDTO.getOrgLevel()));
                }

                // 参数极限值
                if (StringUtils.isNotBlank(orgainzeDTO.getParentCode())) {
                    list.add(cb.like(root.get("parentCode").as(String.class), "%" + orgainzeDTO.getParentCode() + "%"));
                }

                // 参数机构类型
                if (StringUtils.isNotBlank(orgainzeDTO.getOrgType())) {
                    list.add(cb.like(root.get("orgType").as(String.class), "%" + orgainzeDTO.getOrgType() + "%"));
                }
                list.add(cb.equal(root.get("stateCode").as(Integer.class), 1));
                return cb.and(list.toArray(new Predicate[list.size()]));
            }
        };
        Page<OrgainzeVO> page2 = orgainzeRepository.findAll(specification, pageable);
        for (OrgainzeVO orgainzeVO : page2.getContent()) {
            orgainzeVO.setOrgLevelName(paraConfigServer.getConfigName(orgainzeVO.getOrgLevel()));
            orgainzeVO.setOrgTypeName(paraConfigServer.getConfigName(orgainzeVO.getOrgType()));
        }
        return page2;
    }

    public int delete(String[] orgCodes) {
        int i = 0;
        for (String orgCode : orgCodes) {
            i = i + orgainzeRepository.deleteByOrgCode(orgCode, "test", "test");
        }
        return i;
    }

    /**
     * 获取分类信息
     *
     * @return the response wrapper
     */
    public OrgainzeVO getTreeData(String orgCode, String orgType) {
        OrgainzeVO orgainzeVO = orgainzeRepository.findByOrgCodeAndStateCodeAndOrgTypeLike(orgCode, 1, "%" + orgType + "%");
        if (orgainzeVO != null) {
            List<OrgainzeVO> treeDataList = new ArrayList<>();
            Sort sort = new Sort(Sort.Direction.ASC, "orderBy", "orgCode");
            List<OrgainzeVO> list = orgainzeRepository.findByParentCodeAndStateCodeAndOrgTypeLike(orgCode, 1, "%" + orgType + "%", sort);
            for (OrgainzeVO departmentPO : list) {
                OrgainzeVO tree = this.getTree(departmentPO.getOrgCode(), orgType);
                treeDataList.add(tree);
            }
            orgainzeVO.setChildren(treeDataList);
        }
        return orgainzeVO;
    }

    public OrgainzeVO getTreeData(String orgCode, String orgType, String pageName) {
        if ("userManagerHome".equals(pageName)) {
        String userId = CurrentUtil.getUserId();
            if ("U0000260".equals(userId)) {
                return getTreeData(orgCode, orgType);
            }else {
                OrgainzeVO orgainzeVO = orgainzeRepository.findByOrgCodeAndStateCode(orgCode, 1);
                return orgainzeVO;
            }
        }else {
            return getTreeData(orgCode, orgType);
        }
    }


    /**
     * 获取左侧导航
     *
     * @param depCode the depCode
     * @return the response wrapper
     */
    public OrgainzeVO getTree(String depCode, String orgType) {
        OrgainzeVO departmentPO = orgainzeRepository.findByOrgCodeAndStateCode(depCode, 1);
        Sort sort = new Sort(Sort.Direction.ASC, "orgCode");
        List<OrgainzeVO> list = orgainzeRepository.findByParentCodeAndStateCodeAndOrgTypeLike(departmentPO.getOrgCode(), 1, "%" + orgType + "%", sort);
        for (OrgainzeVO dv : list) {
            // 递归计算
            OrgainzeVO departmentPO1 = getTree(dv.getOrgCode(), orgType);
            departmentPO.getChildren().add(departmentPO1);
        }
        return departmentPO;
    }


    /**
     * 获取左侧导航
     *
     * @param
     * @return the response wrapper
     */
    public SysZzjgPO getTreeNew(String zzbm) {
        SysZzjgPO sysZzjgPO = syszzjgRepository.findByZzbm(zzbm);
        Sort sort = new Sort(Sort.Direction.ASC, "orgCode");
        List<SysZzjgPO> list = syszzjgRepository.findByPbm(sysZzjgPO.getZzbm());
        for (SysZzjgPO dv : list) {
            // 递归计算
            SysZzjgPO sysZzjgPO1 = getTreeNew(dv.getZzbm());
            sysZzjgPO.getChildren().add(sysZzjgPO1);
        }
        return sysZzjgPO;
    }

    /**
     * @param orgainzeDTO
     * @return根据该对象更新组织信息
     */
    public int update(OrgainzeDTO orgainzeDTO) {
        OrgainzeVO orgainzeVO = orgainzeRepository.findByOrgCodeAndStateCode(orgainzeDTO.getOrgCode(), 1);
        if (orgainzeVO != null) {
            OrgainzeVO vo = LsBeanUtils.copyProperties(orgainzeDTO, OrgainzeVO.class);
            UpdateTool.copyNullProperties(orgainzeVO, vo);
            orgainzeRepository.saveAndFlush(vo);
            setMqForGrainOrg(vo, Action.ORG_EDIT);
            return 1;
        }
        return 0;
    }

    public List<OrgainzeVO> orgAndDepartTree(String orgCode) {
        List<OrgainzeVO> treeDataList = new ArrayList<>();
        Sort sort = new Sort(Sort.Direction.ASC, "orgCode");
        List<OrgainzeVO> list = orgainzeRepository.findByParentCodeAndStateCode(orgCode, 1, sort);
        for (OrgainzeVO departmentPO : list) {
            OrgainzeVO tree = this.getOrgAndDepartList(departmentPO.getOrgCode(), departmentPO.getOrgType());
            treeDataList.add(tree);
        }
        return treeDataList;
    }

    public List<com.unis.user.common.vo.org.OrgainzeVO> selectByEntity(com.unis.user.common.vo.org.OrgainzeVO orgainzeVO) {
        return orgainzeDomain.selectByEntity(orgainzeVO);
    }

    /**
     * 获取左侧导航
     *
     * @param
     * @return the response wrapper
     */
    public OrgainzeVO getOrgAndDepartList(String orgCode, String orgType) {
        OrgainzeVO departmentPO = orgainzeRepository.findByOrgCodeAndStateCode(orgCode, 1);
        departmentPO.setDepartList(server.getTreeData(departmentPO.getOrgCode()));
        Sort sort = new Sort(Sort.Direction.ASC, "orgCode");
        List<OrgainzeVO> list = orgainzeRepository.findByParentCodeAndStateCodeAndOrgType(departmentPO.getOrgCode(), 1, orgType, sort);
        if (list.size() < 1) {
            departmentPO.setChildren(null);
        }
        for (OrgainzeVO dv : list) {
            // 递归计算
            OrgainzeVO departmentPO1 = getOrgAndDepartList(dv.getOrgCode(), dv.getOrgType());
            departmentPO.getChildren().add(departmentPO1);
        }
        return departmentPO;
    }

    public List<UserPO> getUserInfos(String orgCode, String departCode) {
        String[] departs = null;
        String[] users = null;

        if (!StringUtils.isEmpty(orgCode)) {//组织编号存在

            Sort sort = new Sort(Sort.Direction.ASC, "orderBy");
            List<DepartmentPO> list = repository.findByOrgCodeAndStateCode(orgCode, 1, sort);// 获取所有部门信息
            if (list != null) {
                String[] resources = new String[list.size()];
                for (int i = 0; i < list.size(); i++) {
                    // 拼接角色资源信息
                    resources[i] = list.get(i).getDeptCode();// 拼接部门code信息
                }
                departs = resources;//定义部门数组
            }
        }
        if (!StringUtils.isEmpty(departCode)) {//部门存在
            departs = new String[]{departCode};//将部门置为null
        }
        if (departs != null && users != null) {
            return userRepository.findByDeptCodeInAndUserCodeInAndStateCode(departs, users, 1);
        }
        if (departs != null) {
            return userRepository.findByDeptCodeInAndStateCode(departs, 1);
        }
        if (users != null) {
            return userRepository.findByUserCodeInAndStateCode(users, 1);
        }
        return userRepository.findByStateCode(1);
    }

    public List<UserPO> getUserInfo(String orgCode, String departCode, String roleCode) {
        String[] departs = null;
        String[] users = null;

        if (!StringUtils.isEmpty(orgCode)) {//组织编号存在

            Sort sort = new Sort(Sort.Direction.ASC, "orderBy");
            List<DepartmentPO> list = repository.findByOrgCodeAndStateCode(orgCode, 1, sort);// 获取所有部门信息
            if (list != null) {
                String[] resources = new String[list.size()];
                for (int i = 0; i < list.size(); i++) {
                    // 拼接角色资源信息
                    resources[i] = list.get(i).getDeptCode();// 拼接部门code信息
                }
                departs = resources;//定义部门数组
            }
        }
        if (!StringUtils.isEmpty(departCode)) {//部门存在
            departs = new String[]{departCode};//将部门置为null
        }
        if (!StringUtils.isEmpty(roleCode)) {
            List<UserRoleVO> roleVOs = userRoleRepository.findByRoleCode(roleCode);
            if (roleVOs != null) {
                String[] resources = new String[roleVOs.size()];
                for (int i = 0; i < roleVOs.size(); i++) {
                    // 拼接角色资源信息
                    resources[i] = roleVOs.get(i).getUserCode();// 拼接部门code信息
                }
                users = resources;//将用户code给user数组
            }
        }
        if (departs != null && users != null) {
            return userRepository.findByDeptCodeInAndUserCodeInAndStateCode(departs, users, 1);
        }
        if (departs != null) {
            return userRepository.findByDeptCodeInAndStateCode(departs, 1);
        }
        if (users != null) {
            return userRepository.findByUserCodeInAndStateCode(users, 1);
        }
        return userRepository.findByStateCode(1);
    }

    /**
     * @param areaCode
     * @return根据行政区域后去部门信息
     */
    public List<DepartmentPO> findByDepartmentAreaCode(String areaCode) {
        Sort sort = new Sort(Sort.Direction.ASC, "orderBy");
        List<OrgainzeVO> list = orgainzeRepository.findByCountyCodeAndStateCode(areaCode, 1, sort);
        if (list != null) {
            String[] resources = new String[list.size()];
            for (int i = 0; i < list.size(); i++) {
                // 拼接角色资源信息
                resources[i] = list.get(i).getOrgCode();// 拼接部门code信息
            }
            return repository.findByOrgCodeInAndStateCode(resources, 1, sort);// 获取所有部门信息
        }
        return null;
    }

    public List<OrgainzeVO> findByStateCode() {
        return orgainzeRepository.findByStateCode(1);
    }

    public String findByCode(String orgCode) {
        OrgainzeVO orgainzeVO = orgainzeRepository.findByOrgCodeAndStateCode(orgCode, 1);
        return orgainzeVO == null ? "" : orgainzeVO.getOrgName();
    }

    public List<OrgainzeVO> orgAndDepartTreeNew(String orgCode) {
        List<OrgainzeVO> treeDataList = new ArrayList<>();
        Sort sort = new Sort(Sort.Direction.ASC, "orgCode");
        List<OrgainzeVO> list = orgainzeRepository.findByParentCodeAndStateCode(orgCode, 1, sort);
        for (OrgainzeVO departmentPO : list) {
            // todo 更改获取的数据类型
            if ("LS001".equals(departmentPO.getOrgCode())) {
                List<OrgainzeVO> dept = server.getTreeDataOrg(departmentPO.getOrgCode());
                OrgainzeVO treeData = getTreeData(departmentPO.getOrgCode(), "");
                treeData.getChildren().addAll(0, dept);
                treeDataList.add(treeData);
            }else {
                OrgainzeVO tree = this.getOrgAndDepartListNew(departmentPO.getOrgCode(), departmentPO.getOrgType());
                treeDataList.add(tree);
            }
        }
        return treeDataList;
    }

    public OrgainzeVO getOrgAndDepartListNew(String orgCode, String orgType) {
        OrgainzeVO departmentPO = orgainzeRepository.findByOrgCodeAndStateCode(orgCode, 1);
//		departmentPO.setDepartList(server.getTreeData(departmentPO.getOrgCode()));
        Sort sort = new Sort(Sort.Direction.ASC, "orgCode");
        List<OrgainzeVO> list = orgainzeRepository.findByParentCodeAndStateCodeAndOrgType(departmentPO.getOrgCode(), 1, orgType, sort);
        // 获取当前组织的部门树
        List<OrgainzeVO> departments = server.getTreeDataOrg(orgCode);
        if (list.size() < 1 && departments.size() < 1) {
            departmentPO.setChildren(null);
        }
        for (OrgainzeVO dv : departments) {
            // 递归计算
            departmentPO.getChildren().add(dv);
        }
        for (OrgainzeVO dv : list) {
            // 递归计算
            OrgainzeVO departmentPO1 = getOrgAndDepartListNew(dv.getOrgCode(), dv.getOrgType());
            departmentPO.getChildren().add(departmentPO1);
        }

        return departmentPO;
    }

    /**
     * @param
     * @根据orgName查询orgAreaCode
     */
    public String getOrgAreaCodeByOrgName(String orgName) {
        OrgainzeVO orgainzeVO = orgainzeRepository.findByOrgNameAndStateCode(orgName, 1);
        String countyCode = orgainzeVO.getCountyCode();
        return countyCode;
    }

    /**
     * 根据orgName查询orgCode
     */
    public String getOrgCodeByOrgName(String orgName){
        OrgainzeVO orgainzeVO = orgainzeRepository.findByOrgNameAndStateCode(orgName, 1);
        String orgCode = orgainzeVO.getOrgCode();
        return orgCode;
    }


    /**
     * @param
     * @根据orgCode查询orgName
     */
    public String orgNameByCode(String code) {
        OrgainzeVO orgainzeVO = orgainzeRepository.findByOrgCodeAndStateCode(code, 1);
        String orgName = orgainzeVO.getOrgName();
        return orgName;
    }

    public List<OrgainzeVO> getBizTypeAndOrgType(String orgType) {
        return orgainzeRepository.findByOrgTypeAndStateCode(orgType, 1);
    }

    public OrgainzeVO getAllOrgDescendants(String orgType, String orgId) {
        return orgainzeRepository.findByOrgTypeAndStateCodeAndOrgCode(orgType, 1, orgId);
    }

    public List<OrgainzeVO> findByParentCode(String parentCode) {
        Sort sort = new Sort(Sort.Direction.ASC, "orgCode");
        return orgainzeRepository.findByParentCodeAndStateCode(parentCode, 1, sort);
    }

    public List<OrgainzeVO> findByPid(String parentCode) {
        Sort sort = new Sort(Sort.Direction.ASC, "orgCode");
        return orgainzeRepository.findByParentCodeAndStateCode(parentCode, 1, sort);
    }


    /**
     * 获取分类信息
     *
     * @return the response wrapper
     */
    public SysZzjgPO getTreeDataNew(String zzbm) {
        SysZzjgPO sysZzjgPO = syszzjgRepository.findByZzbm(zzbm);
        if (sysZzjgPO != null) {
            List treeDataList = new ArrayList();
            Sort sort = new Sort(Sort.Direction.ASC, "zzbm");
            List<SysZzjgPO> list = syszzjgRepository.findByPbm(zzbm);
            for (SysZzjgPO sysZzjgPO1 : list) {
                SysZzjgPO tree = this.getTreeNew(sysZzjgPO1.getZzbm());
                treeDataList.add(tree);
            }
            sysZzjgPO.setChildren(treeDataList);
        }

        return sysZzjgPO;
    }

    /**
     * 获取分类信息
     *
     * @return the response wrapper
     */
    public OrgainzeVO getTreeDataGouXiao(String zzbm) {
        /*OrgainzeVO orgainzeVO = orgainzeRepository.findByOrgCodeAndStateCode(zzbm, 1);
        if (orgainzeVO != null) {
            List<OrgainzeVO> list = orgainzeRepository.findByOrgLevelAndStateCode(gxgsOrgLevel, 1);
            OrgainzeVO orgainzeVOSeoical = orgainzeRepository.findByOrgCodeAndStateCode(gouxiaoSpecial, 1);
            list.add(orgainzeVOSeoical);
            for (OrgainzeVO orgTemp : list) {
                List<OrgainzeVO> orgTempList = this.findByParentCode(orgTemp.getOrgCode());
                orgTemp.setChildren(orgTempList);
            }
            orgainzeVO.setChildren(list);
        }

        return orgainzeVO;*/
    	OrgainzeVO orgainzeVO = orgainzeRepository.findByOrgCodeAndStateCode("LS001", 1); // 天津市粮食和物资储备局
    	if (orgainzeVO != null) {
    		List<OrgainzeVO> list = orgainzeRepository.findByOrgLevelAndStateCode(gxgsOrgLevel, 1);
    		OrgainzeVO orgainze2 = orgainzeRepository.findByOrgCodeAndStateCode(zzbm, 1);
    		list.add(orgainze2);
            for (OrgainzeVO orgTemp : list) {
                List<OrgainzeVO> orgTempList = this.findByParentCode(orgTemp.getOrgCode());
                orgTemp.setChildren(orgTempList);
            }
            orgainzeVO.setChildren(list);
    	}
    	return orgainzeVO;
    }

    public OrgainzeVO getTreeDataCompany(String root,String zzbm) {
        OrgainzeVO orgainzeVORoot = orgainzeRepository.findByOrgCodeAndStateCode(root, 1);
        if (orgainzeVORoot != null) {
            OrgainzeVO orgainzeVO = orgainzeRepository.findByOrgCodeAndStateCode(zzbm, 1);
            if(orgainzeVO!=null){
                List<OrgainzeVO> children = new ArrayList<>();
                children.add(orgainzeVO);
                orgainzeVORoot.setChildren(children);
                List<OrgainzeVO> list = this.findByParentCode(zzbm);
                orgainzeVO.setChildren(list);
            }
        }

        return orgainzeVORoot;
    }

    /**
     * 获取分类信息
     *
     * @return the response wrapper
     */
    public List<OrgainzeVO> getTreeDataOrganKudianGouXiao(String zzbm) {
        DKdxxsjyVO dKdxxsjyVO=new DKdxxsjyVO();
        com.unis.common.utils.ResponseWrapper responseWrapper=baseServiceClient.selectKdxx(dKdxxsjyVO);
        Map<String, DKdxxsjyVO> kdMap=null;
        if(responseWrapper.isSuccess() && responseWrapper.getData()!=null){
            List<DKdxxsjyVO> dkList=JsonUtils.parseList(JsonUtils.serialize(responseWrapper.getData()),DKdxxsjyVO.class );
            kdMap=dkList.stream().collect(Collectors.toMap(a->a.getQyjgdm(),a->a,(k1,k2)->k1));
        }else{
            kdMap =new HashMap<>();
        }

        List<OrgainzeVO> list = orgainzeRepository.findByOrgLevelAndOrgTypeAndStateCode(gxgsOrgLevel, "10190005", 1);
        List<OrgainzeVO>  gouXiaoGongSiSub = orgainzeRepository.listByOrgLevelAndParentOrg(liangKuLevel, chuBei);
        log.info("储备公司下属 外地库{}", JSONObject.toJSONString(gouXiaoGongSiSub));
        list.addAll(gouXiaoGongSiSub);
        String orgCode = null;
        for (OrgainzeVO orgTemp : list) {
//            List<OrgainzeVO> orgTempList = orgainzeRepository.listAllChild(orgTemp.getOrgCode());
            List<OrgainzeVO> orgTempList = this.findByParentCode(orgTemp.getOrgCode());
            orgCode=orgTemp.getOrgCode();
            if(kdMap.containsKey(orgCode)){
                DKdxxsjyVO tempDKdxxsjyVO=kdMap.get(orgCode);
                orgTemp.setSskddm(tempDKdxxsjyVO.getKddm());
                orgTemp.setSskdmc(tempDKdxxsjyVO.getKdmc());
                orgTemp.setTyshxydm(tempDKdxxsjyVO.getTyshxydm());
            }
            for(OrgainzeVO temp : orgTempList){
                String tempCode=temp.getOrgCode();
                if(kdMap.containsKey(tempCode)){
                    DKdxxsjyVO tempDKdxxsjyVO=kdMap.get(tempCode);
                    temp.setSskddm(tempDKdxxsjyVO.getKddm());
                    temp.setSskdmc(tempDKdxxsjyVO.getKdmc());
                    temp.setTyshxydm(tempDKdxxsjyVO.getTyshxydm());
                }
            }
            orgTemp.setChildren(orgTempList);
        }
        return list;
    }


    private void setMqForOrgInfo(OrgainzeVO sysOrganizationDO, String action) {
        try {
            OrganizationDTO mqOrgDTO = packageMqOrgDTO(sysOrganizationDO);
            //
            RabbitObjectTO rabbitObjectTO = new RabbitObjectTO();
            rabbitObjectTO.setAction(action);
            rabbitObjectTO.setObject(mqOrgDTO);
            iMessageProvider.send(rabbitObjectTO);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private OrganizationDTO packageMqOrgDTO(OrgainzeVO sysOrganizationDO) {
        OrganizationDTO mqOrgDTO = new OrganizationDTO();

        mqOrgDTO.setId(sysOrganizationDO.getOrgCode());
        mqOrgDTO.setName(sysOrganizationDO.getOrgName());//名称
        mqOrgDTO.setOrders(sysOrganizationDO.getOrderBy());//排序
        mqOrgDTO.setParentId(sysOrganizationDO.getParentCode());//上级节点id
        Sort sort = new Sort(Sort.Direction.ASC, "orgCode");
        if (StringUtils.isNotEmpty(sysOrganizationDO.getParentCode())) {
            OrgainzeVO parentDO = orgainzeRepository.findByOrgCodeAndStateCode(sysOrganizationDO.getParentCode(), 1);
            if (null != parentDO) {
                mqOrgDTO.setParentName(parentDO.getOrgName());//上级节点名称
                mqOrgDTO.setParentAreaCode(parentDO.getCountyCode());
            }
        }
//        mqOrgDTO.setRoot();//是否为根节点 0 代表是， 1代表否
//        mqOrgDTO.setValid();//是否有效（有效 ,无效)
        //if("1" == sysOrganizationDO.getOrgType()) {
        mqOrgDTO.setType("单位");//部门类型 单位 部门
        mqOrgDTO.setTypeCode(0);//部门类型码 0 是单位 1是部门
        mqOrgDTO.setOrgType(sysOrganizationDO.getOrgType());//设置单位类型
		/*} else if("2" == sysOrganizationDO.getOrgType()) {
			mqOrgDTO.setType("部门");//部门类型 单位 部门
			mqOrgDTO.setTypeCode(1);//部门类型码 0 是单位 1是部门
		}*/

        mqOrgDTO.setAreaCode(sysOrganizationDO.getCountyCode());//行政区划代码
        return mqOrgDTO;
    }

    private void setMqForGrainOrg(OrgainzeVO orgainzeVO, String action) {
//    	String orgType = sysOrganizationDO.getOrgType();
//    	String orgId = sysOrganizationDO.getOrgId();
//    	SysOrganizationDO orgDO = sysOrganizationMapper.selectByPrimaryKey(orgId);
//        if(! GRAIN_UNIT__CODE.equals(orgType) && ! GRAIN_UNIT__CODE.equals(orgDO.getOrgType())) {
//            return;
//        }
        if (isGrainUnit(orgainzeVO) || isGrainDept(orgainzeVO)) {
            setMqForOrgInfo(orgainzeVO, action);
        }
    }

    /**
     * 判断是否是粮食局单位
     *
     * @param
     * @return
     * @date 2019年3月8日, 下午3:52:33
     * @author xmpu
     * @version v1.0
     */
    private boolean isGrainUnit(OrgainzeVO orgainzeVO) {
        //if(orgainzeVO.getOrgType().equals(OgTypeEnum.ORG.getCode())) {
        if (GRAIN_UNIT_CODE.equals(orgainzeVO.getOrgType())) {
            return true;
        }
        //}
        return false;
    }

    /**
     * 判断是否是粮食局部门
     *
     * @param
     * @return
     * @date 2019年3月8日, 下午3:56:51
     * @author xmpu
     * @version v1.0
     */
    private boolean isGrainDept(OrgainzeVO orgainzeVO) {
        //if(orgainzeVO.getOrgType().equals(OgTypeEnum.DEPT.getCode())) {
        OrgainzeVO parentDO = orgainzeRepository.findByOrgCodeAndStateCode(orgainzeVO.getParentCode(), 1);
        if (GRAIN_UNIT_CODE.equals(parentDO.getOrgType())) {
            return true;
        }
        //}
        return false;
    }

    /**
     * @param zzbm
     * @return 获取监督检查所需要的数据
     */
    public OrgainzeVO getJdjcTreeData(String zzbm) {
        OrgainzeVO departmentPO = new OrgainzeVO();
        if (zzbm.length() > 5) {
            departmentPO = orgainzeRepository.findByOrgCodeAndStateCode(zzbm, 1);
        } else {
            departmentPO = orgainzeRepository.findByOrgCodeAndStateCode(zzbm, 1);
            if (departmentPO != null) {
                Sort sort = new Sort(Sort.Direction.ASC, "orgCode");
                List<OrgainzeVO> list = orgainzeRepository.findOrgInfo(departmentPO.getOrgCode());
                departmentPO.setChildren(list);
            }
        }
        return departmentPO;
    }

    public List<OrgainzeVO> findByAreaCodeAndOrgType(String areaCode, String orgType) {
        return orgainzeRepository.findByCountyCodeAndOrgTypeAndStateCode(areaCode, orgType, 1);
    }


    /**
     * 通过组织名称获取信息
     *
     * @param orgName
     * @return
     */
    public OrgainzeVO findByOrgName(String orgName) {
        return orgainzeRepository.findByOrgNameAndStateCode(orgName, 1);
    }

    /**
     *  通过递归算法过滤掉"orgType"="10190005"（企业）的数据
     *
     * @param orgainzeDTO
     * @return
     */
    public OrgainzeVO excludeCompany(OrgainzeVO orgainzeDTO) {
        List<OrgainzeVO> children = orgainzeDTO.getChildren();
        ListIterator<OrgainzeVO> iterator = children.listIterator();
        while (iterator.hasNext()) {
            OrgainzeVO orgainzeVO = iterator.next();
            if (orgainzeVO.getChildren() != null && orgainzeVO.getChildren().size() > 0) {
                OrgainzeVO vo = this.excludeCompany(orgainzeVO);
//                if (vo == null) {
//                    orgainzeVO.
//                }
            } else {
                if ("10190005".equals(orgainzeVO.getOrgType())) {
                    iterator.remove();
                }
            }
        }
        orgainzeDTO.setChildren(children);
        return orgainzeDTO;
    }

    /**
     * 功能描述: 获取各盟市下的所有企业
     *
     * @Param: [orgCode, orgType]
     * @Return: com.unis.user.server.model.OrgainzeVO
     * @Author: zoujieli
     * @Date: 2020-04-16 11:44
     */
    /*public OrgainzeVO getCompanyTreeData(String orgCode, String orgType) {
        OrgainzeVO orgainzeVO = orgainzeRepository.findByOrgCodeAndStateCodeAndOrgTypeLike(orgCode, 1, "%" + orgType + "%");
        orgainzeVO.setTyshxydm(orgainzeVO.getOrgCode());
        orgainzeVO.setQymc(orgainzeVO.getOrgName());
        if (orgainzeVO != null) {
            Sort sort = new Sort(Sort.Direction.ASC, "orgCode");
            List<OrgainzeVO> list = orgainzeRepository.findByParentCodeAndStateCodeAndOrgTypeLike(orgCode, 1, "%" + orgType + "%", sort);
            List<CompanyVO> companyVOList = new ArrayList<>();
            Iterator<OrgainzeVO> iterator = list.iterator();
            while (iterator.hasNext()){
                CompanyVO companyVO = new CompanyVO();
                OrgainzeVO next = iterator.next();
                companyVO.setQymc(next.getOrgName());
                companyVO.setTyshxydm(next.getOrgCode());
                companyVO.setSslsxzglbm(next.getOrgCode());
                companyVO.setDwdm(next.getCountyCode());
                companyVOList.add(companyVO);
            }
            for (CompanyVO vo : companyVOList) {
                //根据ORGID获取下面的所有企业
//                CompanyQueryVO companyQueryVO = new CompanyQueryVO();
//                companyQueryVO.setSslsxzglbm(vo.getSslsxzglbm());
                String dwdm = vo.getDwdm();
                if (StringUtils.isNotBlank(dwdm) && dwdm.length() > 4) {
                    ResponseWrapper companyListRW = baseServiceClient.getCompanyInfoByDwdm(vo.getDwdm());
                    List<CompanyVO> companyVOS = (List<CompanyVO>) companyListRW.getData();
                    //List<CompanyVO> companyVOS = JsonUtils.parseList(JsonUtils.serialize(data), CompanyVO.class);
                    vo.setCompanyChildren(companyVOS);
                }
            }
            orgainzeVO.setCompanyChildren(companyVOList);
        }
        return orgainzeVO;
    }*/

    public OrgainzeVO findByOrgCodeAndStateCode(String orgcode, int i, Sort sort) {
        return  orgainzeRepository.findByOrgCodeAndStateCode(orgcode,1);
    }

    public List<OrgainzeVO> getTreeDataOrganGouXiao(String zzbm) {
        DKdxxsjyVO dKdxxsjyVO=new DKdxxsjyVO();
        ResponseWrapper responseWrapper=baseServiceClient.selectKdxxLgd(dKdxxsjyVO);
        System.out.println(responseWrapper.toString());
        Map<String, DKdxxsjyVO> kdMap=null;
        if(responseWrapper.isSuccess() && responseWrapper.getData()!=null){
            Object data = responseWrapper.getData();
            List<DKdxxsjyVO> dkList=JsonUtils.parseList(JsonUtils.serialize(data),DKdxxsjyVO.class );
            for(DKdxxsjyVO dKdxxsjyVO1:dkList){
                OrgainzeVO orgainzeVO = orgainzeRepository.findByOrgCodeAndStateCode(dKdxxsjyVO1.getQyjgdm(),1);
                dKdxxsjyVO1.setKddh(orgainzeVO.getParentCode());
            }
            kdMap=dkList.stream().collect(Collectors.toMap(a->a.getQyjgdm(),a->a,(k1,k2)->k1));
        }else{
            kdMap =new HashMap<>();
        }
        List<OrgainzeVO> list = orgainzeRepository.findByOrgLevelAndStateCode(gxgsOrgLevel, 1);
        List<OrgainzeVO>  gouXiaoGongSiSub = orgainzeRepository.listByOrgLevelAndParentOrg(liangKuLevel, chuBei);
        log.info("储备公司下属 外地库{}", JSONObject.toJSONString(gouXiaoGongSiSub));
        list.addAll(gouXiaoGongSiSub);
        List<OrgainzeVO> newList = new ArrayList<>();
        for (OrgainzeVO orgTemp : list) {
            for (Map.Entry<String, DKdxxsjyVO> entry : kdMap.entrySet()) {
                if(entry.getValue().getKddh().equals(orgTemp.getOrgCode())||entry.getValue().getQyjgdm().equals(orgTemp.getOrgCode())){
                    OrgainzeVO vo = new OrgainzeVO();
                    vo.setTyshxydm(entry.getValue().getTyshxydm());
                    vo.setSskddm(entry.getValue().getKddm());
                    vo.setOrgCode(entry.getValue().getKddm());
                    vo.setOrgName(entry.getValue().getKdmc());
                    vo.setSskdmc(entry.getValue().getKdmc());
                    newList.add(vo);
                }
            }
        }
        for (OrgainzeVO orgTemp : newList) {
            List<OrgainzeVO> child = new ArrayList<>();
            for (Map.Entry<String, DKdxxsjyVO> entry : kdMap.entrySet()) {
                if (entry.getValue().getKddh().equals(orgTemp.getOrgCode())) {
                    OrgainzeVO orgainzeVO = new OrgainzeVO();
                    orgainzeVO.setSskddm(entry.getValue().getKddm());
                    orgainzeVO.setOrgCode(entry.getValue().getKddm());
                    orgainzeVO.setOrgName(entry.getValue().getKdmc());
                    orgainzeVO.setSskdmc(entry.getValue().getKdmc());
                    orgainzeVO.setTyshxydm(entry.getValue().getTyshxydm());
                    child.add(orgainzeVO);
                }
            }
            orgTemp.setChildren(child);
        }
        return newList;
    }
    public List<OrgainzeVO> getTreeDataOrganGouXiaoForQc(String zzbm) {
        DKdxxsjyVO dKdxxsjyVO=new DKdxxsjyVO();
        ResponseWrapper responseWrapper=baseServiceClient.selectKdxxLgdForQc(dKdxxsjyVO);
        System.out.println(responseWrapper.toString());
        Map<String, DKdxxsjyVO> kdMap=null;
        if(responseWrapper.isSuccess() && responseWrapper.getData()!=null){
            Object data = responseWrapper.getData();
            List<DKdxxsjyVO> dkList=JsonUtils.parseList(JsonUtils.serialize(data),DKdxxsjyVO.class );
            for(DKdxxsjyVO dKdxxsjyVO1:dkList){
                OrgainzeVO orgainzeVO = orgainzeRepository.findByOrgCodeAndStateCode(dKdxxsjyVO1.getQyjgdm(),1);
                dKdxxsjyVO1.setKddh(orgainzeVO.getParentCode());
            }
            kdMap=dkList.stream().collect(Collectors.toMap(a->a.getQyjgdm(),a->a,(k1,k2)->k1));
        }else{
            kdMap =new HashMap<>();
        }
        List<OrgainzeVO> list = orgainzeRepository.findByOrgLevelAndStateCode(gxgsOrgLevel, 1);
        OrgainzeVO orgainzeVOSeoical = orgainzeRepository.findByOrgCodeAndStateCode(gouxiaoSpecial, 1);
        list.add(orgainzeVOSeoical);
        List<OrgainzeVO> newList = new ArrayList<>();
        for (OrgainzeVO orgTemp : list) {
            for (Map.Entry<String, DKdxxsjyVO> entry : kdMap.entrySet()) {
                if(entry.getValue().getKddh().equals(orgTemp.getOrgCode())||entry.getValue().getQyjgdm().equals(orgTemp.getOrgCode())){
                    OrgainzeVO vo = new OrgainzeVO();
                    vo.setTyshxydm(entry.getValue().getTyshxydm());
                    vo.setSskddm(entry.getValue().getKddm());
                    vo.setOrgCode(entry.getValue().getKddm());
                    vo.setOrgName(entry.getValue().getKdmc());
                    vo.setSskdmc(entry.getValue().getKdmc());
                    newList.add(vo);
                }
            }
        }
        for (OrgainzeVO orgTemp : newList) {
            List<OrgainzeVO> child = new ArrayList<>();
            for (Map.Entry<String, DKdxxsjyVO> entry : kdMap.entrySet()) {
                if (entry.getValue().getKddh().equals(orgTemp.getOrgCode())) {
                    OrgainzeVO orgainzeVO = new OrgainzeVO();
                    orgainzeVO.setSskddm(entry.getValue().getKddm());
                    orgainzeVO.setOrgCode(entry.getValue().getKddm());
                    orgainzeVO.setOrgName(entry.getValue().getKdmc());
                    orgainzeVO.setSskdmc(entry.getValue().getKdmc());
                    orgainzeVO.setTyshxydm(entry.getValue().getTyshxydm());
                    child.add(orgainzeVO);
                }
            }
            orgTemp.setChildren(child);
        }
        return newList;
    }

    /**
     * 通过组织名称获取信息
     *
     * @param orgName
     * @return
     */
    public OrgainzeVO findByOrgNameAndParentCode(String orgName, String parentCode) {
        return orgainzeRepository.findByOrgNameAndStateCodeAndParentCode(orgName, 1, parentCode);
    }

    /**
     * 获取本级以及下级列表
     * @param orgCode
     * @return
     */
    public List<OrgainzeVO> findCurrentAndChilds(String orgCode) {
        return orgainzeRepository.findCurrentAndChilds(orgCode);
    }

    public List<OrgainzeVO> listDevAndRef() {
        List<OrgainzeVO> list = orgainzeRepository.listDevAndRef();
        return list;
    }

    public List<OrgainzeVO> listAcceptUnit(String orgName) {
        Map<String, Object> res = new HashMap<>();
        List<OrgainzeVO> devAndRefList = orgainzeRepository.listDevAndRef(); // 发改委
//        res.put("devAndRefList", devAndRefList);
        List<OrgainzeVO> childUnitList = orgainzeRepository.listChildUnit(); // 子单位
//        res.put("childUnitList", childUnitList);
        Sort sort = new Sort(Sort.Direction.ASC, "orderBy");
        List<OrgainzeVO> gxList = orgainzeRepository.findByOrgLevelAndOrgTypeAndStateCode(gxgsOrgLevel, "10190005", 1, sort);
//        res.put("gxList", gxList);
        List<OrgainzeVO> warehouseList = orgainzeRepository.listWarehouse();
//        res.put("warehouseList", warehouseList);
        List<OrgainzeVO> ydcckList = new ArrayList<>();
        // 将warehouseList中的数据放入gxList中orgName为德惠松柏储备粮有限公司,河北良禾粮油购销有限公司,衡水和平国储粮库有限责任公司深州分公司,
        // 德惠杨树储备粮有限公司,河北省粮食产业集团晋州粮食储备有限公司,延寿利达粮油有限公司从warehouseList中移除，并放入ydcckList中
        for (OrgainzeVO orgainzeVO : warehouseList) {
            if ("德惠松柏储备粮有限公司".equals(orgainzeVO.getOrgName()) || "河北良禾粮油购销有限公司".equals(orgainzeVO.getOrgName()) ||
                    "衡水和平国储粮库有限责任公司深州分公司".equals(orgainzeVO.getOrgName()) || "德惠杨树储备粮有限公司".equals(orgainzeVO.getOrgName()) ||
                    "河北省粮食产业集团晋州粮食储备有限公司".equals(orgainzeVO.getOrgName()) || "延寿利达粮油有限公司".equals(orgainzeVO.getOrgName())) {
                ydcckList.add(orgainzeVO);
            }
        }
        // warehouseList移除"德惠松柏储备粮有限公司".equals(orgainzeVO.getOrgName()) || "河北良禾粮油购销有限公司".equals(orgainzeVO.getOrgName()) ||
        //                    "衡水和平国储粮库有限责任公司深州分公司".equals(orgainzeVO.getOrgName()) || "德惠杨树储备粮有限公司".equals(orgainzeVO.getOrgName()) ||
        //                    "河北省粮食产业集团晋州粮食储备有限公司".equals(orgainzeVO.getOrgName()) || "延寿利达粮油有限公司".equals(orgainzeVO.getOrgName())数据
        warehouseList.removeIf(orgainzeVO -> "德惠松柏储备粮有限公司".equals(orgainzeVO.getOrgName()) || "河北良禾粮油购销有限公司".equals(orgainzeVO.getOrgName()) ||
                "衡水和平国储粮库有限责任公司深州分公司".equals(orgainzeVO.getOrgName()) || "德惠杨树储备粮有限公司".equals(orgainzeVO.getOrgName()) ||
                "河北省粮食产业集团晋州粮食储备有限公司".equals(orgainzeVO.getOrgName()) || "延寿利达粮油有限公司".equals(orgainzeVO.getOrgName()));

        OrgainzeVO devAndRef = new OrgainzeVO("区粮办", devAndRefList);
        OrgainzeVO gx = new OrgainzeVO("购销公司", gxList);
        OrgainzeVO warehouse = new OrgainzeVO("承储库", warehouseList);
        OrgainzeVO ydcck = new OrgainzeVO("异地承储库", ydcckList);
        List<OrgainzeVO> list = new ArrayList<>();
        list.add(devAndRef);
        list.add(gx);
        list.add(warehouse);
        list.add(ydcck);
        list.addAll(childUnitList);
        res.put("list", list);
        return list;
    }
}
