package com.unis.user.server.server;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Predicate;
import javax.persistence.criteria.Root;

import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.stereotype.Service;

import com.unis.common.base.BaseService;
import com.unis.common.utils.UpdateTool;
import com.unis.user.server.dto.ParaConfigDTO;
import com.unis.user.server.model.ParaConfigVO;
import com.unis.user.server.model.UserPO;
import com.unis.user.server.repository.ParaConfigRepository;
import com.unis.user.server.untils.LsBeanUtils;

/**
 * @author hx
 * 参数信息server类
 */
@Service
public class ParaConfigServer extends BaseService {

	@Autowired
	private ParaConfigRepository paraConfigRepository;

	public List<ParaConfigVO> fingParaConfigList(String paraCode) {
        Sort sort = new Sort(Sort.Direction.ASC, "orderBy");
		return paraConfigRepository.findParaConfigByParaCodeAndStateCode(paraCode,1, sort);
	}

	public ParaConfigVO fingParaConfig(String configCode) {
		// TODO Auto-generated method stub
		return paraConfigRepository.findByConfigCodeAndStateCode(configCode,1);
	}

	public int add(ParaConfigDTO paraConfigDTO) {
		ParaConfigVO paraVO = paraConfigRepository.findByConfigCodeAndStateCode(paraConfigDTO.getConfigCode(),1);
		if(paraVO!=null) {
			return 0;
		}
		ParaConfigVO vo = new ParaConfigVO();
		UpdateTool.copyNullProperties( paraConfigDTO, vo );
		vo.setCreator("test");
		vo.setCreatorCode("test");
		vo.setCreateDate(new Date());
		paraConfigRepository.save(vo);
		return 1;
	}

	public int update(ParaConfigDTO paraConfigDTO) {
		paraConfigRepository.upByConfigCode(paraConfigDTO.getConfigCode(),paraConfigDTO.getConfigName(),paraConfigDTO.getConfigValue(),paraConfigDTO.getConfigLastValue(),paraConfigDTO.getConfigNameEn(),paraConfigDTO.getPym(),paraConfigDTO.getOrderBy(),"test","test");
//		ParaConfigVO configVO = paraConfigRepository.findByConfigCodeAndStateCode(paraConfigDTO.getConfigCode(), 1);
//		ParaConfigVO userPO1 = LsBeanUtils.copyProperties(paraConfigDTO, ParaConfigVO.class);
//		UpdateTool.copyNullProperties(configVO, userPO1);
//		paraConfigRepository.save(userPO1);
		return 1;
	}

	public int delete(String[] configCodes) {
		int i = 0;
		for(String config: configCodes) {
			i = i+ paraConfigRepository.deleteByConfigCode(config);
		}
		return i;
	}

	public Page<ParaConfigVO> findByPage(ParaConfigDTO paraConfigDTO, Integer page, Integer size) {
		PageRequest pageable = PageRequest.of( (page - 1), size, Sort.Direction.ASC, "orderBy" );
		Specification<ParaConfigVO> specification = new Specification<ParaConfigVO>() {
			@Override
			public Predicate toPredicate(Root<ParaConfigVO> root, CriteriaQuery<?> query, CriteriaBuilder cb) {
				List<Predicate> list = new ArrayList<Predicate>();
				//参数编号
				if (StringUtils.isNotBlank(paraConfigDTO.getConfigCode())) {
					list.add( cb.like( root.get( "configCode" ).as( String.class ), "%" + paraConfigDTO.getConfigCode() + "%" ) );
				}
				//参数名称
				if (StringUtils.isNotBlank(paraConfigDTO.getConfigName())) {
					list.add( cb.like( root.get( "configName" ).as( String.class ), "%" +paraConfigDTO.getConfigName() + "%" ) );
				}
				//参数类型code
				if (StringUtils.isNotBlank(paraConfigDTO.getParaCode())) {
					list.add( cb.equal( root.get( "paraCode" ).as( String.class ), paraConfigDTO.getParaCode()) );
				}
				//参数配置值
				if(StringUtils.isNotBlank(paraConfigDTO.getConfigValue())){
					list.add( cb.equal( root.get( "configValue" ).as( String.class ),"%" + paraConfigDTO.getConfigValue() + "%" ) );
				}

				//参数极限值
				if(StringUtils.isNotBlank(paraConfigDTO.getConfigLastValue())){
					list.add( cb.equal( root.get( "configLastValue" ).as( String.class ),"%" + paraConfigDTO.getConfigLastValue() + "%" ) );
				}
				list.add( cb.equal( root.get( "stateCode" ).as( Integer.class ), 1) );
				//list.add(cb.equal(root.get("pid").as(Long.class),dto.getPid()));
				return cb.and( list.toArray( new Predicate[list.size()] ) );
			}
		};
		return paraConfigRepository.findAll(specification, pageable);
	}

	/**
	 * @param configCode
	 * @return获取参数配置名称
	 */
	String getConfigName(String configCode) {
		if(StringUtils.isEmpty(configCode)) {
			return "未定义";
		}
		ParaConfigVO configVO = fingParaConfig(configCode);
		if(configVO==null) {
			return "未定义";
		}
		return configVO.getConfigName();
	}
}
