package com.unis.user.server.server;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Predicate;
import javax.persistence.criteria.Root;

import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.stereotype.Service;

import com.unis.common.base.BaseService;
import com.unis.common.utils.UpdateTool;
import com.unis.user.server.dto.ParaDTO;
import com.unis.user.server.model.ParaConfigVO;
import com.unis.user.server.model.ParaVO;
import com.unis.user.server.repository.BaseRepository;
import com.unis.user.server.repository.ParaRepository;
import org.springframework.transaction.annotation.Transactional;

@Service
public class ParaServer extends BaseService {
	
	@Autowired
	private ParaRepository paraRepository;

	public List<ParaVO> fingParaList() {
		// TODO Auto-generated method stub
		return paraRepository.findByStateCode(1);
	}

	public int update(ParaDTO paraDTO) {	
		return paraRepository.update(paraDTO.getParaCode(),paraDTO.getParaName(),paraDTO.getTableName(),paraDTO.getTableField(),"test","test");
	}

	public int add(ParaDTO paraDTO) {
		//获取参数类型表最大参数
//		Object paraCode = baseRepository.selectByTableNameAndAttr("BAS_PARAMETER","PARA_CODE","");
		ParaVO paraVO = paraRepository.findByParaCode(paraDTO.getParaCode());
		if(paraVO!=null) {
			return 0;
		}
		ParaVO vo = new ParaVO();
		UpdateTool.copyNullProperties( paraDTO, vo );
		vo.setCreator("test");
		vo.setCreatorCode("test");
		vo.setCreateDate(new Date());
		paraRepository.save(vo);
		return 1;
	}
	@Transactional
	public void delete(String[] paraCode) {
		/*int i = 0;*/
		for(String para:paraCode) {
			paraRepository.deleteByParaCode(para);
		}
		//return i;*/
	}

	public Page<ParaVO> findByPage(ParaDTO paraDTO, Integer page, Integer size) {
		PageRequest pageable = PageRequest.of( (page - 1), size, Sort.Direction.ASC, "paraCode" );
		Specification<ParaVO> specification = new Specification<ParaVO>() {
			@Override
			public Predicate toPredicate(Root<ParaVO> root, CriteriaQuery<?> query, CriteriaBuilder cb) {
				List<Predicate> list = new ArrayList<Predicate>();
				//参数编号
				if (StringUtils.isNotBlank(paraDTO.getParaCode())) {
					list.add( cb.like( root.get( "paraCode" ).as( String.class ), "%" + paraDTO.getParaCode() + "%" ) );
				}
				//参数名称
				if (StringUtils.isNotBlank(paraDTO.getParaName())) {
					list.add( cb.like( root.get( "paraName" ).as( String.class ), "%" + paraDTO.getParaName()+ "%" ) );
				}
				//参数配置值
				if(StringUtils.isNotBlank(paraDTO.getTableName())){
					list.add( cb.equal( root.get( "tableName" ).as( String.class ),"%" + paraDTO.getTableName() + "%" ) );
				}
				
				//参数极限值
				if(StringUtils.isNotBlank(paraDTO.getTableField())){
					list.add( cb.equal( root.get( "tableField" ).as( String.class ),"%" + paraDTO.getTableField() + "%" ) );
				}
				list.add( cb.equal( root.get( "stateCode" ).as( Integer.class ), 1) );
				return cb.and( list.toArray( new Predicate[list.size()] ) );
			}
		};
		return paraRepository.findAll(specification, pageable);
	}

	public ParaVO fingParaInfo(String paraCode) {
		// TODO Auto-generated method stub
		return paraRepository.findByParaCodeAndStateCode(paraCode,1);
	}

}
