package com.unis.user.server.server;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.data.domain.Sort;
import com.unis.common.utils.UpdateTool;
import com.unis.user.server.dto.ResourceDTO;
import com.unis.user.server.model.DepartmentPO;
import com.unis.user.server.model.ResourcePO;
import com.unis.user.server.repository.BaseRepository;
import com.unis.user.server.repository.ResourceRepository;
import com.unis.user.server.untils.LsBeanUtils;

@Service
public class ResourceserServer {

	@Autowired
	private ResourceRepository resourceRepository;
	
	@Autowired
	private  BaseRepository baseRepository;

	/**
	 * 保存
	 * 
	 * @param resourceDTO
	 * @return
	 * @throws Exception
	 */
	public boolean save(ResourceDTO resourceDTO) throws Exception {
		ResourcePO resourcePO1 = LsBeanUtils.copyProperties(resourceDTO, ResourcePO.class);
		if (resourceDTO.getStatusCode() == null) {
			resourcePO1.setStateCode(1);
		}
		if (ObjectUtils.equals(resourcePO1.getResourceName(), null)) {
			return false;
		}
//		if (ObjectUtils.equals(resourcePO1.getParentCode(), null)) {
//			return false;
//		}
		if (ObjectUtils.equals(resourcePO1.getResourceType(), null)) {
			return false;
		}
		
		if(StringUtils.isEmpty(resourceDTO.getParentCode())) {
			 String resourceCode = baseRepository.selectByTableNameAndAttr("SYS_RESOURCE_INFO", "RESOURCE_CODE", "RM1", 3);
			 resourcePO1.setParentCode("RM1");
			 resourcePO1.setResourceCode(resourceCode);
		}else {
			 String resourceCode = baseRepository.selectByTableNameAndAttr("SYS_RESOURCE_INFO", "RESOURCE_CODE", resourceDTO.getParentCode(), 3);
			 resourcePO1.setResourceCode(resourceCode);
			 resourcePO1.setParentCode(resourceDTO.getParentCode());
		}
		resourceRepository.save(resourcePO1);
		return true;
	}
	

	/**
	 * 修改
	 * @param resourceDTO
	 * @return
	 */
	public boolean update(ResourceDTO resourceDTO) {
		ResourcePO resourcePO = resourceRepository.findByResourceCodeAndStateCode(resourceDTO.getResourceCode() ,1);

		if (ObjectUtils.equals(resourcePO, null)) {
			return false;
		}
		ResourcePO resourcePO1 = LsBeanUtils.copyProperties(resourceDTO, ResourcePO.class);
		UpdateTool.copyNullProperties(resourcePO, resourcePO1);
		resourceRepository.save(resourcePO1);
		
		return true;
	}

	/**
	 * 多选删除
	 * @param ids
	 * @return
	 * @throws Exception
	 */
	@Transactional(rollbackFor = Exception.class)
	public boolean deletes(String[] ids) throws Exception {
			for (String resourceCode : ids) {
				ResourcePO resourcePO = resourceRepository.findByResourceCodeAndStateCode(resourceCode ,1);
				if (ObjectUtils.notEqual(resourcePO, null)) {
					resourcePO.setStateCode(0);
					resourceRepository.saveAndFlush(resourcePO);
				}
			}
		return true;
	}
	
	
	/**
	 * 分页
	 * @param
	 * @param page
	 * @param size
	 * @return
	 */
	public Map<String, Object> findByPage(Integer status,Integer page, Integer size){
		List<ResourcePO> resourcePOList = resourceRepository.findByStateCode(status);
		List<ResourceDTO> resList = new ArrayList<ResourceDTO>();
		List<ResourceDTO> resDtoList = new ArrayList<ResourceDTO>();
		for (ResourcePO resourcePO : resourcePOList) {
			ResourceDTO res = LsBeanUtils.copyProperties(resourcePO, ResourceDTO.class);
			resList.add(res);
		}
		// 从第几条数据开始
		int firstIndex = (page - 1) * size;
		// 到第几条数据结束
		int lastIndex = page * size;
		if (resList.size() >= lastIndex) {
			resDtoList = resList.subList(firstIndex, lastIndex);
		} else {
			resDtoList = resList.subList(firstIndex, resList.size());
		}
		Map<String, Object> resultMap = new HashMap<>();
		resultMap.put("total", resList.size());
		resultMap.put("resDtoList", resDtoList);
		return resultMap;
	}


	public List<ResourcePO> getTreeData() {
		List<ResourcePO> arrayList = new ArrayList<>();
		Sort sort = new Sort(Sort.Direction.ASC, "resourceIndex");
		List<ResourcePO> list = resourceRepository.findByParentCodeAndStateCode("RM1", 1, sort);
		for (ResourcePO departmentPO : list) {
			ResourcePO tree = this.getTree(departmentPO.getResourceCode());
			arrayList.add(tree);
		}
		return arrayList;
	}


	public ResourcePO getTree(String resourceCode) {
		ResourcePO resourcePO = resourceRepository.findByResourceCodeAndStateCode(resourceCode, 1);
		Sort sort = new Sort(Sort.Direction.ASC, "resourceIndex");
		List<ResourcePO> list = resourceRepository.findByParentCodeAndStateCode(resourcePO.getResourceCode(), 1, sort);
		for (ResourcePO dv : list) {
			//递归计算
			ResourcePO tree = getTree(dv.getResourceCode());
			resourcePO.getChildren().add(tree);
		}
		return resourcePO;
	}
	

}
