package com.unis.user.server.server;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import com.github.pagehelper.Page;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.JsonUtils;
import com.unis.common.vo.base.PageResult;
import com.unis.user.common.vo.role.UserRoleReletedVO;
import com.unis.user.server.domain.role.RoleDomain;
import com.unis.user.server.domain.role.UserRoleReletedDomain;
import com.unis.user.server.model.UserRoleVO;
import com.unis.user.server.repository.RoleResourcesRepository;
import com.unis.user.server.repository.UserRoleRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.unis.common.base.BaseService;
import com.unis.common.utils.UpdateTool;
import com.unis.user.server.dto.RoleInfoDTO;
import com.unis.user.server.model.RoleInfoVO;
import com.unis.user.server.repository.BaseRepository;
import com.unis.user.server.repository.RoleInfoRepository;
import com.unis.user.server.untils.LsBeanUtils;

@Service
public class RoleInfoServer extends BaseService {

	@Autowired
	private RoleInfoRepository roleInfoRepository;

	@Autowired
	private UserRoleRepository userRoleRepository;

	@Autowired
	private BaseRepository baseRepository;

	@Autowired
	private ParaConfigServer paraConfigServer;

	@Autowired
	private RoleResourcesRepository roleResourcesRepository;

	@Autowired
	private UserRoleReletedDomain userRoleReletedDomain;

	@Autowired
	private RoleDomain roleDomain;


	public List<RoleInfoVO> fingRoleList() {
		// TODO Auto-generated method stub
		List<RoleInfoVO> infoVOs = roleInfoRepository.findByStateCodeAndCreatorCode(1,CurrentUtil.getOrgId());
		for(RoleInfoVO roleInfoVO:infoVOs) {
			roleInfoVO.setRoleTypeName(paraConfigServer.getConfigName(roleInfoVO.getRoleType()));
		}
		return infoVOs;
	}

	public List<RoleInfoVO> selectByEntity(){
		RoleInfoVO roleVO=new RoleInfoVO();
		roleVO.setStateCode(1);
		List<RoleInfoVO> infoVOs = roleDomain.selectByEntity(roleVO);
		for(RoleInfoVO roleInfoVO : infoVOs) {
			roleInfoVO.setRoleTypeName(paraConfigServer.getConfigName(roleInfoVO.getRoleType()));
		}
		return infoVOs;
	}

	public int add(RoleInfoDTO roleInfoDto) {
		RoleInfoVO vo = new RoleInfoVO();
		UpdateTool.copyNullProperties( roleInfoDto, vo );
		vo.setRoleCode(baseRepository.selectByTableNameAndAttr("SYS_ROLE_INFO", "ROLE_CODE", "R",7));
		vo.setCreator(CurrentUtil.getUserName());
		//通过组织id
		//vo.setCreatorCode(CurrentUtil.getOrgId());
		vo.setCreatorCode(CurrentUtil.getUserId());
		vo.setCreateDate(new Date());
		roleInfoRepository.save(vo);

		List<UserRoleReletedVO> userRoleReletedVOList=roleInfoDto.getUserRoleReletedVOList();
		if(userRoleReletedVOList!=null && userRoleReletedVOList.size()>0){
			saveUserRoleReleted(userRoleReletedVOList , vo.getRoleCode());
		}else {
            UserRoleReletedVO entity = new UserRoleReletedVO();
            entity.setRelatedRoleIds(vo.getRoleCode());
            List<UserRoleReletedVO> list = new ArrayList<>();
            list.add(entity);
            saveUserRoleReleted(list , vo.getRoleCode());
        }
		return 1;
	}

	public void saveUserRoleReleted(List<UserRoleReletedVO> userRoleReletedVOList, String roleCode){
		UserRoleReletedVO vo=new UserRoleReletedVO();
		vo.setRoleId(roleCode);
		userRoleReletedDomain.deleteByEntity(vo);
		for(UserRoleReletedVO userRoleReletedVO: userRoleReletedVOList){
			if(userRoleReletedVO!=null){
				userRoleReletedVO.setRoleId(roleCode);
				userRoleReletedDomain.insertEntitySelective(userRoleReletedVO);
			}
		}
	}

	public int update(RoleInfoDTO roleInfoDto) {
		RoleInfoVO roleInfoVO = roleInfoRepository.findByRoleCodeAndStateCode(roleInfoDto.getRoleCode(),1);
		if (roleInfoVO!=null) {
			RoleInfoVO vo = LsBeanUtils.copyProperties(roleInfoDto, RoleInfoVO.class);
			UpdateTool.copyNullProperties(roleInfoVO, vo);
			roleInfoRepository.saveAndFlush(vo);

			List<UserRoleReletedVO> userRoleReletedVOList=roleInfoDto.getUserRoleReletedVOList();
			if(userRoleReletedVOList!=null){
				saveUserRoleReleted(userRoleReletedVOList, roleInfoDto.getRoleCode());
			}
			return 1;
		}
		return 0;
	}

	public int delete(String[] roleCodes) {
		int i = 0;
		UserRoleReletedVO userRoleReletedVO=new UserRoleReletedVO();
		for(String roleCode: roleCodes) {
			i=i+roleInfoRepository.deleteByRoleCode(roleCode,"test","test");
			userRoleRepository.deleteByRoleCode(roleCode);
			roleResourcesRepository.deleteByRoleCode(roleCode);

			userRoleReletedVO.setRoleId(roleCode);
			userRoleReletedDomain.deleteByEntity(userRoleReletedVO);
		}
		return i;
	}

	/*public Page<RoleInfoVO> findByPage(RoleInfoDTO roleInfoDto, Integer page, Integer size) {

		PageRequest pageable = PageRequest.of( (page - 1), size, Sort.Direction.DESC, "roleCode" );
		Specification<RoleInfoVO> specification = new Specification<RoleInfoVO>() {
			@Override
			public Predicate toPredicate(Root<RoleInfoVO> root, CriteriaQuery<?> query, CriteriaBuilder cb) {
				List<Predicate> list = new ArrayList<Predicate>();
				//参数编号
				if (StringUtils.isNotBlank(roleInfoDto.getRoleCode())) {
					list.add( cb.like( root.get( "roleCode" ).as( String.class ), "%" +roleInfoDto.getRoleCode() + "%" ) );
				}
				//参数名称
				if (StringUtils.isNotBlank(roleInfoDto.getRoleName())) {
					list.add( cb.like( root.get( "roleName" ).as( String.class ), "%" +roleInfoDto.getRoleName()+ "%") );
				}
				//参数配置值
				if(StringUtils.isNotBlank(roleInfoDto.getRoleType())){
					list.add( cb.equal( root.get( "roleType" ).as( String.class ), roleInfoDto.getRoleType() ) );
				}
				list.add( cb.equal( root.get( "stateCode" ).as( Integer.class ), 1) );
				list.add( cb.equal( root.get( "creatorCode" ).as( String.class ), CurrentUtil.getOrgId()) );
				Predicate predicate=cb.and( list.toArray( new Predicate[list.size()] ) );
				return predicate;
			}
		};

		Page<RoleInfoVO> page2 = roleInfoRepository.findAll(specification, pageable);
		for(RoleInfoVO orgainzeVO : page2.getContent()) {
			orgainzeVO.setRoleTypeName(paraConfigServer.getConfigName(orgainzeVO.getRoleType()));
		}
		return page2;
	}*/

	public List<RoleInfoVO> selectMyByEntity(RoleInfoDTO roleInfoDto) {

		//String orgCode=CurrentUtil.getOrgId();
		String userCode=CurrentUtil.getUserId();
		RoleInfoVO roleInfoVO= JsonUtils.parse(JsonUtils.serialize(roleInfoDto),RoleInfoVO.class);
		roleInfoVO.setStateCode(1);
		roleInfoVO.setCreatorCode(userCode);

		List<UserRoleVO> roleList = userRoleRepository.findByUserCodeAndStateCode(userCode, 1);
		List<String> roleCodeList=new ArrayList<>();
		for(UserRoleVO userRoleVO: roleList){
			roleCodeList.add(userRoleVO.getRoleCode());
		}

		if(roleCodeList.size()>0){
			UserRoleReletedVO userRoleReletedVO=new UserRoleReletedVO();
			userRoleReletedVO.setRoleIdList(roleCodeList);
			List<UserRoleReletedVO> userRoleReletedVOList=userRoleReletedDomain.selectByEntity(userRoleReletedVO);
			roleCodeList.clear();
			for(UserRoleReletedVO userRoleReletedVOTemp: userRoleReletedVOList){
				roleCodeList.add(userRoleReletedVOTemp.getRelatedRoleIds());
			}
			roleInfoVO.setRoleCodeList(roleCodeList);
		}

		List<RoleInfoVO> list= roleDomain.selectByEntity( roleInfoVO);
		for(RoleInfoVO vo : list){
			if(userCode.equals(vo.getCreatorCode())){
				vo.setReadonly(false);
			}else{
				vo.setReadonly(true);
			}
		}
		for(RoleInfoVO orgainzeVO : list) {
			orgainzeVO.setRoleTypeName(paraConfigServer.getConfigName(orgainzeVO.getRoleType()));
		}
		return list;
	}

	public PageResult<RoleInfoVO> findByPage(RoleInfoDTO roleInfoDto, Integer page, Integer size) {
		//String orgCode=CurrentUtil.getOrgId();
        String userCode = CurrentUtil.getUserId();
		RoleInfoVO roleInfoVO= JsonUtils.parse(JsonUtils.serialize(roleInfoDto),RoleInfoVO.class);
		roleInfoVO.setStateCode(1);
		roleInfoVO.setCreatorCode(userCode);

		List<UserRoleVO> roleList = userRoleRepository.findByUserCodeAndStateCode(userCode, 1);
		List<String> roleCodeList=new ArrayList<>();
		for(UserRoleVO userRoleVO: roleList){
            roleCodeList.add(userRoleVO.getRoleCode());
		}

		if(roleCodeList.size()>0){
			UserRoleReletedVO userRoleReletedVO=new UserRoleReletedVO();
			userRoleReletedVO.setRoleIdList(roleCodeList);
			List<UserRoleReletedVO> userRoleReletedVOList=userRoleReletedDomain.selectByEntity(userRoleReletedVO);
			roleCodeList.clear();
			for(UserRoleReletedVO userRoleReletedVOTemp: userRoleReletedVOList){
				roleCodeList.add(userRoleReletedVOTemp.getRelatedRoleIds());
			}
			roleInfoVO.setRoleCodeList(roleCodeList);
		}
		Page<RoleInfoVO> list = roleDomain.selectPageByEntity(page, size , roleInfoVO, "ROLE_CODE DESC");
		for(RoleInfoVO vo : list){
            vo.setReadonly(!userCode.equals(vo.getCreatorCode()));

		}
        PageResult<RoleInfoVO> pageResult = new PageResult<>(list);
        for (RoleInfoVO orgainzeVO : list.getResult()) {
            orgainzeVO.setRoleTypeName(paraConfigServer.getConfigName(orgainzeVO.getRoleType()));
        }
        return pageResult;
	}

	public RoleInfoVO findRoleByCode(String roleCode) {
		RoleInfoVO roleInfoVO= roleInfoRepository.findByRoleCodeAndStateCode(roleCode, 1);
		UserRoleReletedVO userRoleReletedVO=new UserRoleReletedVO();
		userRoleReletedVO.setRoleId(roleCode);
		List<UserRoleReletedVO> userRoleReletedVODb=userRoleReletedDomain.selectByEntity(userRoleReletedVO);
		roleInfoVO.setUserRoleReletedVOList(userRoleReletedVODb);
		return roleInfoVO;
	}

}
