package com.unis.user.server.server;

import java.util.*;

import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Predicate;
import javax.persistence.criteria.Root;

import com.unis.user.server.dao.RoleResourcesDao;
import com.unis.user.server.untils.TreeTableUtil;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.stereotype.Service;

import com.unis.common.base.BaseService;
import com.unis.common.utils.UpdateTool;
import com.unis.user.server.dto.RoleResourcesDTO;
import com.unis.user.server.model.ResourcePO;
import com.unis.user.server.model.RoleInfoVO;
import com.unis.user.server.model.RoleResourcesVO;
import com.unis.user.server.repository.BaseRepository;
import com.unis.user.server.repository.ResourceRepository;
import com.unis.user.server.repository.RoleInfoRepository;
import com.unis.user.server.repository.RoleResourcesRepository;

@Service
public class RoleResourcesServer extends BaseService {

    @Autowired
    private RoleResourcesRepository roleResourcesRepository;

    @Autowired
    private RoleInfoRepository roleInfoRepository;

    @Autowired
    private ResourceRepository resourceRepository;

    @Autowired
    private BaseRepository baseRepository;

    @Autowired
    RoleResourcesDao roleResourcesMapper;

    @Value("${resource.pageResource}")
    private String pageType;
    @Value("${resource.buttonResource}")
    private String buttonType;

    public List<RoleResourcesVO> findRoleResourcesList() {
        // TODO Auto-generated method stub
        return roleResourcesRepository.findByStateCode(1);
    }

    public Page<RoleResourcesVO> findByPage(RoleResourcesDTO roleResourcesDTO, Integer page, Integer size) {
        PageRequest pageable = PageRequest.of((page - 1), size, Sort.Direction.ASC, "id");
        Specification<RoleResourcesVO> specification = new Specification<RoleResourcesVO>() {
            @Override
            public Predicate toPredicate(Root<RoleResourcesVO> root, CriteriaQuery<?> query, CriteriaBuilder cb) {
                List<Predicate> list = new ArrayList<Predicate>();
                //参数编号
                if (StringUtils.isNotBlank(roleResourcesDTO.getRoleCode())) {
                    list.add(cb.like(root.get("roleCode").as(String.class), "%" + roleResourcesDTO.getRoleCode() + "%"));
                }
                //参数编号
                if (StringUtils.isNotBlank(roleResourcesDTO.getRoleName())) {
                    list.add(cb.like(root.get("roleName").as(String.class), "%" + roleResourcesDTO.getRoleName() + "%"));
                }
                //参数编号
                if (StringUtils.isNotBlank(roleResourcesDTO.getResourceCode())) {
                    list.add(cb.like(root.get("resourcesCode").as(String.class), "%" + roleResourcesDTO.getResourceCode() + "%"));
                }
                //参数编号
                if (StringUtils.isNotBlank(roleResourcesDTO.getResourceName())) {
                    list.add(cb.like(root.get("resourcesName").as(String.class), "%" + roleResourcesDTO.getResourceName() + "%"));
                }
                list.add(cb.equal(root.get("stateCode").as(Integer.class), 1));
                return cb.and(list.toArray(new Predicate[list.size()]));
            }
        };
        return roleResourcesRepository.findAll(specification, pageable);
    }

    public int add(RoleResourcesDTO roleResourcesDTO) {
        RoleResourcesVO paraVO = roleResourcesRepository.findByRoleCodeAndStateCodeAndResourceCode(roleResourcesDTO.getRoleCode(), 1, roleResourcesDTO.getResourceCode());
        if (paraVO != null) {
            return 0;
        }
        RoleResourcesVO vo = new RoleResourcesVO();
        UpdateTool.copyNullProperties(roleResourcesDTO, vo);
        vo.setId(Integer.valueOf(baseRepository.selectIdByTableNameAndAttr("SYS_ROLE_RESOURCE", "ID")));
        vo.setCreator("test");
        vo.setCreatorCode("test");
        vo.setCreateDate(new Date());
        roleResourcesRepository.save(vo);
        return 1;
    }

    public List<RoleResourcesVO> findRoleResourcesByCode(String roleCode) {
        return roleResourcesRepository.findByRoleCodeAndStateCode(roleCode, 1);
    }

    public int delete(String roleCode) {
        return roleResourcesRepository.delete(roleCode);
    }

    public int addRoleResources(String[] resources, String roleCode) {
        RoleInfoVO infoVO = roleInfoRepository.findByRoleCodeAndStateCode(roleCode, 1);//获取角色是否存在
        if (infoVO == null) {
            return 0;
        }
        roleResourcesRepository.delete(roleCode);//删除角色资源
        Integer id = Integer.valueOf(baseRepository.selectIdByTableNameAndAttr("SYS_ROLE_RESOURCE", "ID"));
        for (String resource : resources) {
            ResourcePO resourcePO = resourceRepository.findByResourceCodeAndStateCode(resource, 1);//根据code获取资源信息
            //菜单资源不存在，直接跳过
            if (resourcePO == null){
                continue;
            }
            RoleResourcesVO vo = new RoleResourcesVO();
            vo.setRoleCode(roleCode);
            vo.setRoleName(infoVO.getRoleName());
            vo.setResourceCode(resource);
            vo.setResourceName(resourcePO.getResourceName());
            vo.setId(id);
            vo.setCreator("test");
            vo.setCreatorCode("test");
            vo.setCreateDate(new Date());
            roleResourcesRepository.save(vo);
            id++;
        }

        return 1;
    }

//    public List<ResourcePO> findRoleResourcesTree(String[] roleCode, String resourcesCode) {
//		/*StringBuffer sb = new StringBuffer();
//		for (int i = 0; i < roleCode.length; i++) {
//			if (!"".equals(roleCode[i]) && roleCode[i] != null)
//				sb.append("" + roleCode[i] + ",");
//
//		}
//		String result = sb.substring(0,sb.length()-1);*/
//        //获取角色资源信息
//        List<RoleResourcesVO> resourcesVOs = new ArrayList<RoleResourcesVO>();
//        if (StringUtils.isEmpty(resourcesCode)) {
//            resourcesVOs = roleResourcesRepository.findByRoleCodeInAndStateCode(roleCode, 1);
//        } else if (roleCode != null && roleCode.length > 0) {
//            resourcesVOs = roleResourcesRepository.findByRoleCodeInAndStateCodenew(resourcesCode, 1, roleCode);
//        }
//
//        String[] resources = new String[resourcesVOs.size()];
//        for (int i = 0; i < resourcesVOs.size(); i++) {
//            //拼接角色资源信息
//            resources[i] = resourcesVOs.get(i).getResourceCode();
//        }
//        return getTreeData(resources, resourcesCode);
//    }

    //20200527,wys:注释上面的调用递归算法，重新用java实现树形封装
    public List<ResourcePO> findRoleResourcesTree(String[] roleCode, String resourcesCode) {
        //获取角色资源信息
        List<RoleResourcesVO> resourcesVOs = new ArrayList<RoleResourcesVO>();
        if (StringUtils.isEmpty(resourcesCode)) {
            resourcesVOs = roleResourcesRepository.findByRoleCodeInAndStateCode(roleCode, 1);
        } else if (roleCode != null && roleCode.length > 0) {
            resourcesVOs = roleResourcesRepository.findByRoleCodeInAndStateCodenew(resourcesCode, 1, roleCode);
        }
        List<String> resources=new ArrayList<String>();
        for (int i = 0; i < resourcesVOs.size(); i++) {
            //拼接角色资源信息
            String tmpRSCode=resourcesVOs.get(i).getResourceCode();
            if (resources.indexOf(tmpRSCode)==-1) {//去重
                resources.add(tmpRSCode);
            }
        }
        Sort sort = new Sort(Sort.Direction.ASC, "resourceIndex");
        List<ResourcePO> ltsources= resourceRepository.findByStateCodeAndResourceTypeAndResourceCodeIn(1,pageType,resources.toArray(new String[resources.size()]),sort);
        List<ResourcePO> ltsourcesnew= TreeTableUtil.list2TreeList(ltsources,"resourceCode","parentCode","children",resourcesCode);
        return ltsourcesnew;
    }

    public List<ResourcePO> getTreeData(String[] resources, String resourceCode) {
        List<ResourcePO> arrayList = new ArrayList<>();
        Sort sort = new Sort(Sort.Direction.ASC, "resourceIndex");
         List<ResourcePO> list = resourceRepository.findByParentCodeAndStateCodeAndResourceTypeAndResourceCodeIn(resourceCode, 1, pageType, resources, sort);
        // List<ResourcePO> list = resourceRepository.findByParentCodeAndStateCodeAndResourceTypeAndResourceCodeIn("RM1", 1, pageType, resources, sort);
        for (ResourcePO departmentPO : list) {
            ResourcePO tree = this.getTree(departmentPO.getResourceCode(), resources);
            arrayList.add(tree);
        }
        return arrayList;
    }


    public ResourcePO getTree(String resourceCode, String[] resources) {
        ResourcePO resourcePO = resourceRepository.findByResourceCodeAndStateCode(resourceCode, 1);
        Sort sort = new Sort(Sort.Direction.ASC, "resourceIndex");
//		List<ResourcePO> list = resourceRepository.findByParentCodeAndStateCodeAndResourceCodeIn(resourcePO.getResourceCode(), 1,resources, sort);
        List<ResourcePO> list = resourceRepository.findByParentCodeAndStateCodeAndResourceTypeAndResourceCodeIn(resourcePO.getResourceCode(), 1, pageType, resources, sort);
        for (ResourcePO dv : list) {
            //递归计算
            ResourcePO tree = getTree(dv.getResourceCode(), resources);
            resourcePO.getChildren().add(tree);
        }
        return resourcePO;
    }

    /**
     * 获取按钮权限
     * @param roleCode
     * @param resourcesCode
     * @return
     */
    public List<ResourcePO> findRoleResourcesList(String[] roleCode, String resourcesCode) {
        //获取角色资源信息
        List<RoleResourcesVO> resourcesVOs = new ArrayList<RoleResourcesVO>();
        if (StringUtils.isEmpty(resourcesCode)) {
            resourcesVOs = roleResourcesRepository.findByRoleCodeInAndStateCode(roleCode, 1);
        } else if (roleCode != null && roleCode.length > 0) {
            resourcesVOs = roleResourcesRepository.findByRoleCodeInAndStateCodenew(resourcesCode, 1, roleCode);
        }

        String[] resources = new String[resourcesVOs.size()];
        for (int i = 0; i < resourcesVOs.size(); i++) {
            //拼接角色资源信息
            resources[i] = resourcesVOs.get(i).getResourceCode();
        }
        return getButtonData(resources);
    }

    /**
     * 根据resources获取按钮权限
     * @param resources
     * @return
     */
    public List<ResourcePO> getButtonData(String[] resources) {
        Sort sort = new Sort(Sort.Direction.ASC, "resourceIndex");
        return resourceRepository.findByStateCodeAndResourceTypeAndResourceCodeIn(1, buttonType, resources, sort);
    }


    public Set<ResourcePO> findFirstStageRoleResources(String[] roleCodeArray) {
        //获取角色资源信息
        List<RoleResourcesVO> resourcesVOs = new ArrayList<RoleResourcesVO>();
        resourcesVOs = roleResourcesRepository.findByRoleCodeInAndStateCode(roleCodeArray, 1);
        String[] resources = new String[resourcesVOs.size()];
        for (int i = 0; i < resourcesVOs.size(); i++) {
            //拼接角色资源信息
            resources[i] = resourcesVOs.get(i).getResourceCode();
        }
        return getData(resources);
        //return resourcesVOs;
    }

    public List<ResourcePO> findSecondStageRoleResources(String resourcesCode) {
        ResourcePO resourcePO = resourceRepository.findByResourceCodeAndStateCode(resourcesCode, 1);
        List<ResourcePO> children = resourcePO.getChildren();
        return children;
    }

    public Set<ResourcePO> getData(String[] resources) {
        Set<ResourcePO> arrayList = new HashSet<ResourcePO>();
        List<ResourcePO> list = resourceRepository.findByStateCodeAndResourceCodeIn(1, resources);
        //过滤  跟节点
        for (ResourcePO departmentPO : list) {
            if (!"RM1".equals(departmentPO.getParentCode())) {
                arrayList.add(departmentPO);
            }
            if ("RM1001003".equals(departmentPO.getParentCode())) {
                departmentPO.setParentCode(null);
                arrayList.add(departmentPO);
            }

        }
        return arrayList;
    }

	public List<ResourcePO> findRoleResourcesTreeInfo(String[] roleCode, String resourceCode) {
		//获取角色资源信息
        List<RoleResourcesVO> resourcesVOs = new ArrayList<RoleResourcesVO>();
        if (StringUtils.isEmpty(resourceCode)) {
            resourcesVOs = roleResourcesRepository.findByRoleCodeInAndStateCode(roleCode, 1);
        } else if (roleCode != null && roleCode.length > 0) {
            resourcesVOs = roleResourcesRepository.findByRoleCodeInAndStateCodenew(resourceCode, 1, roleCode);
        }
        List<String> resources=new ArrayList<String>();
        for (int i = 0; i < resourcesVOs.size(); i++) {
            //拼接角色资源信息
            String tmpRSCode=resourcesVOs.get(i).getResourceCode();
            if (resources.indexOf(tmpRSCode)==-1) {//去重
                resources.add(tmpRSCode);
            }
        }
        Sort sort = new Sort(Sort.Direction.ASC, "resourceIndex");
        List<ResourcePO> ltsources= resourceRepository.findByStateCodeAndResourceCodeIn(1,resources.toArray(new String[resources.size()]),sort);
        List<ResourcePO> ltsourcesnew= TreeTableUtil.list2TreeList(ltsources,"resourceCode","parentCode","children",resourceCode);
        return ltsourcesnew;
	}

    public List<ResourcePO> listRoleResourcesByCode(String[] roleCodeArray, String userId) {
        return roleResourcesMapper.listRoleResourcesByCode(userId);
    }
}
