package com.unis.user.server.server;

import com.unis.common.base.BaseService;
import com.unis.common.enums.IsLockedEnum;
import com.unis.common.utils.EncryptUtil;
import com.unis.common.utils.LsBeanUtils;

import com.unis.common.utils.ResponseWrapper;
import com.unis.common.utils.UpdateTool;
import com.unis.common.utils.vo.UserDTO;
import com.unis.user.server.dto.*;

import com.unis.user.server.feignclient.BaseServerClient;
import com.unis.user.server.model.*;
import com.unis.user.server.repository.*;


import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang.StringUtils;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.stereotype.Service;

import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Predicate;
import javax.persistence.criteria.Root;
import java.text.SimpleDateFormat;
import java.util.*;

@Service
public class TransactionServer extends BaseService {

	@Autowired
	private TransactionRepository repository;
	@Autowired
	private BaseServerClient baseServerClient;
	@Autowired
	private UserServer userServer;
	@Autowired
	private OrgainzeServer orgainzeServer;
	@Autowired
	private DepartmentServer departmentServer;
	@Autowired
	private UserRepository userRepository;
	@Autowired
	private BaseRepository baseRepository;
	@Autowired
	private UserRoleRepository userRoleRepository;

	/**
	 * 注册
	 *
	 * @param transactionDTO
	 * @return
	 */
	public int register(TransactionDTO transactionDTO) {
		ResponseWrapper byTyshxydm = baseServerClient.findComanyByTyshxydm(transactionDTO.getTyshxydm());
		if (byTyshxydm.getData() != null) {
			//该企业已存在请前往认证
			return 0;
		}
		TransactionPO transactionPO = repository.findByTyshxydmAndStateCode(transactionDTO.getTyshxydm(), 1);
		if (transactionPO != null) {
			return 2;
		}
		OrgainzeDTO orgainzeDTO = new OrgainzeDTO();
		//为orgainzeDTO设置区域编码
		String qymc = transactionDTO.getQymc();
		orgainzeDTO.setOrgName(qymc);
		orgainzeDTO.setCountyCode(transactionDTO.getAreaCode());
		orgainzeDTO.setParentCode("LS001020001");
		String orgCode = orgainzeServer.add(orgainzeDTO);
		if (orgCode != null) {
			List<DepartmentPO> byOrgCode = departmentServer.findByOrgCode(orgCode);
			DepartmentPO departmentPO = byOrgCode.get(0);
			UserDTO userDTO = new UserDTO();
			String pwd = EncryptUtil.generate(transactionDTO.getUserDTO().getUserPassword());
			userDTO.setUserLoginName(transactionDTO.getDwdm());
			userDTO.setUserName(transactionDTO.getQymc());
			userDTO.setUserPassword(pwd);
			userDTO.setDeptCode(departmentPO.getDeptCode());
			userDTO.setCountyCode(transactionDTO.getAreaCode());
			userDTO.setAreaName(transactionDTO.getAreaName());
			userDTO.setOrgCode(orgCode);
			userDTO.setUserType("0");
			userDTO.setIsDisavled(IsLockedEnum.NO.getCode());
			userDTO.setUserMobile(transactionDTO.getLxfs());
			UserPO userPO1 = LsBeanUtils.copyProperties(userDTO, UserPO.class);
			userPO1.setUserCode(baseRepository.selectByTableNameAndAttr("SYS_USER_INFO", "USER_CODE", "U", 7));
			UserPO userPO = userRepository.saveAndFlush(userPO1);
			List<String> userCode = userRoleRepository.findByUserCode(userPO.getUserCode());
			//在用户角色表中添加用户角色
			userCode.add("R0000168"); //交易注册角色
			userServer.saveUserRoles(userCode, userPO1.getUserCode());
			transactionDTO.setUserCode(userPO.getUserCode());

		}
		TransactionPO po = LsBeanUtils.copyProperties(transactionDTO, TransactionPO.class);
		po.setQyzt(1);
		po.setQyjgdm(orgCode);
        Date date =  new Date();
		SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd");
		String formatDate = dateFormat.format(date);
		po.setZcrq(formatDate);
		po.setId(baseRepository.selectByTableNameAndAttr("sys_transaction_user", "ID", "T", 7));
		repository.saveAndFlush(po);
		return 1;
	}

	/**
	 * 通过单位代码查询信息
	 *
	 * @param userLoginName
	 * @return
	 */
	public TransactionPO findByDwdm(String userLoginName) {
		return repository.findByDwdm(userLoginName);
	}

	/**
	 * 认证
	 *
	 * @param transactionDTO
	 */
	public void authentication(TransactionDTO transactionDTO) {
		TransactionPO po = LsBeanUtils.copyProperties(transactionDTO, TransactionPO.class);
		po.setId(baseRepository.selectByTableNameAndAttr("sys_transaction_user", "ID", "T", 7));
		Date date =  new Date();
		SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd");
		String formatDate = dateFormat.format(date);
		po.setZcrq(formatDate);
		List<String> userCode = userRoleRepository.findByUserCode(transactionDTO.getUserCode());
		//在用户角色表中添加用户角色
		userCode.add("R0000172"); //交易认证角色
		userServer.saveUserRoles(userCode, transactionDTO.getUserCode());
		repository.saveAndFlush(po);
	}


	/**
	 * 分页
	 *
	 * @param transactionDTO
	 * @param page
	 * @param size
	 * @return
	 */
	public Page<TransactionDTO> findByPage(TransactionDTO transactionDTO, Integer page, Integer size) {
		PageRequest pageable = PageRequest.of((page - 1), size, Sort.Direction.DESC, "id");    //

//		dto.setDepts(depts);
		Specification<TransactionPO> specification = new Specification<TransactionPO>() {
			@Override
			public Predicate toPredicate(Root<TransactionPO> root, CriteriaQuery<?> query, CriteriaBuilder cb) {
				List<Predicate> list = new ArrayList<Predicate>();
				// 企业名称
				if (StringUtils.isNotBlank(transactionDTO.getQymc())) {
					list.add(cb.like(root.get("qymc").as(String.class), "%" + transactionDTO.getQymc() + "%"));
				}
				// 统一社会信用代码
				if (StringUtils.isNotBlank(transactionDTO.getTyshxydm())) {
					list.add(cb.like(root.get("tyshxydm").as(String.class), "%" + transactionDTO.getTyshxydm() + "%"));
				}
				// 单位代码
				if (StringUtils.isNotBlank(transactionDTO.getDwdm())) {
					list.add(cb.like(root.get("dwdm").as(String.class), "%" + transactionDTO.getDwdm() + "%"));
				}
				//注册时间
				if (StringUtils.isNotBlank(transactionDTO.getZcksrq()) && StringUtils.isNotBlank(transactionDTO.getZcjsrq())) {
					list.add(cb.between(root.get("zcrq").as(String.class), transactionDTO.getZcksrq(), transactionDTO.getZcjsrq()));
				}
                //企业状态
				if (ObjectUtils.notEqual(transactionDTO.getQyzt(),null)) {
					list.add(cb.equal(root.get("qyzt").as(Integer.class), transactionDTO.getQyzt()));
				}
				list.add(cb.equal(root.get("stateCode").as(Integer.class), 1));
				return cb.and(list.toArray(new Predicate[list.size()]));
			}
		};
		Page<TransactionPO> transactionPOS = repository.findAll(specification, pageable);
		List<TransactionDTO> list = new ArrayList<>();
		for (TransactionPO as : transactionPOS.getContent()) {
			TransactionDTO transactionDTO1 = LsBeanUtils.copyProperties(as, TransactionDTO.class);
			list.add(transactionDTO1);
		}
		Page<TransactionDTO> transactionDTOPage = new PageImpl<TransactionDTO>(list, transactionPOS.getPageable(), transactionPOS.getTotalElements());
		return transactionDTOPage;
	}

	/**
	 * 通过企业名称查询是否存在
	 *
	 * @param
	 * @return
	 */
	public TransactionPO findByCompany(String companyName) {
		return repository.findByQymcAndStateCode(companyName, 1);
	}


	/**
	 * 查看详情
	 *
	 * @param id
	 * @return
	 */
	public TransactionPO findById(String id) {
		return repository.findByIdAndStateCode(id, 1);
	}

	/**
	 * 修改
	 *
	 * @param transactionDTO
	 * @return
	 */
	public boolean update(TransactionDTO transactionDTO) {
		TransactionPO transactionPO = repository.findByIdAndStateCode(transactionDTO.getId(), 1);
		if (ObjectUtils.equals(transactionPO, null)) {
			return false;
		}
		TransactionPO transactionPO1 = LsBeanUtils.copyProperties(transactionDTO, TransactionPO.class);
		UpdateTool.copyNullProperties(transactionPO, transactionPO1);
		Date date =  new Date();
		SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd");
		String formatDate = dateFormat.format(date);
		transactionPO1.setZcrq(formatDate);
		transactionPO1.setShyj(null);
		repository.saveAndFlush(transactionPO1);
		/*UserDTO userLoginName = userServer.findByUserLoginName(transactionDTO.getDwdm());
		userRoleRepository.deleteByUserCode(userLoginName.getUserCode());
		List<String> roleCodes = Arrays.asList(new String[]{"R0000121"});//交易企业端角色
		userServer.saveUserRoles(roleCodes, userLoginName.getUserCode());*/
		return true;
	}

	/**
	 * 审核
	 * @param transactionDTO
	 * @return
	 */
	public boolean approval(TransactionDTO transactionDTO) {
		TransactionPO transactionPO = repository.findByIdAndStateCode(transactionDTO.getId(), 1);
		if (ObjectUtils.equals(transactionPO, null)) {
			return false;
		}
		TransactionPO transactionPO1 = LsBeanUtils.copyProperties(transactionDTO, TransactionPO.class);
		UpdateTool.copyNullProperties(transactionPO, transactionPO1);
		repository.saveAndFlush(transactionPO1);
		UserDTO userLoginName = userServer.findByUserLoginName(transactionDTO.getDwdm());
		if (userLoginName==null){
			userLoginName = userServer.findByUserCode(transactionPO.getUserCode());
		}
		if(transactionDTO.getQyzt()==2){
			List<String> byUserCode = userRoleRepository.findByUserCode(userLoginName.getUserCode());
			//roleCodes = Arrays.asList(new String[]{"R0000121"});//交易企业端角色
			byUserCode.add("R0000178");
			userServer.saveUserRoles(byUserCode, userLoginName.getUserCode());
		}
		return true;
	}

	public TransactionPO findByTyshxydm(String tyshxydm) {
		return repository.findByTyshxydmAndStateCode(tyshxydm, 1);
	}

	public TransactionPO findByDwdmAndStateCode(String dwdm) {
		return repository.findByDwdmAndStateCode(dwdm, 1);
	}

	public TransactionPO findByLxfsAndStateCode(String lxfs) {
		return repository.findByLxfsAndStateCode(lxfs, 1);
	}
}