package com.unis.user.server.server;

import com.alibaba.fastjson.JSONObject;
import com.unis.common.config.RabbitObjectTO;
import com.unis.common.constant.CommonConstant;
import com.unis.common.constant.OrgConstant;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.EncryptUtil;
import com.unis.common.utils.ResponseWrapper;
import com.unis.common.utils.rabbitmq.IMessageProvider;
import com.unis.common.utils.vo.ResultDTO;
import com.unis.common.utils.vo.UserDTO;
import com.unis.user.server.config.Action;
import com.unis.user.server.dao.UserInfoDao;
import com.unis.user.server.domain.org.OrgainzeDomain;
import com.unis.user.server.dto.*;
import com.unis.user.server.entity.org.OrgainzeDO;
import com.unis.user.server.enums.IsLockedEnum;
import com.unis.user.server.feignclient.BaseServerClient;
import com.unis.user.server.feignclient.CompanyClient;
import com.unis.user.server.model.*;
import com.unis.user.server.repository.BaseRepository;
import com.unis.user.server.repository.DepartmentRepository;
import com.unis.user.server.repository.OrgainzeRepository;
import com.unis.user.server.repository.UserRepository;
import com.unis.user.server.repository.UserRoleRepository;
import com.unis.user.server.untils.IdsUtilForClient;
import com.unis.user.server.untils.JsonUtils;
import com.unis.user.server.untils.LsBeanUtils;

import com.unis.user.server.untils.UpdateTool;


import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.data.domain.*;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.RequestBody;

import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;
import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.CriteriaBuilder.In;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Predicate;
import javax.persistence.criteria.Root;
import java.io.IOException;
import java.security.NoSuchAlgorithmException;
import java.util.*;

/**
 * @author yang yunhai
 * @date : 时间:2018/6/14 9:38
 */
@Service
@Slf4j
public class UserServer{
	@Autowired
	private UserRepository userRepository;
	@Autowired
	private UserRoleRepository userRoleRepository;
	@Autowired
	private RoleInfoServer roleInfoServer;
	@Autowired
	private BaseRepository baseRepository;
	@PersistenceContext //注入的是实体管理器,执行持久化操作
	private	EntityManager entityManager;
	@Autowired
	private DepartmentServer departmentServer;
	@Autowired
	private OrgainzeRepository orgainzeRepository;
	@Autowired
	private OrgainzeDomain orgainzeDomain;

	@Autowired
	private DepartmentRepository departmentRepository;

	@Autowired
	private ParaConfigServer paraConfigServer;

	@Autowired
	private  OrgainzeServer orgainzeServer;

	@Autowired
	private CompanyClient companyClient;
	@Autowired
	private IMessageProvider iMessageProvider;

	@Autowired
	private BaseServerClient baseServerClient;

	@Autowired
	private AreaServer areaServer;

	@Autowired
    UserInfoDao userInfoDao;

    @Value("${account-code.super-admin}")
    private String superAdmin;

	/**
	 * 更新密码
	 *
	 * @param
	 * @date 2018/7/4
	 * @return boolean
	 */
	public ResultDTO updatePassword(ChangeUserPasswdDTO dto) {
		ResultDTO result = new ResultDTO();
		UserPO userPO = userRepository.findByUserCodeAndStateCode(dto.getUserCode(), 1);

		if(null == userPO) {
			result.setFail("用户不存在！");
			return result;
		}
		String oldPasswd = dto.getUserPassword();
//        if(! EncryptUtil.verify(oldPasswd, sysUserInfoDO.getPwSalt(), sysUserInfoDO.getUserPasswd())) {

		if(! EncryptUtil.verify(oldPasswd, userPO.getUserPassword())) {
			result.setFail("旧密码错误!");
			return result;
		}

		if(! dto.getNewPasswd1().equals(dto.getNewPasswd2())) {
			result.setFail("新密码和确认密码不一致！");
			return result;
		}
		//密码要加密后存储
		String newPasswd = dto.getNewPasswd1();
//        newPasswd = EncryptUtil.generate(newPasswd, sysUserInfoDO.getPwSalt());
		newPasswd = EncryptUtil.generate(newPasswd);
		userPO.setUserPassword(newPasswd);
		userRepository.saveAndFlush(userPO);
		result.setSuccess("密码修改成功！");
		if (!"0".equals(userPO.getUserType())) {
			setMqForUserInfo(userPO, Action.USER_EDIT);
		}

		return result;
	}

	/**
	 * 找回密码
	 * @param
	 * @date 2018/7/4
	 * @return boolean
	 */
	public ResponseWrapper updatePassword(FindUserPasswdDTO dto) {
		ResultDTO result = new ResultDTO();
		UserPO userPO =null;
		if(StringUtils.isNotEmpty(dto.getUserCode())){
			userPO=userRepository.findByUserCodeAndStateCode(dto.getUserCode(), 1);
		}else if(StringUtils.isNotEmpty(dto.getUserLoginName())){
			userPO=userRepository.findByUserLoginNameAndStateCode(dto.getUserLoginName(), 1);
		}else if(StringUtils.isNotEmpty(dto.getMobile())){
			userPO=userRepository.findByUserMobileAndStateCode(dto.getMobile(),1);
		}else{
			return ResponseWrapper.error("缺少唯一标示");
		}
		if(null == userPO) {
			return ResponseWrapper.error("用户不存在");
		}

		if(!dto.getNewPasswd1().equals(dto.getNewPasswd2())) {
			return ResponseWrapper.error("新密码和确认密码不一致");
		}
		//密码要加密后存储
		String newPasswd = dto.getNewPasswd1();
//        newPasswd = EncryptUtil.generate(newPasswd, sysUserInfoDO.getPwSalt());
		newPasswd = EncryptUtil.generate(newPasswd);
		userPO.setUserPassword(newPasswd);
		userRepository.saveAndFlush(userPO);

		if (!"0".equals(userPO.getUserType())) {
			setMqForUserInfo(userPO, Action.USER_EDIT);
		}

		return ResponseWrapper.success("密码修改成功");
	}

	/**
	 * 添加用户
	 *
	 * @param
	 * @date 2018/8/7
	 * @return boolean
	 */
	public String save(UserDTO userDTO) throws Exception {
		//暂时处理区域数据没有问题
		try {
			if(StringUtils.isNotEmpty(userDTO.getCountyCode())){
				String areaName = "";
				if(userDTO.getCountyCode().contains("0000")) {//省用户
					List<AreaVO> areaVO = areaServer.findProvinCode(userDTO.getCountyCode());
					if(areaVO.size()>0) {
						areaName = areaVO.get(0).getProvinName();
					}
				} else if(userDTO.getCountyCode().contains("00")) {//市用户
					List<AreaCityVO> areaCityVO = areaServer.findCityCode(userDTO.getCountyCode());
					if(areaCityVO.size()>0) {
						areaName = areaCityVO.get(0).getCityName();
					}
				} else {//县用户
					List<AreaCountyVO> areaCountyVO = areaServer.findCountyCode(userDTO.getCountyCode());
					if(areaCountyVO.size()>0) {
						areaName = areaCountyVO.get(0).getCountyName();
					}
				}
				userDTO.setAreaName(areaName);
			}
		} catch (Exception e) {
            e.printStackTrace();
		}
		UserPO userPO = LsBeanUtils.copyProperties(userDTO, UserPO.class);
        if (null != userDTO.getSealList() ) {
            userPO.setSeals(StringUtils.join(userDTO.getSealList(), ","));
        }
		userPO.setCreateDate(new Date());
		userPO.setUserCode(baseRepository.selectByTableNameAndAttr("SYS_USER_INFO", "USER_CODE", "U",7));
//                    String defaultPasswd = EncryptUtil.generate(CommonConstant.DEFAULT_PASSWD, passwdSalt);

		String defaultPasswd = null;
		defaultPasswd = EncryptUtil.generate(CommonConstant.DEFAULT_PASSWD);
		//企业用户在企业端进行irpt用户同步
		if ("0".equals(userDTO.getUserType())) {
			userPO.setUserPassword(defaultPasswd);
			userRepository.saveAndFlush(userPO);
			setMqForUserInfo(userPO, Action.USER_ADD);
		} else {
			if(null == userPO.getUserPassword()){
				userPO.setUserPassword(defaultPasswd);
			}else {

				userPO.setUserPassword(defaultPasswd);
			}
			userPO.setUserPassword(defaultPasswd);
			userRepository.saveAndFlush(userPO);
			setMqForUserInfo(userPO, Action.USER_ADD);
		}
		return userPO.getUserCode();
	}
	/**
	 * 更新用户
	 * @param
	 * @date 2018/7/4
	 * @return boolean
	 */
	@Transactional
	public boolean update(UserDTO userDTO) throws Exception{
		//暂时处理区域数据没有问题
		try {
			if(StringUtils.isNotEmpty(userDTO.getCountyCode())){
				String areaName = "";
				if(userDTO.getCountyCode().contains("0000")) {//省用户
					List<AreaVO> areaVO = areaServer.findProvinCode(userDTO.getCountyCode());
					if(areaVO.size()>0) {
						areaName = areaVO.get(0).getProvinName();
					}
				} else if(userDTO.getCountyCode().contains("00")) {//市用户
					List<AreaCityVO> areaCityVO = areaServer.findCityCode(userDTO.getCountyCode());
					if(areaCityVO.size()>0) {
						areaName = areaCityVO.get(0).getCityName();
					}
				} else {//县用户
					List<AreaCountyVO> areaCountyVO = areaServer.findCountyCode(userDTO.getCountyCode());
					if(areaCountyVO.size()>0) {
						areaName = areaCountyVO.get(0).getCountyName();
					}
				}
				userDTO.setAreaName(areaName);
			}
		} catch (Exception e) {
            e.printStackTrace();
		}
		UserPO userPO = userRepository.findByUserCodeAndStateCode(userDTO.getUserCode(), 1);
        if (null != userDTO.getSealList() ) {
            userPO.setSeals(StringUtils.join(userDTO.getSealList(), ","));
        }
		if (ObjectUtils.equals(userPO, null)) {
			return false;
		}
		UserPO userPO1 = LsBeanUtils.copyProperties(userDTO, UserPO.class);
		UpdateTool.copyNullProperties(userPO, userPO1);
		userRepository.updateByCode(userPO1.getUserCode());
		userRepository.saveAndFlush(userPO1);
		//企业用户不在用户中心同步
		if (!"2".equals(userDTO.getUserType())) {
			//TODO TS 注释同步数据，报错
			setMqForUserInfo(userPO1, Action.USER_EDIT);

		}
		//userRepository.updateByCode(userPO1);
		/*StringBuffer sqlbf = new StringBuffer();
		sqlbf.append("UPDATE SYS_USER_INFO SET CREATE_DATE = "+userPO1.getCreateDate()+"," +
				"CREATOR = '"+userPO1.getCreator()+"', " +
				"CREATOR_CODE='"+userPO1.getCreatorCode()+"'," +
				"REFRESH_TIME= "+userPO1.getRefreshTime()+"," +
				"REFRESHER= '"+userPO1.getRefresher()+"'," +
				"REFRESHER_CODE='"+userPO1.getRefresherCode()+"'," +
				"REMARK='"+userPO1.getRemark()+"', " +
				"STATE_CODE= 1," +
				"VERSION = "+userPO1.getVersion()+"," +
				"BUTY='"+userPO1.getButy()+"'," +
				"COUNTY_CODE= '"+userPO1.getCountyCode()+"', " +
				"CURRENT_ADDRESS = '"+userPO1.getCurrentAddress()+"'," +
				"DEPT_CODE = '"+userPO1.getDeptCode()+"', " +
				"DIMISSION_DATE= "+userPO1.getDimissionDate()+"," +
				"ENTER_DATE = "+userPO1.getEnterDate()+"," +
				"HEADSHIP = '"+userPO1.getHeadship()+"'," +
				"IS_DIMISSION = '"+userPO1.getIsDimission()+"'," +
				"IS_DISABLED = "+userPO1.getIsDisavled()+"," +
				"POLITICAL_STATUS = "+userPO1.getPoliticalStatus()+"," +
				"RESIDENCE_ADDRESS = '"+userPO1.getResidenceAddress()+"', " +
				"SPECIALITY = '"+userPO1.getSpeciality()+"'," +
				"USER_ADDRESS = '"+userPO1.getUserAddress()+"'," +
				"USER_CERTNO = '"+userPO1.getUserCertno()+"'," +
				"USER_CERTTYPE = '"+userPO1.getUserCerttype()+"'," +
				"USER_EDUCATION = '"+userPO1.getUserEducation()+"'," +
				"USER_IMGURL= '"+userPO1.getUserImgurl()+"'," +
				"USER_LOGINNAME= '"+userPO1.getUserLoginName()+"'," +
				"USER_MAIL = '"+userPO1.getUserMail()+"'," +
				"USER_MOBILE = '"+userPO1.getUserMobile()+"'," +
				"USER_NAME= '"+userPO1.getUserName()+"', " +
				"USER_PASSWORD = '"+userPO1.getUserPassword()+"'," +
				"USER_POST = '"+userPO1.getUserPost()+"'," +
				"USER_SEX = '"+userPO1.getUserSex()+"'," +
				"USER_TEL = '"+userPO1.getUserTel()+"'," +
				"USER_TITLE = '"+userPO1.getUserTitle()+"'," +
				"USER_TYPE = '"+userPO1.getUserType()+"' WHERE USER_CODE = '"+userPO1.getUserCode()+"'");
		String sql = sqlbf.toString();
		entityManager.createQuery(sql).executeUpdate();*/
		/*try {
			userRepository.saveAndFlush(userPO1);
		} catch (Exception e) {
			e.printStackTrace();
		}*/
		/*UpdateTool.copyNullProperties(userPO, userPO1);
		userRepository.saveAndFlush(userPO1);*/
		return true;
	}

	/**
	 *
	 * @Description: 查询所有用户
	 *
	 * @date 2018年8月23日,下午6:03:09
	 * @author tiechanglong
	 * @version v1.0
	 *
	 * @param
	 * @return
	 */
	public List<UserDTO> findAllList(Integer stateCode) {
		List<UserPO> users = userRepository.findByStateCode(stateCode);
		List<UserDTO> resultUsers = new ArrayList<UserDTO>();
		for (UserPO userPO : users) {
			UserDTO userDTO = LsBeanUtils.copyProperties(userPO, UserDTO.class);
            userDTO.setUserPassword(null);
			resultUsers.add(userDTO);
		}
		return resultUsers;
	}

	/**
	 * 密码重置
	 *
	 * @param userCode
	 * @date 2018/7/4
	 */
	public boolean resetPassword(String userCode) {
		UserPO userPO = userRepository.findByUserCodeAndStateCode(userCode, 1);
		if (ObjectUtils.equals(userPO, null)) {
			return false;
		}
		String defaultPasswd = EncryptUtil.generate(CommonConstant.DEFAULT_PASSWD);
		userPO.setUserPassword(defaultPasswd);
		UserPO userPO1 = userRepository.saveAndFlush(userPO);
		if (ObjectUtils.equals(userPO1, null)) {
			return false;
		}
		setMqForUserInfo(userPO1, Action.USER_EDIT);
		return true;
	}


    public List<UserDTO> findByUserCode(List<String> userCodes) {
        List<UserDTO> userDTOList = new ArrayList<>();
        for (String userCode : userCodes) {
            UserPO userPO = userRepository.findByUserCodeAndStateCode(userCode, 1);
            if (userPO == null) {
                return null;
            }

            List<UserRoleVO> userRoleVOS = userRoleRepository.findByUserCodeAndStateCode(userPO.getUserCode(), 1);
            List<String> userRole = new ArrayList<>();
            List<String> userRoleName = new ArrayList<>();
            for (UserRoleVO userDTO1 : userRoleVOS) {
                userRole.add(userDTO1.getRoleCode());
                userRoleName.add(userDTO1.getRoleName());
            }
            DepartmentPO departmentPO = departmentServer.findByDeptCode(userPO.getDeptCode());
            UserDTO userDTO = LsBeanUtils.copyProperties(userPO, UserDTO.class);
            if (userDTO != null) {
                userDTO.setUserPassword(null);
            }
            if (departmentPO != null) {
                userDTO.setDeptCode(departmentPO.getDeptCode());
                userDTO.setDeptName(departmentPO.getDeptName());
                // 查询机构
                OrgainzeVO orgainzeVO = orgainzeRepository.findByOrgCodeAndStateCode(departmentPO.getOrgCode(), 1);
                if (ObjectUtils.notEqual(orgainzeVO, null)) {
                    userDTO.setOrgCode(orgainzeVO.getOrgCode());
                    userDTO.setOrgName(orgainzeVO.getOrgName());
                }
            }
            userDTO.setUserRoleNameTwo(StringUtils.join(userRoleName, ","));
            userDTO.setUserRole(userRole);
            userDTO.setUserRoleName(userRoleName);
            Optional.ofNullable(userPO.getSeals()).ifPresent(i -> userDTO.setSealList( Arrays.asList(i.split(","))));
            userDTOList.add(userDTO);
        }
        return userDTOList;
    }

	public UserDTO findByUserCode( String userCodes) {
		UserPO userPO = userRepository.findByUserCodeAndStateCode(userCodes, 1);
		UserDTO userDTO = LsBeanUtils.copyProperties(userPO, UserDTO.class);
        if (userDTO != null) {
            userDTO.setUserPassword(null);
        }
        return userDTO;
	}


	public UserPO findByUserTypeAndUserLoginName(String userType,String userLoginName) {
		return userRepository.findByUserTypeAndUserLoginNameAndStateCode(userType,userLoginName,1);
	}

	public Boolean deletes(List<String> stateCode) {
		List<UserPO> userPOList = userRepository.findByUserCodeInAndStateCode(stateCode, 1);
		for (UserPO userPO: userPOList) {
			userPO.setStateCode(0);
			userRepository.saveAndFlush(userPO);
			userRoleRepository.deleteByUserCode(userPO.getUserCode());
			setMqForUserInfo(userPO, Action.USER_DELETE);
		}
		return true;
	}

	public boolean freezeUser(String userCode) {
		UserPO userPO = userRepository.findByUserCodeAndStateCode(userCode, 1);
		if (ObjectUtils.equals(userPO, null)) {
			return false;
		}
		if (userPO.getIsDisavled() == 0) {
			userPO.setIsDisavled(1);
		} else {
			userPO.setIsDisavled(0);
		}
		UserPO userPO1 = userRepository.saveAndFlush(userPO);
		if (ObjectUtils.equals(userPO1, null)) {
			return false;
		}
		return true;
	}

	/**
	 * 分页
	 * @param dto
	 * @param page
	 * @param size
	 * @return
	 */
	public Page<UserDTO>  findByPage(UserDTO dto, Integer page, Integer size) {
		PageRequest pageable = PageRequest.of( (page - 1), size, Sort.Direction.DESC, "userCode" );	//
        String userId = CurrentUtil.getUserId();

//		dto.setDepts(depts);
		Specification<UserPO> specification = (root, query, cb) -> {
            List<Predicate> list = new ArrayList<Predicate>();
            List<DepartmentPO> departmentPOs = new ArrayList<>();
            if(StringUtils.isNotBlank(dto.getOrgCode())){
                departmentPOs = departmentRepository.findByOrgCodeLike(dto.getOrgCode()+"%");
            }
            if(StringUtils.isNotBlank(dto.getDeptCode())){
                departmentPOs = departmentRepository.findByDeptCodeLike(dto.getDeptCode()+"%");
            }
            //姓名
            if (StringUtils.isNotBlank(dto.getUserName())) {
                list.add( cb.or(cb.like( root.get( "userName" ).as( String.class ), "%" + dto.getUserName() + "%" )
                        ,cb.like( root.get( "userLoginName" ).as( String.class ), "%" + dto.getUserName() + "%" )
                ) );
            }
            //部门名称
            if(ObjectUtils.notEqual(dto.getDeptName(),null)){
                list.add( cb.equal( root.get( "deptName" ).as( String.class ),"%" + dto.getDeptName() + "%" ) );
            }
            //部门名称
            if(ObjectUtils.notEqual(dto.getDeptCode(),null)){
                list.add( cb.equal( root.get( "deptCode" ).as( String.class ),dto.getDeptCode()) );
            }
            //组织名称
            if(StringUtils.isNotBlank(dto.getOrgCode())){
                list.add( cb.equal( root.get( "orgCode" ).as( String.class ),dto.getOrgCode() ) );
            }
            //是否禁用
            if (ObjectUtils.notEqual(dto.getIsDisavled(),null)) {
                list.add( cb.equal( root.get( "isDisavled" ).as( Integer.class ), dto.getIsDisavled()) );
            }
            //行政区划
            if (StringUtils.isNotBlank(dto.getCountyCode())) {
                list.add( cb.equal( root.get( "countyCode" ).as( String.class ), dto.getCountyCode()) );
            }
            //性别
            if (StringUtils.isNotBlank(dto.getUserSex())) {
                list.add( cb.equal( root.get( "userSex" ).as( String.class ), dto.getUserSex()) );
            }
            //邮箱
            if(ObjectUtils.notEqual(dto.getUserMail(),null)){
                list.add( cb.equal( root.get( "userMail" ).as( String.class ),"%" + dto.getUserMail() + "%" ) );
            }
            //部门
            //用户类型1粮食局 2企业
            if (StringUtils.isNotBlank(dto.getUserType())) {
                list.add( cb.equal( root.get( "userType" ).as( String.class ), dto.getUserType()) );
            }

            if (StringUtils.isNotBlank(dto.getOrgCode())) {
                if(departmentPOs.size()>0) {
                    In<Object> in = cb.in(root.get("deptCode").as( String.class ));
                    for(DepartmentPO string:departmentPOs) {
                        in.value(string.getDeptCode());
                    }
                    list.add(in);
                } else {
                    list.add( cb.equal( root.get( "deptCode" ).as( String.class ), "" ));
                }

            }
            if (StringUtils.isNotBlank(dto.getDeptCode())) {
//					list.add( cb.equal( root.get( "deptCode" ).as( String.class ), dto.getDeptCode()) );
                if(departmentPOs.size()>0) {
                    In<Object> in = cb.in(root.get("deptCode").as( String.class ));
                    for(DepartmentPO string:departmentPOs) {
                        in.value(string.getDeptCode());
                    }
                    list.add(in);
                } else {
                    list.add( cb.equal( root.get( "deptCode" ).as( String.class ), "" ));
                }
            }
            list.add( cb.equal( root.get( "stateCode" ).as( Integer.class ), 1) );
            if (!superAdmin.equals(userId)) {
                list.add(cb.equal(root.get("isDev").as(Integer.class), 0));
            }
            return cb.and( list.toArray( new Predicate[list.size()] ) );
        };
		Page<UserPO> userPOS = userRepository.findAll(specification, pageable );
		List <UserDTO> list = new ArrayList <>();

		for (UserPO as : userPOS.getContent()) {
			UserDTO userDTO = LsBeanUtils.copyProperties(as,UserDTO.class);
			userDTO.setUserTypeName(paraConfigServer.getConfigName(userDTO.getUserType()));

			DepartmentPO departmentPO = departmentServer.findByDeptCode(userDTO.getDeptCode());
			if(departmentPO!=null) {
				//部门名称
				userDTO.setDeptName(departmentPO.getDeptName());
				userDTO.setOrgCode(departmentPO.getOrgCode());
				OrgainzeVO orgainzeVO = orgainzeRepository.findByOrgCodeAndStateCode(departmentPO.getOrgCode(), 1);
				if(orgainzeVO!=null) {
					//组织名称
					userDTO.setOrgName(orgainzeVO.getOrgName());
				}
			}

			List<UserRoleVO> userRoleVOS = userRoleRepository.findByUserCodeAndStateCode(userDTO.getUserCode(), 1);
			List<String> userRole = new ArrayList<>();
			List<String> userRoleName = new ArrayList<>();
			for (UserRoleVO userDTO1 : userRoleVOS) {
				userRole.add(userDTO1.getRoleCode());
				userRoleName.add(userDTO1.getRoleName());
			}
			StringBuilder sb = new StringBuilder();
			for(String str : userRoleName){
				sb.append(str);
			}
			String userrole = sb.toString();
			userDTO.setUserRoleNameTwo(userrole);
			userDTO.setUserRole(userRole);
			userDTO.setUserRoleName(userRoleName);
            userDTO.setUserPassword(null);
			list.add( userDTO );
		}
		Page <UserDTO> userDTOPage = new PageImpl<>( list, userPOS.getPageable(), userPOS.getTotalElements() );
		return userDTOPage;
	}

	/***
	 * 保存用户角色信息
	 * @param userRoleIdDTO
	 */
	public void saveUserRoles(UserRoleDTO userRoleIdDTO)throws Exception {
		List<String> rolelist = userRoleIdDTO.getRoleCode();
		//新增前先查询是否有该用户得角色信息
		List<UserRoleVO> userRoleVO1 = userRoleRepository.findByUserCodeAndStateCode(userRoleIdDTO.getUserCode(),1);
		/*if (userRoleVO1.size()>0) {
			deletedUserRoles(userRoleIdDTO.getUserCode());
		}*/
		UserPO userPO = userRepository.findByUserCodeAndStateCode(userRoleIdDTO.getUserCode(), 1);
		for (String roleCode : rolelist) {
			UserRoleVO userRoleVO = new UserRoleVO();
			RoleInfoVO roleInfoVO = roleInfoServer.findRoleByCode(roleCode);
			userRoleVO.setRoleCode(roleInfoVO.getRoleCode());
			userRoleVO.setUserCode(userRoleIdDTO.getUserCode());
			userRoleVO.setUserName(userPO.getUserName());
			userRoleVO.setRoleName(roleInfoVO.getRoleName());
			Integer depCode = baseRepository.selectIdByTableNameAndAttr("SYS_USER_ROLES", "ID");
			userRoleVO.setId(depCode);
			userRoleRepository.saveAndFlush(userRoleVO);
		}
	}

	/***
	 * 删除用户下的所选角色
	 * @param userCode
	 */
	public void deletedUserRoles(String userCode) {
		userRoleRepository.deleteByUserCode(userCode);
	}

	public void updateUserRoles(UserRoleDTO userRoleIdDTO) {
		String userCode = userRoleIdDTO.getUserCode();
		userRoleRepository.deleteByUserCode(userCode);
		try {
			saveUserRoles(userRoleIdDTO);
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	public int saveUserRoles(@RequestBody List<String> roleCodes, String userCode) {
		UserPO infoVO = userRepository.findByUserCodeAndStateCode(userCode, 1);//获取角色是否存在
		if(infoVO==null) {
			return 0;
		}
		userRoleRepository.deleteByUserCode(userCode);//删除角色资源
		Integer id = Integer.valueOf(baseRepository.selectIdByTableNameAndAttr("SYS_USER_ROLES", "ID"));
		for(String resource:roleCodes) {
			RoleInfoVO resourcePO = roleInfoServer.findRoleByCode(resource);//根据code获取资源信息
			UserRoleVO vo = new UserRoleVO();
			vo.setRoleCode(resourcePO.getRoleCode());
			vo.setRoleName(resourcePO.getRoleName());
			vo.setUserCode(userCode);
			vo.setUserName(infoVO.getUserName());
			vo.setId(id);
			vo.setCreateDate(new Date());
			userRoleRepository.save(vo);
			id++;
		}
		return 1;
	}

	public UserDTO findByUserLoginName(String userLoginName) {
		UserPO userPO = userRepository.findByUserLoginNameAndStateCode(userLoginName,1);
		UserDTO userDTO = LsBeanUtils.copyProperties(userPO, UserDTO.class);
		if (userPO != null) {
			if (userPO.getUserType().equals("1")) {
				DepartmentPO departmentPO = departmentServer.findByDeptCode(userPO.getDeptCode());
				if (departmentPO != null) {
					OrgainzeVO orgainzeVO = orgainzeRepository.findByOrgCodeAndStateCode(departmentPO.getOrgCode(), 1);
					List<UserRoleVO> userRoleVOS = userRoleRepository.findByUserCodeAndStateCode(userPO.getUserCode(), 1);
					List<String> userRole = new ArrayList<>();
					for (UserRoleVO userDTO1 : userRoleVOS) {
						userRole.add(userDTO1.getRoleCode());
					}
					userDTO.setUserRole(userRole);
					userDTO.setDeptCode(departmentPO.getDeptCode());
					userDTO.setOrgCode(departmentPO.getOrgCode());
					userDTO.setOrgName(orgainzeVO.getOrgName());
					userDTO.setDeptName(departmentPO.getDeptName());
					userDTO.setOrgLevel(orgainzeVO.getOrgLevel());
				} else {
					List<UserRoleVO> userRoleVOS = userRoleRepository.findByUserCodeAndStateCode(userPO.getUserCode(), 1);
					List<String> userRole = new ArrayList<>();
					for (UserRoleVO userDTO1 : userRoleVOS) {
						userRole.add(userDTO1.getRoleCode());
					}
					userDTO.setUserRole(userRole);
				}
			} else {
				DepartmentPO departmentPO = departmentServer.findByDeptCode(userPO.getDeptCode());
				if (departmentPO != null) {
					OrgainzeVO orgainzeVO = orgainzeRepository.findByOrgCodeAndStateCode(departmentPO.getOrgCode(), 1);
					List<UserRoleVO> userRoleVOS = userRoleRepository.findByUserCodeAndStateCode(userPO.getUserCode(), 1);
					List<String> userRole = new ArrayList<>();
					for (UserRoleVO userDTO1 : userRoleVOS) {
						userRole.add(userDTO1.getRoleCode());
					}
					userDTO.setUserRole(userRole);
					userDTO.setDeptCode(departmentPO.getDeptCode());
					userDTO.setOrgCode(departmentPO.getOrgCode());
					userDTO.setOrgName(orgainzeVO.getOrgName());
					userDTO.setDeptName(departmentPO.getDeptName());
				} else {
					List<UserRoleVO> userRoleVOS = userRoleRepository.findByUserCodeAndStateCode(userPO.getUserCode(), 1);
					List<String> userRole = new ArrayList<>();
					for (UserRoleVO userDTO1 : userRoleVOS) {
						userRole.add(userDTO1.getRoleCode());
					}
					userDTO.setUserRole(userRole);
				}
			}
		}
        if (userDTO != null) {
            userDTO.setUserPassword(null);
        }
        return userDTO;
	}

	public UserDTO findByUserLoginName(String userType,String userLoginName) {
		UserPO userPO = new UserPO();

		if(userType.equals("4")) {
			userPO = userRepository.findByUserLoginNameAndStateCode(userLoginName,1);
		} else {
			userPO = userRepository.findByUserTypeAndUserLoginNameAndStateCode(userType,userLoginName,1);
		}
		UserDTO userDTO = LsBeanUtils.copyProperties(userPO, UserDTO.class);
		if(userPO!=null){
			userDTO.setUserMark(userDTO.getUserMark());
			if (userPO.getUserType().equals("1")) {
				DepartmentPO departmentPO = departmentServer.findByDeptCode(userPO.getDeptCode());
				if (departmentPO!=null) {
					OrgainzeVO orgainzeVO = orgainzeRepository.findByOrgCodeAndStateCode(departmentPO.getOrgCode(), 1);
					List<UserRoleVO> userRoleVOS = userRoleRepository.findByUserCodeAndStateCode(userPO.getUserCode(), 1);
					List<String> userRole = new ArrayList<>();
					for (UserRoleVO userDTO1 : userRoleVOS) {
						userRole.add(userDTO1.getRoleCode());
					}
					userDTO.setUserRole(userRole);
					userDTO.setDeptCode(departmentPO.getDeptCode());
					userDTO.setOrgCode(departmentPO.getOrgCode());
					userDTO.setOrgName(orgainzeVO.getOrgName());
					userDTO.setOrgLevel(orgainzeVO.getOrgLevel());
					userDTO.setDeptName(departmentPO.getDeptName());
                    userDTO.setOrgAreaCode(orgainzeVO.getCountyCode());
					userDTO.setOrgType(orgainzeVO.getOrgType());
				}else {
					List<UserRoleVO> userRoleVOS = userRoleRepository.findByUserCodeAndStateCode(userPO.getUserCode(), 1);
					List<String> userRole = new ArrayList<>();
					for (UserRoleVO userDTO1 : userRoleVOS) {
						userRole.add(userDTO1.getRoleCode());
					}
					userDTO.setUserRole(userRole);
				}
			}else {
				DepartmentPO departmentPO = departmentServer.findByDeptCode(userPO.getDeptCode());
				if (departmentPO != null) {
					OrgainzeVO orgainzeVO = orgainzeRepository.findByOrgCodeAndStateCode(departmentPO.getOrgCode(), 1);
					List<UserRoleVO> userRoleVOS = userRoleRepository.findByUserCodeAndStateCode(userPO.getUserCode(), 1);
					List<String> userRole = new ArrayList<>();
					for (UserRoleVO userDTO1 : userRoleVOS) {
						userRole.add(userDTO1.getRoleCode());
					}
					userDTO.setUserRole(userRole);
					userDTO.setDeptCode(departmentPO.getDeptCode());
					userDTO.setOrgCode(departmentPO.getOrgCode());
					userDTO.setOrgLevel(orgainzeVO.getOrgLevel());
					userDTO.setDeptName(departmentPO.getDeptName());
                    userDTO.setOrgAreaCode(orgainzeVO.getCountyCode());
					userDTO.setOrgType(orgainzeVO.getOrgType());
					if(orgainzeVO!=null){
						userDTO.setOrgName(orgainzeVO.getOrgName());
					}
				} else {
					List<UserRoleVO> userRoleVOS = userRoleRepository.findByUserCodeAndStateCode(userPO.getUserCode(), 1);
					List<String> userRole = new ArrayList<>();
					for (UserRoleVO userDTO1 : userRoleVOS) {
						userRole.add(userDTO1.getRoleCode());
					}
					userDTO.setUserRole(userRole);
				}
			}
		}
		return 	userDTO;
	}

	private MqUserDTO packageMqUserDTO(UserPO sysUserInfoDO) {
		MqUserDTO mqUserDTO = new MqUserDTO();
		mqUserDTO.setId(sysUserInfoDO.getUserCode());
		mqUserDTO.setUsername(sysUserInfoDO.getUserLoginName());// 用户账号
		mqUserDTO.setPassword(sysUserInfoDO.getUserPassword());// 用户密码
		mqUserDTO.setName(sysUserInfoDO.getUserName());// 姓名
		mqUserDTO.setSex(sysUserInfoDO.getUserSex());// 用户性别
		mqUserDTO.setPhone(sysUserInfoDO.getUserMobile());// 手机号
		mqUserDTO.setEmail(sysUserInfoDO.getUserMail());// 用户email
		// mqUserDTO.setImg();//用户头像名称
		mqUserDTO.setPhoto(sysUserInfoDO.getUserImgurl());// 用户头像

		mqUserDTO.setDepartmentParentId(sysUserInfoDO.getDeptCode());// 上级节点id
		DepartmentPO departmentPO = departmentRepository.findByDeptCodeAndStateCode(sysUserInfoDO.getDeptCode(), 1);
		if (departmentPO !=null && departmentPO.getDeptName()!=null && departmentPO.getDeptName()!="" ){
			mqUserDTO.setDepartmentName(departmentPO.getDeptName());
		}
		mqUserDTO.setAreaCode(sysUserInfoDO.getCountyCode());// 行政区划代码

		if (departmentPO !=null && StringUtils.isNotEmpty(departmentPO.getOrgCode())) {
			mqUserDTO.setOrgCode(departmentPO.getOrgCode());//组织机构code
			mqUserDTO.setDepartmentCode(departmentPO.getDeptCode());// 部门id
			//OrgainzeVO orgainzeVO = orgainzeRepository.findByOrgCodeAndStateCode(departmentPO.getOrgCode(),1);
			OrgainzeDO orgainzeDO=new OrgainzeDO();
			orgainzeDO.setOrgCode(departmentPO.getOrgCode());
			orgainzeDO.setStateCode(1L);
			com.unis.user.common.vo.org.OrgainzeVO orgainzeVO =orgainzeDomain.selectById(orgainzeDO);
			if (ObjectUtils.notEqual(orgainzeVO, null)) {
				mqUserDTO.setOrgType(orgainzeVO.getOrgType());

				String orgCode=orgainzeVO.getOrgCode();
				if(!OrgConstant.ORG_UNIT_TYPE_GRAIN.equals(orgainzeVO.getOrgType())){
					String tyshxydm=null;
					ResponseWrapper qyxx = baseServerClient.selectQy(orgCode);
					if (qyxx != null && "SUCCESS".equalsIgnoreCase(qyxx.getStatus().name()) && qyxx.getData() != null) {
						JSONObject qyxxJson = JSONObject.parseObject(JSONObject.toJSONString(qyxx.getData()));
						System.out.println("企业信息:"+qyxxJson.toJSONString());
						if(qyxxJson!=null){
							tyshxydm=StringUtils.defaultIfEmpty(qyxxJson.getString("tyshxydm"),"");
							mqUserDTO.setAreaCode(tyshxydm);
						}
					}
					if(StringUtils.isEmpty(tyshxydm)){
						log.error("用户[{}---{},orgCode---{}]同步bi将会失败,找不到统一社会信用代码",sysUserInfoDO.getUserName(),sysUserInfoDO.getUserLoginName(), orgCode);
					}else{
						log.info("用户[{}---{},orgCode---{},社会信用代码---{}]",sysUserInfoDO.getUserName(),sysUserInfoDO.getUserLoginName(), orgCode, tyshxydm);
					}
				}
			}
		}

		// mqUserDTO.setPositionId();//职位id
		mqUserDTO.setPositionName(sysUserInfoDO.getHeadship());// 职位名称
		mqUserDTO.setValid(sysUserInfoDO.getIsDisavled());// 账号是否有效（0有效 ,1无效）

		// mqUserDTO.setSign(Integer.parseInt(UserTypeUtil.getUserType(orgDO.getOrgType())));//用户标志
		// 1:粮食局用户 2:企业用户
		// mqUserDTO.setQyUserId();//企业用户

		return mqUserDTO;
	}

	private void setMqForUserInfo(UserPO sysUserInfoDO, String action) {
		try {
			MqUserDTO mqUserDTO = packageMqUserDTO(sysUserInfoDO);
			// if(action.equals(Action.USER_ADD)) {
			// mqUserDTO.setPassword(CommonConstant.DEFAULT_PASSWD);//明文的默认密码
			// }
			//
			RabbitObjectTO rabbitObjectTO = new RabbitObjectTO();
			rabbitObjectTO.setAction(action);// Action.USER_ADD
			rabbitObjectTO.setObject(mqUserDTO);
			iMessageProvider.send(rabbitObjectTO);
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	/**
	 * 获取该部门的领导人信息
	 * @param loginName
	 * @return
	 */
/*	public List<Map<String, Object>> findByLoginName(String loginName,String orgCode) {
		List<Map<String, Object>> list1 =  new ArrayList<Map<String, Object>>();
		List<DepartmentPO> departmentPOList = departmentServer.findByOrgCode(orgCode);
		UserPO userPO = userRepository.findByUserLoginNameAndStateCode(loginName, 1);
		for (DepartmentPO deptment:departmentPOList) {
			if (deptment.getDeptCode()==userPO.getDeptCode()){
				userRepository.findByDeptCodeAndStateCodeAndHeadShip(userPO.getDeptCode(),1,"10230002");
			}
		}
		List<UserPO> userPO1 = new ArrayList<>();
			Map<String,Object> map = new HashMap<>();
				 userPO1 = userRepository.findByHeadShipAndStateCode("10230002", 1);
		for (UserPO user:userPO1) {
			map.put("userCode",user.getUserCode());
		}
		return  list1;
	}*/

	/**
	 * 根据角色信息匹配考勤人员
	 * @param list
	 * @return
	 */
	public List<Map<String, Object>> findByDeptName(List<DepartmentPO> list) {
		List<Map<String, Object>> list1 =  new ArrayList<Map<String, Object>>();
		for (int i=0;i<list.size();i++){
			Map<String,Object> map = new HashMap<>();
			String deptCode =list.get(i).getDeptCode();
			StringBuffer sqlbf = new StringBuffer();
			sqlbf.append("select u.USER_NAME from SYS_USER_INFO u,SYS_USER_ROLES r where u.DEPT_CODE = '"+deptCode+"' and u.USER_CODE =r.USER_CODE and  r.ROLE_NAME like ('%考勤%')");
			String sql = sqlbf.toString();
			Object name = entityManager.createNativeQuery(sql).getResultList();
			String orgCode = list.get(i).getOrgCode();
			OrgainzeVO orgainzeVO = orgainzeRepository.findByOrgCodeAndStateCode(orgCode, 1);
			//String name = userRepository.findByDeptNameAndUserTitle(deptCode);
			map.put("name", String.valueOf(name));
			map.put("deptCode", list.get(i).getDeptCode());
			map.put("deptName", list.get(i).getDeptName());
			map.put("orgName", orgainzeVO.getOrgName());
			map.put("orgCode",orgCode);
			list1.add(map);
		}
		return  list1;
	}

	/**
	 * 处长
	 * @param mobile
	 * @return
	 */
	public UserDTO getUserInfoBymobile(String mobile) {
		UserPO userPO = userRepository.findByUserMobileAndStateCode(mobile,1);
		/*DepartmentPO departmentPO = departmentServer.findByDeptCode(userPO.getDeptCode());
		OrgainzeVO orgainzeVO = orgainzeRepository.findByOrgCodeAndStateCode(departmentPO.getOrgCode(), 1);
		List<UserRoleVO> userRoleVOS = userRoleRepository.findByUserCodeAndStateCode(userPO.getUserCode(), 1);
		List<String> userRole = new ArrayList<>();
		if(userRoleVOS!=null){
			for (UserRoleVO userDTO :userRoleVOS){
				userRole.add(userDTO.getRoleCode());
			}
		}*/
		UserDTO userDTO = LsBeanUtils.copyProperties(userPO, UserDTO.class);
		/*userDTO.setUserRole(userRole);
		userDTO.setDeptCode(departmentPO.getDeptCode());
		userDTO.setOrgCode(departmentPO.getOrgCode());
		if(orgainzeVO!=null){
			userDTO.setOrgName(orgainzeVO.getOrgName());
		}
		if(departmentPO!=null){
			userDTO.setDeptName(departmentPO.getDeptName());
		}*/
        if (null != userDTO) {
            userDTO.setUserPassword(null);
        }
		return userDTO;
	}

	/**
	 * 副局长
	 * @param deptCode
	 * @return
	 */
	public  List<UserPO> findByBureaus(String deptCode) {
		return userRepository.findByDeptCodeAndStateCodeAndHeadship(deptCode,1,"10230003");
		/*UserDTO userDTO = LsBeanUtils.copyProperties(userPO, UserDTO.class);
			DepartmentPO departmentPO = departmentServer.findByDeptCode(userDTO.getDeptCode());
			OrgainzeVO orgainzeVO = orgainzeRepository.findByOrgCodeAndStateCode(departmentPO.getOrgCode(), 1);
			List<UserRoleVO> userRoleVOS = userRoleRepository.findByUserCodeAndStateCode(userDTO.getUserCode(), 1);
			List<String> userRole = new ArrayList<>();
			for (UserRoleVO userDTO1 : userRoleVOS) {
				userRole.add(userDTO1.getRoleCode());
			}
			userDTO.setUserRole(userRole);
			userDTO.setDeptCode(departmentPO.getDeptCode());
			userDTO.setOrgCode(departmentPO.getOrgCode());
			userDTO.setOrgName(orgainzeVO.getOrgName());
			userDTO.setDeptName(departmentPO.getDeptName());
		return  userDTO;*/
	}

	/**
	 * 局长
	 * @param deptCode
	 * @return
	 */
	public  List<UserPO> findByManager(String deptCode) {
		return userRepository.findByDeptCodeAndStateCodeAndHeadship(deptCode,1,"10230002");
		/*UserDTO userDTO = LsBeanUtils.copyProperties(userPO, UserDTO.class);
		DepartmentPO departmentPO = departmentServer.findByDeptCode(userDTO.getDeptCode());
		OrgainzeVO orgainzeVO = orgainzeRepository.findByOrgCodeAndStateCode(departmentPO.getOrgCode(), 1);
		List<UserRoleVO> userRoleVOS = userRoleRepository.findByUserCodeAndStateCode(userDTO.getUserCode(), 1);
		List<String> userRole = new ArrayList<>();
		for (UserRoleVO userDTO1 : userRoleVOS) {
			userRole.add(userDTO1.getRoleCode());
		}
		userDTO.setUserRole(userRole);
		userDTO.setDeptCode(departmentPO.getDeptCode());
		userDTO.setOrgCode(departmentPO.getOrgCode());
		userDTO.setOrgName(orgainzeVO.getOrgName());
		userDTO.setDeptName(departmentPO.getDeptName());
		return  userDTO;*/
	}


	/***
	 * 查询处长信息
	 * @param deptCode
	 * @return
	 */

	/***
	 * 查询处长信息
	 * @param deptCode
	 * @return
	 */
	public  List<UserPO> findBySectionChief(String deptCode,String headship,String orgCode) {
		List<DepartmentPO> orgCode1 = departmentServer.findByOrgCode(orgCode);
		List<UserPO> list = new ArrayList<>();
		for (DepartmentPO dept:orgCode1) {
			if (deptCode.equals(dept.getDeptCode())){
				list = userRepository.findByDeptCodeAndStateCodeAndHeadship(deptCode, 1, headship);
			}
		}
		return list;
	}

	/***
	 * 通过部门获取用户
	 * * @param deptCode
	 * @return
	 */
	public  List<UserPO> findByDeptCode(String deptCode) {
		List<UserPO> userPOList = userRepository.findByDeptCodeAndStateCode(deptCode, 1);
		return userPOList;
	}



	public UserPO findByName(String userName) {
		return userRepository.findByUserNameAndStateCode(userName,1);
	}

	public List<UserPO> findByUserTypeAndStateCode(int i, int i1) {
		return userRepository.findByUserTypeAndStateCode(i,i);
	}

	public List<UserPO> findAll(int i) {
		return userRepository.findByStateCode(i);
	}

	public List<UserPO> getAllUser(String deptCode) {
		List<UserPO> userList = userRepository.getAllUser(deptCode);
		return userList;
	}

	public List<UserPO> getByType() {
		String  type="1";
		List<UserPO> userList = userRepository.getByType(type);
		return userList;
	}

	public UserPO findByAccount(String bizType, String account) {
		return  userRepository.findByUserTypeAndUserLoginName(bizType, account);
	}

	public List<UserPO> getAllDept() {
		String  type="2";
		List<UserPO> userList = userRepository.getByType(type);
		return userList;
	}

	public List<UserRoleVO> getUserByRole(String[] roleCode) {
		return  userRoleRepository.findByRoleCodeInAndStateCode(roleCode,1);
	}

	/**
	 * 注册信息
	 * @param companyVO
	 */
	public ResponseWrapper registerCompany(CompanyVO companyVO) {
		//设置企业状态为1（通过）
		companyVO.setQyzt(1);
		companyVO.setShzt(0);
		UserDTO userDTOTemp =companyVO.getUserDTO();
		if(userDTOTemp!=null && StringUtils.isNotEmpty(userDTOTemp.getUserMobile())){
			UserDTO userDTODb= getUserInfoBymobile(userDTOTemp.getUserMobile());
			if(userDTODb==null){
				OrgainzeDTO orgainzeDTO = companyVO.getOrgainzeDTO();
				//为orgainzeDTO设置区域编码
				orgainzeDTO.setCountyCode(companyVO.getQyszqy());
				String orgCode = orgainzeServer.add(orgainzeDTO);
				if (orgCode!=null) {
					companyVO.setQyjgdm(orgCode);
					companyClient.insert(companyVO);
					DepartmentDTO departmentDTO = new DepartmentDTO();
					departmentDTO.setOrgCode(orgCode);
					departmentDTO.setDeptName(companyVO.getQymc());
					String depCode = departmentServer.save(departmentDTO);
					UserDTO userDTO = new UserDTO();
					String pwd = EncryptUtil.generate(companyVO.getUserDTO().getUserPassword());
					userDTO.setUserLoginName(companyVO.getUserDTO().getUserLoginName());
					userDTO.setUserName(companyVO.getUserDTO().getUserName());
					userDTO.setUserPassword(pwd);
					userDTO.setDeptCode(depCode);
					userDTO.setOrgCode(orgCode);
					userDTO.setUserType("0");
					userDTO.setIsDisavled(IsLockedEnum.NO.getCode());
					userDTO.setUserMobile(companyVO.getUserDTO().getUserMobile());
					UserPO userPO1 = LsBeanUtils.copyProperties(userDTO, UserPO.class);
					userPO1.setUserCode(baseRepository.selectByTableNameAndAttr("SYS_USER_INFO", "USER_CODE", "U",7));
					userRepository.saveAndFlush(userPO1);
					//在用户角色表中添加用户角色
					List<String> roleCodes = Arrays.asList(new String[]{"R0000181"});//企业角色
					this.saveUserRoles(roleCodes, userPO1.getUserCode());
					return ResponseWrapper.success("注册成功");
				}
				return ResponseWrapper.error();
			}else{
				return ResponseWrapper.error("该手机号已存在");
			}
		}else{
			return ResponseWrapper.error("手机号为空");
		}
	}

	public ResponseWrapper registerTransaction(TransactionDTO transactionDTO) {
		//设置企业状态为1（通过）
		transactionDTO.setQyzt(1);
		UserDTO userDTOTemp =transactionDTO.getUserDTO();
		if(userDTOTemp!=null && StringUtils.isNotEmpty(userDTOTemp.getUserMobile())){
			UserDTO userDTODb= getUserInfoBymobile(userDTOTemp.getUserMobile());
			if(userDTODb==null){
				OrgainzeDTO orgainzeDTO = transactionDTO.getOrgainzeDTO();
				//为orgainzeDTO设置区域编码
				String orgCode = orgainzeServer.add(orgainzeDTO);
				if (orgCode!=null) {
					transactionDTO.setQyjgdm(orgCode);
					companyClient.insertTransaction(transactionDTO);
					DepartmentDTO departmentDTO = new DepartmentDTO();
					departmentDTO.setOrgCode(orgCode);
					departmentDTO.setDeptName(transactionDTO.getQymc());
					String depCode = departmentServer.save(departmentDTO);
					UserDTO userDTO = new UserDTO();
					String pwd = EncryptUtil.generate(transactionDTO.getUserDTO().getUserPassword());
					userDTO.setUserLoginName(transactionDTO.getDwdm());
					userDTO.setUserName(transactionDTO.getQymc());
					userDTO.setUserPassword(pwd);
					userDTO.setDeptCode(depCode);
					userDTO.setOrgCode(orgCode);
					userDTO.setUserType("0");
					userDTO.setIsDisavled(IsLockedEnum.NO.getCode());
					userDTO.setUserMobile(transactionDTO.getUserDTO().getUserMobile());
					UserPO userPO1 = LsBeanUtils.copyProperties(userDTO, UserPO.class);
					userPO1.setUserCode(baseRepository.selectByTableNameAndAttr("SYS_USER_INFO", "USER_CODE", "U",7));
					userRepository.saveAndFlush(userPO1);
					//在用户角色表中添加用户角色
				/*	List<String> roleCodes = Arrays.asList(new String[]{"R0000031"});//企业角色
					this.saveUserRoles(roleCodes, userPO1.getUserCode());*/
					return ResponseWrapper.success("注册成功");
				}
				return ResponseWrapper.error();
			}else{
				return ResponseWrapper.error("该手机号已存在");
			}
		}else{
			return ResponseWrapper.error("手机号为空");
		}
	}


	public List<String> findRoleInfoByUserCode(String userCode) {
		return userRoleRepository.findByUserCode(userCode);
	}

	//根据账号查密码
	public String fingPwByAccount(String account) {
		return userRepository.fingPwByAccount(account);
	}


	//根据OrgCode查询企业状态
	public Integer checkCompany(String orgCode) {

		// 通过企业机构代码获取企业信息
		ResponseWrapper qyxx = baseServerClient.selectQy(orgCode);

		if (!qyxx.getInfoCode().equals(200)) {

			return null;

		}

		Object qyxxObj = qyxx.getData();
		if (qyxxObj != null) {
			JSONObject qyxxJson = JSONObject.parseObject(JsonUtils.serialize(qyxx.getData()));
			Integer qyzt = qyxxJson.getInteger("qyzt");
			return qyzt;
		}

		return null;


	}

	public UserDTO selectByUserLoginName(String loginName) {
		UserPO userPO = userRepository.findByUserLoginNameAndStateCode(loginName,1);
		UserDTO userDTO = LsBeanUtils.copyProperties(userPO, UserDTO.class);
        if (userDTO != null) {
            userDTO.setUserPassword(null);
        }
        return userDTO;
	}



	/*public Map<String, Object> getAllUser(String deptCode) {List<Map<String, String>> list = new ArrayList<>();
        StringBuffer sqlbf = new StringBuffer();
        sqlbf.append("select t.USER_CODE,t.USER_NAME from SYS_USER_INFO t where  t.dept_code like  '%" + deptCode + "%'"  );

        //分页
        String sql =  new String(sqlbf);
        List<Object[]> resultList = entityManager.createNativeQuery(sql).getResultList();
        for (Object[] obj : resultList) {
            Map<String, String> map = new HashMap<>();
            map.put("id", obj[0] == null ?"":obj[0].toString());
            map.put("userName", obj[1] == null ?"":obj[1].toString());
            list.add(map);
        }
        Map<String, Object> map = new HashMap<>();
        map.put("list", list);
        return map;
	}*/

	public String saveNoPassword(UserDTO userDTO) throws Exception {
		//暂时处理区域数据没有问题
		try {
			if(StringUtils.isNotEmpty(userDTO.getCountyCode())){
				String areaName = "";
				if(userDTO.getCountyCode().contains("0000")) {//省用户
					List<AreaVO> areaVO = areaServer.findProvinCode(userDTO.getCountyCode());
					if(areaVO.size()>0) {
						areaName = areaVO.get(0).getProvinName();
					}
				} else if(userDTO.getCountyCode().contains("00")) {//市用户
					List<AreaCityVO> areaCityVO = areaServer.findCityCode(userDTO.getCountyCode());
					if(areaCityVO.size()>0) {
						areaName = areaCityVO.get(0).getCityName();
					}
				} else {//县用户
					List<AreaCountyVO> areaCountyVO = areaServer.findCountyCode(userDTO.getCountyCode());
					if(areaCountyVO.size()>0) {
						areaName = areaCountyVO.get(0).getCountyName();
					}
				}
				userDTO.setAreaName(areaName);
			}
		} catch (Exception e) {
			// TODO: handle exception
		}
		UserPO userPO1 = LsBeanUtils.copyProperties(userDTO, UserPO.class);
		userPO1.setCreateDate(new Date());
		userPO1.setUserCode(baseRepository.selectByTableNameAndAttr("SYS_USER_INFO", "USER_CODE", "U",7));
//                    String defaultPasswd = EncryptUtil.generate(CommonConstant.DEFAULT_PASSWD, passwdSalt);

		/*String defaultPasswd = null;
		if(StringUtils.isEmpty(userDTO.getUserPassword())){
			defaultPasswd = EncryptUtil.generate(CommonConstant.DEFAULT_PASSWD);
		}else{
			defaultPasswd = EncryptUtil.generate(userDTO.getUserPassword());
		}*/
		//企业用户在企业端进行irpt用户同步
		if ("0".equals(userDTO.getUserType())) {
			userPO1.setUserPassword(userDTO.getUserPassword());
			userRepository.saveAndFlush(userPO1);
			setMqForUserInfo(userPO1, Action.USER_ADD);
		} else {
			userPO1.setUserPassword(userDTO.getUserPassword());
			userRepository.saveAndFlush(userPO1);
			setMqForUserInfo(userPO1, Action.USER_ADD);
		}
		return userPO1.getUserCode();
	}

	public List<UserPO> findUserByAreaCode(List<String> areaCodes) {
		//获取所有行政区划下面的单位
		Specification<OrgainzeVO> specification = new Specification<OrgainzeVO>() {
			@Override
			public Predicate toPredicate(Root<OrgainzeVO> root, CriteriaQuery<?> query, CriteriaBuilder cb) {
				List<Predicate> list = new ArrayList<Predicate>();
				list.add( cb.equal( root.get( "orgLevel" ).as( String.class ), "10180007") );
				list.add( cb.equal( root.get( "stateCode" ).as( Integer.class ), 1) );
				In<String> in = cb.in(root.get("countyCode"));
				for(String str:areaCodes){
					in.value(str);
				}
				list.add(in);
				return cb.and( list.toArray( new Predicate[list.size()] ) );
			}
		};
		List<OrgainzeVO> lists = orgainzeRepository.findAll(specification);
		//.findAll(specification);
		List<UserPO> userPOS = null;
		Specification<UserPO> userPOSpecification = new Specification<UserPO>() {
			@Override
			public Predicate toPredicate(Root<UserPO> root, CriteriaQuery<?> query, CriteriaBuilder cb) {
				List<Predicate> list = new ArrayList<Predicate>();
				list.add( cb.equal( root.get( "stateCode" ).as( Integer.class ), 1) );
				In<String> in = cb.in(root.get("orgCode"));
				for(OrgainzeVO orgainzeVO:lists){
					in.value(orgainzeVO.getOrgCode());
				}
				list.add(in);
				return cb.and( list.toArray( new Predicate[list.size()] ) );
			}
		};
		userPOS = userRepository.findAll(userPOSpecification);
		return userPOS;
	}

    public List<OrgainzeVO> findByDeptids(String depts) {
		List<OrgainzeVO> orgainzeVOList = new ArrayList<>();
		Map<String,OrgainzeVO> map = new HashMap<>();
		//Map<String,TreeNode> maps = new HashedMap();
		List<DepartmentPO> departmentPOS = new ArrayList<>();
		String[] arr = depts.split(",");
		//根据deptid获取OrgainzeVO
		Sort sort = new Sort(Sort.Direction.ASC, "orderBy");
		for (String depid:arr){
			DepartmentPO departmentVO = departmentRepository.findByDeptCodeAndStateCode(depid,1);
			List<UserPO> userDTOS = userRepository.findByDeptCode(depid);
			departmentVO.setUserList(userDTOS);
			if(map.get(departmentVO.getOrgCode())==null){
				OrgainzeVO orgainzeVO = orgainzeServer.findByOrgCodeAndStateCode(departmentVO.getOrgCode(),1,sort);
				orgainzeVO.getDepartList().add(departmentVO);
				map.put(departmentVO.getOrgCode(),orgainzeVO);
			}else{
				map.get(departmentVO.getOrgCode()).getDepartList().add(departmentVO);
			}
			departmentPOS.add(departmentVO);
		}
		/*for(DepartmentPO departmentPO:departmentPOS){
			if(map.get(departmentPO.getOrgCode())!=null){

			}
		}*/
		Iterator<Map.Entry<String, OrgainzeVO>> entries = map.entrySet().iterator();
		while(entries.hasNext()){
			Map.Entry<String, OrgainzeVO> entry = entries.next();
			orgainzeVOList.add(entry.getValue());
		}
		/*for (OrgainzeVO orgainzeVO:orgainzeVOList){

		}
		for (String orgcode:arr){
			OrgainzeVO orgainzeVO = orgainzeServer.findByOrgCodeAndStateCode(orgcode,1,sort);
			List<DepartmentPO> departmentPOList = repository.findByOrgCodeAndStateCode(orgcode, 1, sort);
			orgainzeVO.setDepartList(departmentPOList);
			orgainzeVOList.add(orgainzeVO);

		}*/
		return orgainzeVOList;
    }

	public ResponseWrapper addIdsUser(UserDTO userDTO) throws IOException, NoSuchAlgorithmException {
		Properties properties=new Properties();
		properties.load(this.getClass().getClassLoader().getResourceAsStream("trsids-agent.properties"));
		if(properties!=null && Boolean.valueOf(properties.getProperty("sso.on"))){
			String defaultPasswd=null;
			defaultPasswd = CommonConstant.DEFAULT_PASSWD;
			Map<String,Object> map=new HashMap<>();
			map.put("userName",userDTO.getUserLoginName());
			map.put("password",defaultPasswd);
			map.put("firstName",userDTO.getUserName());
			map.put("lastName",userDTO.getUserName());
			map.put("email",userDTO.getUserMail());
			map.put("nickName",userDTO.getUserName());
			map.put("position",userDTO.getUserTitle());
			map.put("tel",userDTO.getUserTel());
			map.put("trueName",userDTO.getUserName());
			map.put("groupName","11");
			String receive =IdsUtilForClient.currentAddUser(map);
			if(receive!=null&&receive.matches("\\{.+\\}")) {
				JSONObject obj = JSONObject.parseObject(receive);
				if(1009==obj.getInteger("code")){
					return ResponseWrapper.success("同步新用户成功");
				}else{
					Map resMap=JsonUtils.parse(receive,Map.class);
					return ResponseWrapper.error(HttpStatus.EXPECTATION_FAILED.value(),"同步新用户失败,"+resMap.get("desc"));
				}
			}
		}
		return ResponseWrapper.success();
	}

	public ResponseWrapper modifyIdsPassword(String userCode) throws IOException, NoSuchAlgorithmException {
		Properties properties=new Properties();
		properties.load(this.getClass().getClassLoader().getResourceAsStream("trsids-agent.properties"));
		if(properties!=null && Boolean.valueOf(properties.getProperty("sso.on"))){
			UserPO userPO = userRepository.findByUserCodeAndStateCode(userCode, 1);
			if (userPO!=null) {
				String defaultPasswd = CommonConstant.DEFAULT_PASSWD;
				String receive =IdsUtilForClient.currentResetUserPwd(userPO.getUserLoginName(),defaultPasswd);
				if(receive!=null&&receive.matches("\\{.+\\}")) {
					JSONObject obj = JSONObject.parseObject(receive);
					if(0==obj.getInteger("code")){
						return ResponseWrapper.success("同步修改密码成功");
					}else{
						Map resMap=JsonUtils.parse(receive,Map.class);
						return ResponseWrapper.error(HttpStatus.EXPECTATION_FAILED.value(),"同步修改密码失败,"+resMap.get("desc"));
					}
				}
			}
		}
		return ResponseWrapper.success();
	}

	public List<UserPO> findByHeadshipAndOrgCode(String headShip, String orgCode) {
		return  userRepository.findByHeadshipLessThanEqualAndOrgCodeAndStateCode(headShip,orgCode,1);
	}

	public List<UserPO> findByHeadshipAndOrgCode(List<String> headShip, String orgCode) {
		List<UserPO> userlist = new ArrayList<UserPO>();
		for (String headship:headShip) {
			List<UserPO> list = new ArrayList<>();
			if (headship.equals("10260008")){
				 list = userRepository.findByHeadshipAndStateCode(headship, 1);
			}else{
				 list = userRepository.findByHeadshipAndOrgCodeAndStateCode(headship, orgCode, 1);
			}
			userlist.addAll(list);
		}
		return  userlist;
	}

    /**
     * 根据菜单资源 获取拥有该资源的用户
     * @param resourceCode 按钮资源编码
     * @return
     */
    public List<UserRoleVO> listUserByResourceCode(String resourceCode) {
        List<UserRoleVO> list = userInfoDao.listUserByResourceCode(resourceCode);
        return list;
    }
}
